function [success, shape_struct] = readbwshapes(filename)
% readbwshapes	- read spike shapes data from BrainWare exported "Spike Times and Shapes as Text" ASCII file 
%--------------------------------------------------------------------------------
% Input(s): 	filename - name of *.txt file (string)
% Output(s):	shape_struct - structure containing spike arrival times and shapes
% Usage:	[success, shape_struct] = readbwshapes('0232_022.txt');
%
% Last modified 09.08.02
% Copyright (c) 2002 Igor Kagan					 
% kigor@tx.technion.ac.il
% http://igoresha.virtualave.net
%
% See also CONVER, UNISPIKEDATF, UNISPLIT.
%--------------------------------------------------------------------------------

shape_struct = [];
success = 0;

if nargin~=1,
	disp('Wrong number of arguments, exiting...');
	return;
end;

[fid, message] = fopen(filename,'r');

if ~fid,
	disp(message);
	return;
end

justopen = 1;

while 1
	cline = fgetl(fid);
	if ~isstr(cline), break, end;
	if length(cline)<3, % empty line
		
	elseif cline(1:3) == 'Set', % start new trial
		if ~justopen
			% fill in previous trial
			shape_struct(Set).sweep(Sweep).data = data;	
		end

		SweepInd = findstr(cline, 'Sweep');
		SetString= cline(4:SweepInd-1);
		Set = str2num(SetString);
		StimParamInd = findstr(cline, 'StimParam');
		SweepString= cline(SweepInd+5:StimParamInd-1);
		Sweep = str2num(SweepString);
		data = [];
		justopen = 0;

	else	% data line
		
		data = [data; str2num(cline)];
		
	end;
end


% fill in last sweep
shape_struct(Set).sweep(Sweep).data = data;

success = 1;

fclose(fid);


