function [out1, out2] = unitret(action,in1,in2,in3,in4);
% unitret 	- universal trial retrieval, display and analysis
%--------------------------------------------------------------------------------
% UNIversal Trials RETrieval	         
% Retrives, displays and analyses experimental data from Max Snodderly Lab       
% Written by I. Kagan, A. Beylin (early tret.m versions)						 
% Copyright (c) 1996-2002 I. Kagan, A. Beylin (see license.txt)							 
% see Unitret\Readme.txt for more information or type 'help unitret' in 	 
% Matlab Command Window							        
%										
% --- The program is revised permanently ---
% See changes.txt for recent changes
% *******************************						 
% * Last modification: 25.11.02 *						 
% *******************************						 
% Short Description:								 
% Reads all years files, including new system datafiles				 
% MATLAB 4.x (partially), MATLAB 5.x and 6.x compatible version					 
%						 
% See 'help unitret' for list of files that are required to run Unitret		 
% See also UNISPLIT, JPSTH, CPRINT.
%--------------------------------------------------------------------------------

%================================================================================
% Revisions needed and further development:
%================================================================================
% - name of file when printing or saving to file, in all figures
% - make function "reading_marked_data" for all purposes
% - make dialogs Cancel button to work properly (i.e. not save new dialog data)
% - fix Show Spikes - Open Spikes histograms discrepancy
% 	(e. g. 1098A009.A02 vs. 1098A009.spe in E:\MONK\Em\em_paper\std\run1\98std
% - fix 'saccades_detect': Saccades in the beginning of the trial are detected, 
% 	but may be there are some before zero...
% - unisplit fix
% - general GUI design
% - improve modularity and code efficiency
% - software file structure and help
% - modify/add ini file with arbitrary information (e.g. paths, directories)
% - make Unitret to run from any folder
% - rewrite clipboard and centroid
% - peak firing rate (155)
% - check and update sqsweep for system 1.2 in conver.m
% - fix "snap cursors inside" in automatic/em mode
%================================================================================


if nargin<1,
        clear global;
	lasterr('');
        h=get(0,'Children');
        close(h);
        fclose('all');
        action='start';
        matlabpath = path;
        act_dir = cd;
        % if isempty(findstr(lower(matlabpath),lower(act_dir))),
                path(matlabpath,act_dir);
	% end;
	addpath([act_dir '\Clipboard']);
	addpath([act_dir '\Igtools']);

	% GET MATLAB VERSION
	v=version;
	% SET WARNING OFF
	warning('off');

end;

global TRET_DAT NAME INI_NAME figcounter TRINFOHndl REFMAT FILEWILDCARD v GRAND_HANDLE EXCEL_NAME
global Show_Return_Menu TotSpk RCIM
global HorizVisualFieldLoc VertVisualFieldLoc HorizPosLED VertPosLED NORMIR 
global SACCADES_STRUCTURE EM_STRUCTURE EM_STRUCTURE_ONE_FILE
global STA_STRUCTURE STA_ONE_FILE MEAN_PSTH
global PFR
global INIFILE SAVE_DIR MFILE_PATH
global TRIALS2TAKE APP_PATH

DefValues = get(0,'UserData');



% REFMAT - matrix containing infomation about selected segments
% RCIM - Reverse Correlation Image Matrix

% try


if strcmp(action,'start'),
	VERDATE = 'ver. 2.1 rev. 25.11.02';

	APP_PATH = which('unitret');
	APP_PATH = APP_PATH(1:end-9);
	INIFILE = [APP_PATH 'unitret.ini'];


	SAVE_DIR = cd;
	MFILE_PATH = 'C:\Monk\Unitret\Mfiles\';
        % graphics initialization
        figcounter=3; %Main, Graph and may be Trial Dump
        REFMAT(:,:)=[];
        RCIM = [];
        NORMIR = []; % Normalized Instantaneous Firing Rate (over number of cells)
        STA_STRUCTURE = [];
        
        % Handlers for GRAND Average Eye Movements Displays
        GRAND_HANDLE = [0 0];
        
        % Default values: - Stored in ROOT object (0) as a UserData
        % DefValues
        ini_exist = exist(INIFILE);
        if(ini_exist~=2),
		HPeriod = 0;					%1
		MinHPeriod = 0;					%2
		MaxHPeriod = 100;				%3

		Trials = 3;					%4
		MinTrials = 1;					%5
		MaxTrials = 9;					%6

		Ymin = -50;					%7
		MinYmin = -1000;				%8
		MaxYmin = 1000;					%9

		Ymax = 50;					%10
		MinYmax = -1000;				%11
		MaxYmax = 1000;					%12


		SpkOnOffCol = 2;				%13
		MinSpkOnOffCol = 1;				%14
		MaxSpkOnOffCol = 4;				%15

		SpkOnOffRow = 6;				%16
		MinSpkOnOffRow = 1;				%17
		MaxSpkOnOffRow = 10;				%18

		EconomyPlot = 0;				%19

		HAverPeriod = 10;				%20
		MinHAverPeriod = 0;				%21
		MaxHAverPeriod = 100;				%22

		EyeMovement = 1;   				%23
		Grid		=0;				%24
		Sigma        =1.5;				%25 for smoothing
		MarkSelect = 0;					%26

		NormalEyeMovement=0;				%27
		RejectSegmentEdge = 0;				%28
		SafetyInterval   =1.1;				%29

		ShapeStripPlot  =0;				%30
		StripPlotWindow = 500;				%31
		MinStripPlotWindow = 1;				%32
		MaxStripPlotWindow = 5000;			%33

		ShrinkTime=0;					%34
		SeparateOnOff=1;				%35
		DrivenRate=1;					%36

		TimeBeforeEvent = 50;				%37
		TimeAfterEvent = 150;				%38

		XGrid	  = 10;					%39
		SaccadeDetect  = 0;				%40

		AverHistYAutoscale=1;				%41
		AverHistYMax=100;				%42

		AverHistXAutoscale=1;				%43
		AverHistXmin=0;					%44
		AverHistXmax=500;				%45

		% ==============================================
		% New additions:
		% ==============================================
		ShapeExist=1;					%46

		CurFlag=0;					%47 to decide first or second cursor (OI)
		FirstX=0;					%48 first cursor position

		BegOfCurSegm=0;                              	%49
		%-----------------------------------------------
		% For Spectrum
		withDC=0;					%50
		DispConcFlag=0;					%51

		%-----------------------------------------------
		SnapInside=0;					%52 Snap |->  <-| (Cursors in "integer number ...")
		FreqAxisEnd=20;                              	%53 Hz, Freq. Axis to Display
		BaseLineActivity=0;				%54 Spontaneous Activity to subtract (mean level)
		%----------------------------------------------- for averaged concatenated
		%NumberOfSegmentsSelected=0;                 	%55 Number of segments selected (in *.sp? file) not used now
		Number_ms_Average=0;		                %55 Number of ms to average
		AverBin=10;                                  	%56 Bin for Averaged
		Cycle_ms=0;					%57 Cycle for Averaged
		Successive=0;					%58 Average successive/not successive segments 
		%----------------------------------------------- for spectrum.m
		nfft=0;						%59 nfft length (one segment)
		noverlap=0;				        %60 length of overlapping
		window=nfft;					%61 length of window
		p=.95;						%62 significance level of confidence limits
		%-----------------------------------------------
		MarkSameSegments=0;				%63
		%-----------------------------------------------
		% The following 6 parameters are for calculation of inc/dec overlapping index:
		x1=0;                                        	%64
		x2=0;						%65
		x3=0;						%66
		x4=0;						%67

		inc=1;						%68 1 - inc, 0 - dec
		IndexMode=0;					%69 Index Mode (0/1)
		%-----------------------------------------------
		RFi = 0;                                     	%70 size of RF INC (min of arc)
		RFstarti = 0;                                	%71 RF INC start
		% DEC VALUES: see below (76-77) (oops...)
		%-----------------------------------------------
		HndltoFig = 0;                               	%72 Handler to Fig, latched when 'WindowButtonDownFcn' pressed
		TrialBegin = 0;                              	%73 Trial to show (current trial)
		%-----------------------------------------------
		LatencyFromSaccade = 40;                     	%74 Latency of eye movement impact on spike train
		%-----------------------------------------------
		TF = 5;                                      	%75 TF (Hz) of sine stimuli (for spectra setup)
		%-----------------------------------------------
		RFd = 0;                                     	%76 size of RF DEC (min of arc)
		RFstartd = 0;                                	%77 RF DEC start
		%-----------------------------------------------
		DisplaySpikes = 1;				%78 Display spikes or not
		%-----------------------------------------------
		Thresh  = 0; 					%79 for EM-spike analyses
		RCHc    = 0;					%80 horizontal center for EM-spikes RC
		RCVc    = 0;					%81 vertical   center for EM-spikes RC
		EMbin       = 10;                            	%82 bin for spikes falling in between EM

		%-----------------------------------------------
		% For Raster Plots
		RastXmin   = 0;					%83 xmin 
		RastXmax   = 0;                              	%84 xmax

		%-----------------------------------------------
		DI = 1; 					%85 Calculate Direction Index

		%-----------------------------------------------
		spike_plot_mode = 1;				%86 1 - spikes, 2 - smoothed spikes, 3 - instantenous
		%-----------------------------------------------
		ISIbin = 10;					%87 bin for ISI in segments statistics
		ISImin = 0;					%88
		ISImax = 0;					%89
		%----------------------------------------------- 
		% EM setup - saccades detection 
		FlankThr = 7; 					%90 Threshold for flanks of saccades, deg/s 
		StableBefore = 50;				%91 Stable period before saccade, ms
		StableAfter  = 0; 				%92 Stable period after saccade, ms
		% Period within which :) subsequent saccade is not allowed to fall after previous saccade
		%   was - Stable period after saccade, ms    
		SaccadeThreshold = 10;				%93 Saccade Threshold velocity, deg/s
		%---------------------
		SmoothEM         = 0; 				%94 Smooth EM
		%---------------------
		InterpolateEM    = 0;				%95 Interpolate EM
		ISR		    = 500;		        %96 Hz - Interpolated (Desired) Sampling Rate
		%---------------------
		DispVel          = 0; 				%97 Display velocity
		DispVelGain      = 10;                       	%98 Display velocity gain
		SaccadesWinSelect= 0;                        	%99 Select windows around saccades
		WinBefore        = 0;				%100 - ms before saccade
		WinAfter         = 100;				%101 - ms after saccade
		%---------------------
		SaccadeThresholdUpperLim = 0;                	%102 Saccade threshold upper lim, deg/s 
		%---------------------
		SacSort             	    = 0;                %103 - Saccades Sorting
		EstimRF                  = 0;                	%104 - Estimate RF from DefValues(64:67) 
		%---------------------
		% Stimulus Parameters:
		%---------------------
		% Bar
		BPBS  = 0;					%105
		BRBS  = 0; 					%106
		BStartX = 0;					%107
		BStartY = 0;					%108
		BTilt = 0;					%109
		BExtentMotion = 0; 				%110

		% Sine
		SPBS  = 0;					%111
		SRBS  = 0; 					%112
		SStartX = 0;					%113
		SStartY = 0;					%114
		STilt = 0;					%115

		Xshift = 0;					%116 % Shifts are calculated for image plots, i.e. in relation to 
		Yshift = 0;					%117 % LLC of image (that is (0,0) is actually (50,50))

		EnhanceGrayImage = 0; 				%118 
		EyePositionWindowBottom = -100;			%119
		EyePositionWindowUp     = 100;               	%120
		SaccadeAmpWindowUp	   = 100;               %121
		SaccadeAmpWindowUpBottom= 0;                 	%122
		%---------------------
		PSTHYlabel             =  2;                 	%123 1-'#spikes',2-'spikes/sec'
		TrigEventTime          =  0;               	%124
		NormByPreTrigFR        =  0;                 	%125
		PreTrigFR              =  0;                 	%126 Pre-trigger Firing Rate
		AccumulateHistograms   =  0; 			%127 if 1 - do not clear averaged hist. (NORMIR) when opening new spikes list

		ImageMode              =  2;                 	%128 Image mode 1 - image, 2 - patches

		%----Select Sac. Windows according to sorting
		SelectMoreBefore       =  0; 			%129 Select windows where FR before > FR after
		SelectMoreAfter        =  0;			%130
		SelectEqual            =  0;                 	%131 

		IndTraces              =  0;                 	%132 Show individual traces in many files' PSTH   
		NoSaccadeBefore        =  300;			%133 The period within which no other saccade is allowed before this one
		NoSaccadeAfter 	  =  300;               	%134 The period within which no other saccade is allowed after this one
		SaveSaccadesData 	  =  0;                 %135 Do not save/save EM data

		CalcInd2               =  0;			%136 Calculate/Do not calculate transience index (TI)
		VC			  =  1; 		%137 Visual control (show graph figure while batch processing)
		SaveSegments		  =  0; 		%138 Save segments while batch processing 

		% Additional Saccade Parameters
		AngleRangeRight 	  =  0;			%139 degrees
		AngleRangeLeft         =  0;			%140 degrees

		BatchProcessing        =  0; 			%141 - batch processing flag

		FixWindowUp 		  = 100;		%142 - Artificial Fix. Window Up
		FixWindowDown	  = -100;			%143 - Artificial Fix. Window Up 

		RejectIfOutFixWin      = 4;			%144   1 - Reject trial if out of fixation window   
		%      2 - Take part of trials before
		%      3 - Take all "within" parts
		%      4 - Take all regardless of fixation window

		TakeDrifts             = 0; 			%145 Take periods between saccades
		Phase 		  = 0;				%146 Phase of sin in degrees (rad=deg*2*pi/360)
		SplitToCycles          = 0; 			%147 Split segments to cycles 
		FitSinAmp	          = 100; 		%148 Fitting sin amplitude
		FitSinDC		  = 0;			%149 Fitting sin DC (pedestal)
		SaveSTA		  = 0; 				%150 Save Saccade-Triggered Averages

		RCH1			  = -50;		%151 RC plot x1
		RCH2			  = 50;			%152 RC plot x2
		RCV1			  = -50;		%153 RC plot y1
		RCV2			  = 50;			%154 RC plot y2
		CalcPeakRate		  = 0;			%155 Calculate Peak Firing Rate

		DetectSem	= 0;				%156 Detect slow eye movements
		SemInterval	= 50;				%157 ms
		SemThreshold	= 5;				%158 Sem threshold

		AutoSelect	= 0;				%159 Take data automatically (0/1)
		ClipPaste	= 1; 				%160 Paste data to clipboard

		%--- eye spectra setup
		eyeWithDC	= 0;				%161 with/without DC
		eyeFreqAxis	= 20;				%162 Hz
		eyeNfft		= 0;				%163 if nfft is zero, the length of the signal is nfft
		eyeNoverlap	= 0;				%164 noverlap
		eyeWindow	= 0;				%165 window
		eyeSignLevel	= 0.95;				%166 significance level
		eyeFs		= 200;				%167 Hz
		eyeSpectrum	= 1;				%168 1-Amplitude,2-Power,3-dB

		detectBlink	= 0;				%169
		blinkInterval	= 80;				%170 Duration of blink (vel > threshold)

		eyeVelocity	= 1;				%171 eye velocity spectra (1/2)
		IFRistep	= 1;				%172 IFR interpolation step
		barVel		= 0;				%173 Bar velocity 
		
		saveFormat      = 1;				%174 save spikes format (batch mode)

		%--- Automatic analysis along parameter space
		measureAnalysis = 2;				%175 analysis measure
		paramAnalysis	= 1;				%176 parameter
		measureNormalizeAnalysis =0;			%177 normalize analysis measure
		openFigAnalysis	= 3;				%178 1 - do not open, 2 - open once and append, 3 - open new each time
		saveMatAnalysis = 1;				%179 0 - do not save, 1 - save
		dispAnalisys    = 1;				%180 0 - do not display, 1 - display

		autoScroll	= 0;				%181 0/1
		
		autoRFmap	= 0;				%182 auto RF mapping
		autoRFmapSign	= 0.01;				%183 auto RF mapping significance
		autoRFmapErrorBar= 1;				%184 autoRFmapping errorbar: 1 - no bars, 2 - std, 3 - sem

		oriFilterHalfWidth	= 7;			%185 number of points for Hanning window (*4)
		oriShiftThreshold= 70;				%186 if (90 - peak) > oriShiftThreshold => shift peak to 90 deg
		
		converSystemVersion = 2.1;			%187 system version
		saveSTIMspikes	    = 1;			%188 save STIM together with spike file

		analyzeBothOddEven    = 1;			%189 analyze segments: 1 - both, 2 - odd, 3 - even

		flash_sac_anal		= 0;			%190 analyze flash/sac.-triggered averages
		base			= 50;			%191 end of base (ms)
		peak 			= 100;			%192 end of peak (ms)
		tail			= 150;			%193 end of tail (ms)

		show_ind_histo		= 0;			%194 0 - do not show individual condition hist., 1 - show
		analysis_logX		= 0;			%195 0 - linear scale X, 1 - log scale X
		smooth_PSTH		= 0;			%196 smooth PSTH (0/1)
		smooth_spikes		= 0;			%197 smooth spikes (0/1)	
		
				
		
		DefValues = [HPeriod, MinHPeriod, MaxHPeriod,... 
                        Trials,     MinTrials,  MaxTrials,...
                        Ymin,       MinYmin,    MaxYmin,...
                        Ymax ,      MinYmax,    MaxYmax,...
                        SpkOnOffCol, MinSpkOnOffCol, MaxSpkOnOffCol,...
                        SpkOnOffRow, MinSpkOnOffRow, MaxSpkOnOffRow,...
                        EconomyPlot, HAverPeriod, MinHAverPeriod, ...
                        MaxHAverPeriod,EyeMovement, Grid,...
                        Sigma, MarkSelect,NormalEyeMovement,...
                        RejectSegmentEdge,SafetyInterval,ShapeStripPlot,...
                        StripPlotWindow,MinStripPlotWindow,MaxStripPlotWindow,...
                        ShrinkTime,SeparateOnOff,DrivenRate,...
                        TimeBeforeEvent,TimeAfterEvent,XGrid,SaccadeDetect,...
                        AverHistYAutoscale,AverHistYMax,AverHistXAutoscale,...
                        AverHistXmin,AverHistXmax,ShapeExist,CurFlag,FirstX, BegOfCurSegm, withDC, DispConcFlag,...
                        SnapInside, FreqAxisEnd, BaseLineActivity,Number_ms_Average,AverBin,Cycle_ms, Successive,...
                        nfft,noverlap,window,p,MarkSameSegments,...
                        x1,x2,x3,x4,inc,IndexMode, RFi, RFstarti, HndltoFig,TrialBegin,LatencyFromSaccade,TF,...
                        RFd, RFstartd, DisplaySpikes, Thresh, RCHc, RCVc, EMbin,...
                        RastXmin, RastXmax, DI, spike_plot_mode, ISIbin, ISImin, ISImax,...
                        FlankThr,StableBefore,StableAfter,SaccadeThreshold,SmoothEM,InterpolateEM,ISR,DispVel,DispVelGain,SaccadesWinSelect,...
                        WinBefore, WinAfter, SaccadeThresholdUpperLim, SacSort, EstimRF,...
                        BPBS, BRBS, BStartX, BStartY, BTilt, BExtentMotion, SPBS, SRBS, SStartX, SStartY, STilt, Xshift, Yshift,...
                        EnhanceGrayImage, EyePositionWindowBottom, EyePositionWindowUp, SaccadeAmpWindowUp, SaccadeAmpWindowUpBottom,...
                        PSTHYlabel, TrigEventTime, NormByPreTrigFR, PreTrigFR, AccumulateHistograms,ImageMode,...
                        SelectMoreBefore, SelectMoreAfter, SelectEqual, IndTraces, NoSaccadeBefore, NoSaccadeAfter, SaveSaccadesData,CalcInd2,... 
                        VC, SaveSegments, AngleRangeRight, AngleRangeLeft, BatchProcessing, FixWindowUp, FixWindowDown, RejectIfOutFixWin,...
                        TakeDrifts, Phase, SplitToCycles, FitSinAmp, FitSinDC, SaveSTA, RCH1, RCH2, RCV1, RCV2, CalcPeakRate,...
			DetectSem, SemInterval, SemThreshold, AutoSelect, ClipPaste,...
			eyeWithDC, eyeFreqAxis, eyeNfft, eyeNoverlap, eyeWindow, eyeSignLevel, eyeFs,eyeSpectrum,...
			detectBlink,blinkInterval,eyeVelocity,IFRistep,barVel,saveFormat,...
			measureAnalysis, paramAnalysis, measureNormalizeAnalysis, openFigAnalysis, saveMatAnalysis, dispAnalisys,...
			autoScroll,autoRFmap,autoRFmapSign,autoRFmapErrorBar, oriFilterHalfWidth, oriShiftThreshold,...
			converSystemVersion,saveSTIMspikes, analyzeBothOddEven,...
			flash_sac_anal, base, peak, tail, show_ind_histo, analysis_logX, smooth_PSTH, smooth_spikes];
	else
		DefValues = unitret('read_ini',INIFILE);
	end
        
        set(0,'UserData', DefValues,...
                'DefaultTextFontName','Arial',...
                'DefaultFigureInvertHardcopy','off',...
		'DefaultTextFontSize',10,...
		'DefaultTextColor','k',...
		'DefaultTextFontWeight','normal',...
		'DefaultFigureNumberTitle','off', ...
                'DefaultFigurePaperType','usletter',...
		'DefaultFigureColor','w',...
		'DefaultTextInterpreter','none');
        
        Fig1 = figure('Units','Normal','Position',[0.005 0.04 .27 .91],'Backingstore','on','Color',[ 0.8157    0.8039    0.7255],...
                'Resize','Off', 'Name',['UNITRET ' VERDATE],'MenuBar','none','Number','off');
        
        if (exist('unitret.png'))
                I  = imread('unitret.png','png');
                axes('Units','Pixels','Position',[65 300 150 150]);
		imshow(I);
		clear I;
        end;
        axis('off');
        
		
        EXCEL_NAME = 'sheet1'; % for DDE to Excel
        
        u1 = uimenu(Fig1,'Label','&File');
        u101 = uimenu(u1,'Label','Open &Experimental Record','Callback','unitret(''read_header'')');
        u102 = uimenu(u1,'Label','Open S&pikes Record','Callback','unitret(''spikes'')');
        u103 = uimenu(u1,'Label','S&how Spikes','Callback','unitret(''show_spikes'')');

        u104 = uimenu(u1,'Label','&Same segments in...','Callback','unitret(''another_cell'')','Separator','on');
        u105 = uimenu(u1,'Label','&Link spikes records...','Callback','unitret(''link_spikes_records'',0,2)','Separator','on');
        u106 = uimenu(u1,'Label','&Add spikes records...','Callback','unitret(''add_spikes_records'',0,2)','Separator','off','enable','off');
        u107 = uimenu(u1,'Label','&Process experimental records from list...','Callback','unitret(''process_exp_records_from_list'',0,0)','Separator','on','enable','on');
	u108 = uimenu(u1,'Label','&Process experimental records from list\trials...','Callback','unitret(''process_exp_records_from_list_trials'',0,0)','Separator','off','enable','on');
	u109 = uimenu(u1,'Label','&Process experimental records...','Callback','unitret(''process_exp_records'',0,0)','Separator','off','enable','on');
	      
	u110 = uimenu(u1,'Label','Process spikes records from list...','Callback','unitret(''process_spike_records_from_list'',0,0);','Separator','on');

        u111 = uimenu(u1,'Label','&Add spikes records from list...','Callback','unitret(''add_spikes_records_from_list'',0,1)','Separator','on');
        u112 = uimenu(u1,'Label','&Show spikes records from list...','Callback','unitret(''add_spikes_records_from_list'',0,0)','Separator','off');
        u113 = uimenu(u1,'Label','Convert any list to exp. records list...','Callback','unitret(''convert_any_list_to_exp_list'',0,0)','Separator','on');
        u114 = uimenu(u1,'Label','Generate list...','Callback','unitret(''generate_list'',0)','Separator','off');
        u115 = uimenu(u1,'Label','Transform list...','Callback','unitret(''transform_list'',0)','Separator','off');
     
        
        u116 = uimenu(u1,'Label','Open &TXT spike file','Callback','unitret(''open_txt_spike_file'',1)','Separator','on');	     
        u117 = uimenu(u1,'Label','Convert TXT spike files to spike files','Callback','unitret(''convert_txt_spike_files'',1)','Separator','off');	     	     
        u118 = uimenu(u1,'Label','Convert TXT multi train spike file to spike file','Callback','unitret(''convert_txt_multi_spike_file'',1)','Separator','off');	     	     
        u119 = uimenu(u1,'Label','Convert TXT multi train spike TIMES file to spike file','Callback','unitret(''convert_txt_multi_spike_times_file'',1)','Separator','off');	     	     
        
        u120 = uimenu(u1,'Label','Return to &Experimental Record','Callback','unitret(''read_header'', get(min(get(0,''Children'')),''Name''), 1 )','Separator','on'); 
        
        u121 = uimenu(u1,'Label','Call &UNISPLIT','Callback','unitret(''exit''); unisplit','Separator','on');	     
        u122 = uimenu(u1,'Label','Call &JPSTH','Callback','jpsth','Separator','on');  
        
	u123 = uimenu(u1,'Label','Convert...','Callback',['unitret(''exit''); conver;'],'Separator','on');  
	u124 = uimenu(u1,'Label','Batch convert...','Callback',['unitret(''batch_conver'');'],'Separator','off');
	u125 = uimenu(u1,'Label','Rename BW exported *.f32 files...','Callback',['unitret(''rename_f32'');'],'Separator','off');
	u126 = uimenu(u1,'Label','Remove e1 suffix','Callback',['unitret(''remove_e1'');'],'Separator','off');
	u127 = uimenu(u1,'Label','Convert BW only (no etd)...','Callback',['unitret(''exit''); conver(''no etd'');'],'Separator','off');
	u128 = uimenu(u1,'Label','Convert all at once!','Callback',['unitret(''convert_all'');'],'Separator','off');

	u129 = uimenu(u1,'Label','Call external &mfile...','Separator','on','Callback','unitret(''call_external_mfile'')');
		      

        u130 = uimenu(u1,'Label','E&xit','Separator','on','Callback','unitret(''exit'')');
        
        % Last u1 submenu 130
 
        Show_Return_Menu = u103;
        
        u2 = uimenu(Fig1,'Label','&Window');
        u201 = uimenu(u2,'Label','&Close all graphic windows','Callback','unitret(''close_all_graphic_windows'');');
        u202 = uimenu(u2,'Label','&Tile all graphic windows','Callback','unitret(''tile_all_graphic_windows'');');        
        
        u3 = uimenu(Fig1,'Label','&Options');
        u301 = uimenu(u3,'Label','Warnings O&FF','Callback','warning off');
        u302 = uimenu(u3,'Label','Warnings O&N','Callback','warning on');
        if ~strcmp(v(1),'5'),
                set(u301,'enable','off');
                set(u302,'enable','off');
        end
        u303 = uimenu(u3,'Label','Set File Wildcard','Callback','unitret(''set_file_wildcard'')','Separator','on');
        u304 = uimenu(u3,'Label','&Preferences...','Callback','unitret(''preferences'')','Separator','on');
        
        TRET_DAT(1) = Fig1;
        set(gcf,'Pointer','Arrow');
        
        u4 = uimenu(Fig1,'Label','&Help');
	u401 = uimenu(u4,'Label','About Unitret...','Callback','unitret(''about Unitret'')');
	u402 = uimenu(u4,'Label','HelpWin on Unitret modules','Callback','helpwin(''unitret'',1,''UNITRET modules'')');
	u403 = uimenu(u4,'Label','Online Help','Callback','web(''http://igoresha.virtualave.net/Matlab/UnitretHelp.html'')');
	u404 = uimenu(u4,'Label','HTML Help','Callback','global APP_PATH; oripath=pwd;cd(APP_PATH);!unitret.chm;cd(oripath);)');
	
	u405 = uimenu(u4,'Label','Readme','Callback','global APP_PATH; oripath=pwd;cd(APP_PATH);!readme.txt;cd(oripath);)','Separator','on');
	u406 = uimenu(u4,'Label','Changes History','Callback','global APP_PATH; oripath=pwd;cd(APP_PATH);!changes.txt;cd(oripath);)','Separator','off');
	u407 = uimenu(u4,'Label','License','Callback','global APP_PATH; oripath=pwd;cd(APP_PATH);!license.txt;cd(oripath);)','Separator','off');
	
	u408 = uimenu(u4,'Label','Delete *.INI file (unitret.ini) and restart','Callback','unitret(''delete_ini'')','Separator','on');
         
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------    
elseif(strcmp(action,'setup_exp'))
        
        
        Fig1 = figure('Backingstore','off','Name','Spike Setup','Color','w',...
                'Units','Normal','Position',[.22 .2 .5 .5],'Resize','on', 'Menubar','none','Number','off');
        set(gcf,'Pointer','Watch');
        
        uicontrol(Fig1,'Style','text','Position',[.2 .91 .5 .08],...
                'Units','normal','ForegroundColor','m',...
                'BackgroundColor','w','String','Spike Display:',...
                'HorizontalAlignment','center');
        
        uicontrol(Fig1,'Style','text','Position',[.02 .85 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',['Histogram, (', num2str(DefValues(2)), '...',...
                        num2str(DefValues(3)),') ms'],'HorizontalAlignment','left');
        
        uicontrol(Fig1,'Style','frame','Position',[.56 .84 .15 .07],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k');
        
        u1 = uicontrol(Fig1,'Style','edit','Position',[.58 .85 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(1)),...
                'HorizontalAlignment','left','Callback','unitret(''update'',1);');
        %-----------------  
        uicontrol(Fig1,'Style','text','Position',[.02 .77 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',['Trials, (', num2str(DefValues(5)), '...',...
                        num2str(DefValues(6)),')'],'HorizontalAlignment','left');
        
        uicontrol(Fig1,'Style','frame','Position',[.56 .76 .15 .07],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k');
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.58 .77 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(4)),...
                'Callback','unitret(''update'',4);');
        %%%%%%%%%%% ----------------
        
        uicontrol(Fig1,'Style','text','Position',[.02 .69 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String','Eye movement scale:','HorizontalAlignment','left');
        
        
        %-----------------------------
        uicontrol(Fig1,'Style','text','Position',[.02 .61 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',['From (',num2str(DefValues(8)),'...',...
                        num2str(DefValues(9)),')'], 'HorizontalAlignment','left');
        
        
        uicontrol(Fig1,'Style','frame','Position',[.56 .60 .15 .07],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k');
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.58 .61 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(7)),...
                'Callback','unitret(''update'',7);');
        %----------------------
        uicontrol(Fig1,'Style','text','Position',[.02 .53 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',['To (',num2str(DefValues(11)),'...',...
                        num2str(DefValues(12)),')'], 'HorizontalAlignment','left');
        
        
        uicontrol(Fig1,'Style','frame','Position',[.56 .52 .15 .07],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k');
        
        u4 = uicontrol(Fig1,'Style','edit','Position',[.58 .53 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(10)),...
                'Callback','unitret(''update'',10);');
        %---------------------
        
        
        u5=	uicontrol(Fig1,'Style','radiobutton','Position',[.02 .45 .26 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Y Grid, 100 ms', 'HorizontalAlignment','left',...
                'value',DefValues(24),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(24) = val; set(0,''userdata'',ud);']);
        
        
        %----------------------------------------
        %----------------------------------
        
        uicontrol(Fig1,'Style','text','Position',[.32 .44 .22 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','X Grid, minarc','HorizontalAlignment','left');
        
        
        uicontrol(Fig1,'Style','frame','Position',[.56 .44 .15 .07],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k');
        
        uicontrol(Fig1,'Style','edit','Position',[.58 .45 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(39)),...
                'Callback',	 ['u=get(gcf,''CurrentObject''); val = str2num(get(u,''string''));',...
                        'ud=get(0,''UserData''); ud(39) = val; set(0,''userdata'',ud);']);
        
        
        %----------------------------------------
        %   	uicontrol(Fig1,'Style','radiobutton','Position',[.72 .45 .26 .05],...
        %	'Units','normalized','BackgroundColor','w',...
        %	'ForegroundColor','k','String','Sac. detector', 'HorizontalAlignment','left',...
        %	'value',DefValues(40),'callback',...
        %	 ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
        %	  'ud=get(0,''UserData''); ud(40) = val; set(0,''userdata'',ud);']);
        
        
        %%%%%%%%%%% ----------------
        
        uicontrol(Fig1,'Style','text','Position',[.02 .38 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String','Event time gate:','HorizontalAlignment','left');
        
        
        
        
        %----------------------------------
        
        uicontrol(Fig1,'Style','text','Position',[.02 .30 .28 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Before event:','HorizontalAlignment','left');
        
        
        uicontrol(Fig1,'Style','frame','Position',[.35 .29 .15 .07],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k');
        
        uicontrol(Fig1,'Style','edit','Position',[.37 .30 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(37)),...
                'Callback',	 ['u=get(gcf,''CurrentObject''); val = str2num(get(u,''string''));',...
                        'ud=get(0,''UserData''); ud(37) = val; set(0,''userdata'',ud);']);
        
        
        %----------------------------------
        
        uicontrol(Fig1,'Style','text','Position',[.52 .30 .28 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','After event:','HorizontalAlignment','left');
        
        
        uicontrol(Fig1,'Style','frame','Position',[.81 .29 .15 .07],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k');
        
        uicontrol(Fig1,'Style','edit','Position',[.83 .30 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(38)),...
                'Callback',	 ['u=get(gcf,''CurrentObject''); val = str2num(get(u,''string''));',...
                        'ud=get(0,''UserData''); ud(38) = val; set(0,''userdata'',ud);']);
        
        
        
        %----------------------------------
        uicontrol(Fig1,'Style','text','Position',[.2 .19 .5 .05],...
                'Units','normal','ForegroundColor','m',...
                'BackgroundColor','w','String','Shape Display:',...
                'HorizontalAlignment','center');
        
        %---------------------
        
        
        u6 = 	uicontrol(Fig1,'Style','radiobutton','Position',[.02 .12 .35 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Shape strip plot', 'HorizontalAlignment','left',...
                'value',DefValues(30),'callback',...
                ['global TRET_DAT; TRET_DAT(10) = 0; u=get(gcf,''CurrentObject'');',...
                        'val = get(u,''value''); ud=get(0,''UserData'');',...
                        'if ud(46)==0, unitret(''errormessage'',''This file contains no shapes data...'',''ERROR'');',...
                        'set(gco,''value'',0);ud(30)=0;set(0,''Userdata'',ud);return; end; ud(30) = val; set(0,''userdata'',ud);']);
        
        %-----------------------------------------------------------------------------------
        
        uicontrol(Fig1,'Style','text','Position',[.4 .12 .25 .05],...
                'Units','normalized','BackgroundColor','w','String','Window',...
                'ForegroundColor','k');
        
        
        
        uicontrol(Fig1,'Style','frame','Position',[.66 .11 .15 .07],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k');
        
        
        u7 = uicontrol(Fig1,'Style','edit','Position',[.68 .12 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(31)),...
                'Callback','unitret(''update'',31);');
        %----------------------------------------------------------------------------------------
        
        
        
        u8 = uicontrol(Fig1,'Style','radiobutton','Position',[.02 .05 .41 .05],...
                'Units','normalized','BackgroundColor','w','String','Shrinked time scale',...
                'ForegroundColor','k','value',DefValues(34),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(34) = val; set(0,''userdata'',ud);']);
        
        u9 = uicontrol(Fig1,'Style','radiobutton','Position',[.5 .05 .20 .05],...
                'Units','normalized','BackgroundColor','w','String','Display spikes',...
                'ForegroundColor','k','value',DefValues(78),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(78) = val; set(0,''userdata'',ud);']);
        

        
        %----------------------------------------------------------------------------------------
        OK_button=uicontrol(Fig1,'Style','pushbutton','Position',[.75 .83 .22 .12],...
                'Units','Normalized','String','OK','Callback',['delete(',num2str(Fig1), '); ',...
                        'drawnow;unitret(''update'',0,2);watchoff;']);
        
        cancel=uicontrol(Fig1,'Style','pushbutton','Position',[.75 .65 .22 .12],...
                'Units','Normalized','String','Cancel','Callback',['delete(',num2str(Fig1), '), return']);
        
        
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
	%---------------------------------------------------------------------------------------------------------------------------------------------------------------    

 elseif(strcmp(action,'setup_auto'))
	
	HelpString = 	['Help for ',action,'|',...
			'|',...
			'Setup for automated (batch) operations|',...
			'visual control - display/hide graphic figure (hide option is faster)|',...
			'auto select - select automatically (can be used in manual mode as well, instead of mouse press)|',...
			'save selected segments - will save segments in "save format"|',...
			'save eye mov. data - will save EM data structures to *.ems MAT file|',...
			'save STA - saccade-triggered averages|',...
			'class. index - currently obsolete|',...
			'clear/accumulate processing - data per one file or for all files in batch (for STA and "add spikes records")|',...
			'autoscroll file forward - automatically scroll pages (trials) forward (like pressing ">>" button)|',...
			];
        
        
        Fig1 = figure('Backingstore','off','Name','Setup Auto','Color','w',...
                'Units','Normal','Position',[.22 .2 .5 .5],'Resize','on', 'Menubar','none','Number','off');
        set(gcf,'Pointer','Watch');       
       

        %-----------Visual Control (show graph figure)
        uicontrol(Fig1,'Style','checkbox','Position',[.05 .9 .2 .04],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0.5686 0.1333 1],'String','visual control', 'HorizontalAlignment','left',...
                'value',DefValues(137),'TooltipString','Display graphic figure during batch operations','callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(137) = val; set(0,''userdata'',ud);']);

	%-----------AutoSelect
	uicontrol(Fig1,'Style','radiobutton','Position',[.05 .8 .2 .05],...
                'Units','normalized','BackgroundColor','w','String','auto select',...
                'ForegroundColor','k','value',DefValues(159),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(159) = val; set(0,''userdata'',ud);']);

        
        %-----------Save Selected Segments 
        uicontrol(Fig1,'Style','checkbox','Position',[.05 .7 .3 .04],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0.5686 0.1333 1],'String','save selected segments', 'HorizontalAlignment','left',...
                'value',DefValues(138),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(138) = val; set(0,''userdata'',ud);']);

        %-----------Save Format
        uicontrol(Fig1,'Style','text','Position',[.4 .75 .15 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0    0.2510    0.5020],'String','save format','HorizontalAlignment','left');
        
        %-----------Save Format
        uicontrol(Fig1,'Style','Popupmenu','Units','Normalized','Position',[.4 .7 .2 .05],...
                'String','spk|MAT SEM|MAT SEMSTIM','Value',DefValues(174),'Callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(174) = val; set(0,''userdata'',ud);']);

        
        %-----------Saccades Data Save
        uicontrol(Fig1,'Style','checkbox','Position',[.05 .6 .3 .04],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0.5686 0.1333 1],'String','save eye mov. data', 'HorizontalAlignment','left',...
                'value',DefValues(135),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(135) = val; set(0,''userdata'',ud);']);
        
        %-----------STA Save
        uicontrol(Fig1,'Style','checkbox','Position',[.05 .5 .3 .04],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0.5686 0.1333 1],'String','save STA', 'HorizontalAlignment','left',...
                'value',DefValues(150),'TooltipString','Saccade-triggered average','callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(150) = val; set(0,''userdata'',ud);']);


    	%-----------Calculate Saccade Impact Classificaion Index
        uicontrol(Fig1,'Style','checkbox','Position',[.05 .4 .2 .04],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0.5686 0.1333 1],'String','class. index', 'HorizontalAlignment','left',...
                'value',DefValues(136),'TooltipString','Saccades impact classification','callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(136) = val; set(0,''userdata'',ud);']);

        %-----------Accumulate/Clear Processing 
        if DefValues(127)
                str = 'accumulate processing';
        else
                str = 'clear processing';
        end
        
        uicontrol(Fig1,'Style','radiobutton','Position',[.05 .3 .30 .05],...
                'Units','normalized','BackgroundColor','w','String',str,...
                'ForegroundColor','k','value',DefValues(127),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(127) = val; set(0,''userdata'',ud);',...
                        'if val==0, set(u,''String'',''clear processing''); else set(u,''String'',''accumulate processing''); end;']);

	%-----------Autoscroll 
        uicontrol(Fig1,'Style','radiobutton','Position',[.05 .2 .30 .05],...
                'Units','normalized','BackgroundColor','w','String','autosroll file forward',...
                'ForegroundColor','k','value',DefValues(181),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(181) = val; set(0,''userdata'',ud);']);


        %----------------------------------------------------------------------------------------
        OK_button=uicontrol(Fig1,'Style','pushbutton','Units','Normalized','Position',[.75 .8 .15 .09],...
                'String','OK','Callback',['delete(',num2str(Fig1), '); ',...
                        'drawnow;unitret(''update'',0,2);watchoff;']);
        
        cancel=uicontrol(Fig1,'Style','pushbutton','Units','Normalized','Position',[.75 .7 .15 .09],...
                'String','Cancel','Callback',['delete(',num2str(Fig1), '), return']);

	Help_button=uicontrol(Fig1,'Style','pushbutton','Units','Normalized','Position',[.75 .6 .15 .09],...
                'String','Help','Callback',['u=get(gcf,''CurrentObject''); str=get(u,''UserData''); unitret(''help_win'',str)']);
	set(Help_button,'Userdata',HelpString);
	
	HTML_HELP_button=uicontrol(Fig1,'Style','pushbutton','Units','Normalized','Position',[.75 .4 .15 .09], 'BackgroundColor',[0.5020    0.5020    0.2510],...
                'String','HTML Help','Callback',['global APP_PATH; cd(APP_PATH); !hh.exe unitret.chm::/HelpSetupAuto.html']);

	
        
        
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
	%---------------------------------------------------------------------------------------------------------------------------------------------------------------    

elseif(strcmp(action,'read_header'))
        
        global EM_STRUCTURE_ONE_FILE STA_ONE_FILE EM_CLASS_ONE_FILE STIM
        EM_STRUCTURE_ONE_FILE = [];
        STA_ONE_FILE = [];
        EM_CLASS_ONE_FILE=[];
        
        ud=get(0,'Userdata');
        ud(46)=1;
        ud(30)=0;
        ud(104)=0;
        set(0,'Userdata',ud);
        
        if  (size(TRET_DAT,2) > 1 ),    % second member exists (pointer on graph figure)
                if strcmp(get(TRET_DAT(2),'Type'),'figure'),
                        delete(TRET_DAT(2));
                        TRET_DAT = TRET_DAT(1);
                end;  
        end;      
        
        set(Show_Return_Menu, 'Label', 'S&how Spikes', 'Callback', 'unitret(''show_spikes'')');
        
        
        old_userdata = get(TRET_DAT(1),'UserData');
        if ~isempty(old_userdata)
                oldfid = old_userdata(1);
                %       fclose(oldfid);
                cc = get(gcf,'children');
                %	for i = 1:length(cc), if strcmp(get(cc(i),'type'),'uicontrol'), delete (cc(i)); end; end;
                fclose('all');
                % cla; axis('off');
                
        end;
        if exist ('in2') % Return to previous experimental record from show_spike mode
                
                INI_NAME = in1;
                FullName = in1;
                filename = in1;
                first = DefValues(73);  
        else 
                first = 0;
                if exist('in1')
                        strdlg=[in1,'.*'];
                else
                        strdlg='*.a??';
                end
                
                [filename, pathname] = uigetfile(strdlg , 'Open Experimental Record...', .4, .4);
                if filename == 0, return; end;
                FullName = [pathname,filename];
                INI_NAME = filename; 
                
                com = ['cd ' pathname(1:length(pathname)-1)]; 
                eval(com);

		STIM = [];
                
        end
        [fid, message] = fopen(FullName,'rb');
        if(fid<0), 
                error(message);
                return;
        end;
        
        
        StartPosition = ftell(fid);
        
        
        % ---------- READING THE FILE HEADER BLOCK -----------------------
        % Common for all actions
        
        blockSTART		=    ftell(fid);
        fseek(fid,2+4, -1);
        FileHeaderLength        =    fread(fid, 1,'ushort');
        fseek(fid,blockSTART, -1);
        
        Ver                     =    fread(fid, 1,'ushort');
        FileLength              =    fread(fid, 1,'long');
        FileHeaderLength        =    fread(fid, 1,'ushort');
        
        GlobSpecBlockNum        =    fread(fid, 1,'ushort');
        TrialsNum               =    fread(fid, 1,'ushort');
        CommLength              =    fread(fid, 1,'ushort');
        GlobSpecBlockLength     =    fread(fid,GlobSpecBlockNum, 'ushort');
        TrialBegin              =    fread(fid,TrialsNum,'long');
        % TrialBegin=[236 24962 67164 110434 150948 193110 231488 274422 318044 354822 388976 431166 465916 500726 534084 566930 595228 639762 681224 718182]';
        
	if unitret('NoSeparator',fid)
                strerr = ['FORMAT ERROR on FILEHEADER: file ', filename, ' skipped'];
                
                unitret('errormessage',strerr,'ERROR');
                fclose(fid);
                return;
        end;
        %disp('FILE HEADER BLOCK .... OK');
        
        % ---------- READING THE FILE SPECIFICATION  BLOCK -----------------------
        blockSTART     	   =    ftell(fid);
        
        FileName                =    (setstr(fread(fid, 14,'char')))';
        FileDate                =    (setstr(fread(fid, 10,'char')))';
        RunModName              =    (setstr(fread(fid, 10,'char')))';
        VideoFramePeriod        =    fread(fid,1,'float');
        ViewDistance            =    fread(fid,1,'float');
        TimeFirstSample         =    fread(fid,1,'float');
        NumSamp2Frame           =    fread(fid,1,'ushort');
        HorizVisualFieldLoc     =    fread(fid,1,'float');
        VertVisualFieldLoc      =    fread(fid,1,'float');
        HorizPosLED             =    fread(fid,1,'float');
        VertPosLED              =    fread(fid,1,'float');
        HorizEyePosGain         =    fread(fid,1,'float');
        VertEyePosGain          =    fread(fid,1,'float');
        EyetrackArbDef          =    fread(fid,1,'float');
        EyetrackArbV0           =    fread(fid,1,'ushort');
        Empty                   =    fread(fid,1,'ushort');
        LeftEdge                =    fread(fid,1,'ushort');
        BottomEdge              =    fread(fid,1,'ushort');
        RightEdge               =    fread(fid,1,'ushort');
        TopEdge                 =    fread(fid,1,'ushort');
        StabFlag                =    fread(fid,1,'ushort');
        Empty                   =    fread(fid,1,'ushort');     % temporal type: flag
        Empty                   =    fread(fid,1,'ushort');     % spatial type: flag
        CompFlag                =    fread(fid,1,'ushort');
        DateTime                =    (setstr(fread(fid, 18,'uchar')))';
        EyePer                  =    fread(fid,1,'float');
        SpikePer                =    fread(fid,1,'float');
        ShapePer                =    unifread([fid, 1,blockSTART,GlobSpecBlockLength],'float');
        FixationType		=    unifread([fid, 1,blockSTART,GlobSpecBlockLength],'ushort');
        
        % IT SHOULD BE READ AUTOMATICALLY FROM FILE
        
        if ~ShapePer,
                ShapePer =  1000/10000;		%ms
        end;
        
        % Shapes exist?
        
        if isnan(ShapePer)
                ud=get(0,'Userdata');
                ud(46)=0;
                set(0,'Userdata',ud);
        end
        
        
        if unitret('NoSeparator',fid)
                strerr = ['FORMAT ERROR on FILE SPECIFICATION BLOCK: file ', filename, ' skipped'];
                unitret('errormessage',strerr,'ERROR');
                fclose(fid);
                return;
        end;
        % disp('FILE SPECIFICATION  BLOCK ....OK');
        
        % ---------- READING THE FILE COMMENT  BLOCK -----------------------
        
        blockSTART     	   =    ftell(fid);
        Comments = (setstr(fread(fid,CommLength, 'char')))';
        
        if unitret('NoSeparator',fid)
                strerr = ['FORMAT ERROR on COMMENTS: file ', filename, ' skipped'];
                unitret('errormessage',strerr,'ERROR');
                fclose(fid);
                return;
        end;
        % disp('FILE COMMENT  BLOCK ...OK');
        
        % textout on the left panel:
        

	set(0,'CurrentFig',TRET_DAT(1));
        cla;
        axes('Position',[0 0 1 1],'Visible','off');
        
        set(text,'Position',[.02 .97],'Color','r','string','File name:'); 
        set(text,'Position',[.5 .97],'Color','k','string',deblank(filename),'Interpreter','none'); 
        
        set(text,'Position',[.02 .95],'Color','r','string','File Date:'); 
        set(text,'Position',[.5 .95],'Color','k','string',deblank(FileDate)); 
        
        set(text,'Position',[.02 .93],'Color','r','string','Run mode:'); 
        set(text,'Position',[.5 .93],'Color','k','string',deblank(RunModName)); 
        
        set(text,'Position',[.02 .91],'Color','r','string','Video frame T, ms:'); 
        set(text,'Position',[.63 .91],'Color','k','string',num2str(VideoFramePeriod)); 
        
        set(text,'Position',[.02 .89],'Color','r','string','View distance,cm:'); 
        set(text,'Position',[.63 .89],'Color','k','string',num2str(ViewDistance)); 
        
        set(text,'Position',[.02 .87],'Color','r','string','First sample time:'); 
        set(text,'Position',[.63 .87],'Color','k','string',num2str(TimeFirstSample)); 
        
        set(text,'Position',[.02 .85],'Color','r','string','Samp. per frame:'); 
        set(text,'Position',[.63 .85],'Color','k','string',num2str(NumSamp2Frame)); 
        
        set(text,'Position',[.02 .83],'Color','r','string','Vis field loc:'); 
        set(text,'Position',[.63 .83],'Color','k','string',...
                [num2str(HorizVisualFieldLoc),',',num2str(VertVisualFieldLoc)]); 
        
        set(text,'Position',[.02 .81],'Color','r','string','LED position:'); 
        set(text,'Position',[.63 .81],'Color','k','string',...
                [num2str(HorizPosLED),',',num2str(VertPosLED)]); 
        
        set(text,'Position',[.02 .79],'Color','r','string','Eye position gain:'); 
        set(text,'Position',[.63 .79],'Color','k','string',...
                [num2str(HorizEyePosGain),',',num2str(VertEyePosGain)]); 
        
        set(text,'Position',[.02 .77],'Color','r','string','Eye track arb. def.:'); 
        set(text,'Position',[.63 .77],'Color','k','string',num2str(EyetrackArbDef)); 
        
        set(text,'Position',[.02 .75],'Color','r','string','Eye track arb. V0.:'); 
        set(text,'Position',[.63 .75],'Color','k','string',num2str(EyetrackArbV0)); 
        
        set(text,'Position',[.02 .73],'Color','r','string','Edge, left, right:'); 
        set(text,'Position',[.63 .73],'Color','k','string',...
                [num2str(LeftEdge),',',num2str(RightEdge)]); 
        
        set(text,'Position',[.02 .71],'Color','r','string','Edge, bottom, top:'); 
        set(text,'Position',[.63 .71],'Color','k','string',...
                [num2str(BottomEdge),',',num2str(TopEdge)]); 
        
        set(text,'Position',[.02 .69],'Color','r','string','Stab flag:'); 
        str = unitret('translate','StabFlag',StabFlag);
        set(text,'Position',[.63 .69],'Color','k','string',str); 
        
        set(text,'Position',[.02 .67],'Color','r','string','Comp flag:'); 
        str = unitret('translate','CompFlag',CompFlag);
        set(text,'Position',[.63 .67],'Color','k','string',str); 
        
        set(text,'Position',[.02 .65],'Color','r','string','Eye period, ms:'); 
        set(text,'Position',[.63 .65],'Color','k','string',num2str(EyePer)); 
        
        set(text,'Position',[.02 .63],'Color','r','string','Spike period, ms:'); 
        set(text,'Position',[.63 .63],'Color','k','string',num2str(SpikePer)); 
        
        set(text,'Position',[.02 .61],'Color','r','string','Shape Period:'); 
        set(text,'Position',[.63 .61],'Color','k','string',num2str(ShapePer)); 
        
        set(text,'Position',[.02 .59],'Color','r','string','Fixation type:'); 
        str = unitret('translate','FixationType',FixationType);
        set(text,'Position',[.63 .59],'Color','k','string',str); 
        
        set(text,'Position',[.02 .57],'Color','r','string','Time:'); 
        set(text,'Position',[.45 .57],'Color','k','string',deblank(DateTime)); 
        
        
        
        
        if (CommLength),
                set(text,'Position',[.02 .55],'Color','r','string','Comments:'); 
                set(text,'Position',[.02 .53],'Color','k','string',deblank(Comments)); 
        end;
        
        TRINFOHndl=uicontrol('Style','Pushbutton','String','Trial Info','Units','Normalized',...
                'Position',[.25 .4 .5 .05],'Callback','unitret(''fulldump'',0);');
        
        
        set(TRET_DAT(1),'Name',deblank(INI_NAME));
        
        
        trial_inf  = [fid TrialsNum TrialBegin'];
        set(TRET_DAT(1),'UserData',trial_inf);
	
        % show graph figure
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
        
        
        drawnow;
        
        unitret('redraw_exp',first); 
        
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
elseif(strcmp(action,'redraw_exp'))
        global STIMULUS SPIKES MOTION SINDATA STIM;
        
        if  (size(TRET_DAT,2) > 1 ),    % second member exists (pointer on graph figure)
                if strcmp(get(TRET_DAT(2),'Type'),'figure'),
                        Fig2 = TRET_DAT(2);
                        set(0,'CurrentFigure',Fig2);
                        kids=get(Fig2,'Children');
                        for i=1:length(kids),
                                tp=get(kids(i),'type');
                                if (strcmp(tp,'axes')) | (strcmp(tp,'uicontrol')) 
                                        delete(kids(i));
                                end;
                        end;
                end;
        else,       
                if ~DefValues(137) & DefValues(141),
                        VC = 'off';
                else
                        VC = 'on';
                end
                
                Fig2 = figure('Units','normal', 'Position',[0.2822    0.0417    0.7148    0.9089],...
                        'Backingstore','on','color','w','Menubar','none',...
                        'DefaultAxesFontSize',9,'DefaultAxesDrawMode','fast',...
                        'DefaultAxesYColor','k','DefaultAxesXColor','k','Visible',VC);
                % set(gcf,'WindowButtonDownFcn','ud = get(0,''Userdata'');ud(72) = gcf;set(0,''Userdata'',ud);');
		
                u1 = uimenu(Fig2, 'Label','&File');
                u101 = uimenu(u1, 'Label','&Save Segment','Callback','unitret(''save'',1);','enable','on','Tag','Save Segment');
                u102 = uimenu(u1, 'Label','Save Segment &As...','Callback','unitret(''save'',2);','enable','on','Tag','Save Segment As...');
                u103 = uimenu(u1, 'Label','Save Segment In &ASCII...','Callback','unitret(''save'',33);','enable','on','Tag','Save Segment In ASCII...');
                u104 = uimenu(u1, 'Label','Save Segment In &MAT...','Callback','unitret(''save'',34,''dialog'');','enable','on','Tag','Save Segment In MAT...');
                u105 = uimenu(u1, 'Label','Save Segment and Stimulus In &MAT...','Callback','unitret(''save'',35,''dialog'');','enable','on','Tag','Save Segment and Stimulus In MAT...');
			      
                u121 = uimenu(u1, 'Label','Send to &Excel','Callback','unitret(''send_to_excel'',1);','Separator','on'); 
                u122 = uimenu(u1, 'Label','S&how Spikes','Callback','unitret(''show_spikes'')','enable','off');
                u123 = uimenu(u1, 'Label','Save screen in &HGL format As...','Callback','unitret(''save'',7);','Separator','on');
                u124 = uimenu(u1, 'Label','&Copy to Clipboard as bitmap','Separator','on','Callback','print -dbitmap'); 
                u125 = uimenu(u1, 'Label','C&opy to Clipboard as metafile','Separator','on','Callback','print -dmeta'); 
                u126 = uimenu(u1, 'Label','Save &Concatenated Segm.','callback','unitret(''save'',13);','Separator','on','enable','off');
                
                u16 = uimenu(u1, 'Label','Se&lect...','Separator','on');
                u17 = uimenu(u1, 'Label','&Deselect','callback','unitret(''mark_deselect'');');
                

		%%% do not rename these menus
                u161 = uimenu(u16, 'Label','&Segment','callback','unitret(''mark_select'',0,1);');
                u162 = uimenu(u16, 'Label','&Odd-Even couple','callback','unitret(''mark_select'',1,1);');
                u168 = uimenu(u16, 'Label','&Even-Odd couple','callback','unitret(''mark_select'',7,1);');
                u163 = uimenu(u16, 'Label','&Whole trial','callback','unitret(''mark_select'',2,1);');
                u165 = uimenu(u16, 'Label','&Event','callback','unitret(''mark_select'',4,1);');
                u166 = uimenu(u16, 'Label','&Arb. Window','callback','unitret(''mark_select'',5,1);');
                u167 = uimenu(u16, 'Label','&Int. Cycles','callback','unitret(''mark_select'',6,1);');
		u169 = uimenu(u16, 'Label','A&ll Cycles','callback','unitret(''mark_select'',8,1);');
                u164 = uimenu(u16, 'Label','&Edge rejection','callback','unitret(''mark_select'',3,1);',...
                        'Separator','on');
                %%% end of "do not rename these menus"
		                
                u130 = uimenu(u1, 'Label','P&rint Setup...','Separator','on','Callback','print -dsetup;');     
                u131 = uimenu(u1, 'Label','&Print','Callback','orient landscape; print;');
                u132 = uimenu(u1, 'Label','E&xit','Separator','on','Callback','unitret(''exit'');');

		u2 = uimenu(Fig2, 'Label','&Auto');
                u201 = uimenu(u2, 'Label','&Setup Auto','Callback','unitret(''setup_auto'')');
                
                u3 = uimenu(Fig2, 'Label','&Setup');
                u301 = uimenu(u3, 'Label','&Setup experimental display','Callback','unitret(''setup_exp'')');
                u302 = uimenu(u3, 'Label','Setup &eye movements','Callback','unitret(''setup_EM'')');
                u303 = uimenu(u3, 'Label','S&pectra Setup','Callback','unitret(''spectra_setup'')','Separator','on');
                
                u4 = uimenu(Fig2, 'Label','&Tools');
                u401 = uimenu(u4, 'Label','&Snap cursors inside','Callback','unitret(''snap_inside'');');
                u402 = uimenu(u4, 'Label','&Eye Position Averages','Callback','unitret(''grand_eye_position'');');
                u403 = uimenu(u4, 'Label','&Peak Firing Rate','Callback','unitret(''peak_firing_rate'');');
                
                u411 = uimenu(u4, 'Label','&RF Stimulus Scheme','Callback','unitret(''rf_stim_scheme'',0);','Separator','on');
                u412 = uimenu(u4, 'Label','&RF Stimulus on Display','Callback','unitret(''rf_stim_display'',0);');
                u413 = uimenu(u4, 'Label','Stimulus on &Monitor','Callback','unitret(''stim_on_monitor'',0);');
		u414 = uimenu(u4, 'Label','Stimulus Summary','Callback','unitret(''stim_summary'',0);');
		
                
                u421 = uimenu(u4, 'Label','&3D Eye Movement Plot','Callback','unitret(''eye_mov_plot'',0);','Separator','on');
                u422 = uimenu(u4, 'Label','&3D EM Plot and RC','Callback','unitret(''eye_mov_plot'',0,1);');
                u423 = uimenu(u4, 'Label','&2D Eye Movement Plot','Callback','unitret(''eye_mov_plot'',1);');
                u424 = uimenu(u4, 'Label','&2D Eye Movement Plot and RC','Callback','unitret(''eye_mov_plot'',1,1);');
                u425 = uimenu(u4, 'Label','Eye Movement - Spikes R&C','Callback','unitret(''eye_mov_spikes_rc'',0);');
                u426 = uimenu(u4, 'Label','&Dublicate RC','Callback','unitret(''eye_mov_spikes_rc'',0);','enable','off');
                u427 = uimenu(u4, 'Label','Eye Movement - Spikes RC (&hist)','Callback','unitret(''eye_mov_spikes_rc'',1);');
                u428 = uimenu(u4, 'Label','Eye Movement Velocity','Callback','unitret(''eye_mov_velocity'',1);');
                u429 = uimenu(u4, 'Label','Estimate mean PSTH','Callback','unitret(''estimate_MEAN_PSTH'',1);');

		u430 = uimenu(u4, 'Label','Add EM &plot to existing 2D plane plot','Callback','unitret(''add_em_plot'',1);');               
                u431 = uimenu(u4, 'Label','Add &RF and stimuli on RC','Callback','unitret(''add_stimuli_on_rc'',1);');
                u432 = uimenu(u4, 'Label','Add &Stimulus on RC','Callback','unitret(''add_stimulus_on_rc'',1);');
		u433 = uimenu(u4, 'Label','&Show 2D plane EM plot','Callback','unitret(''add_em_plot'',0);');
		
                
                
                u5 = uimenu(Fig2, 'Label','&Window');
                u501 = uimenu(u5, 'Label','Copy Previous Window to Clipboard as &bitmap','Callback','ud = get(0,''Userdata''); set(0,''CurrentFigure'',ud(72)); print -dbitmap');
                u502 = uimenu(u5, 'Label','Copy Previous Window to Clipboard as &metafile','Callback','ud = get(0,''Userdata''); set(0,''CurrentFigure'',ud(72)); print -dmeta');
                u503 = uimenu(u5, 'Label','&Print Previous Window','Callback','ud = get(0,''Userdata''); set(0,''CurrentFigure'',ud(72)); print -dwin;');
                u504 = uimenu(u5, 'Label','&Save in HGL format','Callback','ud = get(0,''Userdata''); set(0,''CurrentFigure'',ud(72)); process(''save_hgl'');');
                u505 = uimenu(u5, 'Label','&Save in *.m format','Callback','ud = get(0,''Userdata''); set(0,''CurrentFigure'',ud(72)); process(''save_m'');');
                
                u6 = uimenu(Fig2,'Label','&Go to trial...');
                
                
                trials_inf = get(TRET_DAT(1),'UserData');
                TrialsNum = trials_inf(2);
                TrialBegin = trials_inf(3:TrialsNum+2);
                
                
                if TrialsNum >0,    
                        for(t=1:TrialsNum),
                                uimenu(u6, 'Label',num2str(t),'Callback',['h=get(gcf,''CurrentMenu''); unitret( ''redraw_exp'', str2num( get(h,''Label'')));']);	      
                        end;
                end;
                
                %%% MATLAB5 gcbo $$$ !!!
                
                if DefValues(26)==0,
                        set(u161,'Checked','On');
                elseif DefValues(26)==1,
                        set(u162,'Checked','On');
                elseif DefValues(26)==2,
                        set(u163,'Checked','On');      
                elseif DefValues(26)==4,
                        set(u165,'Checked','On');
                elseif DefValues(26)==5,      
                        set(u166,'Checked','On');
                elseif DefValues(26)==6,      
                        set(u167,'Checked','On');
                elseif DefValues(26)==7,      
                        set(u168,'Checked','On');
                elseif DefValues(26)==8,      
                        set(u169,'Checked','On');
                        
                end;
                
                if DefValues(28),
                        set(u164,'Checked','On');
                end;
                
                set([u161 u162 u163 u165 u166 u167 u168 u169],'Userdata',[u161 u162 u163 u165 u166 u167 u168 u169]);	%create control array
                
                
                TRET_DAT(2:3) = [Fig2; u101];
                TRET_DAT(11) = u17;
        end; 
        % set(gcf,'Pointer','Watch'); %###
        
        if (in1==0), %<-------- First entry into the file
                in1 = 1; 
                set(Fig2,'UserData',[]);
        end; 
        
        set(TRET_DAT(11),'userdata',in1);	% for redrawing when deselect
        DefValues(73) = in1;
        set(0,'Userdata',DefValues)
        
        
        trials_inf = get(TRET_DAT(1),'UserData');
        fid = trials_inf(1);
        TrialsNum = trials_inf(2);
        
        lastfig = min(TrialsNum, in1+DefValues(4)-1);
        nextfig = lastfig+1;
        prevfig = max(1,in1 - DefValues(4));
        
        
        
        % Marked data reading (if any)
        MarkedData = get(Fig2,'UserData');
        
        
        
        % axis location calculations
        
        Trials2Screen = min(DefValues(4),TrialsNum);
        if (Trials2Screen == 9) | (Trials2Screen == 8)|(Trials2Screen == 7),
                col = 3;
                row = 3;
        elseif (Trials2Screen == 6) |(Trials2Screen == 5) ,
                col = 2;
                row = 3;
        elseif Trials2Screen == 4,
                col = 2;
                row = 2;
        elseif Trials2Screen == 3,
                col = 1;
                row = 3;
        elseif Trials2Screen == 2,
                col = 1;
                row = 2;
        elseif Trials2Screen == 1,
                col = 1;
                row = 1;
        else
                col = 2;     % default 6 graphs on screen
                row = 3;
        end;
        
        wi = .05;                          % width of each interval between axises
        hi = .05;                           % higth of each interval between axises
        wt = .9;                            % width of field for axis
        ht = .85;                          % heigth of field for axis  
        wb = (wt-(col-1)*wi)/col;   % x size for one subplot axis 
        hb = (ht-(row-1)*hi)/row;   % y ....
        
        % READING OF THE TRIAL DATA: 
        for(numrow=0:row-1),
                for(numcol=0:col-1),
                        gind = (numrow*col + numcol);
                        tnum = in1 + gind;
                        
                        if(tnum > lastfig), 
                                break;
                        else
                                status = fseek(fid,0,-1);
                                
                                
                                % ---------- READING THE FILE HEADER BLOCK -----------------------
                                % Common for all actions
                                blockSTART		=    ftell(fid);
                                fseek(fid,2+4, -1);
                                FileHeaderLength        =    fread(fid, 1,'ushort');
                                fseek(fid,blockSTART, -1);
                                
                                Ver                     =    fread(fid, 1,'ushort');
                                FileLength              =    fread(fid, 1,'long');
                                FileHeaderLength        =    fread(fid, 1,'ushort');
                                GlobSpecBlockNum        =    fread(fid, 1,'ushort');
                                TrialsNum               =    fread(fid, 1,'ushort');
                                CommLength              =    fread(fid, 1,'ushort');
                                GlobSpecBlockLength     =    fread(fid,GlobSpecBlockNum, 'ushort');
                                TrialBegin              =    fread(fid,TrialsNum,'long'); 
                                % TrialBegin=[236 24962 67164 110434 150948 193110 231488 274422 318044 354822 388976 431166 465916 500726 534084 566930 595228 639762 681224 718182]';
                                
                                
                                if unitret('NoSeparator',fid)
                                        strerr = ['FORMAT ERROR on FILEHEADER: file ', filename, ' skipped'];
                                        unitret('errormessage',strerr,'ERROR');
                                        fclose(fid);
                                        return;
                                end;
                                
                                %disp('FILE HEADER BLOCK .... OK');
                                % ---------- READING THE FILE SPECIFICATION  BLOCK -----------------------
                                
                                blockSTART              =    ftell(fid);
                                
                                FileName                =    (setstr(fread(fid, 14,'char')))';
                                FileDate                =    (setstr(fread(fid, 10,'char')))';
                                RunModName              =    (setstr(fread(fid, 10,'char')))';
                                VideoFramePeriod        =    fread(fid,1,'float');
                                ViewDistance            =    fread(fid,1,'float');
                                TimeFirstSample         =    fread(fid,1,'float');
                                NumSamp2Frame           =    fread(fid,1,'ushort');
                                HorizVisualFieldLoc     =    fread(fid,1,'float');
                                VertVisualFieldLoc      =    fread(fid,1,'float');
                                HorizPosLED             =    fread(fid,1,'float');
                                VertPosLED              =    fread(fid,1,'float');
                                HorizEyePosGain         =    fread(fid,1,'float');
                                VertEyePosGain          =    fread(fid,1,'float');
                                EyetrackArbDef          =    fread(fid,1,'float');
                                EyetrackArbV0           =    fread(fid,1,'ushort');
                                Empty                   =    fread(fid,1,'ushort');
                                LeftEdge                =    fread(fid,1,'ushort');
                                BottomEdge              =    fread(fid,1,'ushort');
                                RightEdge               =    fread(fid,1,'ushort');
                                TopEdge                 =    fread(fid,1,'ushort');
                                StabFlag                =    fread(fid,1,'ushort');
                                Empty                   =    fread(fid,1,'ushort');     % temporal type: flag
                                Empty                   =    fread(fid,1,'ushort');     % spatial type: flag
                                CompFlag                =    fread(fid,1,'ushort');
                                DateTime                =    (setstr(fread(fid, 18,'uchar')))';
                                EyePer                  =    fread(fid,1,'float');
                                SpikePer                =    fread(fid,1,'float');
                                ShapePer                =    unifread([fid, 1,blockSTART,GlobSpecBlockLength],'float');
                                FixationType		=    unifread([fid, 1,blockSTART,GlobSpecBlockLength],'ushort');
                                
                                if ~ShapePer,
                                        ShapePer =  1000/10000;		%ms
                                end;
                                
                                if unitret('NoSeparator',fid)
                                        strerr = ['FORMAT ERROR on file spec block: ', filename, ' skipped'];
                                        unitret('errormessage',strerr,'ERROR');
                                        fclose(fid);
                                        return;
                                end;
                                % disp('FILE SPECIFICATION  BLOCK ....OK');
                                
                                % ---------- READING THE FILE COMMENT  BLOCK -----------------------
                                
                                blockSTART     	   =    ftell(fid);
                                Comments = (setstr(fread(fid,CommLength, 'char')))';
                                
                                if unitret('NoSeparator',fid)
                                        strerr = ['FORMAT ERROR on comments: file ', filename, ' skipped'];
                                        unitret('errormessage',strerr,'ERROR');
                                        fclose(fid);
                                        return;
                                end;
                                
                                
                                % disp('FILE COMMENT  BLOCK ...OK');
                                % READING THE SPECIFIC TRIAL "tnum"
                                
                                TempPos = ftell(fid);
                                
                                if tnum > TrialsNum,
                                        error('Invalid trial number');
                                end;
                                Status = fseek(fid, TrialBegin(tnum),-1);
                                if Status ~=0,
                                        errordlg('File format error','Error');
                                        return
                                end;
                                
                                %--------- READING THE TRIAL HEADER ----------------------------------------
                                blockSTART		        =    ftell(fid);
                                fseek(fid,blockSTART+2, -1);
                                TrialHeaderLength             =    fread(fid, 1,'ushort');
                                fseek(fid,blockSTART, -1);
                                
                                SerNum                          =    fread(fid,1,'ushort');
                                TrialHeaderLength               =    fread(fid,1,'ushort');
                                ParamBlockNum                   =    fread(fid,1,'ushort');
                                DataBlockNum                    =    fread(fid,1,'ushort');
                                ParamBlockLength                =    (fread(fid,ParamBlockNum,'ushort'))';
                                DataBlockLength                 =    (fread(fid,DataBlockNum,'ushort'))';
                               
                                
                                if unitret('NoSeparator',fid)
                                        strerr = ['FORMAT ERROR on Trial Header: ', filename, ' skipped'];
                                        unitret('errormessage',strerr,'ERROR');
                                        fclose(fid);
                                        return;
                                end;
                                
                                % disp('COMMON TRIAL DATA ...OK');
                                
                                %--------- READING THE TRIAL PARAMETERS ----------------------------------------
                                blockSTART     	   		=    ftell(fid);
                                
                                TrialTime               =    (setstr(fread(fid,10, 'char')))';
                                TrialDuration           =    fread(fid,1,'ushort');
                                OneStimDuration         =    fread(fid,1,'ushort');
                                TimeBetweenStim         =    fread(fid,1,'ushort');
                                Tilt                    =    fread(fid,1,'ushort');
                                RadialBoxSize           =    fread(fid,1,'ushort');
                                PerpenBoxSize           =    fread(fid,1,'ushort');
                                XStartPos               =    fread(fid,1,'ushort');
                                YStartPos               =    fread(fid,1,'ushort');
                                ExtentStimMotion        =    fread(fid,1,'short');
                                StimVelocity            =    fread(fid,1,'short');
                                ColorCode               =    fread(fid,1,'ushort');
                                FgrRedInt               =    fread(fid,1,'float');
                                FgrGreenInt             =    fread(fid,1,'float');
                                FgrBlueInt              =    fread(fid,1,'float');
                                BckgrRedInt             =    fread(fid,1,'float');
                                BckgrGreenInt           =    fread(fid,1,'float');
                                BckgrBlueInt            =    fread(fid,1,'float');
                                ElemRedInt              =    fread(fid,1,'float');
                                ElemGreenInt            =    fread(fid,1,'float');
                                ElemBlueInt             =    fread(fid,1,'float');
                                %               * * Applicable to Sinusoid & Gabor:  * *
                                SpatialFreq             =    fread(fid,1,'float');
                                PhRed                   =    fread(fid,1,'ushort');
                                PhGreen                 =    fread(fid,1,'ushort');
                                PhBlue                  =    fread(fid,1,'ushort');
                                StnDiv                  =    fread(fid,1,'float');
                                Contrast                =    fread(fid,1,'float');
                                TempFreq                =    fread(fid,1,'float');
                                %            * * Applicable to REGULAR: * *
                                ElemLength              =    fread(fid,1,'float');
                                ElemWidth               =    fread(fid,1,'float');
                                SpLengthDirec           =    fread(fid,1,'float');
                                SpWidthDirect           =    fread(fid,1,'float');
                                %            * * Additional timing values: * *
                                StartEyeData            =    fread(fid,1,'float');
                                StartSpikeData          =    fread(fid,1,'float');
                                EndSpikeData            =    fread(fid,1,'float');
                                TimeCode                =    fread(fid,1,'ushort');
                                StimTempType            =    fread(fid,1,'ushort');
                                StimSpatType            =    fread(fid,1,'ushort');
                                EyeChoice               =    fread(fid,1,'ushort');
                                %            * * Additional positioning info: * *
                                SweepFract              =    fread(fid,1,'float');
                                TrigTech  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'ushort');
                                SpikeTrig  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                                ShapeTrig  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                                ShapeHist  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                                ShapeLen  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'short');
                                ShapeOff  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'short');
                                
                                FirstStimTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'short');
                                AngleFix(tnum)			=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                                FixChangeTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                                SteadyFixTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                                FixNoChangeTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                                TotalFixDistance(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                                FixFraction(tnum)		=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                                
                                                
                        if unitret('NoSeparator',fid)
                                strerr = ['FORMAT ERROR on Trial Param: ', filename, ' skipped'];
                                unitret('errormessage',strerr,'ERROR');
                                fclose(fid);
                                return;
			end;
			
                        % disp('TRIAL PARAMETERS  ...OK');

			% fix stimulus duration to interger multiple of frame period
			% OneStimDuration = OneStimDuration - mod(OneStimDuration,VideoFramePeriod)
			% TimeBetweenStim = TimeBetweenStim - mod(TimeBetweenStim,VideoFramePeriod)
			ValidDurations = 0:VideoFramePeriod:5000;
			OneStimDuration = ValidDurations(abs(OneStimDuration-ValidDurations)==min(abs(OneStimDuration-ValidDurations)));
			TimeBetweenStim = ValidDurations(abs(TimeBetweenStim-ValidDurations)==min(abs(TimeBetweenStim-ValidDurations)));
			

			[sid, StimulusName] = unitret('ttst2sid',StimTempType,StimSpatType);
				
			STIM(tnum).Format = '2.0';
			STIM(tnum).FileName = FileName;
			
			STIM(tnum).SID = sid;
			STIM(tnum).StabFlag = StabFlag;
			STIM(tnum).StimulusName = StimulusName;
			STIM(tnum).OneStimDuration = OneStimDuration;
			STIM(tnum).TimeBetweenStim = TimeBetweenStim;
			STIM(tnum).Tilt = Tilt;
			STIM(tnum).RadialBoxSize = RadialBoxSize;
			STIM(tnum).PerpenBoxSize = PerpenBoxSize;
			STIM(tnum).XStartPos = XStartPos;
			STIM(tnum).YStartPos = YStartPos;
			STIM(tnum).ExtentStimMotion = ExtentStimMotion;
			STIM(tnum).StimVelocity = StimVelocity;
			STIM(tnum).FgrRedInt = FgrRedInt;
			STIM(tnum).FgrGreenInt = FgrGreenInt;
			STIM(tnum).FgrBlueInt = FgrBlueInt;
			STIM(tnum).BckgrRedInt = BckgrRedInt;
			STIM(tnum).BckgrGreenInt = BckgrGreenInt;
			STIM(tnum).BckgrBlueInt = BckgrBlueInt;
			STIM(tnum).SpatialFreq = SpatialFreq;
			STIM(tnum).TempFreq = TempFreq;
			STIM(tnum).Phase = PhRed;
			STIM(tnum).Contrast = Contrast;
			STIM(tnum).StimTempType = StimTempType;
			STIM(tnum).StimSpatType = StimSpatType;

			if strcmp(RunModName(1:3),'sys')
				if strcmp(RunModName(8),'3')

					STIM(tnum).TE_scale	= SweepFract;
					STIM(tnum).TE_frames	= TrigTech;
					STIM(tnum).TE_length	= SpikeTrig;
					STIM(tnum).TE_offset = ShapeTrig;
					STIM(tnum).TE_file = ShapeHist;
				end
			end

			if ~(strcmp(RunModName(1:3),'sys') | strcmp(RunModName(1:3),'no ')),	% old system
				emformat = 'short';
				emlen = 2;
				spformat = 'long';
			else					% new system (TDT-VSG)
				emformat = 'float32';
				emlen = 4;
				spformat = 'float32';
			end                        
                        
                        %--------- MEMORY ALLOCATION -----------------
                        MaxSampNum =max(DataBlockLength(1)/emlen, DataBlockLength(2)/emlen); 
                        HorizEyePos = zeros(MaxSampNum,1);
                        VertEyePos = zeros(MaxSampNum,1);
                        %Stimulus =  zeros(ceil(TrialDuration/EyePer),1);
                        SpikeArrTime = zeros(DataBlockLength(3)/4,1);



                        %--------- READING THE HORIZONTAL EYE POSITION ----------------------------------------
                        
                        HorizEyePos             =    (fread(fid,DataBlockLength(1)/emlen,emformat))';
                        
                        if unitret('NoSeparator',fid)
                                strerr = ['FORMAT ERROR on Hor. Eye Movement: ', filename, ' skipped'];
                                unitret('errormessage',strerr,'ERROR');
                                fclose(fid);
                                return;
                        end;
                        
                        
                        %----------- READING THE VERTICAL EYE POSITION ---------------------------------------
                        
                        VertEyePos              =    (fread(fid,DataBlockLength(2)/emlen,emformat))';
                        
                        if unitret('NoSeparator',fid)
                                strerr = ['FORMAT ERROR on Vert. Eye Movement: ', filename, ' skipped'];
                                unitret('errormessage',strerr,'ERROR');
                                fclose(fid);
                                return;
                        end;
			
			HorizEyePos = (HorizEyePos - EyetrackArbV0.*ones(size(HorizEyePos)))./(HorizEyePosGain*EyetrackArbDef);
                        % disp('HORIZONTAL EYE POSITION  ...OK');
                        
                        VertEyePos = (VertEyePos - EyetrackArbV0.*ones(size(VertEyePos)))./(VertEyePosGain*EyetrackArbDef);
                        % disp('VERTICAL EYE POSITION ...OK');
                        
                        % ------------ READING THE SPIKES DATA ------------------------------------------------
                        
                        SpikeArrTime            =    (fread(fid,DataBlockLength(3)/4,spformat))';
                        
                        if unitret('NoSeparator',fid)
                                strerr = ['FORMAT ERROR on SPIKES DATA: ', filename, ' skipped'];
                                unitret('errormessage',strerr,'ERROR');
                                fclose(fid);
                                return;
                        end;
                        
                        % disp('SPIKE ARRIVAL TIMES  ...OK');
                        % disp('OK');
                        
                        
                        SpikeArrTime = SpikePer.*SpikeArrTime;
                        
			if emlen==2,	% old system
                        	%------Charley's bug!!!
                        	if (TrialDuration < max(SpikeArrTime)) | (TrialDuration > 10000), 
                                	TrialDuration = max(SpikeArrTime); 
                        	end;
			end
                        
                        if (~isnan(ShapePer) ) %%%!!!
                                
                                % ------------ READING THE SPIKE SHAPE TIMING DATA ------------------------------------------------
                                
                                ShapeArrTime            =    (fread(fid,DataBlockLength(4)/4,'long'))';
                                
                                if unitret('NoSeparator',fid)
                                        strerr = ['FORMAT ERROR on SHAPE TIMING : file ', filename, ' skipped'];
                                        unitret('errormessage',strerr,'ERROR');
                                        fclose(fid);
                                        return;
                                end;
                                
                                ShapeArrTime = ShapePer.*ShapeArrTime;
                                %disp('SHAPE ARRIVAL TIMES  ...OK');
                                
                                
                                % ------------ READING THE SPIKE SHAPE VALUES DATA ------------------------------------------------
                                
                                ShapeAmp            =    (fread(fid,DataBlockLength(5)/2,'short'))';
                                if unitret('NoSeparator',fid)
                                        strerr = ['FORMAT ERROR on SHAPE VALUES: file ', filename, ' skipped'];
                                        unitret('errormessage',strerr,'ERROR');
                                        fclose(fid);
                                        return;
                                end;
                                
                                
                                %disp('SHAPE AMPLITUDE ...OK');
                                %----------------- END READING TRIAL ---------------------------------------------
                                
                        end; % of Read Shape?

                        % SET DRAWING rectangle:--------------------------------------------------------------
                        
                        rect = [0+wi+numcol*(wb+wi) 1-(hi+hb+numrow*(hb+hi)) wb hb];
                        
                        if ~DefValues(30)
                                
                                % CONSIDER THE TIME AXIS... ---------------------------------------------------------
                                EyeTimeAxis = StartEyeData + EyePer.*[0:length(HorizEyePos)-1];
                                %	if DataBlockLength(3),
                                
                                % STORING SPIKES DATA
                                nrow = size(SPIKES,1);                %=TrialsNum of the given file
                                ncol = size(SPIKES,2);
                                
                                
                                SpikesNum = DataBlockLength(3)/4;
                                nncol = max((SpikesNum +3), ncol);
                                tmp = zeros(tnum,nncol);
                                
                                for i=1:nrow,
                                        tmp(i,1:ncol) = SPIKES(i,:);
                                end;
                                SPIKES = [];
                                SPIKES = tmp;
                                
                                SPIKES(tnum,1) = DataBlockLength(3)/4;
                                SPIKES(tnum,2) = StartSpikeData;
                                SPIKES(tnum,3) = EndSpikeData;
                                SPIKES(tnum,4:SpikesNum + 3) = SpikeArrTime;
                                MOTION(tnum,1) = StimVelocity+0.0001;	% sometimes, the velocity is zeroed
                                MOTION(tnum,2)  = Tilt;
                                MOTION(tnum,3) = PerpenBoxSize;
                                
                                %---------- HISTOGRAM COMPUTING -------------------------
                                if DataBlockLength(3),
                                        
                                        if DefValues(1)
                                                bins=(StartSpikeData:DefValues(1):EndSpikeData);
                                                [SpikeHist,N]=hist(SpikeArrTime,bins);
                                                [xx,yy] = bar(N,SpikeHist);
                                                
                                        else
                                                xx = zeros(1,3*SpikesNum);
                                                xx(1:3:(3*SpikesNum-2)) = SPIKES(tnum,4:(SpikesNum + 3));
                                                xx(2:3:(3*SpikesNum-1)) = SPIKES(tnum,4:(SpikesNum + 3));
                                                xx(3:3:(3*SpikesNum))   = SPIKES(tnum,4:(SpikesNum + 3));
                                                yy = zeros(1,3*SpikesNum);
                                                yy(2:3:(3*SpikesNum-1)) = ones(1,SpikesNum); 
                                        end;    
                                end;
                                
                                
                                % STORING STIMULUS DATA;
                                
                                % IF TIME BETWEEN STIMULUS = 0....
                                if TimeBetweenStim == 0,
                                        TimeBetweenStim = OneStimDuration; % for plotting
				end;
				
                                % IF FLAG 'NO MOTION' WAS OBSERVED;
                                if StimTempType==0,             % no motion
                                        StimArrTime=0;
                                        StimNum = 1;
                                        OneStimDuration=0;
                                        TimeBetweenStim=TrialDuration;
                                end;
                                % IF STIMULUS DURATION = 0;
                                if (OneStimDuration+TimeBetweenStim==0)
                                        StimArrTime=0;
                                        StimNum = 1;
                                        OneStimDuration=0;
                                        TimeBetweenStim=TrialDuration;
                                end;
                                StimArrTime = [0:OneStimDuration+TimeBetweenStim:TrialDuration]; %% 08.08.02 changed from TrialDuration-1
                                StimNum = length(StimArrTime);
                                
                                ncol = size(STIMULUS,2);
                                nrow = size(STIMULUS,1);                %=TrialsNum of the given file
                                
                                % put new stimuli vector to the global STIMULUS array    
                                nncol = max((StimNum +4), ncol);
                                tmp = zeros(tnum,nncol);
                                
                                for i=1:nrow,
                                        tmp(i,1:ncol) = STIMULUS(i,:);
                                end;
                                STIMULUS = [];
                                STIMULUS = tmp;
                                
                                
                                
                                STIMULUS(tnum,1) = StimNum;
                                STIMULUS(tnum,2) = TrialDuration;
                                STIMULUS(tnum,3) = OneStimDuration;
                                STIMULUS(tnum,4) = TimeBetweenStim;
                                STIMULUS(tnum,5:(StimNum + 4)) = StimArrTime;
                                Front = 0;
                                
                                SINDATA(tnum,1) = TrialDuration;
                                SINDATA(tnum,2) = TempFreq;
                                SINDATA(tnum,3) = StimSpatType;
                                
                                SpStim = round(OneStimDuration/EyePer); 
                                SpPause = round(TimeBetweenStim/EyePer);
                                SpStimAll = ceil(TrialDuration/EyePer);
                                if(SpStimAll <= 1),
                                        axis off;
                                        text(.3, .5, 'File does not contain any data');
                                        return;
                                end;
                                
                                ax = axes('Position',rect, 'XLim', [0 STIMULUS(tnum,2)], 'YLim',[DefValues(7) DefValues(10)]);
                                if DefValues(24), 
                                        set(ax,'XGrid','on','Xtick',[0:100:STIMULUS(tnum,2)],...
                                                'XtickLabelMode','manual','XTickLabels',[]);	
                                end;
                                strax = sprintf(' %17.13f',ax);
                                button_down_fcn = ['unitret(''pressed'',',num2str(tnum), ',', strax, ');'];
                                set(ax,'ButtonDownFcn', button_down_fcn);
                                
                                
                                % PLOTTING THE EYE MOVEMENT
                                
                                HorEyeMov=line(EyeTimeAxis,HorizEyePos,'Color',[0 .502 0],'ButtonDownFcn',button_down_fcn);
                                VerEyeMov=line(EyeTimeAxis,VertEyePos,'Color','m','ButtonDownFcn',button_down_fcn,'LineWidth',1);
                                
                                eyepos = [EyeTimeAxis; HorizEyePos; VertEyePos];  
                                if DefValues(95), % Interpolate EM
                                        eyepos = unitret('interpolate',eyepos); 
                                end
                                
                                if DefValues(94), % Smoothing
                                        eyepos(2,:) = unitret('smooth',eyepos(2,:));
                                        eyepos(3,:) = unitret('smooth',eyepos(3,:));
                                        line(eyepos(1,:),eyepos(2,:),'Color','k','ButtonDownFcn',button_down_fcn,'LineWidth',0.5);
                                        line(eyepos(1,:),eyepos(3,:),'Color','k','ButtonDownFcn',button_down_fcn,'LineWidth',0.5);
                                end
                                
                                % in order to draw eye movement in selected segment, we must store the pointers to the eye 
                                % movements lines as userdata of axes.
                                set(ax,'UserData',[HorEyeMov VerEyeMov]);
                                
                                
                                
                                
                                % set(ax,'UserData',[HorEyeMov VerEyeMov]);
                                
                                
                                %---------------- SPIKES HISTOGRAM DRAWING --------------------------------------
                                if SpikesNum,
                                        
                                        SpikeAmp = (DefValues(10) - DefValues(7)) / (6*max(yy));
                                        if DefValues(78), % Display Spikes
                                                h = line(xx,SpikeAmp*yy+DefValues(7),'Color','r',...
                                                        'ButtonDownFcn',button_down_fcn,'LineWidth',.5);
                                        end
                                end;
                                
                                %-------------- IF some TRIALS WERE ALREADY MARKED... -----------
                                nr=size(MarkedData,1);
                                for(i=1:nr),
                                        if(tnum==MarkedData(i,1)),
                                                xmn=MarkedData(i,3);
                                                xmx=MarkedData(i,4);
                                                x1 = [xmn+10 xmn+10 xmx-10 xmx-10];
                                                y1 = [DefValues(7) DefValues(10)  DefValues(10) DefValues(7) ];
                                                
                                                line(x1,y1,'Color','b','ButtonDownFcn',button_down_fcn);
                                                %		unitret('grid',[xmn+10 xmx-10 DefValues(7) DefValues(10) 100],'k');
                                        end;
                                end;
                                
                                
                                %--------------  MARK SAME SEGMENTS -----------
                                if DefValues(63)
                                        nr=size(REFMAT,1);
                                        for(i=1:nr),
                                                if(tnum==REFMAT(i,1)),
                                                        xmn=REFMAT(i,2);
                                                        xmx=REFMAT(i,3);
                                                        Mod=REFMAT(i,4);
                                                        x1 = [xmn+10 xmn+10 xmx-10 xmx-10];
                                                        y1 = [DefValues(7) DefValues(10)  DefValues(10) DefValues(7) ];		
                                                        line(x1,y1,'Color',[0.5020 0 1.0000],'ButtonDownFcn',button_down_fcn);
                                                        unitret('fill_current_segment',tnum,gca,[xmn xmx Mod i])
                                                        
                                                        
                                                end;
                                        end;
				end

				yl = get(ax,'Ylim');
                                %---------------- STIMULI DRAWING ----------------------------------------------
                                if (OneStimDuration > 50)		% avoid multiple drawing while flash
                                        for i=1:StimNum,
                                                Slope = Front+SpStim;
                                                if Slope > SpStimAll;
                                                        Slope = SpStimAll;
                                                end;
                                                
                                                x = [StimArrTime(i) (OneStimDuration+StimArrTime(i)-1)];
                                                y = [ones(size(x))+DefValues(7)];
                                                line(x,y,'Color',[0 .5 0],'ButtonDownFcn',button_down_fcn,'LineWidth',1.5);
                                                
                                                x = [(StimArrTime(i)+OneStimDuration) (StimArrTime(i)+OneStimDuration+TimeBetweenStim-1)];
                                                y = [ones(size(x))+DefValues(7)];
                                                line(x,y,'Color','b','ButtonDownFcn',button_down_fcn,'LineWidth',3.5);
                                                
                                                Front = Slope+SpPause;
						if DefValues(159), % automatic select of ALL data
							switch DefValues(26),
							case 0 % driven activity
								if (StimArrTime(i)+OneStimDuration)<=TrialDuration,
									unitret('pressed',tnum,ax,[StimArrTime(i)+1 yl(1)]);
								end
								if (StimArrTime(i)+OneStimDuration+TimeBetweenStim)<=TrialDuration,
									unitret('pressed',tnum,ax,[StimArrTime(i)+OneStimDuration+1 yl(1)]);
								end
								% changed 08.08.02
								% if (StimArrTime(i)+OneStimDuration)<TrialDuration,
								%	unitret('pressed',tnum,ax,[StimArrTime(i)+1 yl(1)]);
								% end
								% if (StimArrTime(i)+OneStimDuration+TimeBetweenStim+1)<TrialDuration,
								%	unitret('pressed',tnum,ax,[StimArrTime(i)+OneStimDuration+1 yl(1)]);
								% end
							case {2,8} % whole trial, all cycles
								if i==1
									unitret('pressed',tnum,ax,[1000 yl(1)]);
								end
							end
							
						end
                                        end
				end

                                 
                                for lineY=0:DefValues(39):DefValues(10)
                                        line([0 STIMULUS(tnum,2)],[0+lineY 0+lineY],'Color','k','LineStyle',':',...
                                                'ButtonDownFcn',button_down_fcn); 
                                end;  
                                
                                for lineY= -DefValues(39):-DefValues(39):DefValues(7)
                                        line([0 STIMULUS(tnum,2)],[0+lineY 0+lineY],'Color','k','LineStyle',':',...
                                                'ButtonDownFcn',button_down_fcn); 
                                end;  
                                
                                %
                                
                                set(text,'String',['Trial #',num2str(tnum)],...
                                        'units','normal','Position',[.2 .9]);
                                
                                unitret('mark_select',DefValues(26),0);
                                unitret('figname');
                                
                                % if saccade searching...--------------------------------
                                
                                SaccadesDetect = DefValues(40);
                                if (SaccadesDetect),
                                        unitret('saccades_detect',eyepos,tnum,ax);
                                end;
                               
                                % uncomment next line if you want SEM structure to be saved to *.mat file
                                % yl = get(ax,'Ylim'); unitret('pressed',tnum,ax,[1000 yl(1)]);
                                
                        else
                                %----------------- draw Shape Strips   
                                
                                
                                arg2 = [length(SpikeArrTime), SpikeArrTime, length(ShapeAmp)/ShapeLen, ShapeAmp];
                                axes('Position',rect,'UserData',arg2);
                                
                                
                                StripPlotStart = 0;
                                StripPlotWindow = DefValues(31);
                                arg1 = [StripPlotStart,StripPlotWindow,ShapePer,ShapeLen,ShapeOff];
                                
                                if (~DefValues(34)), 		% don't shrink the time axis
                                        unitret('draw_stripshape',arg1);
                                else
                                        unitret('draw_shrinkedshape',arg1);
                                end;
                                
                                set(gcf, 'Name', ['Shapes plot: ',get(TRET_DAT(1),'Name')]);
                                
                                set(text,'String',['Trial #',num2str(tnum)],...
                                        'units','normal','Position',[.2 .9]);

				
					
					
                                
                        end;        
                        
                        
                end;
        end;     
end;

if TrialsNum > DefValues(4)
        if nextfig <= TrialsNum,
                uicontrol(Fig2, 'Units','Normalized','Position',[.85 .02, .1 .05],'String','>>',...
                        'Callback',['unitret(''redraw_exp'',', num2str(nextfig), ');']);
        end;
        
        if in1 > DefValues(4)
                uicontrol(Fig2, 'Units','Normalized','Position',[.7 .02, .1 .05],'String','<<',...
                        'Callback',['unitret(''redraw_exp'',', num2str(prevfig), ');']);
                
        end;
end;

% Toolbar
icons = {	'text(.5,.5,''desel'',''Horiz'',''center'',''FontWeight'',''normal'')'
		'text(.5,.5,''cgf'',''Horiz'',''center'',''FontWeight'',''normal'')'
		'text(.5,.5,''drifts'',''Horiz'',''center'',''FontWeight'',''normal'')'};
callbacks = {	'unitret(''mark_deselect'');'
		'unitret(''close_all_graphic_windows'');'
		'ud=get(0,''UserData''); ud(145) = 1; set(0,''userdata'',ud); unitret(''update'',0,2);'};
presstypes = [	'flash'; 'flash'; 'flash' ];

hToolbar = btngroup('GroupID', 'Toolbar', 'ButtonID', ...
	['B1';'B2';'B3'], 'Callbacks', char(deal(callbacks)), 'ButtonColor', [0.5 0.5 1],...
	'Position', [.01 .01 .07*size(callbacks,1) .03 ], 'IconFunctions',char(deal(icons)),...
	'PressType',presstypes, 'GroupSize', [1 size(callbacks,1)],'BevelWidth',0.02);
% End Toolbar

if DefValues(30),
        if ~DefValues(34),
                if length(TRET_DAT) < 10,
                        slinit = 0;
                else
                        slinit = TRET_DAT(10);
                end;
                sl = uicontrol(Fig2, 'Units','Normalized','Position',[.14 .02, .5 .04],'style','slider',...
                        'min',0,'max', EndSpikeData-DefValues(31),...
                        'UserData',[ShapePer,ShapeLen,ShapeOff],'value',slinit);
                strsl = sprintf(' %17.13f',sl);
                
                
                edt = uicontrol(Fig2, 'Units','Normalized','Position',[.02 .02, .1 .04],'style','edit',...
                        'string',slinit,'UserData',[ShapePer,ShapeLen,ShapeOff],'BackgroundColor',[.9 .9 .9]);
                stredt= sprintf(' %17.13f',edt);  
                
                set(sl,'Callback',...
                        ['global TRET_DAT; TRET_DAT(10) = get(gco,''value'');',...
                                'set(',stredt,',''string'',num2str(TRET_DAT(10)));drawnow;',...
                                'unitret(''shape_shift'');']); 
                
                set(edt,'Callback',...
                        ['global TRET_DAT;TRET_DAT(10) = str2num(get(gco,''string''));',...
                                'set(',strsl,',''value'',TRET_DAT(10));drawnow;unitret(''shape_shift'');']);
                
                
        end;  
end;

drawnow
if DefValues(181) & ~DefValues(141)	% Autoscroll: go to the next
					% trial and NOT batch processing
        
        
           if nextfig <= TrialsNum 
               unitret('redraw_exp',nextfig);
           end                    		     
        
end;



set(Fig2, 'Pointer','arrow');
set(TRET_DAT(1),'Pointer','Arrow');

                        
%---------------------------------------------------------------------------------------------------------------------------------------------------------------     

elseif(strcmp(action,'update'))
        % if in3 = 1 do not check min and max values 
        set(gcf,'Pointer','Watch');
        if (in1),
                if nargin < 3,
                        in3 = 0;
                end
                
                h=get(gcf,'CurrentObject');
                
                
                newdata = str2num(deblank(get(h,'String')));
                if (in3)
                        DefValues(in1) = newdata;
                        set(0,'UserData',DefValues);  
                elseif (newdata >= DefValues(in1+1)) & (newdata <= DefValues(in1+2)),
                        DefValues(in1) = newdata;
                        set(0,'UserData',DefValues);       
                else
                        set(h,'String',num2str(DefValues(in1)));
                end;
        else,
                
                if in2 ==2, % Raw data graphs will be updated
                        first = get(TRET_DAT(11),'userdata'); 
                        unitret('redraw_exp',first); 
                end;
                if in2 == 3, % Spike graphs will be updated
                        unitret('redraw_spk',1);
                end
                if in2 == 4 % Spectra setup, no update 
                end;
        end;
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
        
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
        
elseif(strcmp(action,'fulldump'))
        
        
        trials_inf = get(TRET_DAT(1),'UserData');
        fid = trials_inf(1);
        TrialsNum = trials_inf(2);
        TrialBegin = trials_inf(3:TrialsNum+2);
        
        if in1==0,
                str = ['1'];
                if TrialsNum >1,    
                        for(i=2:TrialsNum),
                                str = [str, '|', num2str(i)];      
                        end;
                end;
                Fig1 = figure('Backingstore','on','Color',[ 0.6706    0.8471    0.6902],...
                        'Units','Normal','Position',[0.01 0.04 .4 .9],'Resize','On', 'Name',...
                        'Trial Dump','MenuBar','none','Number','off',...
                        'DefaultAxesPosition',[0 0 1 1],'visible','off');
                figcounter = figcounter + 1; 
                set(gcf,'Pointer','Watch');
                
                
                %uicontrol(Fig1,'Style','text','Position',[.2 .96 .3 .03],'Backgroundcolor',[ 0.6706    0.8471    0.6902],'Foregroundcolor','b',...
                %	       'string','TRIAL #:','units','normal'); 
                
                cla                 
                                
                if strcmp(v(1),'5'),
                        uicontrol(Fig1,'Style','Popupmenu','Units','Normalized','Position',[.5 .5 .3 .5],'String',str,'Callback',...
                                ['l = get(gcf, ''CurrentObject''); s = get(l,''value''); unitret(''fulldump'',s);']);
                        
                else
                        uicontrol(Fig1,'Style','Popupmenu','Units','Normalized','Position',[.5 .95 .3 .5],'String',str,'Callback',...
                                ['l = get(gcf, ''CurrentObject''); s = get(l,''value''); unitret(''fulldump'',s);']);
                        
        end
        
        uicontrol(Fig1,'Style','Pushbutton','Units','Normalized','String','OK','Position',[.3 .02 .4 .03],...
                'Callback','delete(gcf);');
        
        unitret('fulldump',1);
else,
        oldpos = ftell(fid);
        tnum = in1;
        
        if tnum > TrialsNum,
                errordlg('Invalid trial number');
        end;
        Status = fseek(fid, TrialBegin(tnum),-1);
        if Status ~=0,
                errordlg('File format error','Error');
                return
        end;
        
        %--------- READING THE TRIAL HEADER ----------------------------------------
        blockSTART		        =    ftell(fid);
        fseek(fid,blockSTART+2, -1);
        TrialHeaderLength             =    fread(fid, 1,'ushort');
        fseek(fid,blockSTART, -1);
        
        
        SerNum                          =    fread(fid,1,'ushort');
        TrialHeaderLength               =    fread(fid,1,'ushort');
        ParamBlockNum                   =    fread(fid,1,'ushort');
        DataBlockNum                    =    fread(fid,1,'ushort');
        ParamBlockLength                =    (fread(fid,ParamBlockNum,'ushort'))';
        DataBlockLength                 =    (fread(fid,DataBlockNum,'ushort'))';
        
        if unitret('NoSeparator',fid)
                strerr = ['FORMAT ERROR on Trial Header: ', filename, ' skipped'];
                unitret('errormessage',strerr,'ERROR');
                %fclose(fid);
                return;
        end;
        
        % disp('COMMON TRIAL DATA ...OK');
        
        %--------- READING THE TRIAL PARAMETERS ----------------------------------------
        blockSTART     	   		=    ftell(fid);
        
        TrialTime               =    (setstr(fread(fid,10, 'char')))';
        TrialDuration           =    fread(fid,1,'ushort');
        OneStimDuration         =    fread(fid,1,'ushort');
        TimeBetweenStim         =    fread(fid,1,'ushort');
        Tilt                    =    fread(fid,1,'ushort');
        RadialBoxSize           =    fread(fid,1,'ushort');
        PerpenBoxSize           =    fread(fid,1,'ushort');
        XStartPos               =    fread(fid,1,'ushort');
        YStartPos               =    fread(fid,1,'ushort');
        ExtentStimMotion        =    fread(fid,1,'short');
        StimVelocity            =    fread(fid,1,'short');
        ColorCode               =    fread(fid,1,'ushort');
        FgrRedInt               =    fread(fid,1,'float');
        FgrGreenInt             =    fread(fid,1,'float');
        FgrBlueInt              =    fread(fid,1,'float');
        BckgrRedInt             =    fread(fid,1,'float');
        BckgrGreenInt           =    fread(fid,1,'float');
        BckgrBlueInt            =    fread(fid,1,'float');
        ElemRedInt              =    fread(fid,1,'float');
        ElemGreenInt            =    fread(fid,1,'float');
        ElemBlueInt             =    fread(fid,1,'float');
        %               * * Applicable to Sinusoid & Gabor:  * *
        SpatialFreq             =    fread(fid,1,'float');
        PhRed                   =    fread(fid,1,'ushort');
        PhGreen                 =    fread(fid,1,'ushort');
        PhBlue                  =    fread(fid,1,'ushort');
        StnDiv                  =    fread(fid,1,'float');
        Contrast                =    fread(fid,1,'float');
        TempFreq                =    fread(fid,1,'float');
        %            * * Applicable to REGULAR: * *
        ElemLength              =    fread(fid,1,'float');
        ElemWidth               =    fread(fid,1,'float');
        SpLengthDirec           =    fread(fid,1,'float');
        SpWidthDirect           =    fread(fid,1,'float');
        %            * * Additional timing values: * *
        StartEyeData            =    fread(fid,1,'float');
        StartSpikeData          =    fread(fid,1,'float');
        EndSpikeData            =    fread(fid,1,'float');
        TimeCode                =    fread(fid,1,'ushort');
        StimTempType            =    fread(fid,1,'ushort');
        StimSpatType            =    fread(fid,1,'ushort');
        EyeChoice               =    fread(fid,1,'ushort');
        %            * * Additional positioning info: * *
        SweepFract              =    fread(fid,1,'float');
        TrigTech  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'ushort');
        SpikeTrig  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
        ShapeTrig  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
        ShapeHist  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
        ShapeLen  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'short');
        ShapeOff  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'short');
        
        FirstStimTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'short');
        AngleFix(tnum)			=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
        FixChangeTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
        SteadyFixTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
        FixNoChangeTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
        TotalFixDistance(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
        FixFraction(tnum)		=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
        
        
        
        
        
        if unitret('NoSeparator',fid)
                strerr = ['FORMAT ERROR on Trial Param: ', filename, ' skipped'];
                unitret('errormessage',strerr,'ERROR');
                fclose(fid);
                return;
        end;
        % disp('TRIAL PARAMETERS  ...OK');


        
        % textout on the left panel:
        cla;
	set(text,'Position',[.3 .98],'Color','b','string','TRIAL #:'); 

	
        set(text,'Position',[.02 .93],'Color','r','string','Trial Time:'); 
        set(text,'Position',[.52 .93],'Color','k','string',deblank(TrialTime)); 
        
        set(text,'Position',[.02 .91],'Color','r','string','Trial Duration:'); 
        set(text,'Position',[.52 .91],'Color','k','string',num2str(TrialDuration)); 
        
        set(text,'Position',[.02 .89],'Color','r','string','One Stimulus Duration:'); 
        set(text,'Position',[.52 .89],'Color','k','string',num2str(OneStimDuration)); 
        
        set(text,'Position',[.02 .87],'Color','r','string','Time between stimuli:'); 
        set(text,'Position',[.52 .87],'Color','k','string',num2str(TimeBetweenStim)); 
        
        set(text,'Position',[.02 .85],'Color','r','string','Tilt:'); 
        set(text,'Position',[.52 .85],'Color','k','string',num2str(Tilt)); 
        
        set(text,'Position',[.02 .83],'Color','r','string','Radial box size:'); 
        set(text,'Position',[.52 .83],'Color','k','string',num2str(RadialBoxSize)); 
        
        set(text,'Position',[.02 .81],'Color','r','string','Perp. box size'); 
        set(text,'Position',[.52 .81],'Color','k','string',num2str(PerpenBoxSize)); 
        
        set(text,'Position',[.02 .79],'Color','r','string','Start pos:'); 
        set(text,'Position',[.52 .79],'Color','k','string',...
                [num2str(XStartPos),',',num2str(YStartPos)]); 
        
        set(text,'Position',[.02 .77],'Color','r','string','Extent stim motion:'); 
        set(text,'Position',[.52 .77],'Color','k','string', num2str(ExtentStimMotion)); 
        
        set(text,'Position',[.02 .75],'Color','r','string','Stim. velocity :'); 
        set(text,'Position',[.52 .75],'Color','k','string',num2str(StimVelocity )); 
        
        set(text,'Position',[.02 .73],'Color','r','string','ColorCode:'); 
        set(text,'Position',[.52 .73],'Color','k','string',num2str(ColorCode)); 
        
        set(text,'Position',[.02 .71],'Color','r','string','Foreground intensity:'); 
        set(text,'Position',[.52 .71],'Color','k','string',...
                [num2str(FgrRedInt),',',num2str(FgrGreenInt), ',', num2str(FgrBlueInt)]); 
        
        set(text,'Position',[.02 .69],'Color','r','string','Background  intensity:'); 
        set(text,'Position',[.52 .69],'Color','k','string',...
                [num2str(BckgrRedInt),',',num2str(BckgrGreenInt), ',', num2str(BckgrBlueInt)]); 
        
        set(text,'Position',[.02 .67],'Color','r','string','Element intensity:'); 
        set(text,'Position',[.52 .67],'Color','k','string',...
                [num2str(ElemRedInt),',',num2str(ElemGreenInt), ',', num2str(ElemBlueInt)]); 
        
        set(text,'Position',[.02 .65],'Color','b','string','Spatial frequency :'); 
        set(text,'Position',[.52 .65],'Color','b','string',num2str(SpatialFreq)); 
        
        set(text,'Position',[.02 .63],'Color','r','string','Ph:'); 
        set(text,'Position',[.52 .63],'Color','k','string',...
                [num2str(PhRed),',',num2str(PhGreen), ',', num2str(PhBlue)]); 
        
        set(text,'Position',[.02 .61],'Color','r','string','Standard deviation:'); 
        set(text,'Position',[.52 .61],'Color','k','string',num2str(StnDiv)); 
        
        set(text,'Position',[.02 .59],'Color','r','string','Contrast:'); 
        set(text,'Position',[.52 .59],'Color','k','string',num2str(Contrast)); 
        
        set(text,'Position',[.02 .57],'Color','b','string','Temporal frequency:'); 
        set(text,'Position',[.52 .57],'Color','b','string',num2str(TempFreq)); 
        
        set(text,'Position',[.02 .55],'Color','r','string','Elem length:'); 
        set(text,'Position',[.52 .55],'Color','k','string',num2str(ElemLength)); 
        
        set(text,'Position',[.02 .53],'Color','r','string','ElemWidth:'); 
        set(text,'Position',[.52 .53],'Color','k','string',num2str(ElemWidth)); 
        
        set(text,'Position',[.02 .51],'Color','r','string','Space length direc:'); 
        set(text,'Position',[.52 .51],'Color','k','string',num2str(SpLengthDirec)); 
        
        set(text,'Position',[.02 .49],'Color','r','string','Space width direct :'); 
        set(text,'Position',[.52 .49],'Color','k','string',num2str(SpWidthDirect )); 
        
        set(text,'Position',[.02 .47],'Color','r','string','Start eye data:'); 
        set(text,'Position',[.52 .47],'Color','k','string',num2str(StartEyeData)); 
        
        set(text,'Position',[.02 .45],'Color','r','string','Start spike data:'); 
        set(text,'Position',[.52 .45],'Color','k','string',num2str(StartSpikeData)); 
        
        set(text,'Position',[.02 .43],'Color','r','string','End spike data:'); 
        set(text,'Position',[.52 .43],'Color','k','string',num2str(EndSpikeData)); 
        
        set(text,'Position',[.02 .41],'Color','r','string','Time code:'); 
        set(text,'Position',[.52 .41],'Color','k','string',num2str(TimeCode)); 
        
        set(text,'Position',[.02 .39],'Color','r','string','Stim temporal type:');
        str = unitret('translate','StimTempType',StimTempType);
        set(text,'Position',[.52 .39],'Color','k','string',str); 
        
        set(text,'Position',[.02 .37],'Color','r','string','Stim spatial type:'); 
        str = unitret('translate','StimSpatType',StimSpatType);
        set(text,'Position',[.52 .37],'Color','k','string',str);
        
        set(text,'Position',[.02 .35],'Color','r','string','Eye choice:'); 
        str = unitret('translate','EyeChoice',EyeChoice);
        set(text,'Position',[.52 .35],'Color','k','string',str); 

	%
	
        set(text,'Position',[.02 .33],'Color','r','string','Sweep fraction:'); 
        set(text,'Position',[.52 .33],'Color','k','string',num2str(SweepFract)); 
        
        set(text,'Position',[.02 .31],'Color','r','string','Trig tech:'); 
        set(text,'Position',[.52 .31],'Color','k','string',num2str(TrigTech));

	set(text,'Position',[.02 .29],'Color','r','string','Spike trigger:'); 
        set(text,'Position',[.52 .29],'Color','k','string',num2str(SpikeTrig)); 
	
	set(text,'Position',[.02 .27],'Color','r','string','Shape trigger:'); 
        set(text,'Position',[.52 .27],'Color','k','string',num2str(ShapeTrig)); 
        
        set(text,'Position',[.02 .25],'Color','r','string','Shape hist:'); 
        set(text,'Position',[.52 .25],'Color','k','string',num2str(ShapeHist)); 

	%
	
        set(text,'Position',[.02 .23],'Color','r','string','Shape length:'); 
        set(text,'Position',[.52 .23],'Color','k','string',num2str(ShapeLen)); 
        
        set(text,'Position',[.02 .21],'Color','r','string','Shape offset:'); 
        set(text,'Position',[.52 .21],'Color','k','string',num2str(ShapeOff)); 
        
        set(text,'Position',[.02 .19],'Color','r','string','First Stim. Time, ms:'); 
        set(text,'Position',[.52 .19],'Color','k','string',num2str(FirstStimTime(tnum))); 
        
        set(text,'Position',[.02 .17],'Color','r','string','Targets angle, deg:'); 
        set(text,'Position',[.52 .17],'Color','k','string',num2str(AngleFix(tnum))); 
        
        set(text,'Position',[.02 .15],'Color','r','string','Change fix. time, sec:'); 
        set(text,'Position',[.52 .15],'Color','k','string',num2str(FixChangeTime(tnum))); 
        
        set(text,'Position',[.02 .13],'Color','r','string','Fix. time motion, sec:'); 
        set(text,'Position',[.52 .13],'Color','k','string',num2str(SteadyFixTime(tnum))); 
        
        set(text,'Position',[.02 .11],'Color','r','string','No change fix time, sec:'); 
        set(text,'Position',[.52 .11],'Color','k','string',num2str(FixNoChangeTime(tnum))); 

	if 0
        set(text,'Position',[.02 .9],'Color','r','string','Fix. motion dist, minarc:'); 
        set(text,'Position',[.52 .9],'Color','k','string',num2str(TotalFixDistance(tnum))); 
        
        set(text,'Position',[.02 .7],'Color','r','string','Fix. fraction:'); 
        set(text,'Position',[.52 .7],'Color','k','string',num2str(FixFraction(tnum))); 
	end
        
        %    drawnow;
        fseek(fid,oldpos,-1); 
end;
set(gca,'Visible','Off');

set(gcf,'Pointer','Arrow','Visible','on');
set(TRET_DAT(1),'Pointer','Arrow');


%---------------------------------------------------------------------------------------------------------------------------------------------------------------     

elseif(strcmp(action,'pressed'))
        % disp('pressed')
        
        % in1 - tnum;
        % in2 - handle of the current axes
        global STIMULUS SPIKES MOTION SINDATA;
        
        tnum  = in1;
        curax = in2;
        
        EyeMovementHandle=get(curax,'UserData');
        
        
        if (nargin>3), % Saccades Window Selection
                PresPnt=in3;
        else
                PresPnt=get(curax,'CurrentPoint');
        end
        
        NumSt=STIMULUS(tnum,1);         %number of stimuli for given trial
        EndStim=STIMULUS(tnum,2);       %TrialDuration for given trial
        
        x=PresPnt(1,1);
        y=PresPnt(1,2);
        xmin = 0;
        xmax = 0;
        BegOfSegm=0;
        EndOfSegm=0;
        
        FalseChoice = 0;
        if (x<STIMULUS(tnum,5))|(x>EndStim) | (y>DefValues(10)) | (y<DefValues(7))
                return; %erroneous point was clicked
        end;
        
        
        if ((DefValues(26)==5 | DefValues(26)==6) & DefValues(47)==0) % Arb Window or Integer Cycles, first cursor
                set(TRET_DAT(2),'CurrentAxes',curax);   
                
                if DefValues(26)==5 % Arb. Window $$$
                        ll = line([x x],[DefValues(7) DefValues(10)],'EraseMode','background');
                        set(ll,'Color','k');
                        ud=get(0,'UserData');
                        ud(47)=1;
                        ud(48)=x;
                        set(0,'Userdata',ud);
                        
                else % Integer Number of cycles
                        if unitret('is periodic',SINDATA(tnum,3)) % periodic stimulus
                                TrialDuration=SINDATA(tnum,1);
                                TF=abs(SINDATA(tnum,2));
                                SinOffSet=0:(1/TF)*1000:TrialDuration;
                                SinOffSet=SinOffSet(1:length(SinOffSet)-1);
                                
                                if DefValues(52) % Snap inside
                                        %% find right closest cycle begining %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                        index=find(abs(SinOffSet-x) == min(abs(SinOffSet-x)+max(SinOffSet)*(SinOffSet<x)));    %%
                                        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                else      
                                        %% find !any! closest cycle begining %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                        index=find(abs(SinOffSet-x)==min(abs(SinOffSet-x)));                                                     %%
                                        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                end
                                
                                xnew=SinOffSet(index);
                                
                                ll = line([xnew xnew],[DefValues(7) DefValues(10)],'EraseMode','background','Color','k','LineStyle','--');
                                %          set(ll,'Color','b');
                                ud=get(0,'UserData');
                                ud(47)=1;
                                ud(48)=xnew;
				ud(75)=TF;
                                set(0,'Userdata',ud);
                                
                        else % ALTERNATING OR REPEATING SINE WITHOUT WINDOWING 
                                % Find beginning of segment right to x
                                for i=5:NumSt+4,
                                        if x < STIMULUS(tnum,i),
                                                tmp = STIMULUS(tnum,i) - STIMULUS(tnum,4); 
                                                if x < tmp,
                                                        BegOfSegm = STIMULUS(tnum,i-1);
                                                        EndOfSegm = tmp;
                                                        %Mod = 1;
                                                else
                                                        BegOfSegm = tmp;
                                                        EndOfSegm = STIMULUS(tnum,i);	
                                                        %Mod = 0;
                                                end;	    %if x<...
                                                break;
                                        end;	    %if x < STIMULUS(...
                                end;		    %for i=5...
                                %------------------------------------------
                                
                                if EndOfSegm==0,
                                        if ((EndStim - STIMULUS(tnum,NumSt+4)) >= STIMULUS(tnum,3)) &... 
                                                        (x <= (STIMULUS(tnum,NumSt+4)+STIMULUS(tnum,3))) , 
                                                BegOfSegm = STIMULUS(tnum,NumSt+4); 
                                                EndOfSegm = BegOfSegm + STIMULUS(tnum,3);
                                        else
                                                warndlg('  Interval is incomplete   ');
                                                set(TRET_DAT(2),'Pointer','Arrow');
                                                set(TRET_DAT(1),'Pointer','Arrow');
                                                return;  %erroneous point was clicked
                                        end;
                                end;
                                
                                TF=abs(SINDATA(tnum,2));
                                SinOffSet=BegOfSegm:(1/TF)*1000:EndOfSegm;
                                SinOffSet=SinOffSet(1:length(SinOffSet)-1);
                                
                                if DefValues(52) % Snap inside
                                        %% find right closest cycle begining %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                        index=find(abs(SinOffSet-x) == min(abs(SinOffSet-x)+max(SinOffSet)*(SinOffSet<x)));    %%
                                        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                else      
                                        %% find !any! closest cycle begining %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                        index=find(abs(SinOffSet-x)==min(abs(SinOffSet-x)));                                                     %%
                                        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                end
                                
                                xnew=SinOffSet(index);
                                if isempty(xnew)
                                        warndlg('The point you clicked is`nt in stimulus','Message')
                                        return
                                end		
                                
                                ll = line([xnew xnew],[DefValues(7) DefValues(10)],'EraseMode','background','Color','k','LineStyle','--');
                                %          set(ll,'Color','b');
                                ud=get(0,'UserData');
                                ud(47)=1;
                                ud(48)=xnew;
                                ud(49)=BegOfSegm;
				ud(75)=TF;
                                set(0,'Userdata',ud);
                                
                        end % of STIM TYPE
			 
                        
                end % of $$$
                
        else
                
                FalseChoice = 0;
                if (x<STIMULUS(tnum,5))|(x>EndStim) | (y>DefValues(10)) | (y<DefValues(7))
                        return; %erroneous point was clicked
                end;
                if DefValues(26)==0,			%Segment		
                        for i=5:NumSt+4,
                                if x < STIMULUS(tnum,i),
                                        tmp = STIMULUS(tnum,i) - STIMULUS(tnum,4); 
                                        if x < tmp,
                                                xmin = STIMULUS(tnum,i-1);
                                                xmax = tmp;
                                                Mod = 1;
                                        else
                                                xmin = tmp;
                                                xmax = STIMULUS(tnum,i);	
                                                Mod = 0;
                                        end;	    %if x<...
                                        break;
                                end;	    %if x < STIMULUS(...
			end;		    %for i=5...
						   
                elseif DefValues(26)==1			%On/Off couples
                        tmp = STIMULUS(tnum,5:NumSt+4);
                        ind_min=max(find(tmp<=x));
                        xmin = tmp(ind_min);
                        if length(tmp) > ind_min,
                                xmax=tmp(ind_min+1);
                        else
                                xmax=SPIKES(tnum,3);
                        end;
                        Mod=1;
                        
                elseif DefValues(26)==7			%Off/On couples
                        tmp = STIMULUS(tnum,5:NumSt+4);
                        % tmp = [STIMULUS(tnum,5:NumSt+4)-STIMULUS(tnum,4) STIMULUS(tnum,NumSt+4) STIMULUS(tnum,NumSt+4)+STIMULUS(tnum,4)];
                        ind_min=max(find(tmp<=x));
                        xmin = tmp(ind_min)+STIMULUS(tnum,4);
                        if length(tmp) > ind_min,
                                xmax=tmp(ind_min+1)+STIMULUS(tnum,4);
                        else
                                xmax=SPIKES(tnum,3);
                        end;
                        Mod=1;
                        
                elseif DefValues(26)==2 		% spont act data
                        xmin = SPIKES(tnum,2);
                        xmax = SPIKES(tnum,3);
                        Mod = 1;
                elseif DefValues(26)==8 		% all cycles
			TF=abs(SINDATA(tnum,2));
                        xmin = 0;
                        xmax = SPIKES(tnum,3) - mod(SPIKES(tnum,3),1000/TF);
                        Mod = 1;

                        
                elseif DefValues(26)==4 		% event data
                        xmin = max(SPIKES(tnum,2),x-DefValues(37));
                        xmax = min(SPIKES(tnum,3),x+DefValues(38));
                        Mod = 1;
                        
                elseif DefValues(26)==5			% Arb. Window, second cursor
                        
                        xmin = max(SPIKES(tnum,2),DefValues(48));
                        xmax = min(SPIKES(tnum,3),x);
                        
                        if xmax <= xmin,
                                unitret('errormessage','Negative time window - select another rigth limit!','ERROR');
                                set(TRET_DAT(2),'Pointer','Arrow');
                                return
                        end
                        
                        Mod = 1;
                        % set Cursor Flag to 0
                        ud=get(0,'UserData');
                        ud(47)=0;
                        set(0,'Userdata',ud);  
                        
                elseif DefValues(26)==6			% integer number of cycles, second cursor
                        if unitret('is periodic',SINDATA(tnum,3)) % periodic stimulus 
                                xmin = max(SPIKES(tnum,2),DefValues(48));
                                
                                TrialDuration=SINDATA(tnum,1);
                                TF=abs(SINDATA(tnum,2));
                                %% SinOffSet=0:(1/TF)*1000:TrialDuration;
				SinOffSet=0:(1/TF)*1000:SPIKES(tnum,3);

                                if DefValues(52) % Snap inside
                                        %% find left closest cycle begining %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                        index=find(abs(SinOffSet-x) == min(abs(SinOffSet-x)+max(SinOffSet)*(SinOffSet>=x)));  %%
                                        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                else      
                                        %% find !any! closest cycle begining %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                        index=find(abs(SinOffSet-x)==min(abs(SinOffSet-x)));                                                     %%
                                        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                end
                                
                                x=SinOffSet(index);
                                %% xmax = min(SPIKES(tnum,3),x);
				xmax = x;

                        else % REPEATING OR ALTERNATING SINUS
                                
                                % Find beginning of segment left to x
                                BegOfSegm=DefValues(49);
                                EndOfSegm=BegOfSegm+STIMULUS(tnum,3);

                                if x>EndOfSegm
                                        unitret('errormessage','Right limit outside current segment!','ERROR');
                                        set(TRET_DAT(2),'Pointer','Arrow');
                                        return
                                end
                                
                                %------------------------------------------
                                xmin=DefValues(48);
                                TF=abs(SINDATA(tnum,2));
                                SinOffSet=BegOfSegm:(1/TF)*1000:EndOfSegm;
                                
                                if DefValues(52) % Snap inside
                                        %% find left closest cycle begining %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                        index=find(abs(SinOffSet-x) == min(abs(SinOffSet-x)+max(SinOffSet)*(SinOffSet>=x)));  %%
                                        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                else      
                                        %% find !any! closest cycle begining %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                        index=find(abs(SinOffSet-x)==min(abs(SinOffSet-x)));                                                     %%
                                        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                                end          
                                
                                x=SinOffSet(index);
                                
                                xmax = min(SPIKES(tnum,3),x); 
                                
                        end % of STIM TYPE
                        
                        %disp('---------------------------------')
                        %disp(['cycle: ',num2str((1/TF)*1000)])
                        %xmin
                        %xmax
                        if xmax < xmin,
                                unitret('errormessage','Negative or zero time window - select another rigth limit!','ERROR');
                                set(TRET_DAT(2),'Pointer','Arrow');
                                return
                        end
                        if xmax==xmin
                                xmax=xmax+1/TF*1000;
                        end
                        
                        Mod = 1;
                        % set Cursor Flag to 0
                        ud=get(0,'UserData');
                        ud(47)=0;
                        set(0,'Userdata',ud);  
                        
                        
                        
                end;		    			% if Default...
		
                if xmax==0,
                        if ((EndStim - STIMULUS(tnum,NumSt+4)) >= STIMULUS(tnum,3)) &... 
                                        (x <= (STIMULUS(tnum,NumSt+4)+STIMULUS(tnum,3))) , 
                                xmin = STIMULUS(tnum,NumSt+4); 
                                xmax = xmin + STIMULUS(tnum,3);
                                Mod=1;
                        else
                                warndlg('  Interval is incomplete   ');
                                set(TRET_DAT(2),'Pointer','arrow');
                                set(TRET_DAT(1),'Pointer','Arrow');
                                
                                return;  %erroneous point was clicked
                        end;
                end;
                
                %	x1 = [xmin+10 xmin+10 xmax-10 xmax-10]; 
                x1 = [xmin  xmin  xmax-10 xmax-10]; 
                y1 = [DefValues(7) DefValues(10)  DefValues(10) DefValues(7) ];
                
                EyeTimeAxis=get(EyeMovementHandle(1),'XData');
                HorEyeMov = get(EyeMovementHandle(1),'YData');
                VerEyeMov = get(EyeMovementHandle(2),'YData');
		
                imin = min(find(EyeTimeAxis >= xmin));
                imax = max(find(EyeTimeAxis <= xmax));
                
                EyeTimeInterval=EyeTimeAxis(imin:imax);
                HorEyeInterval = HorEyeMov(imin:imax);
                VerEyeInterval = VerEyeMov(imin:imax);
                EyeMotionLength=imax-imin+1;
		
                %here we transform XY eye movement into the new coordinate system,
                % where X axes is parallel to the stimulus tilt and Y axis is 
                %perpendicular to the tilt
                %
                
                % LOOKING FOR SPIKES BETWEEN xmin and xmax timegate
                
                snum = SPIKES(tnum, 1);
                
                SpkInd = find((SPIKES(tnum, 4:snum+3) >= xmin) & ((SPIKES(tnum, 4:snum+3)<xmax)));
                lowind=min(SpkInd)+3;
                upind=max(SpkInd)+3;
                
                
                if DefValues(28),	% reject edge spikes
                        PerpenBoxSize = MOTION(tnum,3);
                        StimVelocity = MOTION(tnum,1);
                        
                        
                        UncertainTime  = DefValues(29)*1000*PerpenBoxSize/StimVelocity;
                        SpikeWindow = SPIKES(tnum,upind) - SPIKES(tnum,lowind);
                        if SpikeWindow <= 2*UncertainTime,
                                warndlg('This segment is too short to reject the edges!');
                                set(gcf,'Pointer','Arrow');
                                return;
                        end;
                        
                end;
                
                
                set(TRET_DAT(2),'CurrentAxes',curax);
                
                
                
                MarkedData = unitret('get_markeddata');
                
                ncol = size(MarkedData,2);
                nrow = size(MarkedData,1);              %=TrialsNum of the given file
                %	lgn = upind-lowind+1;
                lgn=length(SpkInd);
                
                ll = line(x1,y1,'EraseMode','background','Color','k');
                
                set(ll,'ButtonDownFcn','unitret(''erase_me'');','UserData',[tnum, lgn, xmin, xmax]);
                
                % if the interval was clicked twice, we want to exclude it from MarkedData array:
                
                for(m = 1:nrow),
                        if(sum(MarkedData(m,1:4)==[tnum, lgn, xmin, xmax])==4),	%exclude the record
                                ll=line(x1,y1,'EraseMode','none');
                                set(ll,'Color','w'); 
                                MarkedData(m,:) = [];
                                REFMAT(m,:)=[];
                                FalseChoice=1;
                                break;
                        end;
                end;
                
                
                if (~FalseChoice),
                        maxncol = max((lgn+5),ncol);
                        newrow = nrow + 1;
                        tmp = zeros(nrow+1,maxncol);
                        for i=1:nrow,
                                tmp(i,1:ncol) = MarkedData(i,:);
                        end;
                        
                        MarkedData(newrow,1) = tnum;
                        MarkedData(newrow,2) = lgn;
                        MarkedData(newrow,3) = xmin;
                        MarkedData(newrow,4) = xmax;
                        MarkedData(newrow,5) = Mod;
                        MarkedData(newrow,6:lgn+5) = SPIKES(tnum, lowind:upind);
                        MarkedData(newrow,lgn+6)= EyeMotionLength;
                        MarkedData(newrow,lgn+7:(lgn+6+3*EyeMotionLength))= ...
                                [EyeTimeInterval HorEyeInterval VerEyeInterval];
                        
                        motionidx=lgn+7+3*EyeMotionLength;
                        MarkedData(newrow, motionidx:(motionidx+size(MOTION,2)-1)) = MOTION(tnum,:);

                        
                        REFMAT(newrow,1)	= tnum;
                        REFMAT(newrow,2)	= xmin;
                        REFMAT(newrow,3) 	= xmax;
                        REFMAT(newrow,4) 	= Mod;
                        REFMAT(newrow,5:10)= [HorEyeInterval(1:min(6,EyeMotionLength)) zeros(1,6-EyeMotionLength)]; % for control only
                        
                        % set(TRET_DAT(3),'enable','on');
                end;
                
                unitret('set_markeddata',MarkedData);
                set(gcf,'Pointer','Arrow');
                set(TRET_DAT(1),'Pointer','Arrow');
                
                %       vernier_step=100;
                %       unitret('vernier_start',[tnum (xmin+xmax)/2 vernier_step curax]);       
                
        end % for If "first Cursor"
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
        
elseif(strcmp(action,'save'))
	ini_dir = cd;
        % Change to SAVE_DIR
	eval(['cd ' SAVE_DIR]); 
        if (in1 ==1),         %<--------- save menu
                
                unitret('save_markeddata');
                
        elseif(in1==2),
                strdlg=[NAME];
                [filename, pathname] = uiputfile(strdlg, 'Save Selected Segments As...', .4, .4);
                if filename == 0, 
			eval(['cd ',ini_dir]);
                        return;
                else
                        NAME = filename;
                end;
                name = [pathname,NAME];
                % unitret('figname');
		if exist('TRET_DAT')
			if length(TRET_DAT)>1
				set(TRET_DAT(2),'Name',name);
			end
		end
                unitret('save_markeddata',name);
        elseif(in1==3),
                lg = max(find(NAME == '.'));
                sctname = [NAME(1:lg),'sct'];
                unitret('save_scatterdata',sctname,1);
        elseif(in1==4),
                [filename, pathname] = uiputfile('*.sct', 'Save Scatter Data As...', .4, .4);
                if filename == 0, return; end;
                sctname = [pathname,filename];
                unitret('save_scatterdata',sctname,1);  
        elseif(in1==5),
                lg = max(find(NAME == '.'));
                sctname = [NAME(1:lg),'asc'];
                [filename, pathname] = uiputfile(sctname, 'Save Scatter Data in ASCII format', .4, .4);
                if filename == 0, return; end;
                sctname = [pathname,filename];
                unitret('save_scatterdata',sctname,2);
                
        elseif(in1==6),
                %save quasy-stat periods     
                lg = max(find(NAME == '.'));
                qstname = [name(1:lg),'qst'];
                [filename, pathname] = uiputfile(qstname, 'Save quasy-stationary periods in ASCII format', .4, .4);
                if filename == 0, return; end;
                unitret('save_quasystat',qstname);
                
        elseif(in1==7),
                lg = max(find(NAME == '.'));
                sctname = [NAME(1:lg),'hgl'];
                [filename, pathname] = uiputfile(sctname, 'Save Screen in HGL format As..', .4, .4);
                if filename == 0, return; end;
                sctname = [pathname,filename];
                com = ['print -dhpgl ', sctname];
                eval(com);
                set(gcf,'Pointer','arrow');
                
                
                
        elseif(in1==33), % Save in ASCII
                lg = max(find(NAME == '.'));
                spkname = [NAME(1:lg),'sat'];
                [filename, pathname] = uiputfile(spkname, 'Save spikes in ASCII format', .4, .4);
                if filename == 0, return; end;
                eval(['cd ',pathname])
                spkname = [pathname,filename];
                emuname = [filename(1:length(filename)-3),'emv'];
                %[filename, pathname] = uiputfile(emuname, 'Save segment`s EM in ASCII format', .4, .4);
                %if filename == 0, return; end;
                %eval(['cd ',pathname])
                emuname = [pathname,emuname];
                unitret('save_ascii',spkname,emuname,2);
                
        elseif(in1==34), % Save in MAT
                % lg = max(find(NAME == '.'));
                spkname = [INI_NAME,'.mat'];
                if ~(strcmp(in2,'no dialog')),
                        [filename, pathname] = uiputfile(spkname, 'Save segments in MAT format', .4, .4);
                        if filename == 0, return; end;
                        eval(['cd ',pathname])
                        spkname = [pathname,filename];
                end
                
                
                unitret('save_mat',spkname);

        elseif(in1==35), % Save in MAT with Stimulus
                % lg = max(find(NAME == '.'));
                spkname = [INI_NAME,'.SEMSTIM.mat'];
                if ~(strcmp(in2,'no dialog')),
                        [filename, pathname] = uiputfile(spkname, 'Save segments in MAT format', .4, .4);
                        if filename == 0, return; end;
                        eval(['cd ',pathname])
                        spkname = [pathname,filename];
                end
                
                
                unitret('save_semstim_mat',spkname);
                
        end;
	if exist('pathname'),
		SAVE_DIR = pathname;
	end
	eval(['cd ',ini_dir]);
        
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'save_ascii'))
        % Save SpkArrTimes in one file and EM in another
        MarkedData=unitret('get_markeddata');
        
        if (~isempty(MarkedData)),
                
                row_num = size(MarkedData,1);
                if row_num > 1, % more than 1 segment, exit!!!
                        errordlg('Only one segment should be selected!','ERROR');
                        return;
                end
                
                i=1;
                
                SpikesNum = MarkedData(i,2);
                %SpikesInf = MarkedData(i,1:5);
                SpikesData = MarkedData(i,6:SpikesNum+5);
                EyeMotionLength = MarkedData(i,SpikesNum+6);
                EyeTimeInterval= MarkedData(i,(SpikesNum+7):(SpikesNum+EyeMotionLength+6));
                HorEyeInterval = MarkedData(i,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6));
                VerEyeInterval = MarkedData(i,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6));
                %StimVelocity = MarkedData(i,SpikesNum+3*EyeMotionLength+7);
                %StimTilt = MarkedData(i,SpikesNum+3*EyeMotionLength+8);
                
                eval(['save ',in1,' SpikesData -ascii']); 
                eval(['save ',in2,' EyeTimeInterval HorEyeInterval VerEyeInterval -ascii']); 
        end
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'save_mat'))
        % Save SpkArrTimes and EM in *.mat file
        
        % Sample code to read SEM_struct:
        % SEM = struct2cell(SEM_struct); 
        % spikes = cat(1,SEM{i,:,k}); % i-th line of k-th segment 
        
        MarkedData=unitret('get_markeddata');
        SEM_struct = [];
        SEM_struct_one_segment = [];
        if (~isempty(MarkedData)),
                
                row_num = size(MarkedData,1);
                if row_num < 1, % more than 1 segment, exit!
                        errordlg('No segments selected!','ERROR');
                        return;
                end
                
                for i=1:row_num,
                        
                        SpikesNum = MarkedData(i,2);
                        %SpikesInf = MarkedData(i,1:5);
                        SpikesData = MarkedData(i,6:SpikesNum+5);
                        EyeMotionLength = MarkedData(i,SpikesNum+6);
                        EyeTimeInterval= MarkedData(i,(SpikesNum+7):(SpikesNum+EyeMotionLength+6));
                        HorEyeInterval = MarkedData(i,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6));
                        VerEyeInterval = MarkedData(i,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6));
                        %StimVelocity = MarkedData(i,SpikesNum+3*EyeMotionLength+7);
                        %StimTilt = MarkedData(i,SpikesNum+3*EyeMotionLength+8);
                        SEM_struct_one_segment.spikes = SpikesData;
                        SEM_struct_one_segment.eye_time_axis = EyeTimeInterval;
                        SEM_struct_one_segment.eye_hor = HorEyeInterval;
                        SEM_struct_one_segment.eye_ver = VerEyeInterval;
                        
                        if isempty(SEM_struct),
                                SEM_struct = [SEM_struct_one_segment];
                        else
                                SEM_struct = [SEM_struct SEM_struct_one_segment];
                        end
                        
                end 
                eval(['save ',in1,' SEM_struct']); 
        end
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'save_semstim_mat'))
        % Save SpkArrTimes and EM and stimulus info in *.mat file
        
        % Sample code to read SEM_struct:
        % SEM = struct2cell(SEM_struct); 
        % spikes = cat(1,SEM{i,:,k}); % i-th line of k-th segment 

	global STIM
        MarkedData=unitret('get_markeddata');
        SEMSTIM_struct = [];
        SEMSTIM_struct_one_segment = [];
        if (~isempty(MarkedData)),
                
                row_num = size(MarkedData,1);
                if row_num < 1, % less than 1 segment, exit!
                        errordlg('No segments selected!','ERROR');
                        return;
                end
                
                for i=1:row_num,
                        
                        SpikesNum = MarkedData(i,2);
                        %SpikesInf = MarkedData(i,1:5);
                        SpikesData = MarkedData(i,6:SpikesNum+5);
                        EyeMotionLength = MarkedData(i,SpikesNum+6);
                        EyeTimeInterval= MarkedData(i,(SpikesNum+7):(SpikesNum+EyeMotionLength+6));
                        HorEyeInterval = MarkedData(i,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6));
                        VerEyeInterval = MarkedData(i,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6));
                        %StimVelocity = MarkedData(i,SpikesNum+3*EyeMotionLength+7);
                        %StimTilt = MarkedData(i,SpikesNum+3*EyeMotionLength+8);
			SEMSTIM_struct_one_segment.TrialNum = MarkedData(i,1);
			SEMSTIM_struct_one_segment.TimeBegin = MarkedData(i,3);
			SEMSTIM_struct_one_segment.TimeEnd = MarkedData(i,4);
			SEMSTIM_struct_one_segment.spikes = SpikesData;
                        SEMSTIM_struct_one_segment.eye_time_axis = EyeTimeInterval;
                        SEMSTIM_struct_one_segment.eye_hor = HorEyeInterval;
                        SEMSTIM_struct_one_segment.eye_ver = VerEyeInterval;
			SEMSTIM_struct_one_segment.STIM = STIM(MarkedData(i,1));
                        
                        if isempty(SEMSTIM_struct),
                                SEMSTIM_struct = [SEMSTIM_struct_one_segment];
                        else
                                SEMSTIM_struct = [SEMSTIM_struct SEMSTIM_struct_one_segment];
                        end
                        
                end 
                eval(['save ',in1,' SEMSTIM_struct']); 
        end
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');        
        
        %-------------------------------------
elseif(strcmp(action,'save_quasystat'))
        
        
        set(TRET_DAT(9),'UserData',[],'enable','off');
        set(gcf,'Pointer','Arrow')
        %-------------------------------------
elseif(strcmp(action,'save_scatterdata'))
        
        sctname = in1;
        savetype = in2;
        
        %    format of written data is:
        % size of sctdata (vec(1:2))
        % lines of sctdata matrix;
        if savetype==1,		%save as binary
                sctdata = get(TRET_DAT(8),'userdata');
                vec = size(sctdata);
                for i = 1:vec(1),
                        vec = [vec, sctdata(i,:)];
                end;
                
                [fid, message] = fopen(sctname,'wb');
                if(fid<0), 
                        error(message);
                end;
                fwrite(fid,vec,'float');
                
                set(TRET_DAT(8),'Enable','off');
                
        else,			%save as text for EXCEL
                Scatter = unitret('get_markeddata');
                Scatter = [Scatter zeros(size(Scatter,1),1)];
                Scatter(:,9) = Scatter(:,8);
                Scatter(:,8) = Scatter(:,3).*(Scatter(:,4) - Scatter(:,5)).*.001;
                
                % format of ASCII saved data:
                % [Trial_Number, Modality, Velosity, PointerPosition, Start_Segment, End_Segment,  Xmean, Distance, Ymean];
                
                [fid, message] = fopen(sctname,'wt');
                if(fid<0), 
                        error(message);
                end;
                name=get(gcf,'Name');
                fprintf(fid,'%s\n',name);
                fprintf(fid,'%2d\t%d\t%6.2f\t%8.2f\t%8.2f\t%8.2f\t%8.2f\t%8.2f\t%8.2f\n',Scatter');
        end;
        fclose(fid);
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
        
        %-------------------------------------
elseif(strcmp(action,'save_markeddata'))
        
        if nargin>1,
                name = in1;
                NAME = name;
	else
		name = get(TRET_DAT(1),'Name');
		if strcmpi(name(length(name)-2:length(name)),'cl1')
			NAME = [NAME(1:length(NAME)-4),'.cell1',NAME(length(NAME)-3:length(NAME))];
		end
		if strcmpi(name(length(name)-2:length(name)),'cl2')
			NAME = [NAME(1:length(NAME)-4),'.cell2',NAME(length(NAME)-3:length(NAME))];
		end
	end

	MarkedData=unitret('get_markeddata');

	
        if (~isempty(MarkedData)),
                
                row_num = size(MarkedData,1);
                cvec = [];
                [fid,message] = fopen(NAME,'wb');
                for(i=1:row_num)
                        SpikesNum = MarkedData(i,2);
                        SpikesInf = MarkedData(i,1:5);
                        SpikesData = MarkedData(i,6:SpikesNum+5);
                        EyeMotionLength = MarkedData(i,SpikesNum+6);
                        EyeTimeInterval= MarkedData(i,(SpikesNum+7):(SpikesNum+EyeMotionLength+6));
                        HorEyeInterval = MarkedData(i,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6));
                        VerEyeInterval = MarkedData(i,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6));
                        StimVelocity = MarkedData(i,SpikesNum+3*EyeMotionLength+7);
                        StimTilt = MarkedData(i,SpikesNum+3*EyeMotionLength+8);
                        % this routine is used twice. 
                        % 1. when marked data saved (then MarkedData include PerpBoxSize parameter, that is not 
                        %    written in *.spd file
                        % 2. when spikes segment written on disk, after editing in segment show program (then Marked Data, wghich is obtained 
                        % from the *.spd file is not include PerpBoxSize parameter.
                        % In the other parameters, these data is identical. Thus, we should check what kind of 
                        % "marked data" we have
                        if length(MarkedData) >SpikesNum+3*EyeMotionLength+8,
                                % TEMPORARY COMMENT PerpenBoxSize = MarkedData(i,SpikesNum+3*EyeMotionLength+9);
                                
                                if DefValues(28),	% reject edge spikes
                                        UncertainTime  = DefValues(29)*1000*PerpenBoxSize/StimVelocity; 
                                        StartSpkWindow = min(SpikesData) + UncertainTime;
                                        EndSpkWindow   = max(SpikesData) - UncertainTime;
                                        SpikeWindowIndex = find((SpikesData >= StartSpkWindow) & (SpikesData <= EndSpkWindow));
                                        SpikesData = SpikesData(SpikeWindowIndex);
                                        NewSpikesNum = length(SpikesData);
                                        SpikesInf(2) = NewSpikesNum;
                                end;   
                        end;        
                        %  if ~isempty(SpikesData)                    
                        cvec = [SpikesInf SpikesData EyeMotionLength EyeTimeInterval HorEyeInterval VerEyeInterval StimVelocity StimTilt];
                        fwrite(fid,cvec,'float');
                        cvec = [];
                        
                        %	  end;   
                end;
                fclose(fid);
                if length(TRET_DAT)>2,
                        set(TRET_DAT(3),'enable','off');
                end
	end;

	if DefValues(188),		% save STIM together with spikes
		global STIM
		save([NAME '.STIM.mat'],'STIM');
	end		
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
        
        
        %--------------------------------------------------------------------------------------------------------------------------------------------------------------
	
elseif(strcmp(action,'show_spikes'))
	global STIM
        % Same as 'spikes', but takes spikes from marked data, and not from file
        % So, when you change something in one block, do not forget to change in another one
	
        Spk=unitret('get_markeddata');

	% save bar width for OI
	
	DefValues(105)=mean(cat(1,STIM.PerpenBoxSize));
	set(0,'Userdata',DefValues);

        % now as in 'spikes':
        
        set(gcf,'Pointer','Watch');
        if ~isempty(TRINFOHndl)
                if sum(find(get(gcf,'children')==TRINFOHndl))
                        set(TRINFOHndl,'enable','on');
                end
        end
        
        if  (size(TRET_DAT,2) > 1 ),    % second member exists (pointer to graph figure)
                if strcmp(get(TRET_DAT(2),'Type'),'figure'),
                        delete(TRET_DAT(2));
                        TRET_DAT = TRET_DAT(1);
                end;
        end;      
        
        % name = get(gcf, 'Name');
        name = get(TRET_DAT(1), 'Name');
        
        %--------- open graph figure---------------------   
        if  (size(TRET_DAT,2) > 1 ),    % third member exists (pointer on graph figure)
                if strcmp(get(TRET_DAT(1),'Type'),'figure'),
                        Fig2 = TRET_DAT(2);
                        set(0,'CurrentFigure',Fig2);
                        kids=get(Fig1,'Children');
                        for i=1:length(kids),
                                tp=get(kids(i),'type');
                                if (strcmp(tp,'axes')) | (strcmp(tp,'uicontrol'))
                                        delete(kids(i));
                                end;
                        end;
                end;
        else,
                Fig2 = figure('Units','normalized', 'Position',[0.2822    0.0417    0.7148    0.9089],...
                        'Backingstore','on','color','w','DefaultAxesXcolor','k',...
                        'DefaultAxesFontSize',9,'DefaultAxesDrawMode','fast',...
                        'DefaultAxesYColor','k','Menubar','none','Name',['untitled segments from ', name]);
                set(Fig2,'Units','Pixels');
                
        %%% ~~~ set(TRET_DAT(1),'UserData',[]); %  Reset User Data ( TotSpk )
        
        
		unitret('build_Fig2_menu',Fig2,'show_spikes');     
	end;

	%TRET_DAT(2:9) = [Fig2 u11 u22 u23 u32 u33 u16 u18];
	unitret('set_markeddata',Spk);

	% Change Show_Return_Menu to Return (to previous experimental record)
	%set(Show_Return_Menu, 'Label', 'Return to Experimental Record', 'Callback', 'pause(0.5); unitret(''read_header'', get(gcf, ''Name''), 1 )');


	set(gcf,'Pointer','Arrow');
	set(TRET_DAT(1),'Pointer','Arrow');


	unitret('redraw_spk',1);
	set(gcf,'Pointer','Arrow');

%--------------------------------------------------------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'spikes'))
        set(gcf,'Pointer','Watch');
        if ~isempty(TRINFOHndl)
                if sum(find(get(gcf,'children')==TRINFOHndl))
                        set(TRINFOHndl,'enable','on');
                end
        end
        
        
        
        % should be added an option to take marked data from -->  MarkedData=get(TRET_DAT(2),'UserData');
        % now - only from file:
        
        if  (size(TRET_DAT,2) > 1 ),    % second member exists (pointer on graph figure)
                if strcmp(get(TRET_DAT(2),'Type'),'figure'),
                        delete(TRET_DAT(2));
                        TRET_DAT = TRET_DAT(1);
                end;
        end;      
        
        if (nargin<2), % choose file to open,
                wld = get(gcf,'Name');
                [a,b]=min(wld - '.');
                
                
                if DefValues(26)==0,		% driven activity
                        extent = 'SPD';		
                elseif DefValues(26)==1		% on-off couples
                        extent = 'SPC';
                elseif DefValues(26)==2		% spont data
                        extent = 'SPS';
                elseif DefValues(26)==4		% event
                        extent = 'SPE';
                elseif DefValues(26)==5		% arb. segments
                        extent = 'SPA';
                elseif DefValues(26)==6		% integer number of cycles
                        extent = 'SPI';
                elseif DefValues(26)==7		% BioNet TXT simulated file
                        extent = 'SPI';
                end;	
                
                if(a==0)
                        wld = [wld(1:b),extent];
                else
                        wld = ['*.','sp?'];
                end;
                
                [filename, pathname] = uigetfile(wld, 'Retrival of Spike Chosen Data', .4, .4);
                if filename == 0, return; end;
                
        else % open file with name stored in in1
                
                
                filename = in1;
                pathname = [pwd ,'\'];
        end 
        
        FullName = [pathname,filename];
        NAME = FullName;
        
        [fid,message] = fopen(FullName,'rb');
        if fid<0, 
                error(message);
        end;
        cd(pathname(1:length(pathname)-1)); 
        SAVE_DIR = pwd;
        
        
        % Determining the length of data rows. Data file can be assemled from vary trial vectors 
        % with varied length of trials. In order to put the data into the matrix, we must determine
        % the maximal  number of columns and rows. <CR> symbol (or 10 ASCII) used as a border
        % between neubour trials.
        
        [F,lgn] = fread(fid,inf,'char');
        status = fseek(fid,0,-1);  % rewind the file
        ind=0;
        Spk = [];
        
        while(ind<lgn)
                % spikes number, start stim and end stim reading...
                vect=[];
                vect(1:5) = fread(fid,5,'float');
                
                % spikes arrival times reading...
                vect(6:(vect(2)+5)) = fread(fid,vect(2),'float');
                
                % reading of the eye motion interval length , Stim Velocity inf and tilt.	 
                EyeMotionLength=fread(fid,1,'float');
                vect(vect(2)+6) = EyeMotionLength;
                
                tmp=3*EyeMotionLength+2;
                
                vect((vect(2)+7):(vect(2)+8+3*EyeMotionLength))=fread(fid,tmp,'float');
                
                
                ncol = size(Spk,2);
                nrow = size(Spk,1);                %=TrialsNum of the given file
                vlgn = length(vect);
                
                maxncol = max((vlgn+5),ncol);
                newrow = nrow + 1;
                tmp = zeros(newrow,maxncol);
                for i=1:nrow,
                        tmp(i,1:ncol) =Spk(i,:);
                end;
                Spk(newrow,1:vlgn) = vect;
                ind=ftell(fid);
        end;
        fclose(fid);
	
        
        
        %--------- open graph figure---------------------   
        if  (size(TRET_DAT,2) > 1 ),    % third member exists (pointer on graph figure)
                if strcmp(get(TRET_DAT(1),'Type'),'figure'),
                        Fig2 = TRET_DAT(2);
                        set(0,'CurrentFigure',Fig2);
                        kids=get(Fig1,'Children');
                        for i=1:length(kids),
                                tp=get(kids(i),'type');
                                if (strcmp(tp,'axes')) | (strcmp(tp,'uicontrol'))
                                        delete(kids(i));
                                end;
                        end;
                end;
        else,
                Fig2 = figure('Units','normalized', 'Position',[0.2822    0.0417    0.7148    0.9089],...
                        'Backingstore','on','color','w','DefaultAxesXcolor','k',...
                        'DefaultAxesFontSize',9,'DefaultAxesDrawMode','fast',...
                        'DefaultAxesYColor','k','Menubar','none','Name',FullName);
                set(Fig2,'Units','Pixels');
                
                %%% ~~~ set(TRET_DAT(1),'UserData',[]); %  Reset User Data ( TotSpk )
                
                unitret('build_Fig2_menu',Fig2,'spikes');
        end;
        
        %TRET_DAT(2:9) = [Fig2 u11 u22 u23 u32 u33 u16 u18];
        unitret('set_markeddata',Spk);
        
	if DefValues(188) &  exist([FullName '.STIM.mat']),		% load STIM together with spikes
		global STIM
		load([FullName '.STIM.mat']);
	end	
	
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
        
        
        unitret('redraw_spk',1);
        set(gcf,'Pointer','Arrow');
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'open_spk'))
        
        pathname = [pwd ,'\'];
        filename = in1;
        showNORMIR = in2;
        numb       = in3; % number of file in list
        
        FullName = [pathname,filename];
        NAME = filename;
        
        [fid,message] = fopen(FullName,'rb');
        if fid<0, 
                error(message);
        end;
        com = ['cd ' pathname(1:length(pathname)-1)]; 
        eval(com);
        
        
        % Determining the length of data rows. Data file can be assemled from vary trial vectors 
        % with varied length of trials. In order to put the data into the matrix, we must determine
        % the maximal  number of columns and rows. <CR> symbol (or 10 ASCII) used as a border
        % between trials.
        
        [F,lgn] = fread(fid,inf,'char');
        status = fseek(fid,0,-1);  % rewind the file
        ind=0;
        Spk = [];
        
        while(ind<lgn)
                % spikes number, start stim and end stim reading...
                vect=[];
                vect(1:5) = fread(fid,5,'float');
                
                % spikes arrival times reading...
                vect(6:(vect(2)+5)) = fread(fid,vect(2),'float');
                
                % reading of the eye motion interval length , Stim Velocity inf and tilt.	 
                EyeMotionLength=fread(fid,1,'float');
                vect(vect(2)+6) = EyeMotionLength;
                
                tmp=3*EyeMotionLength+2;
                
                vect((vect(2)+7):(vect(2)+8+3*EyeMotionLength))=fread(fid,tmp,'float');
                
                
                ncol = size(Spk,2);
                nrow = size(Spk,1);                %=TrialsNum of the given file
                vlgn = length(vect);
                
                maxncol = max((vlgn+5),ncol);
                newrow = nrow + 1;
                tmp = zeros(newrow,maxncol);
                for i=1:nrow,
                        tmp(i,1:ncol) =Spk(i,:);
                end;
                Spk(newrow,1:vlgn) = vect;
                ind=ftell(fid);
        end;
        fclose(fid);
        
        
        
        process('average_norm',0,Spk,[showNORMIR numb]);
        
        set(gcf,'Pointer','Arrow');
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'redraw_spk'))
        set(gcf,'Pointer','Watch');
        
        ud=get(0,'UserData');
        ud(51)=0;
        set(0,'UserData',ud);
        
        
        PFR = [];				% Peak Firing Rate
        
        kids=get(TRET_DAT(2),'Children');
        for i=1:length(kids),
                tp=get(kids(i),'type');
                if (strcmp(tp,'axes')) | (strcmp(tp,'uicontrol'))
                        delete(kids(i));
                end;
        end;
        
        
        first = in1;
        AccDrawMenu = get(TRET_DAT(7),'UserData');
        AccSegmentDraw = get(AccDrawMenu(1),'Checked');
        
        Spk = unitret('get_markeddata');
        
        if DefValues(147) & first==1, % Split to cycles
                NewSpk = [];
                temprow = zeros(1,size(Spk,2));
                CycleDuration = 1000/DefValues(75);
                k = 0;
                for i = 1:size(Spk,1),
                        
                        TrialNum = Spk(i,1);     	 
                        SpikesNum = Spk(i,2);
                        StartSpikeData = Spk(i,3);
                        EndSpikeData = Spk(i,4);
                        mode = Spk(i,5);
                        SpikesData = Spk(i,6:SpikesNum+5);
                        EyeMotionLength = Spk(i,SpikesNum+6);
                        EyeTimeInterval= Spk(i,(SpikesNum+7):(SpikesNum+EyeMotionLength+6));
                        HorEyeInterval = Spk(i,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6));
                        VerEyeInterval = Spk(i,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6));
                        StimVelocity = Spk(i,SpikesNum+3*EyeMotionLength+7);
                        StimTilt = Spk(i,SpikesNum+3*EyeMotionLength+8);
                        
                        NCycles = (EndSpikeData-StartSpikeData)/CycleDuration;

                        if fix(NCycles) ~= NCycles,
                                errordlg(['Segment duration isn`t a multiple of a cycle!'],['ERROR!'])
				watchoff
				return
                        end
                        for j = 1:NCycles,
                                k = k + 1;
                                NewTrialNum = TrialNum;
                                NewStartSpikeData = StartSpikeData + (j-1)*CycleDuration;
                                NewEndSpikeData = NewStartSpikeData + CycleDuration;
                                NewSpikesData = SpikesData(find( SpikesData>=NewStartSpikeData & SpikesData<NewEndSpikeData ));
                                NewSpikesNum = length(NewSpikesData);
                                NewEyeMotionLength = EyeMotionLength/NCycles;
                                NewEyeTimeInterval = EyeTimeInterval(1+(j-1)*NewEyeMotionLength:j*NewEyeMotionLength);
                                NewHorEyeInterval =  HorEyeInterval(1+(j-1)*NewEyeMotionLength:j*NewEyeMotionLength);
                                NewVerEyeInterval =  VerEyeInterval(1+(j-1)*NewEyeMotionLength:j*NewEyeMotionLength);
                                NewStimVelocity = Spk(i,SpikesNum+3*EyeMotionLength+7);
                                NewStimTilt = Spk(i,SpikesNum+3*EyeMotionLength+8);
                                
                                row = [NewTrialNum NewSpikesNum NewStartSpikeData NewEndSpikeData mode NewSpikesData NewEyeMotionLength NewEyeTimeInterval NewHorEyeInterval NewVerEyeInterval NewStimVelocity NewStimTilt];
                                temprow(1:length(row))= row;
                                NewSpk(k,:) = temprow;
                                
                        end
                        
                end 		
                Spk = NewSpk;
                unitret('set_markeddata',NewSpk);
                
                
        end % of Split to cycles
	
        maxcol = DefValues(13);
        maxrow = DefValues(16);
        
        grapsnum = maxcol*maxrow; % number of the same type graphs on the screen (on or off)
        
        
        color = ['m','b','g', 'r']; c = 1;
        np=size(Spk,1);
        
        
        % Check Number of Plots on the Figure
        % if np>grapsnum
        %    warndlg('Please increase the number of plots on graph (go to Setup)','Advise...');
        %    return
        % end
        
        Spk0 = [];
        Spk1 = [];
        for i=1:np,
                if Spk(i,5) == 0,
                        Spk0 = [Spk0;Spk(i,:)];
                else
                        Spk1 = [Spk1;Spk(i,:)];
                end;
        end;
        
        for i=0:1,
                s(i+1,:) = ['CurSpk = []; CurSpk = Spk', num2str(i),';'];
        end; 
        
        wi = .05;                          % width of each interval between axises
        hi = .03;                           % higth of each interval between axises
        wt = .1;                            % width of field for axis
        ht = .7;                          % heigth of field for axis  
        %      wb = (wt-(2*maxcol-1)*wi)/(2*maxcol);   % x size for one subplot axis 
        %      hb = (ht-(maxrow-1)*hi)/maxrow;   % y ....
        
        wb = (1-3*wi*maxcol)/(2*maxcol);
        colwidth=2*wb+3*wi;
        
        hb = (ht-(maxrow+1)*hi)/maxrow;
        
        
        if DefValues(19),    % economy plot (Raster)
                for m=1:2,
                        eval(s(m,:));
                        k=0;
                        nap(m) = size(CurSpk,1);
                        if(nap(m))
                                axpos = [.05+(0.45+wi)*(~(m-1)) .4 .4 .3];
                                
                                xlim = [0 (max(CurSpk(:,4) - CurSpk(:,3)))];
                                
                                ax = axes('Position',axpos,'DrawMode','fast','TickDir','out',...
                                        'XLimMode','Manual','XLim',xlim,'YTick',[], 'NextPlot','add');
                                
                                for k=1:nap(m),
                                        TrialNum =CurSpk(k,1); 
                                        SpikesNum = CurSpk(k,2);
                                        StartSpikeData = CurSpk(k,3);
                                        EndSpikeData = CurSpk(k,4);
                                        SpikeArrTime = CurSpk(k,(6:SpikesNum+5)) - StartSpikeData;
                                        SpikeAmp = ones(size(SpikeArrTime)).*k;
                                        line(SpikeArrTime,SpikeAmp,'color','b','LineStyle', '.','LineWidth',1);
                                end;
                        end;
                end; 
                
        else,
                
                
                
                
                % main drawing loop:
                for m=1:2,
                        eval(s(m,:));
                        nap(m) = size(CurSpk,1);
                        if(nap(m))
                                for i=0:maxcol-1,
                                        for j=0:maxrow-1,
                                                gind = (i*maxrow+j);
                                                k=first + gind;
                                                if(k>nap(m)),
                                                        break;
                                                else
                                                        TrialNum =CurSpk(k,1); 
                                                        SpikesNum = CurSpk(k,2);
                                                        StartSpikeData = CurSpk(k,3); 
                                                        EndSpikeData = CurSpk(k,4);
                                                        SpikeArrTime = CurSpk(k,(6:SpikesNum+5));
                                                        
                                                        
                                                        EyeMotionLength=CurSpk(k,SpikesNum+6);
                                                        
                                                        EyeTimeInterval= CurSpk(k,(SpikesNum+7):(SpikesNum+EyeMotionLength+6));
                                                        HorEyeInterval = CurSpk(k,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6));
                                                        VerEyeInterval = CurSpk(k,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6));
                                                        StimVelocity = CurSpk(k,(SpikesNum+3*EyeMotionLength+7));
                                                        Tilt = CurSpk(k,(SpikesNum+3*EyeMotionLength+8));
                                                        
                                                        %nado ubrat' chtenie pustogo chisla spikov
                                                        
                                                        %		 axpos = [.01+i*.5+(m-1)*.25 .9-j*.095 .22 .09];
                                                        axpos = [i*colwidth + wi+(~(m-1))*(wi+wb), 1-(j+1)*(hb+hi), wb, hb];
                                                        
                                                        
                                                        if DefValues(86)==1,  % Spikes Plot and EM Plot
                                                                ax = axes('Position',axpos,'DrawMode','fast','TickDir','out',...
                                                                        'XLimMode','Manual','XLim',[CurSpk(k,3) CurSpk(k,4)],'YLimMode',...
                                                                        'Manual','YLim',[DefValues(7) DefValues(10)],'UserData',...
                                                                        CurSpk(k,:),'FontSize',7);
							elseif DefValues(86)==2, %
								spike_train = process('make_train',CurSpk(k,:));
								smoothed_spike_train = unitret('smooth',spike_train,1,3);
                                                                ax = axes('Position',axpos,'DrawMode','fast','TickDir','out',...
                                                                        'XLimMode','Manual','XLim',[CurSpk(k,3) CurSpk(k,4)],'YLimMode',...
                                                                        'Manual','YLim',[0 0.5],'UserData',...
                                                                        CurSpk(k,:),'FontSize',7);
								DefValues(23) = 0; % Do not plot EM
                                                        elseif DefValues(86)==3, % IFR Plot  
                                                                IFR = 1./( diff([0 SpikeArrTime])/1000 ); % in spk/seconds
                                                                YMax= max([IFR 0])+10;
                                                                ax = axes('Position',axpos,'DrawMode','fast','TickDir','out',...
                                                                        'XLimMode','Manual','XLim',[CurSpk(k,3) CurSpk(k,4)],'YLimMode',...
                                                                        'Manual','YLim',[0 YMax],'UserData',...
                                                                        CurSpk(k,:),'FontSize',7);
                                                                
                                                                DefValues(23) = 0; % Do not plot EM
                                                        end 
                                                        
                                                        set(text,'String',['Trial #',num2str(CurSpk(k,1)),', ',num2str(SpikesNum), ' spk'],'units','normal',...
                                                                'Position',[.2 .65],'FontSize',8,'color',[0.5020 0 0.2510]);
                                                        
                                                        strax =    sprintf(' %17.13f',ax);
                                                        
                                                        
                                                        
                                                        if DefValues(23),
                                                                if DefValues(27)
                                                                        EM = [HorEyeInterval;VerEyeInterval];
                                                                        alfa = pi*Tilt/180;
                                                                        Trans = [cos(alfa) sin(alfa); -sin(alfa) cos(alfa)];
                                                                        EMNew = Trans * EM;
                                                                        HorEyeInterval = EMNew(1,:);
                                                                        VerEyeInterval = EMNew(2,:);
                                                                end;
                                                                line(EyeTimeInterval,HorEyeInterval,'Color',[0 .502 0]);
                                                                line(EyeTimeInterval,VerEyeInterval,'Color','m','LineWidth',1);
                                                        end; 
                                                        
                                                        if SpikesNum
                                                                if DefValues(1)
                                                                        bins=(StartSpikeData+DefValues(1)/2:DefValues(1):EndSpikeData-DefValues(1)/2);
                                                                        [N,SpikeHist]=hist(SpikeArrTime,bins);
                                                                        
                                                                        N = N/DefValues(1)*1000;
                                                                        
                                                                        [xx,yy] = bar(SpikeHist,N);
                                                                        
                                                                        if DefValues(155),	% Calculate Peak Firing Rate
                                                                                pfr = max(N);
                                                                                PFR = [PFR pfr];
                                                                                set(text,'String',['pfr ',num2str(pfr),' s/s'],'units','normal',...
                                                                                        'Position',[.2 .95],'FontSize',8,'color',[0 0 0]);
                                                                                
                                                                        end;   
                                                                        
                                                                else
                                                                        xx = zeros(1,3*SpikesNum);
                                                                        xx(1:3:(3*SpikesNum-2)) = SpikeArrTime;
                                                                        xx(2:3:(3*SpikesNum-1)) = SpikeArrTime;
                                                                        xx(3:3:(3*SpikesNum))   = SpikeArrTime;
                                                                        yy = zeros(1,3*SpikesNum);
                                                                        yy(2:3:(3*SpikesNum-1)) = ones(1,SpikesNum); 
                                                                end;
                                                                
                                                                
                                                                if DefValues(86)==1, 
                                                                        SpikeAmp = (DefValues(10) - DefValues(7)) / (3*max(yy));
                                                                        line(xx,SpikeAmp*yy+DefValues(7),'Color',color(c));
								elseif DefValues(86)==2, % smoothed spikes
									line([StartSpikeData:EndSpikeData-1], smoothed_spike_train, 'Color',[ 0 0.2510 0.5020],'LineWidth',1);
                                                                elseif DefValues(86)==3, % IFR
									line(SpikeArrTime, IFR, 'Color',[ 0 0.2510 0.5020],'LineWidth',1); 
                                                                end
                                                        end
                                                        
                                                        % if accumulation function should be drawn...
                                                        if strcmp(AccSegmentDraw,'on'),
                                                                unitret('redraw_accumulation',CurSpk(k,(6:SpikesNum+5)));
                                                        end;    
                                                        %                if any trials were already edited (scrolling during  edit)                   
                                                        
                                                        tmp1 = get(TRET_DAT(5),'UserData');
                                                        if ~isempty(tmp1),
                                                                for jj=1:size(tmp1,1),
                                                                        if (tmp1(jj,1:5) ==CurSpk(k,1:5)), %set new limits
                                                                                set(gca,'XLim',[tmp1(jj,6) tmp1(jj,7)]);
                                                                                break;
                                                                        end;
                                                                end;   
                                                        end;   
                                                        
                                                        if (c==length(color)), 
                                                                c =0;
                                                        end;
                                                        c = c+1;         
                                                end;
                                        end;  
                                end; 
                                
                        end;  
                end;
                
                
                if(nap(1)>grapsnum  | nap(2) > grapsnum ),
                        back = max(1, first - grapsnum); 
                        next = first+grapsnum; 
                        if ( in1 > grapsnum)
                                more_call = ['unitret(''redraw_spk'',',num2str(back),');'];
                                more_button = uicontrol(TRET_DAT(2),'Units','normal', 'Position',[.7 .02, .1 .05],...
                                        'String','<<','Callback',more_call);
                        end;
                        if(next <= nap(1) | next <= nap(2)),
                                more_call = ['unitret(''redraw_spk'',',num2str(next),');'];
                                more_button = uicontrol(TRET_DAT(2),'Units','normal', 'Position',[.85 .02, .1 .05],...
                                        'String','>>','Callback',more_call);
                        end;
                end;
                
        end;  
        
        if isempty(Spk0),
                Spk0 = 0;
        elseif isempty(Spk1)
                Spk1 = 0;
        end;
        
        if (DefValues(20))
                process('average',Spk0,Spk1);
	end;
        
        unitret('figname');
        
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
        
        %%% unitret('redraw_spk',num2str(next));     
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'setup_spk'))
        
        
        Fig1 = figure('Backingstore','off','Name','Display Setup','Color','w',...
                'Units','Normal','Position',[.1 .1 .6 .8],'Resize','On', 'Menubar','none','Number','off');
        set(gcf,'Pointer','Watch');
        
        
        
        uicontrol(Fig1,'Style','text','Position',[.2 .91 .5 .08],...
                'Units','normal','ForegroundColor','m',...
                'BackgroundColor','w','String','Display Setup:',...
                'HorizontalAlignment','center');
        %---------------------------------------------------
        uicontrol(Fig1,'Style','text','Position',[.02 .85 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',['Histogram, (', num2str(DefValues(2)), '...',...
                        num2str(DefValues(3)),') ms'],'HorizontalAlignment','left');
        

        
        u1 = uicontrol(Fig1,'Style','edit','Position',[.48 .85 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(1)),...
                'HorizontalAlignment','left','Callback','unitret(''update'',1);');
        %-----------------  
        
        uicontrol(Fig1,'Style','text','Position',[.02 .77 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',['Hist. Average, (', num2str(DefValues(21)), '...',...
                        num2str(DefValues(22)),') ms'],'HorizontalAlignment','left');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.48 .77 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(20)),...
                'HorizontalAlignment','left','Callback','unitret(''update'',20);');
        %%-------------------------------------------------------------
        
        u20 = uicontrol(Fig1,'Style','checkbox','Position',[.02 .67 .16 .05],...
                'Units','normalized','BackgroundColor','w','Value',DefValues(41),...
                'ForegroundColor','k','String','Y auto',...
                'HorizontalAlignment','left');
        
        
        
        u21 = uicontrol(Fig1,'Style','edit','Position',[.14 .67 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(42)),...
                'HorizontalAlignment','left','Callback',['u=get(gcf,''CurrentObject''); val = str2num(get(u,''string''));',...
                        'ud=get(0,''UserData''); ud(42) = val; set(0,''userdata'',ud);']);
        
        
        set(u20,'UserData',[u21 u20]);
        
        set(u20,'callback', ['r=gco; val = get(r,''Value''); ud = get(r, ''UserData'');',...
                        'if (val), set(ud(1), ''Enable'',''off''), else, set(ud(1), ''Enable'',''on'');end;',...
                        'ud0=get(0,''UserData''); ud0(41) = val; set(0,''userdata'',ud0);']);
        
        if DefValues(41), set(u21,'Enable','off'); else set(u21,'Enable','on'); end;
        %%-------------------------------------------------------------
        
        u30 = uicontrol(Fig1,'Style','checkbox','Position',[.36 .67 .16 .05],...
                'Units','normalized','BackgroundColor','w','Value',DefValues(43),...
                'ForegroundColor','k','String','X auto',...
                'HorizontalAlignment','left');
        
        
        
        u31 = uicontrol(Fig1,'Style','edit','Position',[.48 .67 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(44)),...
                'HorizontalAlignment','left','Callback',['u=get(gcf,''CurrentObject''); val = str2num(get(u,''string''));',...
                        'ud=get(0,''UserData''); ud(44) = val; set(0,''userdata'',ud);']);
       
        
        
        u32 = uicontrol(Fig1,'Style','edit','Position',[.64 .67 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(45)),...
                'HorizontalAlignment','left','Callback',['u=get(gcf,''CurrentObject''); val = str2num(get(u,''string''));',...
                        'ud=get(0,''UserData''); ud(45) = val; set(0,''userdata'',ud);']);
        
        
        set(u30,'UserData',[u31 u32 u30]);
        
        set(u30,'callback', ['r=gco; val = get(r,''Value''); ud = get(r, ''UserData'');',...
                        'if (val), set(ud(1:2), ''Enable'',''off''), else, set(ud(1:2), ''Enable'',''on'');end;',...
                        'ud0=get(0,''UserData''); ud0(43) = val; set(0,''userdata'',ud0);']);
        
        if DefValues(43), set([u31 u32],'Enable','off'); else set([u31 u32],'Enable','on'); end;
        
        %%-------------------------------------------------------------
        uicontrol(Fig1,'Style','text','Position',[.02 .59 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',['Odd-Even cols, (', num2str(DefValues(14)), '...',...
                        num2str(DefValues(15)),')'],'HorizontalAlignment','left');
        
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.48 .59 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(13)),...
                'Callback','unitret(''update'',13);');
        %----------------
        
        
        uicontrol(Fig1,'Style','text','Position',[.02 .51 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',['Odd-Even rows (',num2str(DefValues(17)),'...',...
                        num2str(DefValues(18)),')'], 'HorizontalAlignment','left');
        
        
        u4 = uicontrol(Fig1,'Style','edit','Position',[.48 .51 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(16)),...
                'Callback','unitret(''update'',16);');
        %----------------------
        uicontrol(Fig1,'Style','text','Position',[.02 .45 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Raster Plot', 'HorizontalAlignment','left');
        
        
        u5 = uicontrol(Fig1,'Style','checkbox','Position',[.48 .45 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','value',DefValues(19),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(19) = val; set(0,''userdata'',ud);']);
        
        
        
        % IFR interpolation step 
        u4 = uicontrol(Fig1,'Style','edit','Position',[.86 .45 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(172)),...
		'Callback','unitret(''update'',172,0,1);');


	uicontrol(Fig1,'Style','Popupmenu','Units','Normalized','Position',[.7 .45 .15 .05],...
                'String','spikes|smoothed|IFR','Value',DefValues(86),'Callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(86) = val; set(0,''userdata'',ud);']);
		
	
	uicontrol(Fig1,'Style','radiobutton','Position',[.81 .5 .15 .05],...
                'Units','normalized','BackgroundColor','w','String','Smooth PSTH',...
                'ForegroundColor','k','value',DefValues(196),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(196) = val; set(0,''userdata'',ud);']);
	 
        %---------------------
        %----------------------
        uicontrol(Fig1,'Style','text','Position',[.02 .4 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Eye Movements', 'HorizontalAlignment','left');
        
        
        u6 = uicontrol(Fig1,'Style','checkbox','Position',[.48 .4 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','value',DefValues(23),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(23) = val; set(0,''userdata'',ud);']);
        %---------------------
        
        
        %---------------------
        uicontrol(Fig1,'Style','text','Position',[.02 .35 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Normalized to Y', 'HorizontalAlignment','left');
        
        
        u7 = uicontrol(Fig1,'Style','checkbox','Position',[.48 .35 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','value',DefValues(27),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(27) = val; set(0,''userdata'',ud);']);
        
        
        %---------------------
        
        
        %---------------------
        uicontrol(Fig1,'Style','text','Position',[.02 .3 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Separate odd-even histogram', 'HorizontalAlignment','left');
        
        
        u8 = uicontrol(Fig1,'Style','checkbox','Position',[.48 .3 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','value',DefValues(35),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(35) = val; set(0,''userdata'',ud);']);
        
        
	uicontrol(Fig1,'Style','Popupmenu','Units','Normalized','Position',[.6 .3 .1 .05],...
                'String','both|odd|even','Value',DefValues(189),'Callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(189) = val; set(0,''userdata'',ud);']);


        %---------------------
        uicontrol(Fig1,'Style','text','Position',[.02 .25 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Show rate for:', 'HorizontalAlignment','left');
        
        
        u9 = uicontrol(Fig1,'Style','radiobutton','Position',[.38 .25 .15 .05],...
                'Units','normalized','BackgroundColor','w','String','Spont.',...
                'ForegroundColor','k','value',~DefValues(36),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(36) = ~val; set(0,''userdata'',ud);',...
                        'u9_10=get(u, ''UserData''); set(u9_10(2), ''value'', ~val);']);
        
        
        u10 = uicontrol(Fig1,'Style','radiobutton','Position',[.58 .25 .2 .05],...
                'Units','normalized','BackgroundColor','w','String','Driven',...
                'ForegroundColor','k','value',DefValues(36),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(36) = val; set(0,''userdata'',ud);',...
                        'u9_10=get(u, ''UserData''); set(u9_10(1), ''value'', ~val);']);
        
        set(u9, 'UserData',[u9 u10]);
        set(u10,'UserData',[u9,u10]);
        
        
        %---------------------
        
        uicontrol(Fig1,'Style','radiobutton','Position',[.78 .4 .2 .05],...
                'Units','normalized','BackgroundColor','w','String','DI',...
                'ForegroundColor','k','value',DefValues(85),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(85) = val; set(0,''userdata'',ud);']);
        %---------------------
        
        uicontrol(Fig1,'Style','radiobutton','Position',[.78 .35 .2 .05],...
                'Units','normalized','BackgroundColor','w','String','Split to cycles',...
                'ForegroundColor','k','value',DefValues(147),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(147) = val; set(0,''userdata'',ud);']);
        %---------------------

	 uicontrol(Fig1,'Style','radiobutton','Position',[.78 .3 .2 .05],...
                'Units','normalized','BackgroundColor','w','String','Peak Firing Rate',...
                'ForegroundColor','k','value',DefValues(155),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(155) = val; set(0,''userdata'',ud);']);
        %---------------------
        
        
        uicontrol(Fig1,'Style','text','Position',[.02 .19 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String','Eye movement scale:','HorizontalAlignment','left');
        
        
        %-----------------------------
        uicontrol(Fig1,'Style','text','Position',[.02 .11 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',['From (',num2str(DefValues(8)),'...',...
                        num2str(DefValues(9)),')'], 'HorizontalAlignment','left');
        
        
        u11 = uicontrol(Fig1,'Style','edit','Position',[.28 .11 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(7)),...
                'Callback','unitret(''update'',7);');
        %----------------------
        uicontrol(Fig1,'Style','text','Position',[.02 .03 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',['To (',num2str(DefValues(11)),'...',...
                        num2str(DefValues(12)),')'], 'HorizontalAlignment','left');
        
        
        u12= uicontrol(Fig1,'Style','edit','Position',[.28 .03 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(10)),...
                'Callback','unitret(''update'',10);');
        %---------------------
        uicontrol(Fig1,'Style','text','Position',[.7 .19 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String','PSTH in:','HorizontalAlignment','left');
        
        
        u14 = uicontrol(Fig1,'Style','Popupmenu','Units','Normalized','Position',[.8 .19 .15 .05],...
                'String','#spikes|spikes/sec','Value',DefValues(123),'Callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(123) = val; set(0,''userdata'',ud);']);
        
        %------- Trigger Event Time
        
        %TrigEventTime                           %124
        %NormByPreTrigFR                         %125
        %PreTrigFR                               %126 
        
        
        
        u15= uicontrol(Fig1,'Style','edit','Position',[.8 .12 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(124)),...
                'Callback','unitret(''update'',124,0,1);');
        
        uicontrol(Fig1,'Style','text','Position',[.7 .12 .1 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Trig. event','HorizontalAlignment','left');
        
        
        u16= uicontrol(Fig1,'Style','radiobutton','Position',[.6 .05 .2 .05],...
                'Units','normalized','BackgroundColor','w','String','Norm. by PreTrig. FR:',...
                'ForegroundColor','k','value',DefValues(125),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(125) = val; set(0,''userdata'',ud);',...
                        'u17=get(u,''Userdata''); if val, set(u17,''enable'',''on''); else set(u17, ''enable'',''off''); end;']);
        
        
        u17= uicontrol(Fig1,'Style','edit','Position',[.8 .05 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(126)),...
                'Callback','unitret(''update'',126,0,1);');
        
        set(u16,'Userdata',u17);
        
        if DefValues(125), set(u17,'enable','on'); else set(u17,'enable','off'); end;
        
        u18= uicontrol(Fig1,'Style','radiobutton','Position',[.45 .19 .2 .05],...
                'Units','normalized','BackgroundColor','w','String','Ind. Traces',...
                'ForegroundColor','k','value',DefValues(132),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(132) = val; set(0,''userdata'',ud);']);
        
        %---------------------     
        OK_button=uicontrol(Fig1,'Style','pushbutton','Position',[.75 .9 .22 .06],...
                'Units','Normalized','String','OK','Callback',['delete(',num2str(Fig1), '); unitret(''update'',0,3);']);
        
        cancel=uicontrol(Fig1,'Style','pushbutton','Position',[.75 .82 .22 .06],...
                'Units','Normalized','String','Cancel','Callback',['delete(',num2str(Fig1), '), return']);
        
        
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
        
        
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'spectra_setup'))
        
        
        Fig1 = figure('Backingstore','off','Name','Spectra Setup','Color','w',...
                'Units','Normal','Position',[.22 .3 .5 .6],'Resize','On', 'Menubar','none','Number','off');
        set(gcf,'Pointer','Watch');
        
        
        %............................. 1 ...........................................
        uicontrol(Fig1,'Style','text','Position',[.07 .2 .1 .05],...
                'Units','normal','ForegroundColor',[0.5 0  1],...
                'BackgroundColor','w','String','With DC',...
                'HorizontalAlignment','center');
        
        u1 = uicontrol(Fig1,'Style','checkbox','Position',[.2 .2 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','value',DefValues(50),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(50) = val; set(0,''userdata'',ud);']);
        
        %.............................. end of 1 ....................................
        
        %................................. 2 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .81 .3 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','Frequency Axis Limit:',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.36 .825 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(53)),...
                'Callback',['ud=get(0,''Userdata''); ud(53)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
        
        %.............................. end of 2 ....................................
        
        %............................... 3 .........................................
        uicontrol(Fig1,'Style','text','Position',[.02 .71 .3 .05],...
                'Units','normal','ForegroundColor',[.5 .01 .01],...
                'BackgroundColor','w','String','Mean Baseline activity:',...
                'HorizontalAlignment','center');
        
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.36 .725 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(54)),...
                'Callback',['ud=get(0,''Userdata''); ud(54)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
        
        %................................ end of 3 ..................................
        
        %............................... 4 .........................................
        uicontrol(Fig1,'Style','text','Position',[.02 .61 .3 .05],...
                'Units','normal','ForegroundColor',[.15 .24 .29],...
                'BackgroundColor','w','String','nfft:',...
                'HorizontalAlignment','center');
        
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.36 .625 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(59)),...
                'Callback',['ud=get(0,''Userdata''); ud(59)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
        
        %................................ end of 4 ..................................
        %............................... 5 .........................................
        uicontrol(Fig1,'Style','text','Position',[.02 .51 .3 .05],...
                'Units','normal','ForegroundColor',[.15 .24 .29],...
                'BackgroundColor','w','String','noverlap:',...
                'HorizontalAlignment','center');
        
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.36 .525 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(60)),...
                'Callback',['ud=get(0,''Userdata''); ud(60)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
        
        %................................ end of 5 ..................................
        %............................... 6 .........................................
        uicontrol(Fig1,'Style','text','Position',[.02 .41 .3 .05],...
                'Units','normal','ForegroundColor',[.15 .24 .29],...
                'BackgroundColor','w','String','Window:',...
                'HorizontalAlignment','center');
        
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.36 .425 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(61)),...
                'Callback',['ud=get(0,''Userdata''); ud(61)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
        
        %................................ end of 6 ..................................
        %............................... 7 .........................................
        uicontrol(Fig1,'Style','text','Position',[.02 .31 .3 .05],...
                'Units','normal','ForegroundColor','r',...
                'BackgroundColor','w','String','Significance Level (p):',...
                'HorizontalAlignment','center');
        
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.36 .325 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(62)),...
                'Callback',['ud=get(0,''Userdata''); ud(62)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
        
        %................................ end of 7 ..................................
        %............................... 8 .........................................
        uicontrol(Fig1,'Style','text','Position',[.02 .1 .3 .05],...
                'Units','normal','ForegroundColor',[0.0275    0.6510    0.7216],...
                'BackgroundColor','w','String','TF (Hz)',...
                'HorizontalAlignment','center');
        
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.36 .1 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(75)),...
                'Callback',['ud=get(0,''Userdata''); ud(75)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
        
        %................................ end of 8 ..................................
        
        %............................... 9 .........................................
        uicontrol(Fig1,'Style','text','Position',[.5 .1 .2 .05],...
                'Units','normal','ForegroundColor',[0.0275    0.6510    0.7216],...
                'BackgroundColor','w','String','Phase (deg)',...
                'HorizontalAlignment','center');
        
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.7 .1 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(146)),...
                'Callback',['ud=get(0,''Userdata''); ud(146)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
        
        %................................ end of 9 ..................................
        
        %............................... 10 .........................................
        uicontrol(Fig1,'Style','text','Position',[.5 .2 .2 .05],...
                'Units','normal','ForegroundColor',[0.0275    0.6510    0.7216],...
                'BackgroundColor','w','String','Fitting Sine Amp.',...
                'HorizontalAlignment','center');
        
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.7 .2 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(148)),...
                'Callback',['ud=get(0,''Userdata''); ud(148)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
        
        %................................ end of 10 ..................................
        
        %............................... 11 .........................................
        uicontrol(Fig1,'Style','text','Position',[.5 .3 .2 .05],...
                'Units','normal','ForegroundColor',[0.0275    0.6510    0.7216],...
                'BackgroundColor','w','String','Fitting Sine DC',...
                'HorizontalAlignment','center');
        
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.7 .3 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(149)),...
                'Callback',['ud=get(0,''Userdata''); ud(149)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
        
        %................................ end of 11 ..................................
        
        %---------------------     
        
        
        OK_button=uicontrol(Fig1,'Style','pushbutton','Position',[.75 .9 .22 .06],...
                'Units','Normalized','String','OK','Callback',['delete(',num2str(Fig1), '); unitret(''update'',0,4);']);
        
        cancel=uicontrol(Fig1,'Style','pushbutton','Position',[.75 .82 .22 .06],...
                'Units','Normalized','String','Cancel','Callback',['delete(',num2str(Fig1), '), return']);
        
        
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');

        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'eye_spectra_setup'))
        
        
        Fig1 = figure('Backingstore','off','Name','Eye Spectra Setup','Color','w',...
                'Units','Normal','Position',[.22 .3 .5 .6],'Resize','On', 'Menubar','none','Number','off');
        set(gcf,'Pointer','Watch');
        
        
        %............................. 1 ...........................................
        uicontrol(Fig1,'Style','text','Position',[.07 .2 .1 .05],...
                'Units','normal','ForegroundColor',[0.5 0  1],...
                'BackgroundColor','w','String','With DC',...
                'HorizontalAlignment','center');
        
        u1 = uicontrol(Fig1,'Style','checkbox','Position',[.2 .2 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','value',DefValues(161),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(161) = val; set(0,''userdata'',ud);']);
        
        %.............................. end of 1 ...................................
        
        %................................. 2 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .81 .3 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','Frequency Axis Limit:',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.36 .825 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(162)),...
                'Callback',['ud=get(0,''Userdata''); ud(162)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
        
        %.............................. end of 2 ...................................
        
        %............................... 3 .........................................
        uicontrol(Fig1,'Style','text','Position',[.02 .61 .3 .05],...
                'Units','normal','ForegroundColor',[.15 .24 .29],...
                'BackgroundColor','w','String','nfft:',...
                'HorizontalAlignment','center');
        
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.36 .625 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(163)),...
                'Callback',['ud=get(0,''Userdata''); ud(163)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
        
        %................................ end of 3 .................................

        %............................... 4 .........................................
        uicontrol(Fig1,'Style','text','Position',[.02 .51 .3 .05],...
                'Units','normal','ForegroundColor',[.15 .24 .29],...
                'BackgroundColor','w','String','noverlap:',...
                'HorizontalAlignment','center');
        
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.36 .525 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(164)),...
                'Callback',['ud=get(0,''Userdata''); ud(164)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
        
        %................................ end of 4 .................................

        %............................... 5 .........................................
        uicontrol(Fig1,'Style','text','Position',[.02 .41 .3 .05],...
                'Units','normal','ForegroundColor',[.15 .24 .29],...
                'BackgroundColor','w','String','Window:',...
                'HorizontalAlignment','center');
        
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.36 .425 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(165)),...
                'Callback',['ud=get(0,''Userdata''); ud(165)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
        
        %................................ end of 5 .................................

        %............................... 6 .........................................
        uicontrol(Fig1,'Style','text','Position',[.02 .31 .3 .05],...
                'Units','normal','ForegroundColor','r',...
                'BackgroundColor','w','String','Significance Level (p):',...
                'HorizontalAlignment','center');
        
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.36 .325 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(166)),...
                'Callback',['ud=get(0,''Userdata''); ud(166)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
        
        %................................ end of 6 .................................

        %............................... 7 .........................................
        uicontrol(Fig1,'Style','text','Position',[.02 .1 .3 .05],...
                'Units','normal','ForegroundColor',[0.0275    0.6510    0.7216],...
                'BackgroundColor','w','String','Fs (Hz)',...
                'HorizontalAlignment','center');
        
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.36 .1 .11 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(167)),...
                'Callback',['ud=get(0,''Userdata''); ud(167)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
        
        %................................ end of 7 .................................

	%............................... 8 .........................................
 	u3 = uicontrol(Fig1,'Style','Popupmenu','Units','Normalized','Position',[.8 .19 .15 .05],...
                'String','amplitude|power|dB','Value',DefValues(168),'Callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                'ud=get(0,''UserData''); ud(168) = val; set(0,''userdata'',ud);']);
        %................................ end of 8 .................................

	%............................... 9 .........................................
 	u3 = uicontrol(Fig1,'Style','Popupmenu','Units','Normalized','Position',[.8 .39 .15 .05],...
                'String','position|velocity','Value',DefValues(171),'Callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                'ud=get(0,''UserData''); ud(171) = val; set(0,''userdata'',ud);']);
        %................................ end of 9 .................................        
               
        
        %---------------------     
        
        
        OK_button=uicontrol(Fig1,'Style','pushbutton','Position',[.75 .9 .22 .06],...
                'Units','Normalized','String','OK','Callback',['delete(',num2str(Fig1), '); unitret(''update'',0,4);']);
        
        cancel=uicontrol(Fig1,'Style','pushbutton','Position',[.75 .82 .22 .06],...
                'Units','Normalized','String','Cancel','Callback',['delete(',num2str(Fig1), '), return']);
        
        
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
         
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
elseif(strcmp(action,'remove_segment'))
        if (in1==1),            % remove segments 
                zoom1 on;
                prf = ['global TRET_DAT; ',...
                                'MarkedData = get(TRET_DAT(2),''UserData'');',...
                                'RemovedAxes = gca; rd = get(RemovedAxes,''UserData'');',...
                                'nrow = size(MarkedData,1),',...
                                'for j=1:nrow, if rd == MarkedData(j,:), MarkedData=[MarkedData(1:j-1,:); MarkedData(j+1:nrow,:)] ;break;',...
                                'end;set(TRET_DAT(2),''UserData'',MarkedData);delete(RemovedAxes);end;'];
                set(gcf,'KeyPressFcn',prf);
                
        elseif (in1==0),           % end remove segments 
                set(TRET_DAT(4),'UserData',in1, 'enable','on');
                MarkedData = unitret('get_markeddata');
                
                
                nrow = size(MarkedData,1);
                set(gcf,'KeyPressFcn','');
                zoom1 off;
                
                EditedDataKey = get(TRET_DAT(5),'UserData');
                for i = 1:size(EditedDataKey,1),
                        for j=1:size(MarkedData,1),
                                if(MarkedData(j,1:5)==EditedDataKey(i,1:5)),
                                        MarkedData=[MarkedData(1:j-1,:); MarkedData(j+1:nrow,:)]; nrow = nrow - 1; 
                                        break;
                                end;
                        end;  
                end; 
                
                unitret('set_markeddata',MarkedData);
                set(TRET_DAT(5),'UserData',[]);
                
                unitret('redraw_spk',1);
                
        end
        
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
elseif(strcmp(action,'edit'))
        
        
        if (in1==1),            % edit segments 
                set(TRET_DAT(4),'UserData',in1, 'enable','off');
                set(TRET_DAT(5),'enable','on');
                zoom1 on;
                prf = ['global TRET_DAT; a=get(gcf,''CurrentCharacter''); ',...
                                'if (strcmp (a, ''d'') | strcmp (a,''D'')),',...
                                'MarkedData = get(TRET_DAT(2),''UserData'');',...
                                'RemovedAxes = gca; rd = get(RemovedAxes,''UserData'');',...
                                'nrow = size(MarkedData,1);',...
                                'for j=1:nrow, if rd == MarkedData(j,:), MarkedData(j,:) = [];break;',...
                                'end;end;set(TRET_DAT(2),''UserData'',MarkedData);delete(RemovedAxes);end;']; 
                % set(gcf,'KeyPressFcn',prf);
                
                
        elseif (in1==2),            % edit  all segments according to input times
                cell_a = inputdlg('Please, enter time start and end','Edit All Segments',2);
                if isempty(cell_a), return; end;
                struct_a = cell2struct(cell_a,'time');
                StartTime = struct_a.time(1,:);
                EndTime = struct_a.time(2,:);    
                unitret('edit',3,str2num([StartTime; EndTime]))        
                
        elseif (in1==0),           % end edit segments
                set(TRET_DAT(4),'UserData',in1, 'enable','on');
                MarkedData = unitret('get_markeddata');
                
                
                nrow = size(MarkedData,1);
                set(gcf,'KeyPressFcn','');
                zoom1 off;
                
                set(TRET_DAT(5),'enable','off');
                set(TRET_DAT(3),'enable','on');
                
                %           circumsizing of Marked Data according to axes limits:
                %
                
                
                
                EditedDataKey = get(TRET_DAT(5),'UserData');
                Rem = [];
                for i = 1:size(EditedDataKey,1),
                        for j=1:size(MarkedData,1),
                                if(MarkedData(j,1:5)==EditedDataKey(i,1:5)),
                                        % we must update MarkedData here!
                                        TimeStart = EditedDataKey(i,6);
                                        TimeEnd =   EditedDataKey(i,7);
                                        
                                        %--------------------
                                        % Old Data Reading:
                                        TrialNum =MarkedData(j,1); 
                                        
                                        SpikesNum = MarkedData(j,2);
                                        StartSpikeData = MarkedData(j,3);
                                        EndSpikeData = MarkedData(j,4);
                                        Modality = MarkedData(j,5);
                                        SpikeArrTime = MarkedData(j,6:SpikesNum+5);
                                        
                                        EyeMotionLength=MarkedData(j,SpikesNum+6);    
                                        EyeTimeInterval= MarkedData(j,(SpikesNum+7):(SpikesNum+EyeMotionLength+6));
                                        HorEyeInterval = MarkedData(j,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6));
                                        VerEyeInterval = MarkedData(j,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6));
                                        StimVelocity =   MarkedData(j,(SpikesNum+3*EyeMotionLength+7));
                                        Tilt =           MarkedData(j,(SpikesNum+3*EyeMotionLength+8));
                                        
                                        
                                        SpikeArrInd = find((SpikeArrTime >= TimeStart) & (SpikeArrTime <= TimeEnd));
                                        NewSpikeArrTime = SpikeArrTime(SpikeArrInd);
                                        NewSpikeNum = length(NewSpikeArrTime);
                                        
                                        EyeIntervalInd = find((EyeTimeInterval >= TimeStart) & (EyeTimeInterval <= TimeEnd));
                                        NewEyeInterval = EyeTimeInterval(EyeIntervalInd);
                                        NewHorEyeInterval = HorEyeInterval(EyeIntervalInd);
                                        NewVerEyeInterval = VerEyeInterval(EyeIntervalInd);
                                        NewEyeMotionLength = length(NewEyeInterval);
                                        
                                        ReplaceVector = [TrialNum, NewSpikeNum,StartSpikeData,EndSpikeData,Modality,NewSpikeArrTime,...
                                                        NewEyeMotionLength,NewEyeInterval,NewHorEyeInterval,NewVerEyeInterval,...
                                                        StimVelocity, Tilt];
                                        lrv = length(ReplaceVector);                 
                                        MarkedData(j,:) = zeros(1,size(MarkedData,2));
                                        MarkedData(j,1:lrv) = ReplaceVector;
                                        %                        if length(SpikeArrInd) ==0;
                                        %                          Rem = [Rem,j];
                                        %                        end;
                                        break;
                                end;
                        end;  
                end; 
                %                  if ~isempty(Rem),
                %                   MarkedData(Rem,:) = [];
                %                  end;
                unitret('set_markeddata',MarkedData);
                set(TRET_DAT(5),'UserData',[]);
                
                unitret('redraw_spk',1);
                
                
        elseif (in1==3),           % end edit all segments according to input times
                MarkedData = unitret('get_markeddata');
                
                
                nrow = size(MarkedData,1);
                for j=1:size(MarkedData,1),
                        
                        % Old Data Reading:
                        TrialNum =MarkedData(j,1); 
                        
                        SpikesNum = MarkedData(j,2);
                        StartSpikeData = MarkedData(j,3);
                        EndSpikeData = MarkedData(j,4);
                        Modality = MarkedData(j,5);
                        SpikeArrTime = MarkedData(j,6:SpikesNum+5);
                        
                        TimeStart = StartSpikeData + in2(1);
                        TimeEnd   = StartSpikeData + in2(2);
                        
                        EyeMotionLength=MarkedData(j,SpikesNum+6);    
                        EyeTimeInterval= MarkedData(j,(SpikesNum+7):(SpikesNum+EyeMotionLength+6));
                        HorEyeInterval = MarkedData(j,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6));
                        VerEyeInterval = MarkedData(j,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6));
                        StimVelocity =   MarkedData(j,(SpikesNum+3*EyeMotionLength+7));
                        Tilt =           MarkedData(j,(SpikesNum+3*EyeMotionLength+8));
                        
                        
                        SpikeArrInd = find((SpikeArrTime >= TimeStart) & (SpikeArrTime <= TimeEnd));
                        NewSpikeArrTime = SpikeArrTime(SpikeArrInd);
                        NewSpikeNum = length(NewSpikeArrTime);
                        
                        EyeIntervalInd = find((EyeTimeInterval >= TimeStart) & (EyeTimeInterval <= TimeEnd));
                        NewEyeInterval = EyeTimeInterval(EyeIntervalInd);
                        NewHorEyeInterval = HorEyeInterval(EyeIntervalInd);
                        NewVerEyeInterval = VerEyeInterval(EyeIntervalInd);
                        NewEyeMotionLength = length(NewEyeInterval);
                        
                        ReplaceVector = [TrialNum, NewSpikeNum,StartSpikeData,EndSpikeData,Modality,NewSpikeArrTime,...
                                        NewEyeMotionLength,NewEyeInterval,NewHorEyeInterval,NewVerEyeInterval,...
                                        StimVelocity, Tilt];
                        lrv = length(ReplaceVector);                 
                        MarkedData(j,:) = zeros(1,size(MarkedData,2));
                        MarkedData(j,1:lrv) = ReplaceVector;
                end; 
                unitret('set_markeddata',MarkedData);
                set(TRET_DAT(5),'UserData',[]);
                
                unitret('redraw_spk',1);
                
        elseif (in1==4),           % end edit all segments
                set(TRET_DAT(4),'UserData',in1, 'enable','on');
                MarkedData = unitret('get_markeddata');
                
                
                nrow = size(MarkedData,1);
                set(gcf,'KeyPressFcn','');
                zoom1 off;
                
                set(TRET_DAT(5),'enable','off');
                set(TRET_DAT(3),'enable','on');
                
                %           circumsizing of Marked Data according to axes limits:
                %
                
                
                
                EditedDataKey = get(TRET_DAT(5),'UserData');
                Rem = [];
                for i = 1:size(EditedDataKey,1),
                        for j=1:size(MarkedData,1),
                                if 1, 
                                        if(MarkedData(j,1:5)==EditedDataKey(i,1:5)),
                                                TimeStart = EditedDataKey(i,6); 
                                                TimeEnd =   EditedDataKey(i,7); 
                                                ShiftRight = TimeStart - MarkedData(j,3);
                                                ShiftLeft  = MarkedData(j,4) - TimeEnd;
                                        end %                         	
                                        
                                        
                                        %--------------------
                                        
                                        % Old Data Reading:
                                        TrialNum =MarkedData(j,1); 
                                        
                                        SpikesNum = MarkedData(j,2);
                                        StartSpikeData = MarkedData(j,3);
                                        EndSpikeData = MarkedData(j,4);
                                        Modality = MarkedData(j,5);
                                        SpikeArrTime = MarkedData(j,6:SpikesNum+5);
                                        
                                        TimeStart = StartSpikeData + ShiftRight;
                                        TimeEnd   = EndSpikeData - ShiftLeft;
                                        
                                        EyeMotionLength=MarkedData(j,SpikesNum+6);    
                                        EyeTimeInterval= MarkedData(j,(SpikesNum+7):(SpikesNum+EyeMotionLength+6));
                                        HorEyeInterval = MarkedData(j,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6));
                                        VerEyeInterval = MarkedData(j,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6));
                                        StimVelocity =   MarkedData(j,(SpikesNum+3*EyeMotionLength+7));
                                        Tilt =           MarkedData(j,(SpikesNum+3*EyeMotionLength+8));
                                        
                                        
                                        SpikeArrInd = find((SpikeArrTime >= TimeStart) & (SpikeArrTime <= TimeEnd));
                                        NewSpikeArrTime = SpikeArrTime(SpikeArrInd);
                                        NewSpikeNum = length(NewSpikeArrTime);
                                        
                                        EyeIntervalInd = find((EyeTimeInterval >= TimeStart) & (EyeTimeInterval <= TimeEnd));
                                        NewEyeInterval = EyeTimeInterval(EyeIntervalInd);
                                        NewHorEyeInterval = HorEyeInterval(EyeIntervalInd);
                                        NewVerEyeInterval = VerEyeInterval(EyeIntervalInd);
                                        NewEyeMotionLength = length(NewEyeInterval);
                                        
                                        ReplaceVector = [TrialNum, NewSpikeNum,StartSpikeData,EndSpikeData,Modality,NewSpikeArrTime,...
                                                        NewEyeMotionLength,NewEyeInterval,NewHorEyeInterval,NewVerEyeInterval,...
                                                        StimVelocity, Tilt];
                                        lrv = length(ReplaceVector);                 
                                        MarkedData(j,:) = zeros(1,size(MarkedData,2));
                                        MarkedData(j,1:lrv) = ReplaceVector;
                                        %                        if length(SpikeArrInd) ==0;
                                        %                          Rem = [Rem,j];
                                        %                        end;
                                        %break;
                                end;
                        end;  
                end; 
                %                  if ~isempty(Rem),
                %                   MarkedData(Rem,:) = [];
                %                  end;
                unitret('set_markeddata',MarkedData);
                set(TRET_DAT(5),'UserData',[]);
                
                unitret('redraw_spk',1);
                
                %------------------    
        end;   
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
        
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'redraw_accumulation')),
        TRET_DAT(2)=watchon; 
        
        CurSpk=in1;
        SpikesNum=length(CurSpk);
        if (SpikesNum),
                yy=zeros(SpikesNum,1);
                for i=1:SpikesNum,
                        yy(i) = sum(CurSpk(1:i));
                end;
                limits =get(gca,'Ylim');
                ymin = limits(1);
                ymax=limits(2);
                SumAmp = (ymax - ymin) / yy(SpikesNum);
                accumline= line(CurSpk,SumAmp*yy+ymin,'Color','k','UserData',0);
                
                %                     set(gca,'YLimMode','Manual','Ylim',[0 ymax]);
                %if we remove %, the accumulation graphs will be drawn without spikes data.
                % may be it will be useful in the future.
                
                %here we will select the points for linear regression
                
                strline=sprintf(' %17.13f',accumline);
                button_down_fcn = ['process(''accumulation_pressed'',',strline, ');'];
                set(accumline,'ButtonDownFcn', button_down_fcn);
                
        end                    
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
elseif(strcmp(action,'exit')),
	unitret('write_ini',INIFILE);
        fclose('all');
        kids = get(0,'Children');
        delete(kids);

        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
elseif(strcmp(action,'delete_ini')),
	delete(INIFILE);
        fclose('all');
        kids = get(0,'Children');
        delete(kids);
	unitret;
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
elseif(strcmp(action,'grid')),
        xmin = in1(1);
        xmax = in1(2);
        ymin = in1(3);
        ymax = in1(4);
        stepgrid=in1(5)+300;
        
        
        vx = xmin:stepgrid:xmax;
        br=3*length(vx);
        
        x = zeros(1,br);
        y = zeros(1,br);
        
        x(1:3:br-2) = vx;
        x(2:3:br-1) = vx;
        x(3:3:br) = vx;
        
        y(1:3:br-2) = ymax.*ones(1,br/3);
        y(2:3:br-1) = ymin.*ones(1,br/3);
        y(3:3:br)   = ymax.*ones(1,br/3);
        l=line(x,y,'erasemode','none');
        set(l,'color',in2);
        
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
elseif(strcmp(action,'scatter')),
        
        if  (size(TRET_DAT,2) > 1 ),    % second member exists (pointer on graph figure)
                delete(TRET_DAT(2));
        end;       
        
        set(gcf,'Pointer','Watch');
        wld = get(gcf,'Name');
        [a,b]=min(wld - '.');
        
        if(a==0)
                wld = [wld(1:b),'sct'];
        else
                wld = '*.sct';
        end;
        
        [filename, pathname] = uigetfile(wld, 'Retrival of Scatter Record', .4, .4);
        
        if filename == 0, return; end;
        Fig2 = figure('Units','normal', 'Position',[0.28 0.04 .71 .95],...
                'Backingstore','on','color','w','name', filename,...
                'DefaultAxesFontSize',9,'DefaultAxesDrawMode','fast',...
                'DefaultAxesYColor','k','DefaultAxesXColor','k','Menubar','none');
        
        u1 = uimenu(Fig2,'label','&File');
        
        u12 = uimenu(u1,'Label','Save Scatter Data in &ASCII','Callback','unitret(''save'',5);');
        u13 = uimenu(u1,'Label','P&rint Setup...','Separator','on','Callback','print -dsetup;');     
        u14 = uimenu(u1,'Label','&Print','Callback','orient landscape; print;');
        u15 = uimenu(u1,'Label','E&xit','Separator','on','Callback','unitret(''exit'');');
        
        
        TRET_DAT(2)  = Fig2;	     
        
        
        
        FullName = [pathname,filename];
        NAME = filename;
        
        [fid, message] = fopen(FullName,'rb');
        if(fid<0), 
                error(message);
        end;
        vec = fread(fid,'float');
        vec = vec';
        fclose(fid);
        
        for i=0:vec(1)-1,
                idx = [i*vec(2)+3:(i+1)*vec(2)+2];
                Scatter(i+1,:) = vec(idx);
        end;
        unitret('set_markeddata', Scatter);
        process('redraw_sct',Scatter);
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
elseif(strcmp(action,'figname')),
        if nargin > 1
                name = in1;
        else
                name = NAME;
        end 
        ax = axes('Position',[.48 0.985 1 1],'Units','normal','visible','off');
        
        text(0,0,name,'Units','norm','HorizontalAlignment','Center',...
                'FontSize',10,'Color',[0 0 1],'FontName','Times','Interpreter','none');
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
elseif(strcmp(action,'text2fig')),
        
        ax = axes('Position',[.75 0.985 1 1],'Units','normal','visible','off');
        
        text(0,0,in1,'Units','norm','HorizontalAlignment','Center',...
                'FontSize',10,'Color',[0.0235    0.3137    0.3765],'FontName','Times','Interpreter','none'); 
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
elseif(strcmp(action,'saccades_detect')),
        global SPIKES STIMULUS EM_STRUCTURE_ONE_FILE EM_CLASS_ONE_FILE
        % (STIMULUS(tnum, 2) - trial duration - is used)
        
        EyeTimeAxis = in1(1,:);
        HorizEyePos = in1(2,:);
        VertEyePos  = in1(3,:);
        tnum = in2;
        curax = in3;
        set(gcf,'CurrentAxes',curax);
	yl = get(curax,'Ylim');
        strax = sprintf(' %17.13f',curax);
        button_down_fcn = ['unitret(''pressed'',',num2str(tnum), ',', strax, ');'];
        %set(ax,'ButtonDownFcn', button_down_fcn);
        
        SaveEM = DefValues(135);
        TrialDuration = STIMULUS(tnum, 2);
        
        % reject EM before zero and after the end of the trial
        posind = find(EyeTimeAxis>=0 & EyeTimeAxis < TrialDuration);
        EyeTimeAxis = EyeTimeAxis(posind);
        HorizEyePos = HorizEyePos(posind);
        VertEyePos  = VertEyePos(posind);
        
        saccol = [0    0.2510    0.5020];
        
        % Window applied for all EM (simulates fixational window if file does not have it)
        
        FixWindowUp     = DefValues(142);
        FixWindowDown   = DefValues(143);
        
        RejectIfOutFixWin = DefValues(144);
        %      1 - Reject trial if out of fixation window   
        %      2 - Take part of trials before
        %      3 - Take all "within" parts
        %      4 - Take all regardless of fixation window
        
        if     RejectIfOutFixWin==4,
                FixWindowUp     = 1000;
                FixWindowDown   = -1000;
        elseif RejectIfOutFixWin==1,
                if any(HorizEyePos<FixWindowDown | HorizEyePos>FixWindowUp)...
                                | any(VertEyePos<FixWindowDown | VertEyePos>FixWindowUp),
                        return % reject trial
                end
        elseif RejectIfOutFixWin==2,
                if any(HorizEyePos<FixWindowDown | HorizEyePos>FixWindowUp)...
                                | any(VertEyePos<FixWindowDown | VertEyePos>FixWindowUp),
                        stopind = min( [find(HorizEyePos<FixWindowDown) find(HorizEyePos>FixWindowUp) find(VertEyePos<FixWindowDown) find(VertEyePos>FixWindowUp)] ); 
                        EyeTimeAxis(stopind);
                        if stopind > 50
                                EyeTimeAxis = EyeTimeAxis(1:stopind-1);
                                HorizEyePos = HorizEyePos(1:stopind-1);
                                VertEyePos  = VertEyePos(1:stopind-1);
                                TrialDuration = (length(EyeTimeAxis)-1)*10;
                        else
                                return % reject trial
                        end
                        
                end
        end
        
        
        SaccadesSort = DefValues(103);
        SelectMoreBefore = DefValues(129);
        SelectMoreAfter  = DefValues(130);
        SelectEqual      = DefValues(131);
        
        if SaccadesSort, % Saccades Sorting
                % Get spikes
                SpikesNum       = SPIKES(tnum,1);
                StartSpikeData  = SPIKES(tnum,2);
                EndSpikeData    = SPIKES(tnum,3);
                SpikeArrTime    = SPIKES(tnum,4:SpikesNum + 3);
                
        end 
        
        SaccadesWinSelect = DefValues(99);
        ud=DefValues;
        WinAfter = 0;
        
        if SaccadesWinSelect & ~DefValues(145),
                WinBefore = ud(100);
                WinAfter  = ud(101);
                ud(37) = WinBefore;
                ud(38) = WinAfter;
                ud(26) = 4; % Select Event
                set(0,'Userdata',ud);
        end
        SR = 1000/(EyeTimeAxis(2)-EyeTimeAxis(1)); % Hz - EM sampling rate
        if DefValues(95), % Interpolation on
                SR = DefValues(96); %
        end
        EMint = 1000/SR; % EM sampling interval
        
        FlankThreshold   = DefValues(90)*60/SR; % deg/s -> minarc/10 ms (or other EM sampling  interval)
        StableBefore = DefValues(91)/EMint; % ms -> #samples
        StableAfter  = DefValues(92)/EMint; % ms -> #samples
        SaccadeThreshold = DefValues(93)*60/SR; % deg/s -> minarc/10 ms	
        SaccadeThresholdUpperLim = DefValues(102)*60/SR; % deg/s -> minarc/10 ms	
        
        dxdt = diff(HorizEyePos);
        dydt = diff(VertEyePos);
        
        Velocity = sqrt(dxdt.^2 + dydt.^2);
        
        LenVel = length(Velocity);
	
        EyePositionWindowBottom     = DefValues(119);
        EyePositionWindowUp         = DefValues(120);
        SaccadeAmpWindowUp          = DefValues(121);
        SaccadeAmpWindowBottom      = DefValues(122);
        AngleRangeRight		    = DefValues(139);
        AngleRangeLeft	            = DefValues(140);
        
        AngleRange                  = AngleRangeLeft|AngleRangeRight;
        SaccadePositionWindow       = EyePositionWindowBottom|EyePositionWindowUp;
        SaccadeAmpWindow            = SaccadeAmpWindowBottom|SaccadeAmpWindowUp;
        
        
        
        if ~SaccadePositionWindow,
                InsidePositionWindow = 1;
        else
                InsidePositionWindow = 0;
        end
        
        if ~SaccadeAmpWindow,
                InsideAmpWindow = 1;
        else
                InsideAmpWindow = 0;
        end
        
        if ~AngleRange,
                InsideAngleRange = 1;
        else
                InsideAngleRange = 0;
        end
        
        if 0 % /*
                if SaccadePositionWindow & SaccadeThresholdUpperLim, 
                        SaccadesIndex = find(Velocity > SaccadeThreshold & Velocity < SaccadeThresholdUpperLim ...
                                & ( abs(HorizEyePos(ind)) <= SaccadePositionWindow & abs(VertEyePos(ind)) <= SaccadePositionWindow ) );
                elseif SaccadePositionWindow & ~SaccadeThresholdUpperLim,
                        SaccadesIndex = find(Velocity > SaccadeThreshold & ( abs(HorizEyePos(ind)) <= SaccadePositionWindow & abs(VertEyePos(ind)) <= SaccadePositionWindow ) );
                elseif SaccadeThresholdUpperLim & ~SaccadePositionWindow,
                        SaccadesIndex = find(Velocity > SaccadeThreshold & Velocity < SaccadeThresholdUpperLim);
                else        
                        SaccadesIndex = find(Velocity > SaccadeThreshold);
                end
        end % */
        
        
        
        % if SaccadeThresholdUpperLim,
        %	SaccadesIndex = find(Velocity > SaccadeThreshold & Velocity < SaccadeThresholdUpperLim);
        % else        
        %	SaccadesIndex = find(Velocity > SaccadeThreshold);
        % end
        
        SaccadesIndex = find(Velocity > SaccadeThreshold);
        
        
        BlinkTimes = [];
        
        
        SacSelected = []; % Stack of the selected saccades' times
        AllSaccadesTime = []; % All saccades' times, regardless of constrains
        SelectedSaccadesIndex = [];
        LastValidSaccadeIndex= 0;
        
        AllDirs = []; % Directions of all saccades
        SelDirs = []; % Directions of selected saccades
        
        AllPeakVel = [];
        AllMeanVel = [];
        AllIniVel  = [];
        SelPeakVel = [];
        SelMeanVel = [];
        SelIniVel  = [];
        
        AllAmp     = [];
        SelAmp     = [];
        AllAmpH     = [];
        SelAmpH     = [];
        AllAmpV     = [];
        SelAmpV     = [];
        
        
        for i = 1:length(SaccadesIndex),
                IsBlink = 0;
                % Check flanks
                if SaccadesIndex(i) > StableBefore,

			% Apply FixWindow for ALL saccades 
			% (currently it used only if we are in FixWindow 		 
			% mode 3 - "take within" (FixWindow [-100:100])
			% or
			% mode 4 - "take all" (FixWindow [-1000:1000])
			% (in modes 1 and 2 we should not have by now eye positions out of FixWindow
			% since we filtered them before if in mode 2 or rejected trial if in mode 1) 

			InsideFixWindow = 0;
			LookForwardInd = min(SaccadesIndex(i)+50/EMint, LenVel);
			if HorizEyePos(SaccadesIndex(i):LookForwardInd) >= FixWindowDown & HorizEyePos(SaccadesIndex(i):LookForwardInd) <= FixWindowUp...
					& VertEyePos(SaccadesIndex(i):LookForwardInd) >= FixWindowDown & VertEyePos(SaccadesIndex(i):LookForwardInd) <= FixWindowUp,
				InsideFixWindow = 1;

			end


	
                        % Find all saccades, regardless of constrains, by velocity threshold
                        
                        % Velocity threshold
                        IsSaccade = 0;
                        if max(Velocity(SaccadesIndex(i)-StableBefore:SaccadesIndex(i)-20/EMint)) < FlankThreshold...
                                        & max(Velocity(SaccadesIndex(i)-StableBefore:SaccadesIndex(i)-1)) < SaccadeThreshold...
                                        & EyeTimeAxis(SaccadesIndex(i)) < TrialDuration...
                                        & InsideFixWindow,
                                
                                % Here we stack all saccades that meet main criterion and fit Trial Duration
                                % but they not necessary will be marked by triangle!!! (they have to meet other criteria)  
                                
                                AllSaccadesTime = [AllSaccadesTime EyeTimeAxis(SaccadesIndex(i))];
                                
                                ll = line([EyeTimeAxis(SaccadesIndex(i)) EyeTimeAxis(SaccadesIndex(i))],[yl(1) yl(2)],'Color',saccol,'LineStyle',':'); hold on;
				set(ll,'ButtonDownFcn', button_down_fcn);


				%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
				
				if SaccadePositionWindow,
					InsidePositionWindow = 0;
					LookForwardInd = min(SaccadesIndex(i)+100/EMint, LenVel);
					if HorizEyePos(SaccadesIndex(i):LookForwardInd) >= EyePositionWindowBottom & HorizEyePos(SaccadesIndex(i):LookForwardInd) <= EyePositionWindowUp...
							& VertEyePos(SaccadesIndex(i):LookForwardInd) >= EyePositionWindowBottom & VertEyePos(SaccadesIndex(i):LookForwardInd) <= EyePositionWindowUp,
						InsidePositionWindow = 1;

					end	
				end
				if SaccadeAmpWindow,
					InsideAmpWindow = 0;
					LookForwardInd = min(SaccadesIndex(i)+30/EMint, LenVel);
					HorizAmp = max( abs(HorizEyePos(SaccadesIndex(i)) - HorizEyePos(SaccadesIndex(i):LookForwardInd)) );
					VertAmp  = max( abs(VertEyePos(SaccadesIndex(i)) - VertEyePos(SaccadesIndex(i):LookForwardInd)) );

					if 0 % /*
					if HorizAmp <= SaccadeAmpWindowUp...
							& HorizAmp >= SaccadeAmpWindowBottom...
							& VertAmp <= SaccadeAmpWindowUp...
							& VertAmp >= SaccadeAmpWindowBottom,
						InsideAmpWindow = 1;

					end
					end % */

					Amp = (HorizAmp^2 + VertAmp^2).^0.5;
					if (Amp <= SaccadeAmpWindowUp & Amp >= SaccadeAmpWindowBottom),
						InsideAmpWindow = 1;
					end

				end

				if AngleRange | SaveEM,

					% Estimate Max Amplitude Vector
					LookForwardInd = min(SaccadesIndex(i)+30/EMint, LenVel+1);
					HDs = HorizEyePos(SaccadesIndex(i):LookForwardInd) - HorizEyePos(SaccadesIndex(i));
					VDs = VertEyePos(SaccadesIndex(i):LookForwardInd) - VertEyePos(SaccadesIndex(i));
					AmpVects = (HDs.^2 + VDs.^2).^0.5;
					MaxAmpVect = max(AmpVects);
					MaxAmpVectIndex = find(AmpVects == MaxAmpVect);
					% end of Estimate Max Amplitude Vector


					% Calculate Direction
					a = VDs(MaxAmpVectIndex);
					b = HDs(MaxAmpVectIndex);
					Angle_ = abs(atan(a/b)*180/pi); % in degrees

					if a >= 0 & b >= 0,     % I quadrant
						Direction = Angle_;
					elseif a >= 0 & b < 0,  % II quadrant 
						Direction = 180 - Angle_;
					elseif a <= 0 & b <= 0, % III quadrant 
						Direction = 180 + Angle_;
					else 			% IV quadrant
						Direction = 360 - Angle_;
					end

					if AngleRange,
						InsideAngleRange = 0;
						% Test whether Direction falls within sectror defined by
						% AngleRangeRight--->AngleRangeLeft 
						if Direction > AngleRangeRight & Direction < AngleRangeLeft,
							InsideAngleRange = 1;
						end
					end

				end

				%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
				
                                
                                LastValidSaccadeIndex= LastValidSaccadeIndex+ 1;
                                LookForwardInd = min(SaccadesIndex(i)+30/EMint, LenVel);
				if SaveEM
					AllDirs = [AllDirs Direction];	
					AllIniVel = [AllIniVel Velocity(SaccadesIndex(i))];
					AllMeanVel = [AllMeanVel mean( Velocity(SaccadesIndex(i):LookForwardInd) )];
					AllPeakVel = [AllPeakVel max( Velocity(SaccadesIndex(i):LookForwardInd) )]; 
					AllAmp   = [AllAmp MaxAmpVect];
					AllAmpH    = [AllAmpH HorizAmp];
					AllAmpV    = [AllAmpV VertAmp];
				end
                                
                                % Velocity UpperLim
                                if ~SaccadeThresholdUpperLim,
                                        IsSaccade = 1; 		
                                elseif Velocity(SaccadesIndex(i)) < SaccadeThresholdUpperLim,
                                        IsSaccade = 1;
                                end

				if (SaccadesIndex(i)+100/EMint < LenVel),	% always detect blinks	
					if sum(Velocity(SaccadesIndex(i):SaccadesIndex(i)+DefValues(170)/EMint)>SaccadeThreshold)>0.95*DefValues(170)/EMint,
						set(ll,'Color','k','LineWidth',2);
						BlinkTimes = [BlinkTimes EyeTimeAxis(SaccadesIndex(i))];
						IsBlink = 1;
					end
				end
                        end


                        
                        % Final decision about saccade
                        if IsSaccade & ~IsBlink & InsidePositionWindow & InsideAmpWindow & InsideAngleRange &( (EyeTimeAxis(SaccadesIndex(i))+WinAfter)< TrialDuration )...
				& (EyeTimeAxis(SaccadesIndex(i))-WinBefore) > 0,

                                % Here we mark saccades, but really final decision about selecting
                                % will be made after testing overlaps later on...
                                
                                ll=line([EyeTimeAxis(SaccadesIndex(i)) EyeTimeAxis(SaccadesIndex(i))],[yl(1) yl(2)],'Color',saccol,'LineStyle',':'); hold on;
                                set(ll,'ButtonDownFcn', button_down_fcn);
                                
                                if ( abs(yl(2)-yl(1)) ) >= 25, % Do not plot ugly triangles when graph is small :)
                                        lf=fill([EyeTimeAxis(SaccadesIndex(i))-20,EyeTimeAxis(SaccadesIndex(i)),EyeTimeAxis(SaccadesIndex(i))+20],[yl(2),yl(2)-5,yl(2)],[0.3686    0.0196    0.4549]);
                                else
                                        lf=fill([EyeTimeAxis(SaccadesIndex(i))-10,EyeTimeAxis(SaccadesIndex(i)),EyeTimeAxis(SaccadesIndex(i))+10],[yl(2),yl(2)-0.2,yl(2)],[0.3686    0.0196    0.4549]);
                                end
                                
                                %set(lf,'ButtonDownFcn', button_down_fcn);
                                
                                if SaccadesWinSelect & ~(sum(DefValues(129:131))), % Select All Saccades Windows                              
                                        % We want to get "selected" saccades info even if we actually do not select them
                                        % therefore we may put small (say -1,1) window so even very late
                                        % (near the end of trial) saccades will be taken
                                        % unitret('pressed',tnum,curax,[EyeTimeAxis(SaccadesIndex(i)) yl(1)]);
                                        SacSelected = [SacSelected EyeTimeAxis(SaccadesIndex(i))];
                                        SelectedSaccadesIndex = [SelectedSaccadesIndex LastValidSaccadeIndex];
                                end % of Select Saccades Windows
                                
                                if SaccadesSort, 
                                        
                                        SpikesNumBefore = length(SpikeArrTime(find( SpikeArrTime > EyeTimeAxis(SaccadesIndex(i)) - DefValues(100) & SpikeArrTime < EyeTimeAxis(SaccadesIndex(i)) )));
                                        SpikesNumAfter = length(SpikeArrTime(find( SpikeArrTime > EyeTimeAxis(SaccadesIndex(i)) & SpikeArrTime < EyeTimeAxis(SaccadesIndex(i)) + DefValues(101) )));
                                        if SpikesNumBefore > SpikesNumAfter,
                                                set(ll,'Color',[1.0000         0    0.5020]); % Pink
                                                set(lf,'FaceColor',[1.0000         0    0.5020]); % Pink
                                                if SelectMoreBefore,
                                                        % unitret('pressed',tnum,curax,[EyeTimeAxis(SaccadesIndex(i)) yl(1)]);
                                                        SacSelected = [SacSelected EyeTimeAxis(SaccadesIndex(i))]; 
                                                        SelectedSaccadesIndex = [SelectedSaccadesIndex LastValidSaccadeIndex];
                                                end
                                        elseif SpikesNumBefore < SpikesNumAfter,
                                                set(ll,'Color',[ 0.0275    0.9373    0.5490]); % Green
                                                set(lf,'FaceColor',[ 0.0275    0.9373    0.5490]); % Green
                                                if SelectMoreAfter,
                                                        % unitret('pressed',tnum,curax,[EyeTimeAxis(SaccadesIndex(i)) yl(1)]);
                                                        SacSelected = [SacSelected EyeTimeAxis(SaccadesIndex(i))]; 
                                                        SelectedSaccadesIndex = [SelectedSaccadesIndex LastValidSaccadeIndex];
                                                end
                                        else
                                                if SelectEqual,
                                                        % unitret('pressed',tnum,curax,[EyeTimeAxis(SaccadesIndex(i)) yl(1)]);
                                                        SacSelected = [SacSelected EyeTimeAxis(SaccadesIndex(i))]; 
                                                        SelectedSaccadesIndex = [SelectedSaccadesIndex LastValidSaccadeIndex];
                                                end
                                                
                                                
                                        end
                                        
                                end % of SaccadesSort
                                
                                
                                
                                
                        end % of Final decision about saccade
                end % of if SaccadesIndex(i) > StableBefore,
        end % of for

	AllSemTime = [];
	if DefValues(156) % Slow eye movements
		nave = DefValues(157)/EMint;
		sem_amp = DefValues(158);
		SemIndex = [];
		
		jj = 0;
	        for j=1:LenVel-nave,
			adxdt(j) = abs(sum(dxdt(j:j+nave-1)));
			adydt(j) = abs(sum(dydt(j:j+nave-1)));
			if (adxdt(j) > sem_amp | adydt(j) > sem_amp) & (j - jj)>nave,
				if isempty(find(abs(j-SaccadesIndex)<nave))
					SemIndex = [SemIndex j];
					jj = SemIndex(length(SemIndex));
					line([EyeTimeAxis(j) EyeTimeAxis(j)],[yl(1) yl(2)],'Color',[0.38 0.69 1],'LineStyle',':'); hold on;
					AllSemTime = [AllSemTime EyeTimeAxis(SemIndex)];
				end
			end
		end
	end % of if SEM 
        
        SelSaccadesTime = [];
        
        if 1 & DefValues(145), % Select periods between saccades - drifts
                unitret('select_drifts',tnum,curax,sort([AllSaccadesTime AllSemTime]));
                return
        end
        
        % Now actually select saccades:
        NoSaccadeBefore = DefValues(133);
        NoSaccadeAfter = DefValues(134);
        CheckOverlap = NoSaccadeBefore | NoSaccadeAfter;

        last = length(AllSaccadesTime);
        if SaccadesWinSelect & DefValues(169), % Select and Blinks detect
		for i=1:length(BlinkTimes),
			if ((BlinkTimes(i)-DefValues(100))>0) & ((BlinkTimes(i)+DefValues(101))<TrialDuration) 
				unitret('pressed',tnum,curax,[BlinkTimes(i) yl(1)]);
			end
		end
	
	else 	
	        for i = SelectedSaccadesIndex,
	                if (CheckOverlap & last>1), % No Overlap allowed within NoSaccadeBefore and NoSaccadeAfter
	                        take = 0;
	                        if i==1, % First saccade
	                                if AllSaccadesTime(i+1)-AllSaccadesTime(i) >= NoSaccadeAfter,
	                                        take = 1;
	                                end
	                        elseif i==last, % Last saccade
	                                if AllSaccadesTime(i) - AllSaccadesTime(i-1) >= NoSaccadeBefore,
	                                        take = 1;
	                                end
	                        else
	                                if (AllSaccadesTime(i+1)-AllSaccadesTime(i) >= NoSaccadeAfter) & (AllSaccadesTime(i) - AllSaccadesTime(i-1) >= NoSaccadeBefore),
	                                        take = 1;
	                                end
	                        end
	                        if take == 1,
	                                unitret('pressed',tnum,curax,[AllSaccadesTime(i) yl(1)]);
	                                SelSaccadesTime = [SelSaccadesTime AllSaccadesTime(i)];
	                                if SaveEM,
	                                        SelDirs = [SelDirs AllDirs(i)];
	                                        SelIniVel = [SelIniVel AllIniVel(i)];
	                                        SelMeanVel = [SelMeanVel AllMeanVel(i)];
	                                        SelPeakVel = [SelPeakVel AllPeakVel(i)];
	                                        SelAmp = [SelAmp AllAmp(i)];
	                                        SelAmpH    = [SelAmpH AllAmpH(i)];
	                                        SelAmpV    = [SelAmpV AllAmpV(i)];
	                                end
                                
	                        end
                        
	                else % Select all the saccades found
	                        unitret('pressed',tnum,curax,[AllSaccadesTime(i) yl(1)]);
	                        SelSaccadesTime = [SelSaccadesTime AllSaccadesTime(i)];
	                        if SaveEM,
                                
	                                SelDirs = [SelDirs AllDirs(i)];
	                                SelIniVel = [SelIniVel AllIniVel(i)];
	                                SelMeanVel = [SelMeanVel AllMeanVel(i)];
	                                SelPeakVel = [SelPeakVel AllPeakVel(i)];
	                                SelAmp = [SelAmp AllAmp(i)];
	                                SelAmpH    = [SelAmpH AllAmpH(i)];
	                                SelAmpV    = [SelAmpV AllAmpV(i)];
	                        end
	                end
	        end 
	end % of if blinks or saccades

        if 0 & DefValues(145), % Select periods between saccades - drifts
                unitret('select_drifts',tnum,curax,AllSaccadesTime, SelSaccadesTime);
                return
        end
        
        if DefValues(97), % Display Velocity
                
                Gain = DefValues(98);    
                line(EyeTimeAxis(1:length(Velocity)),Gain*Velocity,'Color',[0.6   0.0078    0.0]);
                plot(EyeTimeAxis(1:length(Velocity)),Gain*Velocity,'k.');
                
                % Plot thresholds
                line([EyeTimeAxis(1) EyeTimeAxis(length(EyeTimeAxis))],Gain*[SaccadeThreshold SaccadeThreshold],'Color','c');
                line([EyeTimeAxis(1) EyeTimeAxis(length(EyeTimeAxis))],Gain*[FlankThreshold FlankThreshold],'Color','b');
                
        end
        if 0, % Separate figure for each trial
                
                figure
                line(EyeTimeAxis,HorizEyePos,'Color',[0 .502 0]);
                line(EyeTimeAxis,VertEyePos,'Color','m');
                line(EyeTimeAxis(1:length(Velocity)),Gain*Velocity,'Color',[0.6   0.0078    0.0]); hold on
                plot(EyeTimeAxis(1:length(Velocity)),Gain*Velocity,'r.'); hold on
                
                % Plot thresholds
                line([EyeTimeAxis(1) EyeTimeAxis(length(EyeTimeAxis))],Gain*[SaccadeThreshold SaccadeThreshold],'Color','c');
                line([EyeTimeAxis(1) EyeTimeAxis(length(EyeTimeAxis))],Gain*[FlankThreshold FlankThreshold],'Color','b');
                
                set(0,'CurrentFigure',TRET_DAT(2));
        end
        
        %--------------------------------
        if SaveEM, % Save EM data 
                %--------------------------------
                em_structure.name = NAME;		%1
                em_structure.tnum = tnum;		%2
                em_structure.dur  = TrialDuration;	%3
                em_structure.hpos = HorizEyePos;	%4
                em_structure.vpos = VertEyePos;		%5
                em_structure.allsac = AllSaccadesTime;	%6  All valid saccades
                em_structure.selsac = SelSaccadesTime;	%7  Selected (and saved) saccades	
                em_structure.alldirs = AllDirs;		%8
                em_structure.seldirs = SelDirs;		%9
                em_structure.allpeakvel = AllPeakVel;	%10
                em_structure.allmeanvel = AllMeanVel;	%11
                em_structure.allinitvel = AllIniVel;	%12
                em_structure.selpeakvel = SelPeakVel;	%13
                em_structure.selmeanvel = SelMeanVel;	%14
                em_structure.selinitvel = SelIniVel;	%15
                em_structure.allamp     = AllAmp;	%16
                em_structure.selamp     = SelAmp;	%17
                em_structure.allampH     = AllAmpH;	%18
                em_structure.selampH     = SelAmpH;	%19
                em_structure.allampV     = AllAmpV;	%20
                em_structure.selampV     = SelAmpV;	%21
                
                
                if isempty(EM_STRUCTURE_ONE_FILE),
                        EM_STRUCTURE_ONE_FILE = em_structure;
                else
                        EM_STRUCTURE_ONE_FILE = [EM_STRUCTURE_ONE_FILE em_structure];
                end
                %--------------------------------
        end  % of if Save EM data 
        %--------------------------------
        
        if SaveEM & ~DefValues(141)  % No batch is running, save EM Data for One File
                sacfilename = [INI_NAME '.ems'];
                EM_STRUCTURE = EM_STRUCTURE_ONE_FILE;
                save(sacfilename,'EM_STRUCTURE','DefValues','-mat');
                EM_STRUCTURE = [];
        end
        
        if 0 % EM Classification: saccade by saccade
                disp('====================')
                disp(num2str(tnum))
                
                % Get spikes
                SpikesNum       = SPIKES(tnum,1);
                StartSpikeData  = SPIKES(tnum,2);
                EndSpikeData    = SPIKES(tnum,3);
                SpikeArrTime    = SPIKES(tnum,4:SpikesNum + 3);
                
                BurstWin = 150;
                Lat = 40;
                BD = 11; % spikes/sec
                valind = [];
                val_drift_ind = [];
                for i=1:length(AllSaccadesTime),
                        if i<length(AllSaccadesTime),
                                ActualBurstEnd = min(AllSaccadesTime(i)+BurstWin, AllSaccadesTime(i+1));
                                SpikesNumBurst(i) = length(SpikeArrTime(find( SpikeArrTime > AllSaccadesTime(i)+Lat & SpikeArrTime < ActualBurstEnd )));
                                SpikesNumDrift(i) = length(SpikeArrTime(find( SpikeArrTime > ActualBurstEnd & SpikeArrTime < AllSaccadesTime(i+1) )));	    	
                                BurstWindow(i) = ActualBurstEnd - AllSaccadesTime(i);
                                DriftWindow(i) = AllSaccadesTime(i+1) - ActualBurstEnd;
                                if length(find(AllSaccadesTime(i)==SelSaccadesTime)),
                                        valind = [valind i];
                                        if DriftWindow(i)>50,
                                                val_drift_ind = [val_drift_ind i];
                                        end
                                end
                        else % last saccade
                                ActualBurstEnd = min(AllSaccadesTime(i)+BurstWin, EndSpikeData);
                                SpikesNumBurst(i) = length(SpikeArrTime(find( SpikeArrTime > AllSaccadesTime(i)+Lat & SpikeArrTime < ActualBurstEnd )));
                                SpikesNumDrift(i) = length(SpikeArrTime(find( SpikeArrTime > ActualBurstEnd & SpikeArrTime < EndSpikeData )));	    	
                                BurstWindow(i) = ActualBurstEnd - AllSaccadesTime(i);
                                DriftWindow(i) = EndSpikeData - ActualBurstEnd;
                                if length(find(AllSaccadesTime(i)==SelSaccadesTime)),
                                        valind = [valind i];
                                        if DriftWindow(i)>50,
                                                val_drift_ind = [val_drift_ind i];
                                        end
                                end
                        end
                end % of for i
                
                FRb = SpikesNumBurst./(BurstWindow-Lat);
                FRd = max(SpikesNumDrift./(DriftWindow+eps) - BD/1000, 0);
                if length(AllSaccadesTime)>0,
                        FRd0 = length(SpikeArrTime(find( SpikeArrTime > 0 & SpikeArrTime < AllSaccadesTime(1) ))) / (AllSaccadesTime(1) - 0) ;
                end
                FRd0 = max(FRd0 - BD/1000, 0);
                
                
                % Find valid saccades and drift periods (at least 50 ms)
                
                n_valsac = length(valind);
                n_valdrift = length(val_drift_ind);
                
                meanFRd = mean(FRd(valind));
                
                n_burst = 0;
                n_drift = 0;
                
                Pr_b = [];
                Pr_d = [];
                sac_b = [];
                sac_d = [];
                
                diff_thresh_b = 0.001; %s/ms
                diff_thresh_d = 0.01;  %s/ms
                for k = 1:n_valsac,
                        i=valind(k);
                        
                        if i==1
                                if abs(FRb(i)-FRd(i))<diff_thresh_b & abs(FRd(i)- FRd0)<diff_thresh_d,
                                        n_valsac = n_valsac - 1;
                                        n_valdrift = n_valdrift - 1;
                                else	
                                        if FRb(i) > 3*FRd(i),
                                                n_burst=n_burst+1;
                                                sac_b = [sac_b SelSaccadesTime(k)];
                                                
                                        end
                                        
                                        if length(find(i==val_drift_ind)),
                                                
                                                if (FRd(i) > 2*FRd0 | 2*FRd(i) < FRd0) & abs(FRd(i)- FRd0)>diff_thresh_d,
                                                        n_drift=n_drift+1;
                                                        sac_d = [sac_d SelSaccadesTime(k)];
                                                end
                                        end
                                end
                                
                        else 
                                if abs(FRb(i) -FRd(i))<diff_thresh_b & abs(FRd(i)- FRd(i-1))<diff_thresh_d,
                                        n_valsac = n_valsac - 1;
                                        n_valdrift = n_valdrift - 1;
                                else	
                                        if FRb(i) > 3*FRd(i),
                                                n_burst=n_burst+1;
                                                sac_b = [sac_b SelSaccadesTime(k)];
                                                
                                        end
                                        
                                        if length(find(i==val_drift_ind)),
                                                
                                                if (FRd(i) > 2*FRd(i-1) | 2*FRd(i) < FRd(i-1)) & abs(FRd(i)- FRd(i-1))>diff_thresh_d,
                                                        n_drift=n_drift+1;
                                                        sac_d = [sac_d SelSaccadesTime(k)];
                                                end
                                        end
                                end
                        end
                end	
                Pr_b = n_burst/n_valsac
                Pr_d = n_drift/n_valdrift
                sac_b
                sac_d
                
                
                if isempty(EM_CLASS_ONE_FILE)
                        EM_CLASS_ONE_FILE.name = NAME;
                        EM_CLASS_ONE_FILE.n_burst  = n_burst;
                        EM_CLASS_ONE_FILE.n_drift  = n_drift;
                        EM_CLASS_ONE_FILE.n_valsac  = n_valsac;
                        EM_CLASS_ONE_FILE.n_valdrift  = n_valdrift;
                        EM_CLASS_ONE_FILE.Pr_b = n_burst/n_valsac;
                        EM_CLASS_ONE_FILE.Pr_d = n_drift/n_valdrift;
                        EM_CLASS_ONE_FILE
                else
                        
                        n_burst=n_burst + EM_CLASS_ONE_FILE.n_burst;
                        n_drift=n_drift + EM_CLASS_ONE_FILE.n_drift;
                        n_valsac=n_valsac + EM_CLASS_ONE_FILE.n_valsac;
                        n_valdrift=n_valdrift + EM_CLASS_ONE_FILE.n_valdrift;
                        
                        EM_CLASS_ONE_FILE.n_burst  = n_burst;
                        EM_CLASS_ONE_FILE.n_drift  = n_drift;
                        EM_CLASS_ONE_FILE.n_valsac  = n_valsac;
                        EM_CLASS_ONE_FILE.n_valdrift  = n_valdrift;
                        EM_CLASS_ONE_FILE.Pr_b = n_burst/n_valsac;
                        EM_CLASS_ONE_FILE.Pr_d = n_drift/n_valdrift;
                        
                end
                
                disp('--------------------')
                EM_CLASS_ONE_FILE
        end % if EM Classification
        
        
        
        
        
        
        
        
        out1 = [AllSaccadesTime];
        out2 = [];
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % OLD Sasha's STUFF
        
        %	[HorizEyePos(SaccadesIndex(i)) HorizEyePos(SaccadesIndex(i)+1)]
        
        %   x = [0 0 -.08 0 .08];
        %   y = [0 1  .8  1 .8];
        
        %   arrow = x + y.*sqrt(-1);
        %    yl = get(gca,'Ylim');
        %   amp = 0.3*(yl(2) - yl(1));
        %   x0 = amp*x;
        %   y0 = amp*y + 0.8*yl(1);
        
        %   for i=1:length(SaccadesIndex),
        %      x = x0+SaccadesTime(i); 
        %      line(x,y0,'Color','k');
        %   end;
        
        %   line(EyeTimeAxis(1:length(Velocity)),Velocity+0.6*yl(1),'Color',[0.6   0.0078    0.0]);
        
        % END OF OLD STUFF
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
elseif(strcmp(action,'select_drifts'))
        global SPIKES STIMULUS SINDATA
        tnum = in1;
        curax = in2;
        AllSaccadesTime = in3;
        if nargin > 4
                SelSaccadesTime = in4;
        else
                SelSaccadesTime = -1;
        end
        
        StimNum		= STIMULUS(tnum, 1);
        TrialDuration	= STIMULUS(tnum, 2);
        OneStimDuration = STIMULUS(tnum, 3);
        TimeBetweenStim = STIMULUS(tnum, 4);
        StimArrTime	= STIMULUS(tnum,5:(StimNum + 4));


	
        TF = abs(SINDATA(tnum,2));
        OneCycleDur = 1/TF*1000;
        
        SinOffSet=0:(1/TF)*1000:TrialDuration;
	StimOffSet = sort([StimArrTime StimArrTime+OneStimDuration]);
	
	StimOffSet = StimOffSet(find(StimOffSet<=TrialDuration-max(OneStimDuration,TimeBetweenStim))); % 08.08.02 changed to <= from <
	if DefValues(26)==1,			% odd-even couples
		StimOffSet = StimOffSet(1:2:end-1);
	elseif DefValues(26)==7,		% even-odd couples
		StimOffSet = StimOffSet(2:2:end);
	end
        % SinOffSet=SinOffSet(1:length(SinOffSet)-1);
        
        SelectMode = DefValues(26);
        yl = get(curax,'Ylim');
        ud = get(0,'Userdata');
        
        WinBefore = ud(100);
        WinAfter  = ud(101);
        ud(37) = WinBefore;
        ud(38) = WinAfter;
        set(0,'Userdata',ud);
        
        AllSaccadesTime = [0 AllSaccadesTime TrialDuration];
        if ~(SelSaccadesTime==-1), % select drift periods ONLY after selected saccades
                for i = 1:length(SelSaccadesTime),
                        SegmentStart = SelSaccadesTime(i) + WinAfter;
                        SegmentEnd = AllSaccadesTime( find(AllSaccadesTime==SelSaccadesTime(i))+1 );		
                        if (SegmentEnd - SegmentStart) >0,       
                                unitret('pressed',tnum,curax,[SegmentStart yl(1)]);
                                unitret('pressed',tnum,curax,[SegmentEnd yl(1)]);
                        end
                end
        else
                for i = 1:length(AllSaccadesTime)-1;
                        if ud(26)==0	% driven activity

				SegmentStart = AllSaccadesTime(i)+WinAfter;
				SegmentEnd   = min( AllSaccadesTime(i+1), TrialDuration);
				if (SegmentEnd - SegmentStart) >= min(OneStimDuration,TimeBetweenStim),
					StimOffSetWithin = StimOffSet(find(StimOffSet>SegmentStart & StimOffSet<=SegmentEnd-max(OneStimDuration,TimeBetweenStim)));
					% 08.08.02 changed < to <=
					for i=1:length(StimOffSetWithin)
				
						%if (StimArrTimeWithin(i)+OneStimDuration+TimeBetweenStim+1)<SegmentEnd,
							unitret('pressed',tnum,curax,[StimOffSetWithin(i)+5 yl(1)]);
						%end
					end
				end
				% SegmentStart = SinOffSet( min(find(SinOffSet >= (AllSaccadesTime(i) + WinAfter) )) );
                                % SegmentEnd   = SinOffSet( max(find(SinOffSet <= AllSaccadesTime(i+1))));
                                        
				
			elseif ud(26)==1 | ud(26)==7 % odd-even couples / even-odd couples
                                
				SegmentStart = AllSaccadesTime(i)+WinAfter;
				SegmentEnd   = min( AllSaccadesTime(i+1), TrialDuration);
				if (SegmentEnd - SegmentStart) >= OneStimDuration+TimeBetweenStim,
					
					StimOffSetWithin = StimOffSet(find(StimOffSet>SegmentStart & StimOffSet<=SegmentEnd-(OneStimDuration+TimeBetweenStim)));
					for i=1:length(StimOffSetWithin)
				
						%if (StimArrTimeWithin(i)+OneStimDuration+TimeBetweenStim+1)<SegmentEnd,
							unitret('pressed',tnum,curax,[StimOffSetWithin(i)+5 yl(1)]);
						%end
					end
				end
				
                                
                        elseif ud(26)==2	% spont data
                                
                        elseif ud(26)==4	% event data
                                
                        elseif ud(26)==5        % Selecting Arbitrary Window
                                SegmentStart = AllSaccadesTime(i) + WinAfter;
                                SegmentEnd   = min( AllSaccadesTime(i+1) - 10, TrialDuration); 	
                                if (SegmentEnd - SegmentStart) >= 50,       
                                        unitret('pressed',tnum,curax,[SegmentStart yl(1)]);
                                        unitret('pressed',tnum,curax,[SegmentEnd yl(1)]);
                                end	
                        elseif ud(26)==6        % integer number of cycles
                                if unitret('is periodic',SINDATA(tnum,3))	% periodic stimulus 			
                                        SegmentStart = SinOffSet( min(find(SinOffSet >= (AllSaccadesTime(i) + WinAfter) )) );
                                        SegmentEnd   = SinOffSet( max(find(SinOffSet <= AllSaccadesTime(i+1))));
                                        
                                        if (SegmentEnd - SegmentStart) >= OneCycleDur,       
                                                unitret('pressed',tnum,curax,[SegmentStart yl(1)]);
                                                unitret('pressed',tnum,curax,[SegmentEnd yl(1)]);
                                        end
                                else % Not grating stimuli 
                                        return
                                end	
                        end;	
                        
                end
        end
        
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
elseif(strcmp(action,'mark_select'))
        
        
        
        
        
        if ( ((in1==0) | (in1 == 1) | (in1 == 7) | (in1 == 2) | (in1==4)) & in2) ,
                curmen = get(gcf,'CurrentMenu');
                
                
                SelHand =get(curmen,'userdata'); 
                set(SelHand,'Checked','off');
                set(curmen,'Checked','on');
                DefValues(26) = in1;
                set(0,'UserData',DefValues); 
                %
        elseif ((in1 == 5 | in1==6 | in1==8) & in2), % Integer number of cycles
                curmen = get(gcf,'CurrentMenu');
                
                SelHand =get(curmen,'userdata'); 
                set(SelHand,'Checked','off');
                set(curmen,'Checked','on');
                DefValues(26) = in1;
                set(0,'UserData',DefValues); 
                %
        elseif (in1 == 3) & in2,
                % reject the uncertain period, while stimulus did not cover completely
                % the receptive field of the cell.
                if DefValues(28)==0,
                        set(curmen,'Checked','on');
                        DefValues(28) = 1;
                else
                        set(curmen,'Checked','off');
                        DefValues(28) = 0;
                end;
                set(0,'UserData',DefValues);
                
                
        end;
        
        if DefValues(26)==0,		% driven activity
                extent = '.SPD';
                figname = 'Selecting stimulus-driven segments';		
        elseif DefValues(26)==1 	% on-off couples
                extent = '.SPC';
                figname = 'Selecting odd/even couples';	
        elseif DefValues(26)==7		% off-on couples
                extent = '.SPC';
                figname = 'Selecting even/odd couples';		
        elseif DefValues(26)==2		% spont data
                extent = '.SPS';     
                figname = 'Selecting ongoing activity';		
        elseif DefValues(26)==4		% event data
                extent = '.SPE';
                figname = 'Selecting event-driven segments';
        elseif DefValues(26)==5         % Selecting Arbitrary Window
                extent = '.SPA'; 
                figname = 'Selecting Arbitrary Window';	
        elseif DefValues(26)==6         % integer number of cycles
                extent = '.SPI'; 
                figname = 'Selecting integer number of cycles';	
        elseif DefValues(26)==8         % all cycles
                extent = '.SPI'; 
                figname = 'Selecting all cycles';		
        end;	
        %%%%
        FileName = get(TRET_DAT(1),'Name');
        
        ext_length = length(extent);
        
        [x,y]=min(abs(FileName - '.'));
        if (x==0), % point exists in the filename)
                NAME = [FileName(1:y),extent(2:ext_length)];
        else
                NAME = [FileName(1:min(8,length(FileName))),extent];
        end;
        
        
        set(TRET_DAT(2),'Name',figname);
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
elseif(strcmp(action,'mark_deselect'))
        REFMAT=[];
        unitret('set_markeddata',[]);
        first = get(TRET_DAT(11),'userdata');
        
        if DefValues(99) | DefValues(145) | DefValues(159), % Saccades Window Select or Drift Select or AutoSelect
                ud=DefValues;
                ud(99)  = 0;
                ud(129) = 0;
                ud(130) = 0;
                ud(131) = 0;
                ud(145) = 0; % Cancel "Take_drifts"
		ud(159) = 0; % Cancel "AutoSelect"
                set(0,'UserData',ud);
        end
        unitret('redraw_exp',first);
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
elseif(strcmp(action,'translate'))
        
        in2 = in2+1;
        
        if strcmp(in1,'StimTempType'),
                strings = str2mat('No motion','Alternating','Flashing','Repeating');
                
        elseif strcmp(in1,'StimSpatType'), 
                strings  = str2mat('Solid tilted rectangular','Sinus','Gabor','6-th deriv of Gaussian',...
                        'Regular texture','Random','Wsine','Csine-sq','Ssine','MAX_PAT_TYPE',...
			'Csine-si','Csine-ramp','Fwsine','Wsquare','SqSweep'); 

	% StimSpatType table - corresponds to st+1 in conver.m
	%
	% Solid tilted rectangular	1
	% Sinus				2
	% Gabor				3
	% 6-th deriv of Gaussian	4
	% Regular texture		5
	% Random			6
	% Wsine				7
	% Csine-sq			8
	% Ssine				9
	% MAX_PAT_TYPE			10
	% Csine-si			11
	% Csine-ramp			12
	% Fwsine			13
	% Wsquare			14
	% SqSweep 			15
 
                
        elseif strcmp(in1,'EyeChoice'), 
                strings  = str2mat('No eyes','Left','Right','Both');
                
        elseif strcmp(in1,'StabFlag'),  
                strings  = str2mat('No stab.','Every frame','Even frames');
                
        elseif strcmp(in1,'CompFlag'),  
                strings  = str2mat('Control PC','Anal PC','TDT PC');
                
                
        elseif strcmp(in1,'FixationType'),
                strings  = str2mat('1 static LED','Multiple LEDs','Oscilloscope',...
                        'Stimulus target');
                
        end;
        if in2 > size(strings,1) | isnan(in2)
                out1 = 'unknown';
        else   
                out1 = deblank(strings(in2,:)); 
        end;
        %-----------------------------------------------------------------------
elseif(strcmp(action,'is periodic'))
        
	out1 = any(in1==[6:13]);

        %-----------------------------------------------------------------------    
elseif(strcmp(action,'NoSeparator')),
        
        Separator = (setstr(fread(in1, 4,'uchar')))';
        if Separator  == 'wwww',
                out1 = 0;
        else
                out1 = 1;
        end;
        %-----------------------------------------------------------------------  
elseif(strcmp(action,'get_obj'))
        parent_handler = in1;
        wanted_type = in2;
        
        kids = get(parent_handler,'Children');
        for i=1:length(kids),
                tp=get(kids(i),'type');
                if (strcmp(tp,wanted_type))
                        out1 = [out1, kids(i)];
                end;
        end;
        
        %------------------------------------------------------------------------
elseif(strcmp(action,'draw_stripshape'))
        
        
        StripPlotStart = in1(1);
        StripPlotWindow = in1(2);
        ShapePer = in1(3);
        ShapeLen = in1(4);
        ShapeOff = in1(5);
        
        
        ShapeInfo = get(gca,'UserData');
        
        SpikesNum = ShapeInfo(1);
        SpikeArrTime = ShapeInfo(2:SpikesNum+1);
        
        ShapeNum = ShapeInfo(SpikesNum+2);
        ShapeAmp = ShapeInfo(SpikesNum+3:SpikesNum+(ShapeNum*ShapeLen)+2);
        
        StripPlotEnd = StripPlotStart+StripPlotWindow;
        ShapeTimeAxis = [StripPlotStart:ShapePer:StripPlotEnd];
        ShapeSignal = zeros(1, size(ShapeTimeAxis,2));
        
        % the specific numbers of spikes we need to insert              
        SpikeInd = find((SpikeArrTime >= StripPlotStart) & (SpikeArrTime < StripPlotEnd)); 
        
        % position of the beginning of spike shapes to be inserted in the show interval, in shape samples units       
        InsertPos = max((ceil((SpikeArrTime(SpikeInd) - StripPlotStart)/ShapePer) - ShapeOff),1);
        
        for i = 0:length(InsertPos)-1,
                LowLim = (SpikeInd(i+1)-1)*ShapeLen+1;
                UpperLim = min(SpikeInd(i+1)*ShapeLen, length(ShapeAmp));
                
                ShapeSignal(InsertPos(i+1):InsertPos(i+1)+ShapeLen-1) = ShapeAmp(LowLim:UpperLim);
        end;
        
        
        
        if max(abs(ShapeSignal)),
                strips(ShapeSignal,(StripPlotWindow)/10 , 1/ShapePer);
                kids = get(gca,'Children');
                set(kids,'Color','b');
        else
                set(text,'String','No shape data in the window','units','normal','Position',[.2 .6]);
                set(gca,'Visible','off')
        end;
        
        % strips clears "userdata" field of curent axes - WHY - X3!
        set(gca,'UserData',ShapeInfo);
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
elseif(strcmp(action,'draw_shrinkedshape'));
        
        
        StripPlotStart = in1(1);
        StripPlotWindow = in1(2);
        ShapePer = in1(3);
        ShapeLen = in1(4);
        ShapeOff = in1(5);
        Ms2Tick = 20;
        TickPnt = 10;
        
        ShapeInfo = get(gca,'UserData');
        
        SpikesNum = ShapeInfo(1);
        SpikeArrTime = ShapeInfo(2:SpikesNum+1);
        TickNum = round(diff(SpikeArrTime))/Ms2Tick;
        
        ShapeNum = ShapeInfo(SpikesNum+2);
        ShapeAmp = ShapeInfo(SpikesNum+3:SpikesNum+(ShapeNum*ShapeLen)+2);
        TickAmp = 2*max(abs(ShapeAmp));     
        
        ShapeSig = zeros(1,10000);       
        NewLength = 0;
        for i = 0:ShapeLen:length(ShapeAmp)-2,
                LowLim =   i+1;
                UpperLim = i+ShapeLen;          
                
                arg = [TickNum(i/ShapeLen+1),i, TickAmp,TickPnt];
                ticks = unitret('make_ticks',arg);
                lt = length(ticks);
                sind = lt+ShapeLen;
                
                ShapeSig(1:NewLength+sind) = [ShapeSig(1:NewLength), ShapeAmp(LowLim:UpperLim),ticks];
                NewLength = NewLength+sind;
        end;
        
        ShapeSig = ShapeSig(1:NewLength);
        
        if max(abs(ShapeSig)),
                strips(ShapeSig,(length(ShapeSig))/10);
                %         plot(ticks,ShapeSig); 
                kids = get(gca,'Children');
                set(kids,'Color','b');
        else
                set(text,'String','No shape data in the window','units','normal','Position',[.2 .6]);
                set(gca,'Visible','off')
        end;
        
        % strips clears "userdata" field of curent axes - WHY - X3!
        set(gca,'UserData',ShapeInfo);
        
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
elseif(strcmp(action,'make_ticks'))
        TickNum = in1(1);
        %   TickStart = in1(2);
        TickAmp = in1(3);
        Ms2Tick = in1(4);
        
        %   xtick = zeros(1,(Ms2Tick+3)*TickNum);
        %   ytick = zeros(1,(Ms2Tick+3)*TickNum);
        ytick = zeros(1,(Ms2Tick)*TickNum);
        
        for i = 0:TickNum-1,
                %     Offset = Ms2Tick+3;
                Offset = Ms2Tick;
                %     xtick(Offset*i+1) = i*Ms2Tick;
                %     xtick(Offset*i+2) = i*Ms2Tick;
                %     xtick(Offset*i+3) = i*Ms2Tick;
                %     xtick(Offset*i+4) = i*Ms2Tick;
                %     xtick(Offset*i+Ms2Tick:(Offset*i+Ms2Tick+3)) = [1:4]+i*Ms2Tick;
                ytick(Offset*i+2) = TickAmp;
                %     ytick(Offset*i+3) = -TickAmp;
        end;  
        
        %  out1  = [xtick; ytick];
        out1 = ytick;
        %--------------------------------------------------------------------------------------
elseif(strcmp(action,'shape_shift'))
        disp_axes = sort(unitret('get_obj', gcf, 'axes'));
        
        
        StripPlotStart = TRET_DAT(10);
        ShapeInfo = get(gco,'UserData');
        
        StripPlotWindow = DefValues(31);
        ShapePer = ShapeInfo(1);
        ShapeLen = ShapeInfo(2);
        ShapeOff = ShapeInfo(3);
        
        arg1 = [StripPlotStart,StripPlotWindow,ShapePer,ShapeLen,ShapeOff];
        
        for i=1:length(disp_axes),
                set(gcf,'CurrentAxes',disp_axes(i));
                disp_lines = unitret('get_obj', disp_axes(i), 'line');
                if ~isempty(disp_lines)
                        delete(disp_lines);
                end;
                unitret('draw_stripshape', arg1);
        end; 
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % FROM "C~PRINT"
elseif(strcmp(action,'InitRead')),
        fileHandler = in1(1);
        unitNum     = in1(2);
        blockStart  = in1(3);
        blockSize   = in1(4);
        
        unitFormat  = in2;
        
        curPos = ftell(fileHandler);		% find current position
        if (curPos - blockStart) < blockSize     
                out1 = fread(fileHandler,unitNum,unitFormat);
        else
                out1 = NaN;
        end;
        
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif(strcmp(action,'errormessage'))
        f = figure('Backingstore','off','Units','norm','position',[.2 .45 .6 .1],'menubar','none','name',in2,...
                'color',[.6 .7 .8],'NumberTitle','off','UserData',0);
        u1 = uicontrol('Units','norm','style','pushbutton','position',...
                [.4 .1 .2 .35],'string','OK','UserData',1);   
        
        set(text,'Position',[.05, .7],'units','norm','string',in1,'color','w','fontsize',12)
        set(gca,'visible','off','position',[0 0 1 1])
        
        
        %     if (exist('error.mat'))
        %	load error;
        %	axes('Units','Normalized','Position',[.1 .4 .8 .3]);
        %	colormap(map);
        %        image(X);
        %     end;
        %     axis('off');
        
        waitforbuttonpress;
        delete(gcf);
        %-----------------------------------------------------------------------  
        
elseif(strcmp(action,'erase_me'))
        MarkedData = unitret('get_markeddata');
        ll = gco;   
        ud = get(ll,'Userdata');
        tnum=ud(1);
        lgn=ud(2);
        xmin=ud(3);
        xmax=ud(4);
        % disp('kuku')
        nrow= size(MarkedData,1);
        for(m = 1:nrow),
                if(sum(MarkedData(m,1:4)==[tnum, lgn, xmin, xmax])==4),	%exclude the record
                        %			ll=line(x1,y1,);
                        set(ll,'EraseMode','none','Color','w');
                        delete(ll); 
                        MarkedData(m,:) = [];
                        FalseChoice=1;
                        break;
                end;
        end;
        unitret('set_markeddata',MarkedData);
        %-----------------------------------------------------------------------  
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
        
elseif(strcmp(action,'display_concatenated')) % Display Concatenated, analog of 'redraw_spk'
        
        set(gcf,'Pointer','Watch');
        ud=get(0,'UserData');
        ud(51)=1; %DispConcFlag
        set(0,'Userdata',ud);
        
        kids=get(TRET_DAT(2),'Children');
        for i=1:length(kids),
                tp=get(kids(i),'type');
                if (strcmp(tp,'axes')) | (strcmp(tp,'uicontrol'))
                        delete(kids(i));
                end;
        end;
        
        
        first = in1;
        AccDrawMenu= get(TRET_DAT(7),'UserData');
        AccSegmentDraw = get(AccDrawMenu(1),'Checked');
        
        Spk = unitret('get_markeddata');
        
        %maxcol = DefValues(13);
        %maxrow = DefValues(16);
        
        maxcol = 10;
        maxrow = 100;
        grapsnum = maxcol*maxrow; % number of the same type graphs on the screen (on or off)
        
        
        color = ['m','b','g', 'r']; c = 1;
        np=size(Spk,1);
        
        % Check Number of Plots on the Figure
        % if np>grapsnum
        %    warndlg('Please increase the number of plots on graph (go to Setup)','Advise...');
        %    return
        % end
        
        Spk0 = [];
        Spk1 = [];
        for i=1:np,
		if 0 %***
                if Spk(i,5) == 0,
                        Spk0 = [Spk0;Spk(i,:)];
                else
                        Spk1 = [Spk1;Spk(i,:)];
                end;
		end
		Spk1 = [Spk1;Spk(i,:)];
        end;
        
        for i=0:1,
                s(i+1,:) = ['CurSpk = []; CurSpk = Spk', num2str(i),';'];
        end; 
        
        wi = .05;                          % width of each interval between axises
        hi = .03;                           % higth of each interval between axises
        wt = .1;                            % width of field for axis
        ht = .7;                          % heigth of field for axis  
        %      wb = (wt-(2*maxcol-1)*wi)/(2*maxcol);   % x size for one subplot axis 
        %      hb = (ht-(maxrow-1)*hi)/maxrow;   % y ....
        
        wb = (1-3*wi*maxcol)/(2*maxcol);
        colwidth=2*wb+3*wi;
        
        hb = (ht-(maxrow+1)*hi)/maxrow;
        
        
        if DefValues(19),    % economy plot (Raster)
                for m=1:2,
                        eval(s(m,:));
                        k=0;
                        nap(m) = size(CurSpk,1);
                        if(nap(m))
                                axpos = [.05+(0.45+wi)*(~(m-1)) .4 .4 .3];                                
                                xlim = [0 (max(CurSpk(:,4) - CurSpk(:,3)))];
                                				
                                ax = axes('Position',axpos,'DrawMode','fast','TickDir','out',...
                                        'XLimMode','Manual','XLim',xlim,'YTick',[], 'NextPlot','add');
                                
                                for k=1:nap(m),
                                        TrialNum =CurSpk(k,1); 
                                        SpikesNum = CurSpk(k,2);
                                        StartSpikeData = CurSpk(k,3);
                                        EndSpikeData = CurSpk(k,4);
                                        SpikeArrTime = CurSpk(k,(6:SpikesNum+5)) - StartSpikeData;
                                        SpikeAmp = ones(size(SpikeArrTime)).*k;
                                        line(SpikeArrTime,SpikeAmp,'color','b','LineStyle', '.','LineWidth',1);
                                end;
                        end;
                end;  
        else,
                
                
                TotalEyeTimeInterval=[];
                TotalHorEyeInterval=[];
                TotalVerEyeInterval=[];
                TotalSpkArrTime=[];
                TotSpk=[];
                CurOffset=0;
                TotSpk(1)=99; %#trial
                TotSpk(2)=sum(Spk(:,2));  %#spikes
                TotSpk(3)=0; %to
                TotSpk(4)=sum( Spk(:,4)-Spk(:,3) ); %tend
                TotSpk(5)=69; %modality
                
                % main drawing loop:
                for m=1:2,
                        eval(s(m,:));
                        nap(m) = size(CurSpk,1);
                        if(nap(m))
                                for i=0:maxcol-1,
                                        for j=0:maxrow-1,
                                                
                                                gind = (i*maxrow+j);
                                                k=first + gind;
                                                if(k>nap(m)),
                                                        break;
                                                else
                                                        TrialNum =CurSpk(k,1); 
                                                        SpikesNum = CurSpk(k,2);
                                                        StartSpikeData = CurSpk(k,3);
                                                        EndSpikeData = CurSpk(k,4);
                                                        SpikeArrTime = CurSpk(k,(6:SpikesNum+5));
                                                        
                                                        EyeMotionLength=CurSpk(k,SpikesNum+6);
                                                        
                                                        EyeTimeInterval= CurSpk(k,(SpikesNum+7):(SpikesNum+EyeMotionLength+6));
                                                        HorEyeInterval = CurSpk(k,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6));
                                                        VerEyeInterval = CurSpk(k,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6));
                                                        StimVelocity = CurSpk(k,(SpikesNum+3*EyeMotionLength+7));
                                                        Tilt = CurSpk(k,(SpikesNum+3*EyeMotionLength+8));
                                                        
                                                        %nado ubrat' chtenie pustogo chisla spikov
                                                        
                                                        %		 axpos = [.01+i*.5+(m-1)*.25 .9-j*.095 .22 .09];
                                                        axpos = [i*colwidth + wi+(~(m-1))*(wi+wb), 1-(j+1)*(hb+hi), wb, hb];
                                                        
                                                %%~%%ax = axes('Position',axpos,'DrawMode','fast','TickDir','out',...
                                                %%  'XLimMode','Manual','XLim',[CurSpk(k,3) CurSpk(k,4)],'YLimMode',...
                                                %%  'Manual','YLim',[DefValues(7) DefValues(10)],'UserData',...
                                                %%   CurSpk(k,:),'FontSize',7);
                                                
                                                
                                                %%~%% set(text,'String',['Trial #',num2str(CurSpk(k,1)),', ',num2str(SpikesNum), ' spk'],'units','normal',...
                                                %% 'Position',[.2 .65],'FontSize',8,'color',[0.5020 0 0.2510]);
                                                
                                                %%strax =    sprintf(' %17.13f',ax);
                                                
                                                
                                                
                                                if DefValues(23),
                                                        if DefValues(27)
                                                                EM = [HorEyeInterval;VerEyeInterval];
                                                                alfa = pi*Tilt/180;
                                                                Trans = [cos(alfa) sin(alfa); -sin(alfa) cos(alfa)];
                                                                EMNew = Trans * EM;
                                                                HorEyeInterval = EMNew(1,:);
                                                                VerEyeInterval = EMNew(2,:);
                                                        end;
                                                        %line(EyeTimeInterval,HorEyeInterval,'Color',[0 .502 0]);
                                                        %line(EyeTimeInterval,VerEyeInterval,'Color','m','LineWidth',1);
                                                        
							if DefValues(171)==2, % eye velocity
	                                                        TotalHorEyeInterval=[TotalHorEyeInterval diff(HorEyeInterval)];
        	                                                TotalVerEyeInterval=[TotalVerEyeInterval diff(VerEyeInterval)];
								TotalEyeTimeInterval=[TotalEyeTimeInterval EyeTimeInterval(1:length(EyeTimeInterval)-1)-StartSpikeData+CurOffset];
							else
	                                                        TotalHorEyeInterval=[TotalHorEyeInterval HorEyeInterval];
        	                                                TotalVerEyeInterval=[TotalVerEyeInterval VerEyeInterval];
								TotalEyeTimeInterval=[TotalEyeTimeInterval EyeTimeInterval-StartSpikeData+CurOffset];
							end
                                                end; 
                                                
                                                if SpikesNum
                                                        if DefValues(1)
                                                                bins=(StartSpikeData:DefValues(1):EndSpikeData);
                                                                [N,SpikeHist]=hist(SpikeArrTime,bins);
                                                                [xx,yy] = bar(SpikeHist,N);
                                                                
                                                        else
                                                                xx = zeros(1,3*SpikesNum);
                                                                xx(1:3:(3*SpikesNum-2)) = SpikeArrTime;
                                                                xx(2:3:(3*SpikesNum-1)) = SpikeArrTime;
                                                                xx(3:3:(3*SpikesNum))   = SpikeArrTime;
                                                                yy = zeros(1,3*SpikesNum);
                                                                yy(2:3:(3*SpikesNum-1)) = ones(1,SpikesNum); 
                                                        end;
                                                        
                                                        
                                                        
                                                        SpikeAmp = (DefValues(10) - DefValues(7)) / (3*max(yy));
                                                        %line(xx,SpikeAmp*yy+DefValues(7),'Color',color(c));
                                                end
                                                TotalSpkArrTime=[TotalSpkArrTime SpikeArrTime-StartSpikeData+CurOffset];
                                                CurOffset=CurOffset+EndSpikeData-StartSpikeData;
                                                % if accumulation function should be drawn...
                                                if strcmp(AccSegmentDraw,'on'),
                                                        unitret('redraw_accumulation',CurSpk(k,(6:SpikesNum+5)));
                                                end;    
                                                %                if any trials were already edited (scrolling during  edit)                   
                                                
                                                tmp1 = get(TRET_DAT(5),'UserData');
                                                if ~isempty(tmp1),
                                                        for jj=1:size(tmp1,1),
                                                                if (tmp1(jj,1:5) ==CurSpk(k,1:5)), %set new limits
                                                                        set(gca,'XLim',[tmp1(jj,6) tmp1(jj,7)]);
                                                                        break;
                                                                end;
                                                        end;   
                                                end;   
                                                
                                                if (c==length(color)), 
                                                        c =0;
                                                end;
                                                c = c+1;         
                                        end;
                                end;  
                        end; 
                        
                end;  
        end;
        
        if (DefValues(86)==1 | DefValues(86)==2), 
                
                TotSpk=[TotSpk TotalSpkArrTime];
                axpos=[.1 .7 .8 .2];
                ax = axes('Position',axpos,'DrawMode','fast','TickDir','out',...
                        'XLimMode','Manual','XLim',[TotSpk(3) TotSpk(4)],'YLimMode',...
                        'Manual','YLim',[DefValues(7) DefValues(10)],'UserData',...
                        TotSpk,'FontSize',7);
        elseif DefValues(86)==3,
                IFR = 1./( diff([0 TotalSpkArrTime])/1000 ); % in spk/seconds
                YMax= max([IFR 0])+10;
                TotSpk=[TotSpk TotalSpkArrTime];
                axpos=[.1 .7 .8 .2];
                ax = axes('Position',axpos,'DrawMode','fast','TickDir','out',...
                        'XLimMode','Manual','XLim',[TotSpk(3) TotSpk(4)],'YLimMode',...
                        'Manual','YLim',[0 YMax],'UserData',...
                        TotSpk,'FontSize',7);
                DefValues(23) = 0;
        end
        
        
        % ~~~ set(TRET_DAT(1),'UserData',TotSpk);
        
        %%%%%~%%%%% set(gcf,'UserData',TotSpk);
        set(text,'String',['Concatenated ',num2str(np),' segments; Total # spikes: ',num2str(TotSpk(2)),'; Mean Firing Rate ',num2str(TotSpk(2)/( TotSpk(4)/1000 )),' spk/s'],'units','normal',...
                'Position',[.1 1.1],'FontSize',8,'color',[0.5020 0 0.2510]);
        set(text,'String',['Normalized MFR: ',num2str(TotSpk(2)/TotSpk(4),3)],'units','normal',...
                'Position',[0 -0.22],'FontSize',8,'color',[0.5020  0  0.5020]);
        
        strax =    sprintf(' %17.13f',ax);
        
        if DefValues(23), 
                % Plot Concatenated Spike And Eye Movements Plot
                line(TotalEyeTimeInterval,TotalHorEyeInterval,'Color',[0 .502 0]);
                line(TotalEyeTimeInterval,TotalVerEyeInterval,'Color','m','LineWidth',1);
        end
        
        if DefValues(1)
                bins=(TotSpk(3):DefValues(1):TotSpk(4));
                [N,SpikeHist]=hist(TotalSpkArrTime,bins);
                [xx,yy] = bar(SpikeHist,N);
                
        else
                SpikesNum=TotSpk(2);
                xx = zeros(1,3*SpikesNum);
                
                xx(1:3:(3*SpikesNum-2)) = TotalSpkArrTime;
                xx(2:3:(3*SpikesNum-1)) = TotalSpkArrTime;
                xx(3:3:(3*SpikesNum))   = TotalSpkArrTime;
                yy = zeros(1,3*SpikesNum);
                yy(2:3:(3*SpikesNum-1)) = ones(1,SpikesNum); 
        end;
        
        if (DefValues(86)==1 | DefValues(86)==2), 
                line(xx,SpikeAmp*yy+DefValues(7),'Color','r');
        elseif(DefValues(86)==3),
		line(TotalSpkArrTime, [IFR], 'Color','r','LineWidth',1.5); 
        end
        
        if(nap(1)>grapsnum  | nap(2) > grapsnum ),
                back = max(1, first - grapsnum); 
                next = first+grapsnum; 
                if ( in1 > grapsnum)
                        more_call = ['unitret(''redraw_spk'',',num2str(back),');'];
                        more_button = uicontrol(TRET_DAT(2),'Units','normal', 'Position',[.7 .02, .1 .05],...
                                'String','<<','Callback',more_call);
                end;
                if(next <= nap(1) | next <= nap(2)),
                        more_call = ['unitret(''redraw_spk'',',num2str(next),');'];
                        more_button = uicontrol(TRET_DAT(2),'Units','normal', 'Position',[.85 .02, .1 .05],...
                                'String','>>','Callback',more_call);
                end;
        end;
        
end;  

if 0 %***
if isempty(Spk0),
        Spk0 = 0;
elseif isempty(Spk1)
        Spk1 = 0;
end;
end

% PLOT HISTOGRAM OF CONCATENATED
%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% CELL... vector format:
% in each row one segment:
% #trial
% #spikes
% to
% tend
% modality
% spikes arrival times 
% ...
%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if (DefValues(20))
        ConcSpk1=[];
        ConcSpk1(1)=99; %#trial
        ConcSpk1(2)=sum(Spk1(:,2)); %#spikes
        ConcSpk1(3)=0; %to
        ConcSpk1(4)=sum( Spk1(:,4)-Spk1(:,3) ); %tend
        ConcSpk1(5)=69; %modality
        OffSet=0;
        for i=1:size(Spk1,1),
                ConcSpk1=[ConcSpk1 Spk1(i,6:Spk1(i,2)+5) - Spk1(i,3) + OffSet];   
                OffSet=OffSet+Spk1(i,4)-Spk1(i,3);
        end   
        process('average',Spk1,ConcSpk1,1);
        
end;

unitret('figname');

set(gcf,'Pointer','Arrow');
set(TRET_DAT(1),'Pointer','Arrow');

out1.time	= TotalEyeTimeInterval;
out1.hor	= TotalHorEyeInterval;
out1.ver	= TotalVerEyeInterval;

%=============================================================================================================

elseif(strcmp(action,'display_averaged'))
        global AVC % Average Concatenated
        AVC=[];
        
        if (in1==1), % SET UP
                
                
                % Set Up Averaging:
                
                Fig1 = figure('Backingstore','off','Name','Average Setup','Color','w',...
                        'Units','Normal','Position',[.22 .3 .3 .4],'Resize','On', 'Menubar','none','Number','off');
                set(gcf,'Pointer','Watch');
                
                Spk      = unitret('get_markeddata');
                
                % ~~~ TotalSpk = get(TRET_DAT(1),'UserData');
                TotalSpk = TotSpk; % TotSpk is global variable
                if isempty(TotalSpk)
                        TotalTime ='? (run "Display Concatenated")';
                        colour='r';
                        enableOK='off';
                else
                        TotalTime = num2str(TotalSpk(4)-TotalSpk(3));
                        colour=[.15 .3 .2];
                        enableOK='on';
                end
                
                if DefValues(55) | isempty(TotalSpk) % not zero, already was set
                        ms        = DefValues(55);                        
                else
                        ms        = (TotalSpk(4)-TotalSpk(3));                 
                end
                
                %............................. 1 ...........................................
                uicontrol(Fig1,'Style','text','Position',[.07 .7 .3 .05],...
                        'Units','normal','ForegroundColor',[.1 .2 .3],...
                        'BackgroundColor','w','String','Average over ',...
                        'HorizontalAlignment','center');
                
                u1 = uicontrol(Fig1,'Style','edit','Position',[.38 .68 .2 .08],...
                        'Units','normalized','BackgroundColor','w',...
                        'ForegroundColor','b','String',num2str(ms),...
                        'Callback',['ud=get(0,''Userdata''); ud(55)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
                
                uicontrol(Fig1,'Style','text','Position',[.6 .7 .15 .05],...
                        'Units','normal','ForegroundColor',[.1 .2 .3],...
                        'BackgroundColor','w','String','ms',...
                        'HorizontalAlignment','center');
                %.............................. end of 1 ....................................
                
                %............................. 2 ...........................................
                uicontrol(Fig1,'Style','text','Position',[.07 .6 .3 .05],...
                        'Units','normal','ForegroundColor',[.1 .2 .3],...
                        'BackgroundColor','w','String','Bin [ms]',...
                        'HorizontalAlignment','center');
                
                u1 = uicontrol(Fig1,'Style','edit','Position',[.38 .58 .2 .08],...
                        'Units','normalized','BackgroundColor','w',...
                        'ForegroundColor','b','String',num2str(DefValues(56)),...
                        'Callback',['ud=get(0,''Userdata''); ud(56)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
                
                %.............................. end of 2 ....................................
                
                %............................. 3 ...........................................
                uicontrol(Fig1,'Style','text','Position',[.07 .5 .3 .05],...
                        'Units','normal','ForegroundColor',[.1 .2 .3],...
                        'BackgroundColor','w','String','Cycle [ms]',...
                        'HorizontalAlignment','center');
                
                u1 = uicontrol(Fig1,'Style','edit','Position',[.38 .48 .2 .08],...
                        'Units','normalized','BackgroundColor','w',...
                        'ForegroundColor','b','String',num2str(DefValues(57)),...
                        'Callback',['ud=get(0,''Userdata''); ud(57)=str2num(get(gco,''string'')); set(0,''UserData'',ud);']);
                
                %.............................. end of 3 ....................................
                
                %............................. 4 ...........................................
                uicontrol(Fig1,'Style','text','Position',[.07 .4 .3 .05],...
                        'Units','normal','ForegroundColor',[.1 .2 .3],...
                        'BackgroundColor','w','String','Successive',...
                        'HorizontalAlignment','center');
                
                u1 = uicontrol(Fig1,'Style','checkbox','Position',[.38 .38 .2 .08],...
                        'Units','normalized','BackgroundColor','w',...
                        'ForegroundColor','b','value',DefValues(58),...
                        'Callback',['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                                'ud=get(0,''UserData''); ud(58) = val; set(0,''userdata'',ud);']);
                %.............................. end of 4 ....................................
                
                
                uicontrol(Fig1,'Style','text','Position',[.1 .2 .9 .05],...
                        'Units','normal','ForegroundColor',colour,...
                        'BackgroundColor','w','String',['Total Time: ',TotalTime,' ms'],...
                        'HorizontalAlignment','left');
                
                uicontrol(Fig1,'Style','text','Position',[.1 .1 .7 .05],...
                        'Units','normal','ForegroundColor',[.15 .4 .3],...
                        'BackgroundColor','w','String',['Min Segment: ',num2str(min(Spk(:,4)-Spk(:,3))),' ms'],...
                        'HorizontalAlignment','left');
                
                %---------------------     
                OK_button=uicontrol(Fig1,'Style','pushbutton','Position',[.75 .9 .22 .06],'Enable',enableOK,...
                        'Units','Normalized','String','OK','Callback',['delete(',num2str(Fig1), '); unitret(''display_averaged'',2);']);
                
                cancel=uicontrol(Fig1,'Style','pushbutton','Position',[.75 .82 .22 .06],...
                        'Units','Normalized','String','Cancel','Callback',['delete(',num2str(Fig1), '), return']);
                
                
                set(gcf,'Pointer','Arrow');
                set(TRET_DAT(1),'Pointer','Arrow');
                
        else % PLOT AVERAGED
                
                set(0,'CurrentFigure',TRET_DAT(2));
                set(TRET_DAT(2),'Pointer','Watch');
                delete(gca)
                unitret('figname');
                Spk        = unitret('get_markeddata');
                TotalSpk   = TotSpk; % TotSpk is global variable
                Spikes     = TotalSpk(6:length(TotalSpk));
                
                AverPer=DefValues(55);
                AverBin=DefValues(56);
                TotalTime=TotalSpk(4)-TotalSpk(3);
                if DefValues(57) % another cycle is chosen
                        Cycle=DefValues(57);
                else 
                        Cycle=ceil(min(Spk(:,4)-Spk(:,3)));
                end
                
                % Check if AverPer is set
                if AverPer==0,
                        AverPer=TotalTime;
                end
                
                if DefValues(58), % Successive
                        NumOfHist=floor(TotalTime/AverPer); 
                        To=0;
                        CurAverSegm=zeros(NumOfHist,Cycle);
                        
                        for i=1:NumOfHist
                                To=AverPer*(i-1);
                                Tend=To+AverPer;
                                CurSpikes=Spikes(find(Spikes>=To & Spikes<Tend));    
                                for j=1:floor(AverPer/Cycle),
                                        CurSegm=zeros(1,Cycle);
                                        to=Cycle*(j-1)+To;
                                        tend=to+Cycle;
                                        CurCycle=CurSpikes(find(CurSpikes>=to & CurSpikes<tend));
                                        CurSegm(1,ceil(CurCycle-to+eps)) = ones(1,length(CurCycle));
                                        CurAverSegm(i,:)=CurAverSegm(i,:)+CurSegm;
                                end         
                        end
                        Norm=floor(AverPer/Cycle);	% Normalization: how many cycles are summed
                        TitleString=[num2str(NumOfHist),' averaged periods of ',num2str(AverPer),' ms; ',num2str(floor(AverPer/Cycle)),' "cycles" of ',num2str(Cycle),' ms in each. Successive.',' ',num2str(Norm),' cycles averaged'];
                else % not successive, 1st + 1st ... 2nd + 2nd... ...
                        NumOfHist=floor(AverPer/Cycle); 
                        To=0;
                        CurAverSegm=zeros(NumOfHist,Cycle);
                        for i=1:NumOfHist,
                                to=Cycle*(i-1);
                                for j=1:floor(TotalTime/AverPer),
                                        CurSegm=zeros(1,Cycle);
                                        To=AverPer*(j-1);
                                        t0=To+to;
                                        tend=t0+Cycle;
                                        CurCycle=Spikes(find(Spikes>=t0 & Spikes<tend));	
                                        CurSegm(1,ceil(CurCycle-t0+eps)) = ones(1,length(CurCycle));
                                        CurAverSegm(i,:)=CurAverSegm(i,:)+CurSegm;
                                end
                        end
                        Norm=floor(TotalTime/AverPer);	 % Normalization: how many cycles are summed
                        TitleString=[num2str(floor(TotalTime/AverPer)),' averaged periods of ',num2str(AverPer),' ms; ',num2str(floor(AverPer/Cycle)),' "cycles" of ',num2str(Cycle),' ms in each.',' ',num2str(Norm),' cycles averaged'];
                end % Successive/Not Successive 
                
                Aver=reshape(CurAverSegm',1,size(CurAverSegm,1)*size(CurAverSegm,2));
                
                Bins=AverBin/2:AverBin:Cycle*NumOfHist-AverBin/2;
                ax=axes('Position',[.1 .4 .8 .2],'DrawMode','fast','TickDir','out',...
                        'XLimMode','Manual','XLim',[0 Cycle*NumOfHist],'YLimMode',...
                        'Manual','UserData',Aver,'FontSize',7,'Box','off');
                cla
                
                
                for i=1:length(Bins),
                        AH(i)=sum( Aver(1+(i-1)*AverBin:(i*AverBin) ) );
                end
                AH=AH/(Norm*AverBin);	
                hb = bar(Bins,1000*AH,1,'k'); % in spikes/s
		set(hb,'FaceColor',[0.5 0.5 0.5]);
                AVC(1,:)= Bins;
                AVC(2,:)= AH;
                
                set(gca,'FontSize',7,'Box','off','TickDir','out');
                
                set(text,'String',['n=',num2str(sum(Aver)),'; ' TitleString],'units','normal',...
                        'Position',[.1 1.1],'FontSize',8,'color',[0.5020 0 0.2510]);
                
                set(text,'String',['Mean Activity: ',num2str(sum(Aver)/TotalTime),' ( ',num2str(sum(Aver)/(TotalTime/1000)),' spk/s )'],'units','normal',...
                        'Position',[0 -.3],'FontSize',9,'color',[.2 .3 .3]);	%[0.7020 0.0 0.2510] bordo
                
                set(gcf,'Pointer','Arrow');
                set(TRET_DAT(1),'Pointer','Arrow');
        end 
        
        
        %=============================================================================================================
elseif(strcmp(action,'snap_inside'))
        
        curmen = get(gcf,'CurrentMenu');
        %SelHand =get(curmen,'userdata'); 
        %set(SelHand,'Checked','off');
        
        
        DefValues(52) = ~DefValues(52);
        if DefValues(52)
                set(curmen,'Checked','on');
        else
                set(curmen,'Checked','off');
        end
        set(0,'UserData',DefValues); 
        
        %--------------------------------------------------------------------------------------------------------------
        
elseif(strcmp(action,'another_cell'))
        if isempty(REFMAT)
                warndlg('No Segments Template have been selected yet!')
                return
        else
                DefValues(63)=1;
                set(0,'UserData',DefValues)
                unitret('read_header',NAME(1:length(NAME)-4));
                
                pause   
                [filename, pathname] = uiputfile([NAME(1:length(NAME)-4),'.s??'], 'Save Same Segments As...', .4, .4);
                if filename == 0, 
                        return;
                else
                        NAME = filename;
                end;
                name = [pathname,NAME];
                unitret('save_markeddata',name);
                
                % Re-initialize
                DefValues(63)=0;
                set(0,'UserData',DefValues)  
        end
        
        %---------------------------------------------------------------------------------------------------------------------------------------------------------------     
        
elseif(strcmp(action,'fill_current_segment'))
        % like 'p($)ressed'
        
        
        % here - in1 = tnum;
        % in2 - handle of the current axes
        % in3 - [xmin,xmax, Mod, REFMATrow]
        global STIMULUS SPIKES MOTION;
        
        tnum  = in1;
        curax = in2;
        
        EyeMovementHandle=get(curax,'UserData');
        
        NumSt=STIMULUS(tnum,1);         %number of stimuli for given trial
        EndStim=STIMULUS(tnum,2);       %TrialDuration for given trial
        
        xmin=in3(1);
        xmax=in3(2);
        Mod=in3(3);
        REFMATrow=in3(4);
        
        EyeTimeAxis=get(EyeMovementHandle(1),'XData');
        HorEyeMov = get(EyeMovementHandle(1),'YData');
        VerEyeMov = get(EyeMovementHandle(2),'YData');
        
        imin = min(find(EyeTimeAxis >= xmin));
        imax = max(find(EyeTimeAxis <= xmax));
        
        EyeTimeInterval=EyeTimeAxis(imin:imax);
        HorEyeInterval = HorEyeMov(imin:imax);
        
        if sum( ( REFMAT(REFMATrow,5:min(10,length(EyeTimeInterval)+4)) ~= HorEyeInterval(1:min(6,length(EyeTimeInterval))) ) ) % Lost of synchronization
                warndlg(['Lost of synchronization in ',num2str(tnum),' trial. Selection should be terminated...'])
                DefValues(63)=0;
                set(0,'UserData',DefValues)  
                return
        end	 
        
        VerEyeInterval = VerEyeMov(imin:imax);
        EyeMotionLength=imax-imin+1;
        %here we transform XY eye movement into the new coordinate system,
        % where X axes is parallel to the stimulus tilt and Y axis is 
        %perpendicular to the tilt
        %
        
        % LOOKING FOR SPIKES BETWEEN xmin and xmax timegate
        
        snum = SPIKES(tnum, 1);
        
        SpkInd = find((SPIKES(tnum, 4:snum+3) >= xmin) & ((SPIKES(tnum, 4:snum+3)<xmax)));
        lowind=min(SpkInd)+3;
        upind=max(SpkInd)+3;
        
        set(TRET_DAT(2),'CurrentAxes',curax);
        
        MarkedData = unitret('get_markeddata');
        
        ncol = size(MarkedData,2);
        nrow = size(MarkedData,1);              %=TrialsNum of the given file
        lgn=length(SpkInd);
        
        
        maxncol = max((lgn+5),ncol);
        newrow = nrow + 1;
        tmp = zeros(nrow+1,maxncol);
        for i=1:nrow,
                tmp(i,1:ncol) = MarkedData(i,:);
        end;
        
        MarkedData(newrow,1) = tnum;
        MarkedData(newrow,2) = lgn;
        MarkedData(newrow,3) = xmin;
        MarkedData(newrow,4) = xmax;
        MarkedData(newrow,5) = Mod;
        MarkedData(newrow,6:lgn+5) = SPIKES(tnum, lowind:upind);
        MarkedData(newrow,lgn+6)= EyeMotionLength;
        MarkedData(newrow,lgn+7:(lgn+6+3*EyeMotionLength))= ...
                [EyeTimeInterval HorEyeInterval VerEyeInterval];
        
        motionidx=lgn+7+3*EyeMotionLength;
        MarkedData(newrow, motionidx:(motionidx+size(MOTION,2)-1)) = MOTION(tnum,:);
        
        
        set(TRET_DAT(3),'enable','on');
        
        
        unitret('set_markeddata',MarkedData);
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'send_to_excel'))
        % This section takes some of MarkedData and sends it to Excel sheet 
        % according to format:
        % eye-x  eye-y	raw spike binned spikes	seg starts seg end file # trial #
        
        if in1 == 1,
                % Ask about changing Excel topic (EXCEL_NAME)
                
                bc =[0.5529    0.8118    0.8941];
                Fig = figure('Backingstore','on','Color',bc,...
                        'Units','Normalized','Position',[0.3 0.4 .4 .2],'Resize','Off', 'Name',...
                        'SELECT EXCEL SHEET','MenuBar','none','Number','off');
                
                uicontrol(Fig,'Style','text','Position',[.07 .45 .3 .15],...
                        'Units','normal','ForegroundColor','b',...
                        'BackgroundColor',[0.7529    0.7529    0.7529],'String','Sending data to:',...
                        'HorizontalAlignment','center');
                
                uicontrol(Fig,'Style','frame','Position',[.05 .33 .65 .4],...
                        'Units','normalized','BackgroundColor',[0.7529    0.7529    0.7529],...
                        'ForegroundColor','k');
                
                u1 = uicontrol(Fig,'Style','edit','Position',[.35 .5 .3 .1],...
                        'Units','normalized','BackgroundColor','w',...
                        'ForegroundColor','k','String',EXCEL_NAME,...
                        'HorizontalAlignment','left','Callback','global EXCEL_NAME; ');
                
                
                OK_button=uicontrol(Fig,'Style','pushbutton','Position',[.75 .7 .22 .22],'Userdata',u1, ...
                        'Units','Normalized','String','OK');
                set(Fig,'Userdata',u1);
                set(OK_button,'Callback',['u1 = get(gcf,''Userdata''); global EXCEL_NAME; EXCEL_NAME = get(u1,''String''); delete(',num2str(Fig), '),unitret(''send_to_excel'',2,EXCEL_NAME);']);
                
                cancel=uicontrol(Fig,'Style','pushbutton','Position',[.75 .4 .22 .22],...
                        'Units','Normalized','String','Cancel','Callback',['delete(',num2str(Fig), '), return']);
                
                
        else % (in1==2),
                
                set(gcf,'Pointer','Watch')
                global EXCEL_NAME
                EXCEL_NAME = in2;
                
                MarkedData=unitret('get_markeddata');
                
                if (~isempty(MarkedData)),
                        
                        row_num = size(MarkedData,1);
                        offset=1;
                        excel_name = EXCEL_NAME;
                        head = 'eye-x	eye-y	raw spike	bin spikes	seg starts	seg end	file #	trial #';
                        
                        
                        for i=1:row_num,
                                
                                SpikesNum = MarkedData(i,2);
                                SpikesInf = MarkedData(i,1:5);
                                TrialNum  = MarkedData(i,1);
                                To        = MarkedData(i,3);
                                Tend      = MarkedData(i,4);
                                SpikesData = MarkedData(i,6:SpikesNum+5)';
                                
                                EyeMotionLength = MarkedData(i,SpikesNum+6);
                                EyeTimeInterval= MarkedData(i,(SpikesNum+7):(SpikesNum+EyeMotionLength+6))';
                                HorEyeInterval = MarkedData(i,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6))';
                                VerEyeInterval = MarkedData(i,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6))';          
                                if isempty(SpikesData), % No spikes in segment
                                        SpikesData = 'no spikes';
                                        binned_spikes = zeros(length(EyeTimeInterval),1);
                                else
                                        [binned_spikes, bins] = hist(SpikesData, EyeTimeInterval+(EyeTimeInterval(2)-EyeTimeInterval(1))/2);
                                        binned_spikes = binned_spikes';
                                end 
                                
                                
                                % Send data to excel
                                dde2e(excel_name, ['r1c',num2str(offset),':r1c',num2str(offset+7)], head);
                                dde2e(excel_name, ['r2c',num2str(offset),':r',num2str(length(HorEyeInterval)+1),'c',num2str(offset)], HorEyeInterval);
                                dde2e(excel_name, ['r2c',num2str(offset+1),':r',num2str(length(VerEyeInterval)+1),'c',num2str(offset+1)], VerEyeInterval);
                                dde2e(excel_name, ['r2c',num2str(offset+2),':r',num2str(length(SpikesData)+1),'c',num2str(offset+2)], SpikesData);
                                dde2e(excel_name, ['r2c',num2str(offset+3),':r',num2str(length(binned_spikes)+1),'c',num2str(offset+3)], binned_spikes);
                                dde2e(excel_name, ['r2c',num2str(offset+4),':r2c',num2str(offset+4)], To);
                                dde2e(excel_name, ['r2c',num2str(offset+5),':r2c',num2str(offset+5)], Tend);
                                dde2e(excel_name, ['r2c',num2str(offset+6),':r2c',num2str(offset+6)], INI_NAME);
                                [rc, DDEChannel] = dde2e(excel_name, ['r2c',num2str(offset+7),':r2c',num2str(offset+7)], TrialNum);
                                
                                offset = offset + 8;
                                
                        end % of loop for segments (row_num)
                        
                        % Terminate DDE conversation
                        % rc = ddeterm(DDEchannel);
                        set(gcf,'Pointer','Arrow')
                end
        end
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'grand_eye_position'))
        
        MarkedData=unitret('get_markeddata');
        
        if (~isempty(MarkedData)),
                
                row_num = size(MarkedData,1);
                H_E_Motion = [];
                V_E_Motion = [];
                
                for(i=1:row_num)
                        SpikesNum = MarkedData(i,2);
                        
                        EyeMotionLength = MarkedData(i,SpikesNum+6);
                        EyeTimeInterval = MarkedData(i,(SpikesNum+7):(SpikesNum+EyeMotionLength+6));
                        HorEyeInterval  = MarkedData(i,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6));
                        VerEyeInterval  = MarkedData(i,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6));
                        
                        H_E_Motion = [H_E_Motion HorEyeInterval];
                        V_E_Motion = [V_E_Motion VerEyeInterval];
                end;
                
                H_Grand_Ave = mean(H_E_Motion); 
                V_Grand_Ave = mean(V_E_Motion); 
                
                unitret('grand_handle','Hor	Ver',[H_Grand_Ave V_Grand_Ave]);
                
        end
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'stim_on_monitor'))
        % Plot Stimulus on Monitor
        % Monitor dimensions in minarc MonW x MonH

	global HCELL
        
        % like Trial Info:
        trials_inf = get(TRET_DAT(1),'UserData');
        fid = trials_inf(1);
        TrialsNum = trials_inf(2);
        TrialBegin = trials_inf(3:TrialsNum+2);
        
        if in1==0,
                str = ['1'];
                if TrialsNum >1,    
                        for(i=2:TrialsNum),
                                str = [str, '|', num2str(i)];      
                        end;
                end;
                
                Fig1 = figure('Backingstore','off','Name','Stimulus on Monitor','Color','w',...
                        'Units','Normal','Position',[.22 .2 .78 .7],'Resize','On', 'Menubar','none','Number','off',...
                        'DefaultAxesPosition',[0 0 1 01],'visible','on');
                figcounter = figcounter + 1; 
                set(gcf,'WindowButtonDownFcn','ud = get(0,''Userdata'');ud(72) = gcf;set(0,''Userdata'',ud);');
                cla
                set(gca,'Visible','off')
                set(gcf,'Pointer','Watch', 'Userdata',gca);
                
                set(text,'Position',[.3 .98],'Color','b','string','TRIAL #:'); 
                
                if strcmp(v(1),'5'),
                        tnumHndl = uicontrol(Fig1,'Style','Popupmenu','Units','Normalized','Position',[.5 .5 .5 .5],'String',str,'Callback',...
                                ['l = get(gcf, ''CurrentObject''); s = get(l,''value''); cla; unitret(''stim_on_monitor'',s);']);
                        
                else
                        tnumHndl = uicontrol(Fig1,'Style','Popupmenu','Units','Normalized','Position',[.7 .95 .3 .5],'String',str,'Callback',...
                                ['l = get(gcf, ''CurrentObject''); s = get(l,''value''); cla; unitret(''stim_on_monitor'',s);']);
                        
                end
                
                
                uicontrol(Fig1,'Style','Pushbutton','Units','Normalized','String','OK','Position',[.3 .02 .4 .05],...
                        'Callback','delete(gcf);');
                
                HCELL = cell(16,1);
                unitret('stim_on_monitor',1);
                
        else,
                oldpos = ftell(fid);
                tnum = in1;
                
                
                if tnum > TrialsNum,
                        errordlg('Invalid trial number');
                end;
                Status = fseek(fid, TrialBegin(tnum),-1);
                if Status ~=0,
                        errordlg('File format error','Error');
                        return
                end;
                
                %--------- READING THE TRIAL HEADER ----------------------------------------
                blockSTART		        =    ftell(fid);
                fseek(fid,blockSTART+2, -1);
                TrialHeaderLength             =    fread(fid, 1,'ushort');
                fseek(fid,blockSTART, -1);
                
                
                SerNum                          =    fread(fid,1,'ushort');
                TrialHeaderLength               =    fread(fid,1,'ushort');
                ParamBlockNum                   =    fread(fid,1,'ushort');
                DataBlockNum                    =    fread(fid,1,'ushort');
                ParamBlockLength                =    (fread(fid,ParamBlockNum,'ushort'))';
                DataBlockLength                 =    (fread(fid,DataBlockNum,'ushort'))';
                
                if unitret('NoSeparator',fid)
                        strerr = ['FORMAT ERROR on Trial Header: ', filename, ' skipped'];
                        unitret('errormessage',strerr,'ERROR');
                        %fclose(fid);
                        return;
                end;
                
                % disp('COMMON TRIAL DATA ...OK');
                
                %--------- READING THE TRIAL PARAMETERS ----------------------------------------
                blockSTART     	   		=    ftell(fid);
                
                TrialTime               =    (setstr(fread(fid,10, 'char')))';
                TrialDuration           =    fread(fid,1,'ushort');
                OneStimDuration         =    fread(fid,1,'ushort');
                TimeBetweenStim         =    fread(fid,1,'ushort');
                Tilt                    =    fread(fid,1,'ushort');
                RadialBoxSize           =    fread(fid,1,'ushort');
                PerpenBoxSize           =    fread(fid,1,'ushort');
                XStartPos               =    fread(fid,1,'ushort');
                YStartPos               =    fread(fid,1,'ushort');
                ExtentStimMotion        =    fread(fid,1,'short');
                StimVelocity            =    fread(fid,1,'short');
                ColorCode               =    fread(fid,1,'ushort');
                FgrRedInt               =    fread(fid,1,'float');
                FgrGreenInt             =    fread(fid,1,'float');
                FgrBlueInt              =    fread(fid,1,'float');
                BckgrRedInt             =    fread(fid,1,'float');
                BckgrGreenInt           =    fread(fid,1,'float');
                BckgrBlueInt            =    fread(fid,1,'float');
                ElemRedInt              =    fread(fid,1,'float');
                ElemGreenInt            =    fread(fid,1,'float');
                ElemBlueInt             =    fread(fid,1,'float');
                %               * * Applicable to Sinusoid & Gabor:  * *
                SpatialFreq             =    fread(fid,1,'float');
                PhRed                   =    fread(fid,1,'ushort');
                PhGreen                 =    fread(fid,1,'ushort');
                PhBlue                  =    fread(fid,1,'ushort');
                StnDiv                  =    fread(fid,1,'float');
                Contrast                =    fread(fid,1,'float');
                TempFreq                =    fread(fid,1,'float'); 
                %            * * Applicable to REGULAR: * *
                ElemLength              =    fread(fid,1,'float');
                ElemWidth               =    fread(fid,1,'float');
                SpLengthDirec           =    fread(fid,1,'float');
                SpWidthDirect           =    fread(fid,1,'float');
                %            * * Additional timing values: * *
                StartEyeData            =    fread(fid,1,'float');
                StartSpikeData          =    fread(fid,1,'float');
                EndSpikeData            =    fread(fid,1,'float');
                TimeCode                =    fread(fid,1,'ushort');
                StimTempType            =    fread(fid,1,'ushort');
                StimSpatType            =    fread(fid,1,'ushort');
                EyeChoice               =    fread(fid,1,'ushort');
                %            * * Additional positioning info: * *
                SweepFract              =    fread(fid,1,'float');
                TrigTech  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'ushort');
                SpikeTrig  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                ShapeTrig  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                ShapeHist  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                ShapeLen  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'short');
                ShapeOff  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'short');
                
                FirstStimTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'short');
                AngleFix(tnum)			=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                FixChangeTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                SteadyFixTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                FixNoChangeTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                TotalFixDistance(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                FixFraction(tnum)		=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                
                
                
                
                
                if unitret('NoSeparator',fid)
                        strerr = ['FORMAT ERROR on Trial Param: ', filename, ' skipped'];
                        unitret('errormessage',strerr,'ERROR');
                        fclose(fid);
                        return;
                end;
                % disp('TRIAL PARAMETERS  ...OK');


                cla;
                tc = [0.5020   0    0.5020];

		% TEXTOUT

		vlim  = 0.85;
		vstep = (0.85 - 0.20)/16;
		k = 1;
		
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','One stim. duration:'); 
                h(1) = text('Position',[.2 vlim-vstep*(k-1)],'Color','k','string',num2str(OneStimDuration));
		
		k = k+1;
		set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Time between stim.:'); 
                h(2) = text('Position',[.2 vlim-vstep*(k-1)],'Color','k','string',num2str(TimeBetweenStim));

		k = k+1;
	        set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Tilt:'); 
                h(3) = text('Position',[.2 vlim-vstep*(k-1)],'Color','k','string',num2str(Tilt));

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Radial box size:'); 
                h(4) = text('Position',[.2 vlim-vstep*(k-1)],'Color','k','string',num2str(RadialBoxSize)); 

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Perp. box size'); 
                h(5) = text('Position',[.2 vlim-vstep*(k-1)],'Color','k','string',num2str(PerpenBoxSize)); 

		k = k+1;
		set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Start pos:'); 
                h(6) = text('Position',[.2 vlim-vstep*(k-1)],'Color','k','string',...
                        [num2str(XStartPos),',',num2str(YStartPos)]); 

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Extent stim motion:'); 
                h(7) = text('Position',[.2 vlim-vstep*(k-1)],'Color','k','string', num2str(ExtentStimMotion)); 

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Stim. velocity :'); 
                h(8) = text('Position',[.2 vlim-vstep*(k-1)],'Color','k','string',num2str(StimVelocity));

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Foreground intensity:'); 
                h(9) = text('Position',[.2 vlim-vstep*(k-1)],'Color','k','string',...
                        [num2str(FgrRedInt),',',num2str(FgrGreenInt), ',', num2str(FgrBlueInt)]); 

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Background  intensity:'); 
                h(10) = text('Position',[.2 vlim-vstep*(k-1)],'Color','k','string',...
                        [num2str(BckgrRedInt),',',num2str(BckgrGreenInt), ',', num2str(BckgrBlueInt)]);

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Spatial frequency :'); 
                h(11) = text('Position',[.2 vlim-vstep*(k-1)],'Color','k','string',[num2str(SpatialFreq), ' (',num2str(PerpenBoxSize/60*SpatialFreq,2),' cycles)']);

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Temporal frequency:'); 
                h(12) = text('Position',[.2 vlim-vstep*(k-1)],'Color','k','string',num2str(TempFreq));

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Phase:'); 
                h(13) = text('Position',[.2 vlim-vstep*(k-1)],'Color','k','string',...
                        [num2str(PhRed),',',num2str(PhGreen), ',', num2str(PhBlue)]);

		k = k+1;
		set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Contrast:'); 
                h(14) = text('Position',[.2 vlim-vstep*(k-1)],'Color','k','string', num2str(Contrast));

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Stim temporal type:');
                str = unitret('translate','StimTempType',StimTempType);
                h(15) = text('Position',[.2 vlim-vstep*(k-1)],'Color','k','string',str); 

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Stim spatial type:'); 
                str = unitret('translate','StimSpatType',StimSpatType);
                h(16) =text('Position',[.2 vlim-vstep*(k-1)],'Color','k','string',str);
		
                Stimulus = str;            
 

		hc = get(h,'String');
		ind = cellcmp(hc,HCELL);
		HCELL = hc;

		indd = find(ind==0);
		set(h(indd),'Color','b');
		
                
                %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                % PLOT STIMULUS ON MONITOR %
                %%%%%%%%%%%%%%%%%%%%%%%%%%%%
                ud = get(0,'Userdata');
                Axes = sort(get(gcf, 'Children'));
                
                
                if length(Axes) > 3, % 3 is number of childrens without plot ...
                        delete(Axes(length(Axes)))
                end
                plotHndl = axes('position', [.4 .25 .55 .65], 'box', 'on', 'YColor', 'k', 'XColor', 'k', 'Visible', 'on');   
                axis('equal')
                
                MonW = 800;
                MonH = 600;
                
                % Plot Monitor
                plot([0 MonW MonW 0 0],[0 0 MonH MonH 0],'b'), hold on
                % axis([0 MonW 0 MonH])
                
                % Plot Visual Field Location
                plot(HorizVisualFieldLoc - HorizPosLED, VertVisualFieldLoc - VertPosLED,'m*'), hold on
                
                % Plot Stimulus
                
                Tilt = 2*pi*Tilt/360; % deg.->rad	
                
                % Calculate bar axis coordinates
                xa1 = XStartPos+RadialBoxSize/2*cos(Tilt); 
                ya1 = YStartPos+RadialBoxSize/2*sin(Tilt);
                
                xa2 = XStartPos-RadialBoxSize/2*cos(Tilt);
                ya2 = YStartPos-RadialBoxSize/2*sin(Tilt);
                
                %line([xa1 xa2], [ya1 ya2], 'LineStyle','-','LineWidth',0.5,'Color',[0 0.2510 0.5020]), hold on
                
                % Take into account width of the bar
                veradd = PerpenBoxSize/2*cos(Tilt); 
                horadd = PerpenBoxSize/2*sin(Tilt); 
                
                x1 = xa2 - horadd;
                x4 = xa2 + horadd;
                x2 = xa1 - horadd;
                x3 = xa1 + horadd;
                
                y1 = ya2 + veradd;
                y4 = ya2 - veradd;
                y2 = ya1 + veradd;
                y3 = ya1 - veradd;
                
                line([x1 x2 x3 x4 x1 ],[y1 y2 y3 y4 y1],'LineWidth',1,'Color',[0 0.2510 0.5020]), hold on
                
                %axis([0 200 0 200])
                
                % Plot Sweep
                alpha  = (pi - Tilt);
                
                xes = XStartPos - ExtentStimMotion*sin(alpha); %(x end sweep)
                yes = YStartPos - ExtentStimMotion*cos(alpha); %(y end sweep)
                
                line([XStartPos xes],[YStartPos yes],'Color',[ 0    0.5020    0.7529]), hold on
                h = plot(xes + (XStartPos - xes)/2, yes + (YStartPos - yes)/2,'rx');, hold on
                
                % in2 = [DefValues(110) DefValues(71) DefValues(70) DefValues(77) DefValues(76)]; % ExtentMotion, RFInc border, RFInc size, ...
                % in3 = DefValues(111:115); % SPBS, SRBS, X, Y, Tilt
                
                set(gca, 'box', 'on', 'YColor', 'k', 'XColor', 'k', 'Visible', 'on'); 
                xlabel('minarc')
                ylabel('minarc')
                
                
                %%%% END OF PLOT SCHEME %%%%
                
                textoutHndl=get(gcf,'Userdata');
                set(gcf,'CurrentAxes',textoutHndl); 
                
                
                
        end % if #trial
        
        
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
        
        
        
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'rf_stim_scheme'))
        % RF and Stimulus Parameters

	global HCELL
	
        
        % like Trial Info:
        trials_inf = get(TRET_DAT(1),'UserData');
        fid = trials_inf(1);
        TrialsNum = trials_inf(2);
        TrialBegin = trials_inf(3:TrialsNum+2);
        
        if in1==0,
                str = ['1'];
                if TrialsNum >1,    
                        for(i=2:TrialsNum),
                                str = [str, '|', num2str(i)];      
                        end;
                end;
                
                Fig1 = figure('Backingstore','off','Name','RF and Stimulus Setup','Color','w',...
                        'Units','Normal','Position',[.22 .2 .78 .7],'Resize','On', 'Menubar','none','Number','off',...
                        'DefaultAxesPosition',[0 0 1 01],'visible','on');
                figcounter = figcounter + 1; 
                set(gcf,'WindowButtonDownFcn','ud = get(0,''Userdata'');ud(72) = gcf;set(0,''Userdata'',ud);');
                cla
                set(gca,'Visible','off')

                set(gcf,'Pointer','Watch', 'Userdata',gca);	% set gcf Userdata here
                
                set(text,'Position',[.3 .98],'Color','b','string','TRIAL #:'); 
                
                if strcmp(v(1),'5'),
                        tnumHndl = uicontrol(Fig1,'Style','Popupmenu','Units','Normalized','Position',[.5 .5 .5 .5],'String',str,'Callback',...
                                ['l = get(gcf, ''CurrentObject''); s = get(l,''value''); cla; unitret(''rf_stim_scheme'',s);']);
                        
                else
                        tnumHndl = uicontrol(Fig1,'Style','Popupmenu','Units','Normalized','Position',[.7 .95 .3 .5],'String',str,'Callback',...
                                ['l = get(gcf, ''CurrentObject''); s = get(l,''value''); cla; unitret(''rf_stim_scheme'',s);']);
                        
                end
                
                uicontrol(Fig1,'Style','text','Position',[.02 .95 .3 .05],...
                        'Units','normal','ForegroundColor',[.1 .3 .3],...
                        'BackgroundColor','w','String','RF INC border/size:',...
                        'HorizontalAlignment','center');
                
                
                u1 =  uicontrol(Fig1,'Style','edit','Position',[.27 .95 .10 .05],...
                        'Units','normalized','BackgroundColor','w',...
                        'ForegroundColor','k','String',num2str(DefValues(71)),...
                        'Callback',['ud=get(0,''Userdata''); ud(71)=str2num(get(gco,''string'')); set(0,''UserData'',ud);tnumHndl = get(gco,''Userdata''); tnum = get(tnumHndl,''Value''); unitret(''rf_stim_scheme'',tnum);']);
                
                u2 = uicontrol(Fig1,'Style','edit','Position',[.37 .95 .10 .05],...
                        'Units','normalized','BackgroundColor','w',...
                        'ForegroundColor','k','String',num2str(DefValues(70)),...
                        'Callback',['ud=get(0,''Userdata''); ud(70)=str2num(get(gco,''string'')); set(0,''UserData'',ud);tnumHndl = get(gco,''Userdata''); tnum = get(tnumHndl,''Value''); unitret(''rf_stim_scheme'',tnum);']);
                
                
                uicontrol(Fig1,'Style','text','Position',[.02 .90 .3 .05],...
                        'Units','normal','ForegroundColor',[.1 .3 .3],...
                        'BackgroundColor','w','String','RF DEC border/size:',...
                        'HorizontalAlignment','center');
                
                
                u3 = uicontrol(Fig1,'Style','edit','Position',[.27 .90 .10 .05],...
                        'Units','normalized','BackgroundColor','w',...
                        'ForegroundColor','k','String',num2str(DefValues(77)),...
                        'Callback',['ud=get(0,''Userdata''); ud(77)=str2num(get(gco,''string'')); set(0,''UserData'',ud);tnumHndl = get(gco,''Userdata''); tnum = get(tnumHndl,''Value''); unitret(''rf_stim_scheme'',tnum);']);
                
                u4 = uicontrol(Fig1,'Style','edit','Position',[.37 .90 .10 .05],...
                        'Units','normalized','BackgroundColor','w',...
                        'ForegroundColor','k','String',num2str(DefValues(76)),...
                        'Callback',['ud=get(0,''Userdata''); ud(76)=str2num(get(gco,''string'')); set(0,''UserData'',ud);tnumHndl = get(gco,''Userdata''); tnum = get(tnumHndl,''Value''); unitret(''rf_stim_scheme'',tnum);']);
                
                set(gca,'Userdata',[u1 u2 u3 u4]);
                set([u1 u2 u3 u4],'Userdata',tnumHndl);
                
                uicontrol(Fig1,'Style','Pushbutton','Units','Normalized','String','OK','Position',[.3 .02 .4 .05],...
                        'Callback','delete(gcf);');
                
                
                EstRFHndl = uicontrol(Fig1,'Style','checkbox','Position',[.05 .05 .22 .05],...
                        'Units','normalized','BackgroundColor','w',...
                        'ForegroundColor',[0    0.2824    0.4157],'String','estimate RF', 'HorizontalAlignment','left',...
                        'value',DefValues(104),'callback',...
                        [' u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                                'ud=get(0,''UserData''); ud(104) = val; set(0,''userdata'',ud); tnumHndl = get(gco,''Userdata''); tnum = get(tnumHndl,''Value''); unitret(''rf_stim_scheme'',tnum);']);
                
                set(EstRFHndl,'Userdata',tnumHndl);
                
		HCELL = cell(16,1);                
                unitret('rf_stim_scheme',1);
                
        else,
                oldpos = ftell(fid);
                tnum = in1;
                
                
                if tnum > TrialsNum,
                        errordlg('Invalid trial number');
                end;
                Status = fseek(fid, TrialBegin(tnum),-1);
                if Status ~=0,
                        errordlg('File format error','Error');
                        return
                end;
                
                %--------- READING THE TRIAL HEADER ----------------------------------------
                blockSTART		        =    ftell(fid);
                fseek(fid,blockSTART+2, -1);
                TrialHeaderLength             =    fread(fid, 1,'ushort');
                fseek(fid,blockSTART, -1);
                
                
                SerNum                          =    fread(fid,1,'ushort');
                TrialHeaderLength               =    fread(fid,1,'ushort');
                ParamBlockNum                   =    fread(fid,1,'ushort');
                DataBlockNum                    =    fread(fid,1,'ushort');
                ParamBlockLength                =    (fread(fid,ParamBlockNum,'ushort'))';
                DataBlockLength                 =    (fread(fid,DataBlockNum,'ushort'))';
                
                if unitret('NoSeparator',fid)
                        strerr = ['FORMAT ERROR on Trial Header: ', filename, ' skipped'];
                        unitret('errormessage',strerr,'ERROR');
                        %fclose(fid);
                        return;
                end;
                
                % disp('COMMON TRIAL DATA ...OK');
                
                %--------- READING THE TRIAL PARAMETERS ----------------------------------------
                blockSTART     	   		=    ftell(fid);
                
                TrialTime               =    (setstr(fread(fid,10, 'char')))';
                TrialDuration           =    fread(fid,1,'ushort');
                OneStimDuration         =    fread(fid,1,'ushort');
                TimeBetweenStim         =    fread(fid,1,'ushort');
                Tilt                    =    fread(fid,1,'ushort');
                RadialBoxSize           =    fread(fid,1,'ushort');
                PerpenBoxSize           =    fread(fid,1,'ushort');
                XStartPos               =    fread(fid,1,'ushort');
                YStartPos               =    fread(fid,1,'ushort');
                ExtentStimMotion        =    fread(fid,1,'short');
                StimVelocity            =    fread(fid,1,'short');
                ColorCode               =    fread(fid,1,'ushort');
                FgrRedInt               =    fread(fid,1,'float');
                FgrGreenInt             =    fread(fid,1,'float');
                FgrBlueInt              =    fread(fid,1,'float');
                BckgrRedInt             =    fread(fid,1,'float');
                BckgrGreenInt           =    fread(fid,1,'float');
                BckgrBlueInt            =    fread(fid,1,'float');
                ElemRedInt              =    fread(fid,1,'float');
                ElemGreenInt            =    fread(fid,1,'float');
                ElemBlueInt             =    fread(fid,1,'float');
                %               * * Applicable to Sinusoid & Gabor:  * *
                SpatialFreq             =    fread(fid,1,'float');
                PhRed                   =    fread(fid,1,'ushort');
                PhGreen                 =    fread(fid,1,'ushort');
                PhBlue                  =    fread(fid,1,'ushort');
                StnDiv                  =    fread(fid,1,'float');
                Contrast                =    fread(fid,1,'float');
                TempFreq                =    fread(fid,1,'float'); 
                %            * * Applicable to REGULAR: * *
                ElemLength              =    fread(fid,1,'float');
                ElemWidth               =    fread(fid,1,'float');
                SpLengthDirec           =    fread(fid,1,'float');
                SpWidthDirect           =    fread(fid,1,'float');
                %            * * Additional timing values: * *
                StartEyeData            =    fread(fid,1,'float');
                StartSpikeData          =    fread(fid,1,'float');
                EndSpikeData            =    fread(fid,1,'float');
                TimeCode                =    fread(fid,1,'ushort');
                StimTempType            =    fread(fid,1,'ushort');
                StimSpatType            =    fread(fid,1,'ushort');
                EyeChoice               =    fread(fid,1,'ushort');
                %            * * Additional positioning info: * *
                SweepFract              =    fread(fid,1,'float');
                TrigTech  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'ushort');
                SpikeTrig  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                ShapeTrig  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                ShapeHist  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                ShapeLen  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'short');
                ShapeOff  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'short');
                
                FirstStimTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'short');
                AngleFix(tnum)			=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                FixChangeTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                SteadyFixTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                FixNoChangeTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                TotalFixDistance(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                FixFraction(tnum)		=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                
                
                
                
                
                if unitret('NoSeparator',fid)
                        strerr = ['FORMAT ERROR on Trial Param: ', filename, ' skipped'];
                        unitret('errormessage',strerr,'ERROR');
                        fclose(fid);
                        return;
                end;
                % disp('TRIAL PARAMETERS  ...OK');
                cla;


                tc = [0.5020   0    0.5020];

		
		% TEXTOUT

		vlim  = 0.85;
		vstep = (0.85 - 0.20)/16;
		k = 1;
		
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','One stim. duration:'); 
                h(1) = text('Position',[.25 vlim-vstep*(k-1)],'Color','k','string',num2str(OneStimDuration));
		
		k = k+1;
		set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Time between stim.:'); 
                h(2) = text('Position',[.25 vlim-vstep*(k-1)],'Color','k','string',num2str(TimeBetweenStim));

		k = k+1;
	        set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Tilt:'); 
                h(3) = text('Position',[.25 vlim-vstep*(k-1)],'Color','k','string',num2str(Tilt));

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Radial box size:'); 
                h(4) = text('Position',[.25 vlim-vstep*(k-1)],'Color','k','string',num2str(RadialBoxSize)); 

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Perp. box size'); 
                h(5) = text('Position',[.25 vlim-vstep*(k-1)],'Color','k','string',num2str(PerpenBoxSize)); 

		k = k+1;
		set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Start pos:'); 
                h(6) = text('Position',[.25 vlim-vstep*(k-1)],'Color','k','string',...
                        [num2str(XStartPos),',',num2str(YStartPos)]); 

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Extent stim motion:'); 
                h(7) = text('Position',[.25 vlim-vstep*(k-1)],'Color','k','string', num2str(ExtentStimMotion)); 

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Stim. velocity :'); 
                h(8) = text('Position',[.25 vlim-vstep*(k-1)],'Color','k','string',num2str(StimVelocity));

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Foreground intensity:'); 
                h(9) = text('Position',[.25 vlim-vstep*(k-1)],'Color','k','string',...
                        [num2str(FgrRedInt),',',num2str(FgrGreenInt), ',', num2str(FgrBlueInt)]); 

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Background  intensity:'); 
                h(10) = text('Position',[.25 vlim-vstep*(k-1)],'Color','k','string',...
                        [num2str(BckgrRedInt),',',num2str(BckgrGreenInt), ',', num2str(BckgrBlueInt)]);

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Spatial frequency :'); 
                h(11) = text('Position',[.25 vlim-vstep*(k-1)],'Color','k','string',[num2str(SpatialFreq), ' (',num2str(PerpenBoxSize/60*SpatialFreq,2),' cycles)']);

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Temporal frequency:'); 
                h(12) = text('Position',[.25 vlim-vstep*(k-1)],'Color','k','string',num2str(TempFreq));

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Phase:'); 
                h(13) = text('Position',[.25 vlim-vstep*(k-1)],'Color','k','string',...
                        [num2str(PhRed),',',num2str(PhGreen), ',', num2str(PhBlue)]);

		k = k+1;
		set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Contrast:'); 
                h(14) = text('Position',[.25 vlim-vstep*(k-1)],'Color','k','string', num2str(Contrast));

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Stim temporal type:');
                str = unitret('translate','StimTempType',StimTempType);
                h(15) = text('Position',[.25 vlim-vstep*(k-1)],'Color','k','string',str); 

		k = k+1;
                set(text,'Position',[.02 vlim-vstep*(k-1)],'Color',tc,'string','Stim spatial type:'); 
                str = unitret('translate','StimSpatType',StimSpatType);
                h(16) =text('Position',[.25 vlim-vstep*(k-1)],'Color','k','string',str);
		
                Stimulus = str;
                
 
                
 

		hc = get(h,'String');
		ind = cellcmp(hc,HCELL);
		HCELL = hc;

		indd = find(ind==0);
		set(h(indd),'Color','b');
                
                %%%%%%%%%%%%%%%%%%%%%%%
                % PLOT SCHEME
                %%%%%%%%%%%%%%%%%%%%%%%
                ud = get(0,'Userdata');
                Axes = sort(get(gcf, 'Children'));
                
                
                if length(Axes) > 10, % 10 is number of childrens without plot ...
                        delete(Axes(length(Axes)))
                end
                plotHndl = axes('position', [.55 .4 .43 .44], 'box', 'on', 'YColor', 'k', 'XColor', 'k', 'Visible', 'on');   
                
                RFi = ud(70);
                RFd = ud(76);
                
                
                % Stimulus
                
                bg = [BckgrRedInt  BckgrGreenInt  BckgrBlueInt];        
                fg = [FgrRedInt FgrGreenInt FgrBlueInt];
                
                
                maxInt = max([fg*(PerpenBoxSize>0) bg]);
                if maxInt > 1, bg = bg/maxInt; fg = fg/maxInt; end;
                
                %    if max(fg) > 1, fg = fg/max(fg); end;
                %    if max(bg) > 1, bg = bg/max(bg); end;
                
                verlim = RadialBoxSize;
                horlim = PerpenBoxSize + 10;
                
                fill([0 0 horlim horlim],[0 verlim verlim 0],bg), hold on
                x1 = horlim/2-PerpenBoxSize/2; x2 = horlim/2+PerpenBoxSize/2;
                y1 = verlim/2-RadialBoxSize/2; y2 = verlim/2+RadialBoxSize/2;
                if PerpenBoxSize>0
                        fill([x1 x1 x2 x2],[y1 y2 y2 y1],fg); hold on
                end
                
                
                
                
                % RF picture
                
                leftlim_i = ud(71);
                leftlim_d = ud(77);
                %patch([leftlim leftlim leftlim+RF leftlim+RF], [0 1 1 0], [0.7255 0.7843 0.7765]), hold on
                line([leftlim_i leftlim_i], [0 verlim], 'Color','w','Linewidth', 3),hold on, 
                line([leftlim_i+RFi leftlim_i+RFi], [0 verlim], 'Color','w','Linewidth', 3),hold on,
                line([leftlim_d leftlim_d], [0 verlim], 'Color','k','Linewidth', 3),hold on, 
                line([leftlim_d+RFd leftlim_d+RFd], [0 verlim], 'Color','k','Linewidth', 3),hold on,
                
                % if (strcmp('Sinus',Stimulus) | strcmp('Wsine',Stimulus) | strcmp('Csine',Stimulus)),
		if ~isempty(findstr(lower(Stimulus),'sin'))
                        % plot sine (assumes that all RGB phases are the same!)
                        % Note that what is actually displayed is COS, with 0 at center of box!, so that phase zero 
                        % means peak of luminance at the center of box...
                        t = -(x2-x1)/2:0.1:(x2-x1)/2;
                        s = Contrast*verlim/2*cos(2*pi*SpatialFreq*t/60 + PhRed/360*2*pi)+verlim/2;
                        plot(t+(x2+x1)/2, s,'w'), hold on
                        plot(t+(x2+x1)/2, ones(1,length(t))*verlim/2,'k','Linewidth',1)
                        
                end
                
                
                
                set(gca, 'box', 'on', 'YColor', 'k', 'XColor', 'k', 'Visible', 'on'); 
                xlabel('min of arc')
                ylabel('min of arc')
                
                
                %%%% END OF PLOT SCHEME %%%%
                
                textoutHndl=get(gcf,'Userdata');
                set(gcf,'CurrentAxes',textoutHndl); 
                
                
                
                % Save Stimulus Parameters   
                ud = get(0,'Userdata');
                
                if (StimSpatType == 0 & ExtentStimMotion >0), 	% Bar
                        ud(105:110) = [PerpenBoxSize RadialBoxSize XStartPos YStartPos Tilt ExtentStimMotion];   
                else 						% Sine
                        ud(111:115) = [PerpenBoxSize RadialBoxSize XStartPos YStartPos Tilt];
                end   
                
                
                if DefValues(104),
                        % RF PARAMETERS CALCULATION (based on DefValues(64:67) -> x1, x2, x3, x4
                        x1 = DefValues(64); 
                        x2 = DefValues(65);
                        x3 = DefValues(66);
                        x4 = DefValues(67);
                        Delay = DefValues(74);
                        
                        if (x1 < x2), % <--Sweep
                                
                                INCb = StimVelocity*( (x1 - Delay)/1000 );
                                INCs = StimVelocity*( (x2 - x1)/1000 );
                                
                                DECb = StimVelocity*( (x3 - Delay)/1000 );
                                DECs = StimVelocity*( (x4 - x3)/1000 );
                                
                        else          % -->Sweep
                                
                                INCb = StimVelocity*( (OneStimDuration - (x1 - Delay))/1000 );
                                INCs = StimVelocity*( (x1 - x2)/1000 );
                                
                                DECb = StimVelocity*( (OneStimDuration - (x3 - Delay))/1000 );
                                DECs = StimVelocity*( (x4 - x3)/1000 );
                        end
                        
                        % Correct for PerpenBoxSize 
                        if (INCs > PerpenBoxSize),
                                INCb = INCb + PerpenBoxSize/4;
                                INCs = INCs - PerpenBoxSize/2;
                        end
                        if (DECs > PerpenBoxSize),
                                DECb = DECb + PerpenBoxSize/4;
                                DECs = DECs - PerpenBoxSize/2;
                        end
                        
                        u = get(textoutHndl,'Userdata');
                        set(u(1),'String',num2str(INCb));
                        set(u(2),'String',num2str(INCs));
                        set(u(3),'String',num2str(DECb));
                        set(u(4),'String',num2str(DECs));
                        
                        ud(70) = INCs; 
                        ud(71) = INCb;
                        ud(76) = DECs;
                        ud(77) = DECb;
                        
                end
                set(0,'Userdata',ud);
        end % if #trial
        
        
        
        
        
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
        %--------------------------------------------------------------------------------------------------------------
	
elseif(strcmp(action,'stim_summary'))
        % stimulus summary of the file, trial by trial
	global HCELL

	% like Trial Info:
	trials_inf = get(TRET_DAT(1),'UserData');
	fid = trials_inf(1);
	TrialsNum = trials_inf(2);
	TrialBegin = trials_inf(3:TrialsNum+2);

	if in1==0,

		HCELL = cell(1,16);
		in1 = 1;
		Fig1 = figure('Backingstore','off','Name',['Stimulus summary for ' deblank(INI_NAME)],'Color','w',...
			'Units','Normal','Position',[.01 .2 .99 .7],'Resize','On','Number','off',...
			'DefaultAxesPosition',[0 0 1 01],'visible','on');
		figcounter = figcounter + 1; 
		set(gcf,'WindowButtonDownFcn','ud = get(0,''Userdata'');ud(72) = gcf;set(0,''Userdata'',ud);');
		cla
		set(gca,'Visible','off');

		uicontrol(Fig1,'Style','Pushbutton','Units','Normalized','String','OK','Position',[.2 .02 .3 .05],...
			'Callback','delete(gcf);');

		if TrialsNum >10,
			hn = uicontrol(Fig1,'Style','Pushbutton','Units','Normalized','String','Next','Position',[.85 .02 .1 .05],...
			'Callback','unitret(''stim_summary'',get(gco,''UserData'')+10);');
		end

		set([hn],'UserData',in1);

	else
		Fig1 = gcf;
		clf
		set(gca,'Visible','off');
		
		uicontrol(Fig1,'Style','Pushbutton','Units','Normalized','String','OK','Position',[.2 .02 .3 .05],...
			'Callback','delete(gcf);');

		if (in1+10 <= TrialsNum),
			hn = uicontrol(Fig1,'Style','Pushbutton','Units','Normalized','String','Next','Position',[.85 .02 .1 .05],...
			'Callback','unitret(''stim_summary'',get(gco,''UserData'')+10);');
			set([hn],'UserData',in1);
		end

		
		if (in1>1)
			hp = uicontrol(Fig1,'Style','Pushbutton','Units','Normalized','String','Prev','Position',[.75 .02 .1 .05],...
			'Callback','unitret(''stim_summary'',get(gco,''UserData'')-10);');
			set([hp],'UserData',in1);
		end
	end

	for tnum = in1:min(TrialsNum,in1+9),
  
                Status = fseek(fid, TrialBegin(tnum),-1);
                if Status ~=0,
                        errordlg('File format error','Error');
                        return
                end;
                
                %--------- READING THE TRIAL HEADER ----------------------------------------
                blockSTART		        =    ftell(fid);
                fseek(fid,blockSTART+2, -1);
                TrialHeaderLength             =    fread(fid, 1,'ushort');
                fseek(fid,blockSTART, -1);
                
                
                SerNum                          =    fread(fid,1,'ushort');
                TrialHeaderLength               =    fread(fid,1,'ushort');
                ParamBlockNum                   =    fread(fid,1,'ushort');
                DataBlockNum                    =    fread(fid,1,'ushort');
                ParamBlockLength                =    (fread(fid,ParamBlockNum,'ushort'))';
                DataBlockLength                 =    (fread(fid,DataBlockNum,'ushort'))';
                
                if unitret('NoSeparator',fid)
                        strerr = ['FORMAT ERROR on Trial Header: ', filename, ' skipped'];
                        unitret('errormessage',strerr,'ERROR');
                        %fclose(fid);
                        return;
                end;
                
                % disp('COMMON TRIAL DATA ...OK');
                
                %--------- READING THE TRIAL PARAMETERS ----------------------------------------
                blockSTART     	   		=    ftell(fid);
                
                TrialTime               =    (setstr(fread(fid,10, 'char')))';
                TrialDuration           =    fread(fid,1,'ushort');
                OneStimDuration         =    fread(fid,1,'ushort');
                TimeBetweenStim         =    fread(fid,1,'ushort');
                Tilt                    =    fread(fid,1,'ushort');
                RadialBoxSize           =    fread(fid,1,'ushort');
                PerpenBoxSize           =    fread(fid,1,'ushort');
                XStartPos               =    fread(fid,1,'ushort');
                YStartPos               =    fread(fid,1,'ushort');
                ExtentStimMotion        =    fread(fid,1,'short');
                StimVelocity            =    fread(fid,1,'short');
                ColorCode               =    fread(fid,1,'ushort');
                FgrRedInt               =    fread(fid,1,'float');
                FgrGreenInt             =    fread(fid,1,'float');
                FgrBlueInt              =    fread(fid,1,'float');
                BckgrRedInt             =    fread(fid,1,'float');
                BckgrGreenInt           =    fread(fid,1,'float');
                BckgrBlueInt            =    fread(fid,1,'float');
                ElemRedInt              =    fread(fid,1,'float');
                ElemGreenInt            =    fread(fid,1,'float');
                ElemBlueInt             =    fread(fid,1,'float');
                %               * * Applicable to Sinusoid & Gabor:  * *
                SpatialFreq             =    fread(fid,1,'float');
                PhRed                   =    fread(fid,1,'ushort');
                PhGreen                 =    fread(fid,1,'ushort');
                PhBlue                  =    fread(fid,1,'ushort');
                StnDiv                  =    fread(fid,1,'float');
                Contrast                =    fread(fid,1,'float');
                TempFreq                =    fread(fid,1,'float'); 
                %            * * Applicable to REGULAR: * *
                ElemLength              =    fread(fid,1,'float');
                ElemWidth               =    fread(fid,1,'float');
                SpLengthDirec           =    fread(fid,1,'float');
                SpWidthDirect           =    fread(fid,1,'float');
                %            * * Additional timing values: * *
                StartEyeData            =    fread(fid,1,'float');
                StartSpikeData          =    fread(fid,1,'float');
                EndSpikeData            =    fread(fid,1,'float');
                TimeCode                =    fread(fid,1,'ushort');
                StimTempType            =    fread(fid,1,'ushort');
                StimSpatType            =    fread(fid,1,'ushort');
                EyeChoice               =    fread(fid,1,'ushort');
                %            * * Additional positioning info: * *
                SweepFract              =    fread(fid,1,'float');
                TrigTech  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'ushort');
                SpikeTrig  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                ShapeTrig  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                ShapeHist  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                ShapeLen  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'short');
                ShapeOff  		        =    unifread([fid, 1,blockSTART,ParamBlockLength],'short');
                
                FirstStimTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'short');
                AngleFix(tnum)			=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                FixChangeTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                SteadyFixTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                FixNoChangeTime(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                TotalFixDistance(tnum)	 	=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                FixFraction(tnum)		=    unifread([fid, 1,blockSTART,ParamBlockLength],'float');
                
                
                
                
                
                if unitret('NoSeparator',fid)
                        strerr = ['FORMAT ERROR on Trial Param: ', filename, ' skipped'];
                        unitret('errormessage',strerr,'ERROR');
                        fclose(fid);
                        return;
                end;
                % disp('TRIAL PARAMETERS  ...OK');


                tc = [0.5020   0    0.5020];

		
		% TEXTOUT

		vlim  = 0.85;
		vstep = (0.85 - .220)/14;
		hstep = (1 - 0.2)/10;
		k = 1;
		hk = tnum-in1+1;

		set(text,'Position',[.2 0.95],'Color','k','string',deblank(INI_NAME),'Interpreter','none'); 

		set(text,'Position',[.2+hstep*(hk-1) 0.9],'Color',tc,'string',num2str(tnum)); 
		
                set(text,'Position',[.01 vlim-vstep*(k-1)],'Color',tc,'string','One stim. duration:'); 
                h(1) = text('Position',[.2+hstep*(hk-1) vlim-vstep*(k-1)],'Color','k','string',num2str(OneStimDuration));
		
		k = k+1;
		set(text,'Position',[.01 vlim-vstep*(k-1)],'Color',tc,'string','Time between stim.:'); 
                h(2) = text('Position',[.2+hstep*(hk-1) vlim-vstep*(k-1)],'Color','k','string',num2str(TimeBetweenStim));

		k = k+1;
	        set(text,'Position',[.01 vlim-vstep*(k-1)],'Color',tc,'string','Tilt:'); 
                h(3) = text('Position',[.2+hstep*(hk-1) vlim-vstep*(k-1)],'Color','k','string',num2str(Tilt));

		k = k+1;
                set(text,'Position',[.01 vlim-vstep*(k-1)],'Color',tc,'string','Radial box size:'); 
                h(4) = text('Position',[.2+hstep*(hk-1) vlim-vstep*(k-1)],'Color','k','string',num2str(RadialBoxSize)); 

		k = k+1;
                set(text,'Position',[.01 vlim-vstep*(k-1)],'Color',tc,'string','Perp. box size'); 
                h(5) = text('Position',[.2+hstep*(hk-1) vlim-vstep*(k-1)],'Color','k','string',num2str(PerpenBoxSize)); 

		k = k+1;
		set(text,'Position',[.01 vlim-vstep*(k-1)],'Color',tc,'string','Start pos:'); 
                h(6) = text('Position',[.2+hstep*(hk-1) vlim-vstep*(k-1)],'Color','k','string',...
                        [num2str(XStartPos),',',num2str(YStartPos)]); 

		k = k+1;
                set(text,'Position',[.01 vlim-vstep*(k-1)],'Color',tc,'string','Extent stim motion:'); 
                h(7) = text('Position',[.2+hstep*(hk-1) vlim-vstep*(k-1)],'Color','k','string', num2str(ExtentStimMotion)); 

		k = k+1;
                set(text,'Position',[.01 vlim-vstep*(k-1)],'Color',tc,'string','Stim. velocity :'); 
                h(8) = text('Position',[.2+hstep*(hk-1) vlim-vstep*(k-1)],'Color','k','string',num2str(StimVelocity));

		k = k+1;
                set(text,'Position',[.01 vlim-vstep*(k-1)],'Color',tc,'string','Foreground intensity:'); 
                h(9) = text('Position',[.2+hstep*(hk-1) vlim-vstep*(k-1)],'Color','k','string',...
                        [num2str(FgrRedInt),',',num2str(FgrGreenInt), ',', num2str(FgrBlueInt)]); 

		k = k+1;
                set(text,'Position',[.01 vlim-vstep*(k-1)],'Color',tc,'string','Background  intensity:'); 
                h(10) = text('Position',[.2+hstep*(hk-1) vlim-vstep*(k-1)],'Color','k','string',...
                        [num2str(BckgrRedInt),',',num2str(BckgrGreenInt), ',', num2str(BckgrBlueInt)]);

		k = k+1;
                set(text,'Position',[.01 vlim-vstep*(k-1)],'Color',tc,'string','Spatial frequency :'); 
                h(11) = text('Position',[.2+hstep*(hk-1) vlim-vstep*(k-1)],'Color','k','string',[num2str(SpatialFreq)]);

		k = k+1;
                set(text,'Position',[.01 vlim-vstep*(k-1)],'Color',tc,'string','Temporal frequency:'); 
                h(12) = text('Position',[.2+hstep*(hk-1) vlim-vstep*(k-1)],'Color','k','string',num2str(TempFreq));

		k = k+1;
                set(text,'Position',[.01 vlim-vstep*(k-1)],'Color',tc,'string','Phase:'); 
                h(13) = text('Position',[.2+hstep*(hk-1) vlim-vstep*(k-1)],'Color','k','string',...
                        [num2str(PhRed),',',num2str(PhGreen), ',', num2str(PhBlue)]);

		k = k+1;
		set(text,'Position',[.01 vlim-vstep*(k-1)],'Color',tc,'string','Contrast:'); 
                h(14) = text('Position',[.2+hstep*(hk-1) vlim-vstep*(k-1)],'Color','k','string', num2str(Contrast));

		if hk == 1
		k = k+1;
			set(text,'Position',[.01 vlim-vstep*(k-1)],'Color',tc,'string','Stim temporal type:');
			str = unitret('translate','StimTempType',StimTempType);
			h(15) = text('Position',[.2+hstep*(hk-1) vlim-vstep*(k-1)],'Color','k','string',str); 

			k = k+1;
			set(text,'Position',[.01 vlim-vstep*(k-1)],'Color',tc,'string','Stim spatial type:'); 
			str = unitret('translate','StimSpatType',StimSpatType);
			h(16) =text('Position',[.2+hstep*(hk-1) vlim-vstep*(k-1)],'Color','k','string',str);            
		end

		hc = get(h,'String');
		ind = cellcmp(hc,HCELL);
		HCELL = hc;

		indd = find(ind==0);
		set(h(indd),'Color','b');
		
	end
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
        %--------------------------------------------------------------------------------------------------------------
	
elseif(strcmp(action,'rf_stim_display'))
        
        Fig1 = figure('Backingstore','off','Name','RF and stimuli Display Setup','Color','w',...
                'Units','Normal','Position',[.05 .2 .4 .7],'Resize','On', 'Menubar','none','Number','off',...
                'DefaultAxesPosition',[0 0 1 1],'visible','on');
        figcounter = figcounter + 1; 
        set(gcf,'WindowButtonDownFcn','ud = get(0,''Userdata'');ud(72) = gcf;set(0,''Userdata'',ud);');
        
        ud = zeros(1,17);
        ud(1:6) = DefValues(105:110);
        ud(7:10)=[DefValues(71) DefValues(70) DefValues(77) DefValues(76)]; 
        ud(11:15) = DefValues(111:115);
        
        
        set(gcf,'Pointer','Arrow', 'Userdata',ud);
        
        
        
        %................................. 1 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .9 .3 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','Bar PBS',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.36 .9 .3 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(ud(1)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(1)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',105,0,1);']);
        
        %.............................. end of 1 ....................................
        
        
        %................................. 2 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .85 .3 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','Bar RBS',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.36 .85 .3 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(ud(2)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(2)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',106,0,1);']);
        
        %.............................. end of 2 ....................................
        
        %................................. 3 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .80 .3 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','Bar XStart Position',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.36 .80 .3 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(ud(3)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(3)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',107,0,1);']);
        
        %.............................. end of 3 ....................................
        
        %................................. 4 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .75 .3 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','Bar YStart Position',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.36 .75 .3 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(ud(4)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(4)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',108,0,1);']);
        
        %.............................. end of 4 ....................................
        
        %................................. 5 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .70 .3 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','Tilt',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.36 .70 .3 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(ud(5)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(5)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',109,0,1);']);
        
        %.............................. end of 5 ....................................
        
        %................................. 6 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .65 .3 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','Sweep Extent',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.36 .65 .3 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(ud(6)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(6)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',110,0,1);']);
        
        %.............................. end of 6 ....................................
        
        %................................. 7 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .60 .4 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','RF INC border/size',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.46 .60 .15 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(ud(7)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(7)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',71,0,1);']);
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.66 .60 .15 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(ud(8)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(8)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',70,0,1);']);
        
        %.............................. end of 7 ....................................
        
        %................................. 8 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .55 .4 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','RF DEC border/size',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.46 .55 .15 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(ud(9)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(9)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',77,0,1);']);
        u2 = uicontrol(Fig1,'Style','edit','Position',[.66 .55 .15 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(ud(10)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(10)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',76,0,1);']);
        
        %.............................. end of 8 ....................................
        
        %................................. 9 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .50 .3 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','S. PerpenBoxSize',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.36 .50 .3 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(ud(11)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(11)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',111,0,1);']);
        
        %.............................. end of 9 ....................................
        
        %................................. 10 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .45 .3 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','S. RadialBoxSize',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.36 .45 .3 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(ud(12)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(12)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',112,0,1);']);
        
        %.............................. end of 10 ....................................
        
        %................................. 11 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .40 .3 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','S. XStartPos',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.36 .40 .3 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(ud(13)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(13)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',113,0,1);']);
        
        %.............................. end of 11 ....................................
        
        
        %................................. 12 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .35 .3 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','S. YStartPos',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.36 .35 .3 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(ud(14)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(14)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',114,0,1);']);
        
        %.............................. end of 12 ....................................
        
        %................................. 13 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .30 .3 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','S. Tilt',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.36 .30 .3 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(ud(15)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(15)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',115,0,1);']);
        
        %.............................. end of 13 ....................................
        
        %................................. 14 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .25 .3 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','Xshift',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.36 .25 .3 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(116)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(16)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',116,0,1);']);
        
        %.............................. end of 14 ....................................
        %................................. 15 .......................................
        uicontrol(Fig1,'Style','text','Position',[.02 .20 .3 .05],...
                'Units','normal','ForegroundColor',[.1 .3 .3],...
                'BackgroundColor','w','String','Yshift',...
                'HorizontalAlignment','center');
        
        
        u2 = uicontrol(Fig1,'Style','edit','Position',[.36 .20 .3 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(117)),...
                'Callback',['ud=get(gcf,''Userdata''); ud(17)=str2num(get(gco,''string'')); set(gcf,''UserData'',ud);unitret(''update'',117,0,1);']);
        
        %.............................. end of 15 ....................................
        
        %---------------------     
        Plot_button=uicontrol(Fig1,'Style','pushbutton','Position',[.75 .9 .22 .06],...
                'Units','Normalized','String','Draw','Callback',['unitret(''draw_rf_stim_display'',gcf);']);
        
        OK=uicontrol(Fig1,'Style','pushbutton','Position',[.75 .82 .22 .06],...
                'Units','Normalized','String','OK','Callback',['delete(',num2str(Fig1), '), return']);
        
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'draw_rf_stim_display')),
        input_val = get(in1,'Userdata'); 
        in1 = input_val(1:5);
        in2 = input_val(6:10);
        in3 = input_val(11:15);
        
        figure
        set(gcf,'WindowButtonDownFcn','ud = get(0,''Userdata'');ud(72) = gcf;set(0,''Userdata'',ud);', ...
                'Name', 'RF and stimuli Display','Color','w');
        
        % DRAW:
        PerpenBoxSize = in1(1);
        RadialBoxSize = in1(2);
        XStartPos = in1(3);
        YStartPos = in1(4);
        Tilt = 2*pi*in1(5)/360;
        
        % Calculate bar axis coordinates
        xa1 = XStartPos+RadialBoxSize/2*cos(Tilt); 
        ya1 = YStartPos+RadialBoxSize/2*sin(Tilt);
        
        xa2 = XStartPos-RadialBoxSize/2*cos(Tilt);
        ya2 = YStartPos-RadialBoxSize/2*sin(Tilt);
        
        line([xa1 xa2], [ya1 ya2], 'LineStyle','--','Color',[0 0.2510 0.5020]), hold on
        
        % Take into account width of the bar
        veradd = PerpenBoxSize/2*cos(Tilt); 
        horadd = PerpenBoxSize/2*sin(Tilt); 
        
        x1 = xa2 - horadd;
        x4 = xa2 + horadd;
        x2 = xa1 - horadd;
        x3 = xa1 + horadd;
        
        y1 = ya2 + veradd;
        y4 = ya2 - veradd;
        y2 = ya1 + veradd;
        y3 = ya1 - veradd;
        
        line([x1 x2 x3 x4 x1 ],[y1 y2 y3 y4 y1],'LineWidth',2,'Color',[0 0.2510 0.5020]), hold on
        
        %axis([0 200 0 200])
        
        % Plot Sweep
        SweepExtent = in2(1);
        
        alpha  = (pi - Tilt);
        
        xes = XStartPos - SweepExtent*sin(alpha); %(x end sweep)
        yes = YStartPos - SweepExtent*cos(alpha);
        
        line([XStartPos xes],[YStartPos yes],'Color', [0    0.5020    0.7529]), hold on
        plot(xes + (XStartPos - xes)/2, yes + (YStartPos - yes)/2,'rx'), hold on
        
        % plot RF INC limits
        leftlimI = in2(2); % from end of sweep
        rfsizeI  = in2(3);
        rigthlimI = leftlimI+rfsizeI;
        
        % Left border
        xlr=xes+(SweepExtent - leftlimI)*sin(alpha);
        ylr=yes+(SweepExtent - leftlimI)*cos(alpha);
        
        
        xl1 = xlr+RadialBoxSize/2*cos(Tilt); 
        yl1 = ylr+RadialBoxSize/2*sin(Tilt);
        
        xl2 = xlr-RadialBoxSize/2*cos(Tilt);
        yl2 = ylr-RadialBoxSize/2*sin(Tilt);
        
        line([xl1 xl2], [yl1 yl2], 'LineWidth',2,'Color','m'), hold on
        
        % Rigth border
        xrr=xes+(SweepExtent - rigthlimI)*sin(alpha);
        yrr=yes+(SweepExtent - rigthlimI)*cos(alpha);
        
        
        xr1 = xrr+RadialBoxSize/2*cos(Tilt); 
        yr1 = yrr+RadialBoxSize/2*sin(Tilt);
        
        xr2 = xrr-RadialBoxSize/2*cos(Tilt);
        yr2 = yrr-RadialBoxSize/2*sin(Tilt);
        
        line([xr1 xr2], [yr1 yr2], 'LineWidth',2,'Color','m'), hold on
        
        % plot RF DEC limits
        leftlimD = in2(4); % from end of sweep
        rfsizeD  = in2(5);
        rigthlimD = leftlimD+rfsizeD;
        
        % Left border
        xlr=xes+(SweepExtent - leftlimD)*sin(alpha);
        ylr=yes+(SweepExtent - leftlimD)*cos(alpha);
        
        
        xl1 = xlr+RadialBoxSize/2*cos(Tilt); 
        yl1 = ylr+RadialBoxSize/2*sin(Tilt);
        
        xl2 = xlr-RadialBoxSize/2*cos(Tilt);
        yl2 = ylr-RadialBoxSize/2*sin(Tilt);
        
        line([xl1 xl2], [yl1 yl2], 'LineWidth',2,'Color','k'), hold on
        
        % Rigth border
        xrr=xes+(SweepExtent - rigthlimD)*sin(alpha);
        yrr=yes+(SweepExtent - rigthlimD)*cos(alpha);
        
        
        xr1 = xrr+RadialBoxSize/2*cos(Tilt); 
        yr1 = yrr+RadialBoxSize/2*sin(Tilt);
        
        xr2 = xrr-RadialBoxSize/2*cos(Tilt);
        yr2 = yrr-RadialBoxSize/2*sin(Tilt);
        
        line([xr1 xr2], [yr1 yr2], 'LineWidth',2,'Color','k'), hold on
        
        
        % Plot Sine/Flash/Static
        
        SPerpenBoxSize = in3(1);
        SRadialBoxSize = in3(2);
        SXStartPos = in3(3);
        SYStartPos = in3(4);
        STilt = 2*pi*in3(5)/360;
        
        
        % Calculate bar axis coordinates
        xa1 = SXStartPos+SRadialBoxSize/2*cos(STilt); 
        ya1 = SYStartPos+SRadialBoxSize/2*sin(STilt);
        
        xa2 = SXStartPos-SRadialBoxSize/2*cos(STilt);
        ya2 = SYStartPos-SRadialBoxSize/2*sin(STilt);
        
        line([xa1 xa2], [ya1 ya2], 'Color',[0 0.4078 0],'LineStyle','--'), hold on
        
        % Take into account width of the stimulus
        veradd = SPerpenBoxSize/2*cos(STilt); 
        horadd = SPerpenBoxSize/2*sin(STilt); 
        
        x1 = xa2 - horadd;
        x4 = xa2 + horadd;
        x2 = xa1 - horadd;
        x3 = xa1 + horadd;
        
        y1 = ya2 + veradd;
        y4 = ya2 - veradd;
        y2 = ya1 + veradd;
        y3 = ya1 - veradd;
        
        line([x1 x2 x3 x4 x1 ],[y1 y2 y3 y4 y1],'Color',[0 0.4078 0]), hold on
        set(gca,'XColor','k','YColor','k');
        axis('equal')
        unitret('figname')
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'eye_mov_plot')),
        if nargin<3, in2 = 0; end;
        if in1 == 0, % 3D 
                % unitret('show_spikes');
                
                bc =[0 0.3373 0.6745];
                Fig = figure('Backingstore','off','Name',['Eye Movements Plot'],'Color','w',...
                        'Units','Normal','Position',[.1 .1 .8 .8],'Resize','On', 'Menubar','none','Number','off');
                set(gcf,'WindowButtonDownFcn','ud = get(0,''Userdata'');ud(72) = gcf;set(0,''Userdata'',ud);');
                
                %Fig = figure('Backingstore','off','Name',['Eye Movements Plot Setup'],'Color',bc,...
                %		    'Units','Normal','Position',[.4 .4 .5 .4],'Resize','On', 'Menubar','none','Number','off');
                
                MarkedData=unitret('get_markeddata');
                
                if (~isempty(MarkedData)),
                        
                        row_num = size(MarkedData,1);      
                        for i=1:row_num,
                                
                                SpikesNum = MarkedData(i,2);
                                SpikesInf = MarkedData(i,1:5);
                                TrialNum  = MarkedData(i,1);
                                To        = MarkedData(i,3);
                                Tend      = MarkedData(i,4);
                                SpikeArrTime = MarkedData(i,6:SpikesNum+5)';
                                
                                EyeMotionLength = MarkedData(i,SpikesNum+6);
                                EyeTimeInterval= MarkedData(i,(SpikesNum+7):(SpikesNum+EyeMotionLength+6))';
                                HorEyeInterval = MarkedData(i,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6))';
                                VerEyeInterval = MarkedData(i,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6))';          
                                
                                set(gcf,'Userdata',[i 0]);
                                v1 = uicontrol(gcf,'Style','slider','Position',[.01 .01 .1 .05],...
                                        'Units','normalized','BackgroundColor','w',...
                                        'ForegroundColor','k','Value',0,'Min', 0 ,'Max', 360,...
                                        'Callback',['v1= (get(gco,''value'')); v2= (get(get(gco,''Userdata''),''value'')); set(gca,''View'',[v1 v2]); ']);
                                v2 = uicontrol(gcf,'Style','slider','Position',[.01 .07 .1 .05],...
                                        'Units','normalized','BackgroundColor','w',...
                                        'ForegroundColor','k','Value',0,'Min', 0 ,'Max', 360,...
                                        'Callback',['v2= (get(gco,''value'')); v1= (get(get(gco,''Userdata''),''value'')); set(gca,''View'',[v1 v2]); ']);
                                set(v1,'Userdata',v2);
                                set(v2,'Userdata',v1);
                                
                                uicontrol(gcf,'Style','text','String','Y Scale','Units','normalized','Position',[.01 .65 .1 .03],'ForegroundColor',[ 0.6353 0.8784 1.0000]);
                                Ylim_1_Hndl = uicontrol(gcf,'Style','edit','Position',[.01 .6 .05 .03],...
                                        'Units','normalized','BackgroundColor',[ 0.6353 0.8784 1.0000],...
                                        'ForegroundColor','b',...
                                        'Callback',['Ylim_1 = (get(gco,''string'')); YlimOld =  get(gca,''Ylim''); set(gca,''Ylim'',[str2num(Ylim_1)   YlimOld(2)] ); ']);
                                Ylim_2_Hndl = uicontrol(gcf,'Style','edit','Position',[.01 .55 .05 .03],...
                                        'Units','normalized','BackgroundColor',[ 0.6353 0.8784 1.0000],...
                                        'ForegroundColor','b',...
                                        'Callback',['Ylim_2 = (get(gco,''string'')); YlimOld =  get(gca,''Ylim''); set(gca,''Ylim'',[YlimOld(1) str2num(Ylim_2) ] ); ']);
                                
                                uicontrol(gcf,'Style','text','String','Z Scale','Units','normalized','Position',[.01 .45 .1 .03],'ForegroundColor',[ 0.6353 0.8784 1.0000]);
                                Zlim_1_Hndl = uicontrol(gcf,'Style','edit','Position',[.01 .4 .05 .03],...
                                        'Units','normalized','BackgroundColor',[ 0.6353 0.8784 1.0000],...
                                        'ForegroundColor','b',...
                                        'Callback',['Zlim_1 = (get(gco,''string'')); ZlimOld =  get(gca,''Zlim''); set(gca,''Zlim'',[str2num(Zlim_1)   ZlimOld(2)]); ']);
                                Zlim_2_Hndl = uicontrol(gcf,'Style','edit','Position',[.01 .35  .05 .03],...
                                        'Units','normalized','BackgroundColor',[ 0.6353 0.8784 1.0000],...
                                        'ForegroundColor','b',...
                                        'Callback',['Zlim_2 = (get(gco,''string'')); ZlimOld =  get(gca,''Zlim''); set(gca,''Zlim'',[ZlimOld(1) str2num(Zlim_2) ]); ']);
                                
                                axes('Position',[0.2 0.2 0.7 0.7])
                                
                                
                                
                                
                                plot3( EyeTimeInterval,HorEyeInterval, VerEyeInterval,'b-', EyeTimeInterval,HorEyeInterval, VerEyeInterval,'b.','MarkerSize',10), hold on
                                xlabel('time')
                                
                                set(gca,'XColor','k','YColor','k','ZColor','k');
                                
                                %-----------------------------------------------
                                if in2 == 1, % Add RC
                                        if isempty(RCIM),
                                                warndlg('Please, calculate RC first!..','WARNING');
                                                return
                                        end
                                        
                                        Xlim = get(gca,'Xlim');
                                        % Center (0,0) coordinates
                                        Hc=DefValues(80)/2;
                                        Vc=DefValues(81)/2;
                                        
                                        range = max(max(max(RCIM)), 1);
                                        mapcol = [1:-1/range:0]';
                                        if DefValues(118),
                                                limcol = DefValues(118); % the color next to white-(no spikes)
                                                mapcol = [1 (limcol - limcol/range):-limcol/range:0]';
                                        end
                                        map = [mapcol mapcol mapcol];
                                        colormap(map)
                                        
                                        I = imrotate(RCIM, 90); 
                                        [x,y,z] = meshgrid( Xlim(1), 0-Hc:size(I,2)-Hc-1 , 0-Vc:size(I,1)-Vc-1 );
                                        warp(x,y,z,I+1,map), hold on
                                        
                                        
                                        % Get previous RC Axes:
                                        % axesHndl = sort(get(DefValues(72), 'Children'));
                                        %%% Currently on RC figure plot axes are children #7 (from 13) 
                                        %Ylim = get(axesHndl(7),'Xlim');
                                        %Zlim = get(axesHndl(7),'Ylim');
                                        % set(gca,'Ylim',Ylim,'Zlim',Zlim)
                                        plot3(EyeTimeInterval(1)*ones(size(HorEyeInterval)),  HorEyeInterval, VerEyeInterval, 'Color', [0.0157    0.6627    0.9412],'LineWidth',1), hold on
                                        
                                        set(gca,'box','on'); 
                                        
                                        
                                        
                                        
                                end % of if Add RC
                                unitret('draw_spike_train_3D'); 
                                view(20,30)
                                
                        end % of loop for segments (row_num)
                else
                        warndlg('No Segments Selected!..','WARNING');
                        return
                end
        elseif in1 == 1, %2D plot
                MarkedData=unitret('get_markeddata');
                
                if (~isempty(MarkedData)),
                        
                        row_num = size(MarkedData,1);      
                        for i=1:row_num,
                                
                                SpikesNum = MarkedData(i,2);
                                SpikesInf = MarkedData(i,1:5);
                                TrialNum  = MarkedData(i,1);
                                To        = MarkedData(i,3);
                                Tend      = MarkedData(i,4);
                                SpikeArrTime = MarkedData(i,6:SpikesNum+5) - DefValues(74); % - latency from saccade
                                
                                EyeMotionLength = MarkedData(i,SpikesNum+6);
                                EyeTimeInterval= MarkedData(i,(SpikesNum+7):(SpikesNum+EyeMotionLength+6))';
                                HorEyeInterval = MarkedData(i,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6))';
                                VerEyeInterval = MarkedData(i,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6))';          
                                
                                Fig = figure('Backingstore','off','Name',['2D Eye Movements Plot'],'Color','w',...
                                        'Units','Normal','Position',[.2 .2 .7 .7],'Resize','On', 'Menubar','none','Number','off');
                                set(gcf,'WindowButtonDownFcn','ud = get(0,''Userdata'');ud(72) = gcf;set(0,''Userdata'',ud);');
                                
                                axes('Position',[0.2 0.2 0.7 0.7])
                                
                                % Latency controls:
                                uicontrol(gcf,'Style','text','String','Latency','Units','normalized','Position',[.01 .85 .11 .04],'ForegroundColor','w');
                                LatencyHndl = uicontrol(gcf,'Style','edit','Position',[.01 .8 .05 .03],...
                                        'String',num2str(DefValues(74)),...
                                        'Units','normalized','BackgroundColor','w',...
                                        'ForegroundColor','b',...
                                        'Callback',['ud = get(0,''Userdata''); ud(74) = str2num(get(gco,''String'')); set(0,''Userdata'',ud); unitret(''eye_mov_plot'',1);']);
                                
                                
                                % Axes controls:
                                uicontrol(gcf,'Style','text','String','X Scale','Units','normalized','Position',[.01 .65 .1 .03],'ForegroundColor',[ 0.6353 0.8784 1.0000]);
                                Xlim_1_Hndl = uicontrol(gcf,'Style','edit','Position',[.01 .6 .05 .03],...
                                        'Units','normalized','BackgroundColor',[ 0.6353 0.8784 1.0000],...
                                        'ForegroundColor','b',...
                                        'Callback',['Xlim_1 = (get(gco,''string'')); XlimOld =  get(gca,''Xlim''); set(gca,''Xlim'',[str2num(Xlim_1)  XlimOld(2)]); ']);
                                Xlim_2_Hndl = uicontrol(gcf,'Style','edit','Position',[.01 .55 .05 .03],...
                                        'Units','normalized','BackgroundColor',[ 0.6353 0.8784 1.0000],...
                                        'ForegroundColor','b',...
                                        'Callback',['Xlim_2 = (get(gco,''string'')); XlimOld =  get(gca,''Xlim''); set(gca,''Xlim'',[XlimOld(1) str2num(Xlim_2)]); ']);
                                
                                uicontrol(gcf,'Style','text','String','Y Scale','Units','normalized','Position',[.01 .45 .1 .03],'ForegroundColor',[ 0.6353 0.8784 1.0000]);
                                Ylim_1_Hndl = uicontrol(gcf,'Style','edit','Position',[.01 .4 .05 .03],...
                                        'Units','normalized','BackgroundColor',[ 0.6353 0.8784 1.0000],...
                                        'ForegroundColor','b',...
                                        'Callback',['Ylim_1 = (get(gco,''string'')); YlimOld =  get(gca,''Ylim''); set(gca,''Ylim'',[str2num(Ylim_1)  YlimOld(2)]); ']);
                                Ylim_2_Hndl = uicontrol(gcf,'Style','edit','Position',[.01 .35  .05 .03],...
                                        'Units','normalized','BackgroundColor',[ 0.6353 0.8784 1.0000],...
                                        'ForegroundColor','b',...
                                        'Callback',['Ylim_2 = (get(gco,''string'')); YlimOld =  get(gca,''Ylim''); set(gca,''Ylim'',[YlimOld(1) str2num(Ylim_2)]); ']);
                                
                                uicontrol(gcf,'Style','text','String','Z Scale','Units','normalized','Position',[.01 .25 .1 .03],'ForegroundColor',[ 0.6353 0.8784 1.0000]);
                                Zlim_1_Hndl = uicontrol(gcf,'Style','edit','Position',[.01 .20 .05 .03],...
                                        'Units','normalized','BackgroundColor',[ 0.6353 0.8784 1.0000],...
                                        'ForegroundColor','b',...
                                        'Callback',['Zlim_1 = (get(gco,''string'')); ZlimOld =  get(gca,''Zlim''); set(gca,''Zlim'',[str2num(Zlim_1)  ZlimOld(2)]); ']);
                                
                                Zlim_2_Hndl = uicontrol(gcf,'Style','edit','Position',[.01 .15 .05 .03],...
                                        'Units','normalized','BackgroundColor',[ 0.6353 0.8784 1.0000],...
                                        'ForegroundColor','b',...
                                        'Callback',['Zlim_2 = (get(gco,''string'')); ZlimOld =  get(gca,''Zlim''); set(gca,''Zlim'',[ZlimOld(1) str2num(Zlim_2)]); ']);
                                
                                v1 = uicontrol(gcf,'Style','slider','Position',[.01 .01 .1 .05],...
                                        'Units','normalized','BackgroundColor','w',...
                                        'ForegroundColor','k','Value',0,'Min', 0 ,'Max', 360,...
                                        'Callback',['v1= (get(gco,''value'')); v2= (get(get(gco,''Userdata''),''value'')); set(gca,''View'',[v1 v2]); ']);
                                v2 = uicontrol(gcf,'Style','slider','Position',[.01 .07 .1 .05],...
                                        'Units','normalized','BackgroundColor','w',...
                                        'ForegroundColor','k','Value',0,'Min', 0 ,'Max', 360,...
                                        'Callback',['v2= (get(gco,''value'')); v1= (get(get(gco,''Userdata''),''value'')); set(gca,''View'',[v1 v2]); ']);
                                set(v1,'Userdata',v2);
                                set(v2,'Userdata',v1);
                                
                                NumP = length(EyeTimeInterval);
                                if isempty(SpikeArrTime), % No spikes in segment
                                        binned_spikes = zeros(length(EyeTimeInterval),1);
                                        bins = EyeTimeInterval;
                                else
                                        % [binned_spikes, bins] = hist(SpikeArrTime, EyeTimeInterval+(EyeTimeInterval(2)-EyeTimeInterval(1))/2);
                                        [binned_spikes, bins] = hist(SpikeArrTime, EyeTimeInterval);
                                end
                                Hz  = zeros(1,3*NumP);
                                Hz(2:3:3*NumP-1)  = binned_spikes;
                                Hx  = zeros(1,3*NumP);
                                Hx(1:3:3*NumP-2) = HorEyeInterval; 
                                Hx(2:3:3*NumP-1) = HorEyeInterval; 
                                Hx(3:3:3*NumP)   = HorEyeInterval; 
                                Hy  = zeros(1,3*NumP);
                                Hy(1:3:3*NumP-2) = VerEyeInterval; 
                                Hy(2:3:3*NumP-1) = VerEyeInterval; 
                                Hy(3:3:3*NumP)   = VerEyeInterval; 
                                line(Hx,Hy,Hz,'LineWidth', 0.5, 'Color', 'r'); hold on
                                plot3(HorEyeInterval,VerEyeInterval,zeros(1,NumP),'k'), hold on
                                set(gca,'View',[320 30],'Zlim', [0 max(binned_spikes)+5],'box','on','XGrid','on','YGrid','on',...
                                        'XColor',[0 .502 0],'YColor','m','ZColor','k'); 
                                
                                %-----------------------------------------------
                                if in2 == 1, % Add RC
                                        if isempty(RCIM),
                                                warndlg('Please, calculate RC first!..','WARNING');
                                                return
                                        end
                                        
                                        Xlim = get(gca,'Xlim');
                                        Ylim = get(gca,'Ylim');
                                        % Center (0,0) coordinates
                                        Hc=DefValues(80)/2;
                                        Vc=DefValues(81)/2;
                                        
                                        range = max(max(max(RCIM)), 1);
                                        mapcol = [1:-1/range:0]';
                                        if DefValues(118),
                                                limcol = DefValues(118); % the color next to white-(no spikes)
                                                mapcol = [1 (limcol - limcol/range):-limcol/range:0]';
                                        end
                                        map = [mapcol mapcol mapcol];
                                        colormap(map)
                                        
                                        I = RCIM; 
                                        if DefValues(128) == 1, % Image
                                                [x,y] = meshgrid( 0-Hc:size(I,2)-Hc-1 , 0-Vc:size(I,1)-Vc-1);
                                                if strcmp(v(1),'5'),
                                                        [x,y] = meshgrid( 0-Hc:size(I,2)-Hc-1 , 0-Vc:size(I,1)-Vc-1);
                                                else
                                                        [x,y] = meshgrid( 0-Hc:size(I,2)-Hc-1 , size(I,1)-Vc-1:-1:0-Vc);
                                                end
                                                z = zeros(size(I));
                                                
                                                warp(x,y,z,I+1,map), hold on
                                        elseif DefValues(128) == 2, % Patch
                                                unitret('image2patch',I,map(2:size(map,1),:),2);
                                                
                                        end
                                        
                                        set(gca,'Ydir','normal')
                                        
                                        % if strcmp(v(1),'5'),
                                        %	set(gca,'Ydir','normal')
                                        % else 
                                        %	set(gca,'Ydir','reverse')
                                        % end
                                        
                                        
                                        % Get previous RC Axes:
                                        % axesHndl = sort(get(DefValues(72), 'Children'));
                                        %%% Currently on RC figure plot axes are children #7 (from 13) 
                                        %Ylim = get(axesHndl(7),'Xlim');
                                        %Zlim = get(axesHndl(7),'Ylim');
                                        % set(gca,'Ylim',Ylim,'Zlim',Zlim)
                                        
                                        
                                        
                                end % of if Add RC
                                
                                
                        end % of loop for segments (row_num)
                else
                        warndlg('No Segments Selected!..','WARNING');
                        return
                end   
                
                
                
                
        end % of 2D/3D selection 
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'draw_spike_train_3D'))
        ud = get(gcf,'Userdata');
        
        if ud(2),
                delete(ud(2)) % delete previous spike train
        end
        i = ud(1); % segment number
        MarkedData=unitret('get_markeddata');
        
        SpikesNum = MarkedData(i,2);
        SpikeArrTime = MarkedData(i,6:SpikesNum+5)';
        
        
        Ylim = get(gca,'Ylim');
        Zlim = get(gca,'Zlim');
        
        SpikeAmp = abs(Zlim(2) - Zlim(1))/5;
        xx = zeros(1,3*SpikesNum);
        xx(1:3:(3*SpikesNum-2)) = SpikeArrTime;
        xx(2:3:(3*SpikesNum-1)) = SpikeArrTime;
        xx(3:3:(3*SpikesNum))   = SpikeArrTime;
        yy = zeros(1,3*SpikesNum);
        yy(2:3:(3*SpikesNum-1)) = ones(1,SpikesNum);
        h = line(xx,Ylim(1)*ones(1,length(xx)),SpikeAmp*yy+Zlim(1),'Color','r');
        set(gcf,'Userdata',[i h])
        % set(gca,'Ydir','reverse');
        
        
        
        
        
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'eye_mov_spikes_rc'))
        
        % Reverse Correlation between Eye Movements and Spike Train
        set(gcf,'Pointer','watch');
        
        if nargin < 3, % no new lower limit is provided
                V = 1000; %(-500:499)
                H = 1000;
                LowerLim = -500;
                UpperLim =  499;
        else
                LowerLim = in2(1);
                UpperLim = in2(2);
                V = dist(LowerLim,UpperLim)+1;
                H = V;
        end   
        
        Latency   = DefValues(74);
        Threshold = DefValues(79);
        EMbin     = DefValues(82); 
        
        MarkedData=unitret('get_markeddata');
        RF = zeros(V,H);
        if (~isempty(MarkedData)),
                
                row_num = size(MarkedData,1);     
                maxV = []; 
                maxH = []; 
                VerOffset = [];
                HorOffset = [];
                for i=1:row_num,
                        
                        SpikesNum = MarkedData(i,2);
                        SpikesInf = MarkedData(i,1:5);
                        TrialNum  = MarkedData(i,1);
                        To        = MarkedData(i,3);
                        Tend      = MarkedData(i,4);			
                        SpikeArrTime = MarkedData(i,6:SpikesNum+5);
                        SpikeArrTime = SpikeArrTime(find(SpikeArrTime-To > Latency)) - Latency; % - latency from saccade
                        
                        EyeMotionLength = MarkedData(i,SpikesNum+6);
                        EyeTimeInterval= MarkedData(i,(SpikesNum+7):(SpikesNum+EyeMotionLength+6))';
                        HorEyeInterval = MarkedData(i,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6))';
                        VerEyeInterval = MarkedData(i,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6))';          
                        if EMbin > 10; % bin is more than 10 ms
                                EyeTimeInterval = EyeTimeInterval(1:EMbin/10:EyeMotionLength);
                                VerEyeInterval = VerEyeInterval(1:EMbin/10:EyeMotionLength);
                                HorEyeInterval = HorEyeInterval(1:EMbin/10:EyeMotionLength);
                        end
                        
                        minVEI = min(VerEyeInterval);
                        minHEI = min(HorEyeInterval);
                        %  if minVEI <= LowerLim,
                        
                        %        RF = zeros(V+dist(LowerLim,minVEI), H);		
                        %        LowerLim = minVEI;
                        %        unitret('eye_mov_spikes_rc',in1,[minVEI-1 UpperLim]);
                        %  elseif minHEI <= LowerLim,
                        
                        %        RF = zeros(V, H+dist(LowerLim,minHEI));	
                        %	LowerLim = minHEI;
                        %	unitret('eye_mov_spikes_rc',in1,[minHEI-1 UpperLim]);
                        %  end
                        VerPos = VerEyeInterval'-LowerLim;
                        HorPos = HorEyeInterval'-LowerLim;
                        
                        %  if (max(VerPos)>V | max(HorPos)>H), % Upper limit is exceeded
                        %	unitret('errormessage','Eye Positions exceed limits. Setting new ones...','WARNING');
                        %        unitret('eye_mov_spikes_rc',in1,[LowerLim UpperLim+100]);                        
                        %  end
                        
                        if isempty(SpikeArrTime), % No spikes in segment
                                binned_spikes = zeros(length(EyeTimeInterval),1);
                                bins = EyeTimeInterval;
                        else
                                % [binned_spikes, bins] = hist(SpikeArrTime, EyeTimeInterval+(EyeTimeInterval(2)-EyeTimeInterval(1))/2);
                                [binned_spikes, bins] = hist(SpikeArrTime, EyeTimeInterval);
                        end
                        
                        
                        MaxV = max(VerPos);
                        MaxH = max(HorPos);
                        MinV = min(VerPos);
                        MinH = min(HorPos);
                        if (MaxV>V | MaxH>H | MinV <= 0 | MinH <=0),
                                unitret('errormessage',['Eye Positions exceed limits (segm. #',num2str(i),'). Aborting...'],'WARNING');
                                set(gcf,'Pointer','Arrow');
                                return;
                        end
                        
                        for k=1:length(binned_spikes),
                                RF(VerPos(k),HorPos(k)) = RF(VerPos(k),HorPos(k))+binned_spikes(k);
                        end
                        
                        
                        % real min value of eye positions
                        VerOffset = [VerOffset min(VerEyeInterval)]; 
                        HorOffset = [HorOffset min(HorEyeInterval)]; 
                        
                        maxV=[maxV MaxV];
                        maxH=[maxH MaxH];
                        minV=[minV MinV];
                        minH=[minH MinH];
                        
                        
                        
                end % of loop for segments
                
                
                
                
                VerOffset =  round(min(VerOffset));
                HorOffset =  round(min(HorOffset)); 
                
                maxV = round(max(maxV));  
                maxH = round(max(maxH));  
                minV = round(min(minV));  
                minH = round(min(minH)); 
                
                Fig = figure('Backingstore','off','Name',['RC'],'Color','w',...
                        'Units','Normal','Position',[.2 .1 .7 .75],'Resize','On', 'Menubar','none','Number','off');
                set(gcf,'WindowButtonDownFcn','ud = get(0,''Userdata'');ud(72) = gcf;set(0,''Userdata'',ud);');
                
                % Axes controls:
                uicontrol(gcf,'Style','text','String','X Scale','Units','normalized','Position',[.01 .65 .1 .03],'ForegroundColor',[ 0 0 0.3],'BackgroundColor',[0.8 1 0.8]);
                Xlim_1_Hndl = uicontrol(gcf,'Style','edit','Position',[.01 .6 .05 .04],...
                        'Units','normalized','BackgroundColor',[ 1 1 1],...
                        'ForegroundColor','b',...
                        'Callback',['Xlim_1 = (get(gco,''string'')); XlimOld =  get(gca,''Xlim''); ud = get(0,''Userdata''); set(gca,''Xlim'',[str2num(Xlim_1) + ud(80)   XlimOld(2)] );  ud(151)=str2num(Xlim_1); set(0,''Userdata'',ud); unitret(''update_ticklabels'');']);
                Xlim_2_Hndl = uicontrol(gcf,'Style','edit','Position',[.01 .55 .05 .04],...
                        'Units','normalized','BackgroundColor',[ 1 1 1],...
                        'ForegroundColor','b',...
                        'Callback',['Xlim_2 = (get(gco,''string'')); XlimOld =  get(gca,''Xlim''); ud = get(0,''Userdata''); set(gca,''Xlim'',[XlimOld(1) str2num(Xlim_2) + ud(80) ] ); ud(152)=str2num(Xlim_2); set(0,''Userdata'',ud); unitret(''update_ticklabels'');']);
                
                uicontrol(gcf,'Style','text','String','Y Scale','Units','normalized','Position',[.01 .45 .1 .03],'ForegroundColor',[ 0 0 0.3],'BackgroundColor',[0.8 1 0.8]);
                Ylim_1_Hndl = uicontrol(gcf,'Style','edit','Position',[.01 .4 .05 .04],...
                        'Units','normalized','BackgroundColor',[ 1 1 1],...
                        'ForegroundColor','b',...
                        'Callback',['Ylim_1 = (get(gco,''string'')); YlimOld =  get(gca,''Ylim''); ud = get(0,''Userdata''); set(gca,''Ylim'',[str2num(Ylim_1) + ud(81)   YlimOld(2)]); ud(153)=str2num(Ylim_1); set(0,''Userdata'',ud); unitret(''update_ticklabels'');']);
                Ylim_2_Hndl = uicontrol(gcf,'Style','edit','Position',[.01 .35  .05 .04],...
                        'Units','normalized','BackgroundColor',[ 1 1 1],...
                        'ForegroundColor','b',...
                        'Callback',['Ylim_2 = (get(gco,''string'')); YlimOld =  get(gca,''Ylim''); ud = get(0,''Userdata''); set(gca,''Ylim'',[YlimOld(1) str2num(Ylim_2) + ud(81) ]); ud(154)=str2num(Ylim_2); set(0,''Userdata'',ud); unitret(''update_ticklabels'');']);	                	                		
                RC_ax= axes('Position',[0.3 0.2 0.6 0.7]);
                
                %RCHrange = DefValues(80);
                %RCVrange = DefValues(81);
                RCH1 = DefValues(151);
                RCH2 = DefValues(152);
                RCV1 = DefValues(153);
                RCV2 = DefValues(154);
                
                DefValues(80) = - DefValues(151);
                DefValues(81) = - DefValues(153);
                set(0,'Userdata',DefValues);
                
                Offset = - LowerLim;
                %if (abs(RCH1) + abs(RCH2) + abs(RCV1) + abs(RCV2)) == 0,
                
                %	RFE = RF((Offset - RCVrange/2 + 1):(Offset + RCVrange/2),(Offset - RCHrange/2 + 1):(Offset + RCHrange/2)); % Currently center is (50,50)
                %else
                RFE = RF((Offset + RCV1 + 1):(Offset + RCV2),(Offset + RCH1 + 1):(Offset + RCH2));
                %end
                
                if Threshold, 
                        [vi,hi] = find( (RFE<Threshold) & (RFE > 0));
                        for l = 1:length(vi),
                                RFE(vi(l),hi(l)) = 0;
                        end
                end
                
                
                
                % RFE = (RF(minV:maxV,minH:maxH)); 
                clear RF;
                if in1==0, % Intensity plot
                        range = max(max(max(RFE)), 1);
                        mapcol = [1:-1/range:0]';
                        if DefValues(118), % Enhance image's contrast
                                limcol = DefValues(118); % the color next to white-(no spikes)
                                mapcol = [1 (limcol - limcol/range):-limcol/range:0]';
                        end
                        
                        map = [mapcol mapcol mapcol];
                        colormap(map)
                        
                        % Set default area to show:
                        RFEV = size(RFE,1);
                        RFEH = size(RFE,2);
                        if RFEV < 100,
                                v1 = 1;
                                v2 = RFEV;
                        else 
                                DAV = 100; % Default V. Area
                                v1 = max(1, -VerOffset - DAV/2);
                                v2 = v1 + DAV -1;  
                        end  
                        if RFEH < 100,
                                h1 = 1;
                                h2 = RFEH; 
                        else               
                                DAH = 100; % Default H. Area 
                                h1 = max(1, -HorOffset - DAH/2);
                                h2 = h1 + DAH -1;
                        end
                        
                        % Center (0,0) coordinates
                        Hc=DefValues(80);
                        Vc=DefValues(81);
                        %Hc = -DefValues(151);
                        %Vc = -DefValues(153);
                        
                        
                        RCIM = RFE;
                        
                        if DefValues(128) == 1, % Image
                                h = image(RFE+1); hold on;
                                set(gcf,'Name','RC: Image');
                        elseif DefValues(128) == 2, % Patch
                                h = unitret('image2patch', RCIM, map(2:size(map,1),:),1);
                                set(gcf,'Name','RC: Patch');
                        end
                        
                        % [c,h] = contour(RFE+1,15); hold on; % Contour plot
                        
                        axis('square')
                        %Ylim = floor(get(gca,'Ylim'));
                        %set(gca,'YTick',[Ylim(1):(Ylim(2)-Ylim(1))/5:Ylim(2)]);
                        
                        
                        set(h,'ButtonDownFcn','unitret(''assign_center'',gca);');
                        
                        %plot(Hc, Vc, 'r*'), hold on % Currently center is (50,50)
                        unitret('update_ticklabels');
                        
                        xlabel('Horizontal Position (minarc)')
                        ylabel('Vertical Position (minarc)')
                        title(['RC of Eye Positions and Spike Train, n=',num2str(sum(sum(RFE))), '; Latency ',num2str(Latency),' ms'])
                        %hc = colorbar;
                        %set(hc,'YTick',[0:1:max(max(RF))],'YTicklabels',[0:1:max(max(RF))])
                        set(gca,'box','on','XColor','k','YColor','k','Ydir','normal');
                        
                        
                        %    set(gca,'XTick',[CurLimX(1) :(CurLimX(2) - CurLimX(1))/5:CurLimX(2) - CurLimX(1)],...
                        %        'XTickLabels',[HorOffset-1:(CurLimX(2) - CurLimX(1))/5:CurLimX(2) - CurLimX(1)+HorOffset+1]); 
                        %	set(gca,'YTick',[CurLimY(1) :(CurLimY(2) - CurLimY(1))/5:CurLimY(2) - CurLimY(1)],...
                        %        'YTickLabels',[VerOffset-1:(CurLimY(2) - CurLimY(1))/5:CurLimY(2) - CurLimY(1)+VerOffset+1]); 
                        
                        % Latency controls:
                        uicontrol(gcf,'Style','text','String','Latency','Units','normalized','Position',[.01 .85 .11 .04],'ForegroundColor','w','BackgroundColor',[0 0.4 0]);
                        LatencyHndl = uicontrol(gcf,'Style','edit','Position',[.01 .8 .05 .03],...
                                'String',num2str(DefValues(74)),...
                                'Units','normalized','BackgroundColor','w',...
                                'ForegroundColor','b',...
                                'Callback',['ud = get(0,''Userdata''); ud(74) = str2num(get(gco,''String'')); set(0,''Userdata'',ud); unitret(''eye_mov_spikes_rc'',0);']);
                        
                        % Spike Threshold controls:
                        uicontrol(gcf,'Style','text','String','Threshold','Units','normalized','Position',[.01 .15 .11 .04],'ForegroundColor','w','BackgroundColor',[0 0.4 0]);
                        LatencyHndl = uicontrol(gcf,'Style','edit','Position',[.01 .1 .05 .03],...
                                'String',num2str(DefValues(79)),...
                                'Units','normalized','BackgroundColor','w',...
                                'ForegroundColor','b',...
                                'Callback',['ud = get(0,''Userdata''); ud(79) = str2num(get(gco,''String'')); set(0,''Userdata'',ud); unitret(''eye_mov_spikes_rc'',0);']);
                        
                        % EM bin controls:
                        uicontrol(gcf,'Style','text','String','EM bin (ms)','Units','normalized','Position',[.15 .15 .11 .04],'ForegroundColor','w','BackgroundColor',[0 0.4 0]);
                        LatencyHndl = uicontrol(gcf,'Style','edit','Position',[.15 .1 .05 .03],...
                                'String',num2str(DefValues(82)),...
                                'Units','normalized','BackgroundColor','w',...
                                'ForegroundColor','b',...
                                'Callback',['ud = get(0,''Userdata''); ud(82) = str2num(get(gco,''String'')); set(0,''Userdata'',ud); unitret(''eye_mov_spikes_rc'',0);']);
                        
                elseif  in1==1, % Histogram (mesh)    
                        mapcol = [0:1/(max(max(RFE))+1):1]';
                        map = [mapcol mapcol mapcol];
                        colormap(map)
                        
                        mesh(RFE), hold on;
                        set(gca,'box','off','XColor','k','YColor','k','ZColor','k','View',[320 32]); 
                        xlabel('Horizontal Position')
                        ylabel('Vertical Position')
                        
                        % Add Controls Specific for 3D Plot
                        % Latency controls:
                        uicontrol(gcf,'Style','text','String','Latency','Units','normalized','Position',[.01 .85 .11 .04],'ForegroundColor','w');
                        LatencyHndl = uicontrol(gcf,'Style','edit','Position',[.01 .8 .05 .03],...
                                'String',num2str(DefValues(74)),...
                                'Units','normalized','BackgroundColor','w',...
                                'ForegroundColor','b',...
                                'Callback',['ud = get(0,''Userdata''); ud(74) = str2num(get(gco,''String'')); set(0,''Userdata'',ud); unitret(''eye_mov_spikes_rc'',1);']);
                        
                        Zlim_1_Hndl = uicontrol(gcf,'Style','edit','Position',[.01 .20 .05 .03],...
                                'Units','normalized','BackgroundColor',[ 0 0 0.8],...
                                'ForegroundColor','b',...
                                'Callback',['Zlim_1 = (get(gco,''string'')); ZlimOld =  get(gca,''Zlim''); set(gca,''Zlim'',[str2num(Zlim_1)  ZlimOld(2)]); ']);
                        
                        Zlim_2_Hndl = uicontrol(gcf,'Style','edit','Position',[.01 .15 .05 .03],...
                                'Units','normalized','BackgroundColor',[ 0 0 0.8],...
                                'ForegroundColor','b',...
                                'Callback',['Zlim_2 = (get(gco,''string'')); ZlimOld =  get(gca,''Zlim''); set(gca,''Zlim'',[ZlimOld(1) str2num(Zlim_2)]); ']);
                        
                        v1 = uicontrol(gcf,'Style','slider','Position',[.01 .01 .1 .05],...
                                'Units','normalized','BackgroundColor','w',...
                                'ForegroundColor','k','Value',0,'Min', 0 ,'Max', 360,...
                                'Callback',['v1= (get(gco,''value'')); v2= (get(get(gco,''Userdata''),''value'')); set(gca,''View'',[v1 v2]); ']);
                        v2 = uicontrol(gcf,'Style','slider','Position',[.01 .07 .1 .05],...
                                'Units','normalized','BackgroundColor','w',...
                                'ForegroundColor','k','Value',0,'Min', 0 ,'Max', 360,...
                                'Callback',['v2= (get(gco,''value'')); v1= (get(get(gco,''Userdata''),''value'')); set(gca,''View'',[v1 v2]); ']);
                        set(v1,'Userdata',v2);
                        set(v2,'Userdata',v1);
                end % of if for which analysis should be made
                
                
                %  elseif ~(isempty(RCIM)), % Dublicate RC
                
        else
                
                warndlg('No Segments Selected!..','WARNING');
                return
        end 
        unitret('figname')
        set(gcf,'CurrentAxes',RC_ax);
        set(gcf,'Pointer','arrow')  
        set(TRET_DAT(2),'Pointer','arrow');
        
        %---------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'estimate_MEAN_PSTH'))
        % Eye velocity analysis
        
        global MEAN_PSTH
        MEAN_PSTH = [];
        
        MarkedData=unitret('get_markeddata');
        if (~isempty(MarkedData)),
                row_num = size(MarkedData,1);     
                
                for i=1:row_num,
                        
                        SpikesNum = MarkedData(i,2);
                        SpikesInf = MarkedData(i,1:5);
                        
                        TrialNum  = MarkedData(i,1);
                        To        = MarkedData(i,3);
                        Tend      = MarkedData(i,4);
                        SpikeArrTime = MarkedData(i,6:SpikesNum+5);
                        EyeMotionLength = MarkedData(i,SpikesNum+6);
                        EyeTimeInterval= MarkedData(i,(SpikesNum+7):(SpikesNum+EyeMotionLength+6))';
                        HorEyeInterval = MarkedData(i,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6))';
                        VerEyeInterval = MarkedData(i,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6))';          
                        
                        
                        if isempty(SpikeArrTime), % No spikes in segment
                                binned_spikes = zeros(length(EyeTimeInterval),1);
                                bins = EyeTimeInterval+(EyeTimeInterval(2)-EyeTimeInterval(1))/2;
                        else
                                [binned_spikes, bins] = hist(SpikeArrTime, EyeTimeInterval + (EyeTimeInterval(2)-EyeTimeInterval(1))/2 );
                                %[binned_spikes, bins] = hist(SpikeArrTime, EyeTimeInterval);
                        end
                        
                        ESR = 10; % ms - Eye Sampling Rate
                        binned_spikes = binned_spikes/ESR*1000; % in spikes/s
                        TF = DefValues(75);
                        
                        
                        % Smooth binned_spikes                
                        SFR = unitret('smooth',binned_spikes); 
                        
                        CycleBins = (1000/TF)/ESR; % 20
                        NCycles = length(binned_spikes) / CycleBins;
                        
                        % Estimate mean cycle PSTH - smoothed
                        r_smoothed_spikes = reshape(SFR,CycleBins,NCycles);
                        mean_cycle_PSTH = mean(r_smoothed_spikes,2);
                        MEAN_PSTH = [MEAN_PSTH; mean_cycle_PSTH'];
                end
                MEAN_PSTH = mean(MEAN_PSTH, 1)
        end
        
        
        %---------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'eye_mov_velocity'))
        % Eye velocity analysis
        
        global STA_ONE_FILE STA_STRUCTURE MEAN_PSTH
        
        set(gcf,'Pointer','watch');
        set(gcf,'WindowButtonDownFcn','ud = get(0,''Userdata'');ud(72) = gcf;set(0,''Userdata'',ud);');
        
        MarkedData=unitret('get_markeddata');
        if (~isempty(MarkedData)),
                
                row_num = size(MarkedData,1);     
                
                for i=1:row_num,
                        
                        SpikesNum = MarkedData(i,2);
                        SpikesInf = MarkedData(i,1:5);
                        
                        TrialNum  = MarkedData(i,1);
                        To        = MarkedData(i,3);
                        Tend      = MarkedData(i,4);
                        SpikeArrTime = MarkedData(i,6:SpikesNum+5); %- DefValues(74); % - latency from saccade
                        
                        EyeMotionLength = MarkedData(i,SpikesNum+6);
                        EyeTimeInterval= MarkedData(i,(SpikesNum+7):(SpikesNum+EyeMotionLength+6))';
                        HorEyeInterval = MarkedData(i,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6))';
                        VerEyeInterval = MarkedData(i,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6))';          
                        
                        
                        if isempty(SpikeArrTime), % No spikes in segment
                                binned_spikes = zeros(length(EyeTimeInterval),1);
                                bins = EyeTimeInterval+(EyeTimeInterval(2)-EyeTimeInterval(1))/2;
                        else
                                [binned_spikes, bins] = hist(SpikeArrTime, EyeTimeInterval + (EyeTimeInterval(2)-EyeTimeInterval(1))/2 );
                                %[binned_spikes, bins] = hist(SpikeArrTime, EyeTimeInterval);
                        end
                        
                        ESR = 10; % ms - Eye Sampling Rate
                        binned_spikes = binned_spikes/ESR*1000; % in spikes/s
                        TF = DefValues(75);
                        
                        
                        % Smooth binned_spikes                
                        SFR = unitret('smooth',binned_spikes); 
                        
                        CycleBins = (1000/TF)/ESR; % 20
                        NCycles = length(binned_spikes) / CycleBins;
                        
                        % Estimate mean cycle PSTH - binned
                        r_binned_spikes = reshape(binned_spikes,CycleBins,NCycles);
                        mean_cycle_PSTH = mean(r_binned_spikes');
                        mean_cycle_PSTH_NCycles = mean_cycle_PSTH'*ones(1,NCycles); 
                        resid_bin = binned_spikes - reshape(mean_cycle_PSTH_NCycles,1,NCycles*CycleBins);
                        
                        if isempty(MEAN_PSTH),
                                % Estimate mean cycle PSTH - smoothed
                                r_smoothed_spikes = reshape(SFR,CycleBins,NCycles);
                                mean_cycle_PSTH = mean(r_smoothed_spikes');
                                mean_cycle_PSTH_NCycles_matrix = mean_cycle_PSTH'*ones(1,NCycles);
                                mean_cycle_PSTH_NCycles = reshape(mean_cycle_PSTH_NCycles,1,NCycles*CycleBins);
                                resid_smooth = SFR - mean_cycle_PSTH_NCycles;
                        else
                                mean_cycle_PSTH = MEAN_PSTH;
                                mean_cycle_PSTH_NCycles_matrix = mean_cycle_PSTH'*ones(1,NCycles);
                                mean_cycle_PSTH_NCycles = reshape(mean_cycle_PSTH_NCycles,1,NCycles*CycleBins);
                                resid_smooth = SFR - mean_cycle_PSTH_NCycles;
                        end
                        
                        % Eye Velocities
                        HV = diff(HorEyeInterval);
                        VV = diff(VerEyeInterval);
                        TV = (HV.^2+VV.^2).^.5; % Total velocity
                        TV=TV';
                        
                        % Fitting sine
                        ph = DefValues(146)*2*pi/360; % phase in radians
                        Amp = DefValues(148); 
                        DC = DefValues(149); 
                        fs = max(DC+Amp*sin(2*pi*1/(1000/TF)*EyeTimeInterval+ph),0); % half-rectified sin
                        d  = abs(SFR'-fs);
                        [XC, lags] = xcorr(TV',d(1:length(TV)),'coeff');
                        
                        figure
                        
                        subplot(3,1,1);
                        plot(EyeTimeInterval(1:length(EyeTimeInterval)-1),HV, 'Color',[0 .502 0]), hold on; 
                        plot(EyeTimeInterval(1:length(EyeTimeInterval)-1),VV, 'Color','m'), hold on;
                        plot(EyeTimeInterval(1:length(EyeTimeInterval)-1),TV, 'Color','r', 'LineWidth',2), hold on;
                        
                        
                        subplot(3,1,2);
                        plot(EyeTimeInterval,binned_spikes,'r'), hold on
                        plot(EyeTimeInterval,SFR,'Color','b', 'Linewidth',2), hold on
                        plot(EyeTimeInterval,fs,'Color','k', 'Linewidth',2), hold on
                        plot(EyeTimeInterval,mean_cycle_PSTH_NCycles,'Color','g', 'Linewidth',1), hold on
                        
                        
                        ax = subplot(3,1,3);
                        
                        % Non-linear (sinusoidal) fit
                        % [beta,r,J] = nlinfit(EyeTimeInterval,SFR,'sinmodel',[TF p])
                        
                        hold on; 
                        plot(EyeTimeInterval,d), hold on;
                        plot(EyeTimeInterval,abs(resid_smooth), 'm'), hold on;
                        eyepos = [EyeTimeInterval'; HorEyeInterval'; VerEyeInterval'];   
                        [AllSaccadesTime, out2] = unitret('saccades_detect',eyepos,TrialNum,ax);
                        
                        e_d = sum(d)/length(d);
                        e_resid_smooth = sum(abs(resid_smooth))/length(resid_smooth);
                        xlabel(['e_d: ', num2str(e_d),'  e_resid_smooth: ',num2str(e_resid_smooth)]);
                        
                        
                        figure
                        
                        % Cross-Correlation
                        [XCd, lags] = xcorr(TV',d(1:length(TV)),'coeff');
                        [XCresid_smooth, lags] = xcorr(TV',abs(resid_smooth(1:length(TV))),'coeff');
                        plot(lags*ESR, XCd), hold on;
                        plot(lags*ESR, XCresid_smooth,'m'), hold on;
                        
                        set(gca,'Xlim',[-1500/ESR 1500/ESR]);
                        xlabel('ms')
                        
                        % Saccades-triggered averages
                        SaveSTA = DefValues(150);
                        WinBefore = DefValues(100);
                        WinAfter  = DefValues(101);
                        TimeAxis  = -WinBefore:ESR:WinAfter;
                        
                        
                        sta_one_trial = []; % Saccades-triggered activity
                        for k = 1:length(AllSaccadesTime),
                                
                                STAind = find(EyeTimeInterval >= (AllSaccadesTime(k)-WinBefore) & EyeTimeInterval <= (AllSaccadesTime(k)+WinAfter));
                                if length(STAind) == ((WinBefore + WinAfter)/ESR + 1), 
                                        sta_one_trial = [sta_one_trial; abs(resid_smooth(STAind))];
                                end
                        end % of for each saccade
                        
                        
                        %--------------------------------
                        if SaveSTA, % Save STA data 
                                %--------------------------------
                                
                                if isempty(STA_ONE_FILE),
                                        STA_ONE_FILE = sta_one_trial;
                                else
                                        STA_ONE_FILE = [STA_ONE_FILE; sta_one_trial];
                                end
                        else
                                STA_ONE_FILE = sta_one_trial;		
                                %--------------------------------
                        end  % of if Save STA data 
                        %--------------------------------
                        figure
                        plot(TimeAxis,mean(STA_ONE_FILE,1))
                        xlabel(['Time (ms)  ',num2str(size(STA_ONE_FILE,1)),' saccades'])
                        
                        if SaveSTA & ~DefValues(127), % (No batch is running), Clear Processing, save STA Data for One File
                                stafilename = [NAME(1:length(NAME)-3) 'sta'];
                                STA_STRUCTURE = STA_ONE_FILE;
                                eval(['save ',stafilename,' STA_STRUCTURE DefValues']);
                                STA_STRUCTURE = [];
                        elseif SaveSTA & DefValues(127), % Accumulate Processing, save STA Data for Many Files
                                stafilename = ['current.sta'];
                                STA_STRUCTURE = [STA_STRUCTURE; STA_ONE_FILE];
                                eval(['save ',stafilename,' STA_STRUCTURE DefValues']);		
                        end
                        
                        
                        
                        
                        % System Identification
                        % eval(['inp',num2str(i),'= SFR(1:length(TV));']);
                        % eval(['out',num2str(i),' = TV;']);
                        
                        % figure
                        % Delay = DefValues(74);
                        % IndShift = floor(Delay/ESR);
                        % semilogy( TV(1:(length(SFR)-IndShift+1)),SFR(IndShift:length(SFR)),'bo' )
                        
                        % Wavelet
                        % figure
                        
                        %s = binned_spikes;
                        %ls = length(s);
                        %[C,L] = wavedec(s,3,'db1');
                        
                        %cA3 = appcoef(C,L,'db1',3);
                        %cD3 = detcoef(C,L,3);
                        %cD2 = detcoef(C,L,2);
                        %cD1 = detcoef(C,L,1);
                        
                        %A3 = wrcoef('a',C,L,'db1',3);
                        %D1 = wrcoef('d',C,L,'db1',1);
                        %D2 = wrcoef('d',C,L,'db1',2);
                        %D3 = wrcoef('d',C,L,'db1',3);
                        
                        %subplot(2,2,1); plot(A3);
                        %subplot(2,2,2); plot(D1);
                        %subplot(2,2,3); plot(D2);
                        %subplot(2,2,4); plot(D3);
                        
                end % of loop for segments
                
                
                
                % Fig = figure('Backingstore','off','Name',['Eye Movements Plot'],'Color','w',...
                %	   'Units','Normal','Position',[.2 .2 .7 .75],'Resize','On', 'Menubar','none','Number','off');
                
                
                
        else
                warndlg('No Segments Selected!..','WARNING');
                return
        end 
        set(gcf,'Pointer','arrow')  
        set(TRET_DAT(2),'Pointer','arrow');
        
        %--------------------------------------------------------------------------------------------------------------
	elseif(strcmp(action,'add_em_plot'))

	if in1 == 1,			% Add Eye Movements plot to previous graph
		PH = DefValues(72); % Handler to previous plot
		set(0,'CurrentFigure',PH);
	else				% Create new plot
		Fig = figure('Backingstore','off','Name',['2D plane EM plot'],'Color','w',...
                        'Units','Normal','Position',[.2 .1 .7 .75],'Resize','On', 'Menubar','none','Number','off');
                set(gcf,'WindowButtonDownFcn','ud = get(0,''Userdata'');ud(72) = gcf;set(0,''Userdata'',ud);');
	end
		
        MarkedData=unitret('get_markeddata');
        
        % Center (0,0) coordinates
        Hc=DefValues(80);
        Vc=DefValues(81);
        
        if (~isempty(MarkedData)),
                
                row_num = size(MarkedData,1);
                % color = ['b','r','k','m','y','g'];
                color = [0 0 1;
                        1 0 0;
                        0 0 0;
                        1 0 1;
                        1 1 0;
                        0 1 0;
                        0.6235         0    0.3137;];
                
                
                lc = length(color);
                
                for i=1:row_num,
                        
                        SpikesNum = MarkedData(i,2);
                        SpikesInf = MarkedData(i,1:5);
                        TrialNum  = MarkedData(i,1);
                        To        = MarkedData(i,3);
                        Tend      = MarkedData(i,4);
                        SpikeArrTime = MarkedData(i,6:SpikesNum+5) - DefValues(74); % - latency from saccade
                        
                        EyeMotionLength = MarkedData(i,SpikesNum+6);
                        EyeTimeInterval= MarkedData(i,(SpikesNum+7):(SpikesNum+EyeMotionLength+6))';
                        HorEyeInterval = MarkedData(i,(SpikesNum+EyeMotionLength+7):(SpikesNum+2*EyeMotionLength+6))';
                        VerEyeInterval = MarkedData(i,(SpikesNum+2*EyeMotionLength+7):(SpikesNum+3*EyeMotionLength+6))'; 
                        hold on
                        
                        %	  plot(HorEyeInterval+Hc, VerEyeInterval+Vc, 'Color', 'b', 'Linewidth', 0.5), hold on; plot(HorEyeInterval(1)+Hc, VerEyeInterval(1)+Vc, 'o','Color',[1.0000    0.5020    0.2510]), hold on
                        plot(HorEyeInterval+Hc, VerEyeInterval+Vc, 'Color', color( rem(i,lc)*(rem(i,lc)~=0) + lc*(rem(i,lc)==0), : ), 'Linewidth', 0.1), hold on; plot(HorEyeInterval(1)+Hc, VerEyeInterval(1)+Vc, 'o','Color',[1.0000    0.5020    0.2510] ), hold on
                        %plot(HorEyeInterval(1)+Hc, VerEyeInterval(1)+Vc, 'o','Color',color( rem(i,lc)*(rem(i,lc)~=0) + lc*(rem(i,lc)==0), : ) ), hold on
                        
                        % plot(Hc, Vc, 'r*'), hold on % Currently center is (50,50), hold on
                end
        end         
        
        ud(141) = 1;
        
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'add_spikes_records'))
        if  (size(TRET_DAT,2) > 1 ),    % second member exists (pointer on graph figure)
                if strcmp(get(TRET_DAT(2),'Type'),'figure'),
                        delete(TRET_DAT(2));
                        TRET_DAT = TRET_DAT(1);
                end;
        end;      
        % NOT IMPLEMENTED
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'add_spikes_records_from_list'))
        
        
        if  (size(TRET_DAT,2) > 1 ),    % second member exists (pointer on graph figure)
                if strcmp(get(TRET_DAT(2),'Type'),'figure'),
                        delete(TRET_DAT(2));
                        TRET_DAT = TRET_DAT(1);
                end;
        end;    
        
        % Get file names list (.lst - txt file - names in column)
        [filename, pathname] = uigetfile('*.lst', ['Please, choose file names list'], .4, .4);
        if filename == 0, return; end;
        
        
        FullName = [pathname,filename];
        fid=fopen(FullName,'rt');
        eval(['cd ', pathname]);
        LIST = [];
        
        while 1
                name = fgetl(fid);
                if ~isstr(name), break, end
                LIST = [LIST; name];
        end
        
        fclose(fid);
        NPages = 1;
        
        
        Fig2 = figure('Units','normalized', 'Position',[0.2850    0.0150    0.7012    0.9100],...
                'Backingstore','on','color','w','DefaultAxesXcolor','k',...
                'DefaultAxesFontSize',9,'DefaultAxesDrawMode','fast',...
                'DefaultAxesYColor','k','Menubar','none','Name',[FullName,': ',num2str(NPages)]);
        
        unitret('figname',[FullName,': ',num2str(NPages)])
        set(Fig2,'Units','Pixels');
        
        TRET_DAT(2) = Fig2;
        
        NumFilesInList = size(LIST,1);
        % Graph grid
        Wid = 4;
        Hei = 4;
        NPlotsOnPage = Wid*Hei;
        
        if ~DefValues(127), % Clear NORMIR
                NORMIR = [];
                bins = [];
                SACCADES_STRUCTURE = [];
                saccades_cell = [];
        end
        
        
        
        hw = waitbar(0,'Please wait...');
        
        for k=1:NumFilesInList,
                set(0,'CurrentFigure',hw);
                waitbar(k/NumFilesInList);
                set(0,'CurrentFigure',Fig2);
                
                if k-(NPages-1)*NPlotsOnPage > NPlotsOnPage,
                        NPages = NPages + 1;
                        Fig2 = figure('Units','normalized', 'Position',[0.2850    0.0150    0.7012    0.9100],...
                                'Backingstore','on','color','w','DefaultAxesXcolor','k',...
                                'DefaultAxesFontSize',9,'DefaultAxesDrawMode','fast',...
                                'DefaultAxesYColor','k','Menubar','none','Name',[FullName,': ',num2str(NPages)]);
                        unitret('figname',[FullName,': ',num2str(NPages)])
                end
                
                subplot(Hei,Wid ,k-(NPages-1)*NPlotsOnPage)    
                unitret('open_spk',LIST(k,:), in2, k);
                
                % TEMPORAL ADDITION 
                % set(gca,'Xtick',[0 DefValues(124) DefValues(100)+DefValues(101)])
                % set(gca,'Xticklabel',[-DefValues(100) 0 DefValues(101)])
                % set(gca,'Xtick',[0 200 400 600])
                % set(gca,'Xticklabel',[-200 0 200 400])
                % line([0 500],[stdv(k) stdv(k)],'LineStyle','--','Color','k','MarkerSize',2)
                
        end % of for LIST
        close(hw)
        
        
        
        if in2 == 1, % "Add...", not just "Show..." Display NORMIR
                
                
                if DefValues(123) == 1,     % Histogram in #spikes
                        Ylabel = '#spikes';
                elseif  DefValues(123) == 2 % Histogram in spikes/sec
                        Ylabel = 'spikes/sec';
                end
                if DefValues(125),
                        Ylabel = ['Normalized ' Ylabel];
                end
                
                Fig3 = figure('Units','normalized', 'Position',[0.2    0.2    0.5    0.5],...
                        'Backingstore','on','color','w','DefaultAxesXcolor','k',...
                        'DefaultAxesFontSize',9,'DefaultAxesDrawMode','fast',...
                        'DefaultAxesYColor','k','Name',['Averaged IR for: ', FullName]);
                
                figcounter = figcounter + 1;
                
                bins=(DefValues(20)/2:DefValues(20):DefValues(20)*(size(NORMIR,2))-DefValues(20)/2);
                if DefValues(132), % Plot individual traces             
                        plot(bins, NORMIR), hold on
                end
                
                se = std(NORMIR);
                AveNORMIR = mean(NORMIR);
                
                % errorbar(bins,AveNORMIR,se); hold on
                % plot(bins,AveNORMIR,'Color','k','Linewidth',2), hold on
                [x,y]=bar(bins,AveNORMIR);
                plot(x,y,'Color','k','Linewidth',2), hold on
                
                set(gca,'Xlim',[0 bins(length(bins))+DefValues(20)/2],'Ylim',[0 max(AveNORMIR)+max(se)])
                
                %[xx,yy] = bar(SpikeHist,N,1);
                %set(line,'Xdata',xx,'YData',yy,'Color','b');
                
                
                ylim=get(gca,'YLim');
                xlim=get(gca,'XLim');
                
                if DefValues(124), % PSTH Trigger 
                        plot([DefValues(124) DefValues(124)],ylim,'Color','r');	
                end
                
                grid
                title([FullName,' ',num2str(NumFilesInList), ' cells averaged'])
                ylabel(Ylabel);
                xlabel('ms')
                %unitret('figname',['Averaged IR for: ', FullName])
                
        end % of if show NORMIR
        
        if ~isempty(SACCADES_STRUCTURE),
                saccades_cell = struct2cell(SACCADES_STRUCTURE);
        end
        save sac_struct SACCADES_STRUCTURE saccades_cell NORMIR bins
        
        %msgbox([LIST],'File list:')
        %msgbox([num2str(k),' files were added'],'Unitret Message'); 
        
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'link_spikes_records'))
        
        set(gcf,'Pointer','Watch');
        if ~isempty(TRINFOHndl)
                if sum(find(get(gcf,'children')==TRINFOHndl))
                        set(TRINFOHndl,'enable','off');
                end
        end
        
        
        if  (size(TRET_DAT,2) > 1 ),    % second member exists (pointer on graph figure)
                if strcmp(get(TRET_DAT(2),'Type'),'figure'),
                        delete(TRET_DAT(2));
                        TRET_DAT = TRET_DAT(1);
                end;
        end;      
        
        
        wld = get(gcf,'Name');
        [a,b]=min(wld - '.');
        
        
        if DefValues(26)==0,		% driven activity
                extent = 'SPD';		
        elseif DefValues(26)==1		% on-off couples
                extent = 'SPC';
        elseif DefValues(26)==2		% spont data
                extent = 'SPS';
        elseif DefValues(26)==4		% event
                extent = 'SPE';
        elseif DefValues(26)==5		% arb. segments
                extent = 'SPA';
        elseif DefValues(26)==6		% integer number of cycles
                extent = 'SPI';
        elseif DefValues(26)==7		% simulated file (from BioNet)
                extent = 'SPM';
        end;
        
        if nargin < 4,
                in3 = '...'; % Previous name
        end
        for k=1:2, % Takes two files and links them
                if(a==0)
                        wld = [wld(1:b),extent];
                else
                        wld = ['*.','sp?'];
                end;
                
                if k == 1, 
                        if in1 == 0, % first two files  
                                [filename, pathname] = uigetfile(wld, ['Please, choose ', num2str(k), ' spikes file...(was ',in3,')'], .4, .4);
                                if filename == 0, return; end;
                        else 
                                filename = 'templink.tmp';
                                pathname = [pwd,'\'];
                        end
                else 
                        [filename, pathname] = uigetfile(wld, ['Please, choose ', num2str(in2), ' spikes file... (was ',in3,')'], .4, .4);
                        if filename == 0,  
                                NAME = wld;
                                unitret('save',2);
                                return; 
                        end;
                end
                
                FullName = [pathname,filename];
                NAME = filename;
                prev_name = filename;
                
                [fid,message] = fopen(FullName,'rb');
                if fid<0, 
                        error(message);
                end;
                com = ['cd ' pathname(1:length(pathname)-1)]; 
                eval(com);
                
                
                [F,lgn] = fread(fid,inf,'char');
                status = fseek(fid,0,-1);  % rewind the file
                ind=0;
                Spk = [];
                
                while(ind<lgn)
                        % spikes number, start stim and end stim reading...
                        vect=[];
                        vect(1:5) = fread(fid,5,'float');
                        
                        % spikes arrival times reading...
                        vect(6:(vect(2)+5)) = fread(fid,vect(2),'float');
                        
                        % reading of the eye motion interval length , Stim Velocity inf and tilt.	 
                        EyeMotionLength=fread(fid,1,'float');
                        vect(vect(2)+6) = EyeMotionLength;
                        
                        tmp=3*EyeMotionLength+2;
                        
                        vect((vect(2)+7):(vect(2)+8+3*EyeMotionLength))=fread(fid,tmp,'float');
                        
                        
                        ncol = size(Spk,2);
                        nrow = size(Spk,1);                %=TrialsNum of the given file
                        vlgn = length(vect);
                        
                        maxncol = max((vlgn+5),ncol);
                        newrow = nrow + 1;
                        tmp = zeros(newrow,maxncol);
                        for i=1:nrow,
                                tmp(i,1:ncol) =Spk(i,:);
                        end;
                        Spk(newrow,1:vlgn) = vect;
                        ind=ftell(fid);
                        
                end;
                fclose(fid);
                com = ['Spk',num2str(k),'=Spk;'];
                eval(com);
                
        end % of loop for files
        
        r1 = size(Spk1,1);
        r2 = size(Spk2,1);
        c1 = size(Spk1,2);
        c2 = size(Spk2,2);
        
        ROWS = max(r1,r2);
        COLS = max(c1,c2);
        PAD = zeros(ROWS,COLS);
        
        Spk1pad = PAD;
        Spk2pad = PAD;
        
        Spk1pad(1:r1,1:c1) = Spk1;
        Spk2pad(1:r2,1:c2) = Spk2;
        
        SPK = [Spk1pad(1:r1,:); Spk2pad(1:r2,:)];
        set(gcf,'Userdata',SPK);
        NAME = 'templink.tmp';
        
        unitret('save_markeddata','templink.tmp');
        unitret('link_spikes_records',1,in2+1, prev_name);
        
        set(gcf,'Pointer','Arrow');
        
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'link_spikes_records_old'))
        
        set(gcf,'Pointer','Watch');
        if ~isempty(TRINFOHndl)
                if sum(find(get(gcf,'children')==TRINFOHndl))
                        set(TRINFOHndl,'enable','off');
                end
        end
        
        
        if  (size(TRET_DAT,2) > 1 ),    % second member exists (pointer on graph figure)
                if strcmp(get(TRET_DAT(2),'Type'),'figure'),
                        delete(TRET_DAT(2));
                        TRET_DAT = TRET_DAT(1);
                end;
        end;      
        
        
        wld = get(gcf,'Name');
        [a,b]=min(wld - '.');
        
        
        if DefValues(26)==0,		% driven activity
                extent = 'SPD';		
        elseif DefValues(26)==1		% on-off couples
                extent = 'SPC';
        elseif DefValues(26)==2		% spont data
                extent = 'SPS';
        elseif DefValues(26)==4		% event
                extent = 'SPE';
        elseif DefValues(26)==5		% arb. segments
                extent = 'SPA';
        elseif DefValues(26)==6		% integer number of cycles
                extent = 'SPI';
        elseif DefValues(26)==7		% simulated file (from BioNet)
                extent = 'SPM';
        end;	
        for k=1:2, % Currently two files may be linked
                if(a==0)
                        wld = [wld(1:b),extent];
                else
                        wld = ['*.','sp?'];
                end;
                
                [filename, pathname] = uigetfile(wld, ['Please, choose ', num2str(k), ' spikes file...'], .4, .4);
                if filename == 0, return; end;
                FullName = [pathname,filename];
                NAME = filename;
                
                [fid,message] = fopen(FullName,'rb');
                if fid<0, 
                        error(message);
                end;
                com = ['cd ' pathname(1:length(pathname)-1)]; 
                eval(com);
                
                
                [F,lgn] = fread(fid,inf,'char');
                status = fseek(fid,0,-1);  % rewind the file
                ind=0;
                Spk = [];
                
                while(ind<lgn)
                        % spikes number, start stim and end stim reading...
                        vect=[];
                        vect(1:5) = fread(fid,5,'float');
                        
                        % spikes arrival times reading...
                        vect(6:(vect(2)+5)) = fread(fid,vect(2),'float');
                        
                        % reading of the eye motion interval length , Stim Velocity inf and tilt.	 
                        EyeMotionLength=fread(fid,1,'float');
                        vect(vect(2)+6) = EyeMotionLength;
                        
                        tmp=3*EyeMotionLength+2;
                        
                        vect((vect(2)+7):(vect(2)+8+3*EyeMotionLength))=fread(fid,tmp,'float');
                        
                        
                        ncol = size(Spk,2);
                        nrow = size(Spk,1);                %=TrialsNum of the given file
                        vlgn = length(vect);
                        
                        maxncol = max((vlgn+5),ncol);
                        newrow = nrow + 1;
                        tmp = zeros(newrow,maxncol);
                        for i=1:nrow,
                                tmp(i,1:ncol) =Spk(i,:);
                        end;
                        Spk(newrow,1:vlgn) = vect;
                        ind=ftell(fid);
                        
                end;
                fclose(fid);
                com = ['Spk',num2str(k),'=Spk;'];
                eval(com);
                
        end % of loop for files
        
        r1 = size(Spk1,1);
        r2 = size(Spk2,1);
        c1 = size(Spk1,2);
        c2 = size(Spk2,2);
        
        ROWS = max(r1,r2);
        COLS = max(c1,c2);
        PAD = zeros(ROWS,COLS);
        
        Spk1pad = PAD;
        Spk2pad = PAD;
        
        Spk1pad(1:r1,1:c1) = Spk1;
        Spk2pad(1:r2,1:c2) = Spk2;
        
        SPK = [Spk1pad(1:r1,:); Spk2pad(1:r2,:)];
        set(gcf,'Userdata',SPK);
        
        
        unitret('save',2);
        
        set(gcf,'Pointer','Arrow');
        
        
        
        
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'go_to_trial'))
        trials_inf = get(TRET_DAT(1),'UserData');
        fid = trials_inf(1);
        TrialsNum = trials_inf(2);
        TrialBegin = trials_inf(3:TrialsNum+2);
        
        str = ['1'];
        if TrialsNum >1,    
                for(i=2:TrialsNum),
                        str = [str, '|', num2str(i)];      
                end;
        end;
        
        Fig1 = figure('Backingstore','off','Name','Go to trial...','Color','w',...
                'Units','Normal','Position',[.4 .5 0.5 .2],'Resize','On', 'Menubar','none','Number','off',...
                'DefaultAxesPosition',[0 0 1 01],'visible','on');
        
        
        if strcmp(v(1),'5'),
                uicontrol(Fig1,'Style','Popupmenu','Units','Normalized','Position',[.5 .5 .5 .5],'String',str,'Callback',...
                        ['l = get(gcf, ''CurrentObject''); s = get(l,''value''); delete(gcf); unitret(''rf_stim_scheme'',s);']);
                
        else
                uicontrol(Fig1,'Style','Popupmenu','Units','Normalized','Position',[.5 .95 .3 .5],'String',str,'Callback',...
                        ['l = get(gcf, ''CurrentObject''); s = get(l,''value''); delete(gcf); unitret(''redraw_exp'',s);']);
                
        end
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'smooth')),
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % see Abeles 1982: Quantification, smoothing, and confidence limits for single-units'
        % histogram. Journal of Neurosci Meth 5: 317-325
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	% in1 - signal
	% in2 - bin for Gaussian
	% in3 - sigma of Gaussian
	
	if nargin<3,
		bin = 1;
	else
		bin = in2;
	end
	
        if nargin<4,
		s=DefValues(25); % SIGMA (ms)
	else
		s=in3;
	end
	
        t=-3*s:bin:3*s;
	lg = length(t);
        b=exp(-t.^2/(2*s^2));
        % Normalization 
        tb=(1.003/(2*pi*s)^.5)*b;
        divider=sum(tb);
        ini_len = length(in1);

	in1=[in1(1)*ones(size(1:lg/2)) in1 in1(end)*ones(size(1:lg/2))];
	     
	%in1=[fliplr(in1(1:lg/2)) in1 fliplr(in1(length(in1)-lg/2:length(in1)))];
     
        %in1=in1(3*s:length(in1)-(3*s+1));
        
        out1=(1/divider)*(1.003/(2*pi*s)^.5)*conv(in1,b);
	out1 = out1(lg+1:end-lg);
        out1 = resample(out1,ini_len,length(out1));
	
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'update_ticklabels'))
        % for EM-spikes RC plot
        if nargin < 2, in1 = 0; end;
        % Center (0,0) coordinates
        Hc=DefValues(80);
        Vc=DefValues(81);
        
        
        
        if in1 == 1, % RC on 3D	        
                YTick = get(gca,'YTick');
                ZTick = get(gca,'ZTick');
                
                set(gca,'ZTickLabels',ZTick-Vc,'YTickLabels',YTick-Hc)
                
        else
                
                XTick = get(gca,'XTick'); 
                YTick = get(gca,'YTick');
                set(gca,'XTickLabels',XTick-Hc,'YTickLabels',YTick-Vc)
        end
        
        
        
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'open_txt_spike_file'))
        % open txt (ZEROS AND ONES) file, where ONE means spike and ZERO no spike
        [filename, pathname] = uigetfile('*.txt', 'Retrival of Spike Train (TXT)', .4, .4);
        if filename == 0, return; end;
        FullName = [pathname,filename];
        NAME = filename;
        [fid,message] = fopen(FullName,'rt');
        if fid<0, 
                error(message);
        end;    
        
        com = ['cd ' pathname(1:length(pathname)-1)]; 
        eval(com);
        
        T = fscanf(fid,'%d');
        unitret('convert_train_to_spike_file',T,in1);
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'convert_train_to_spike_file'))
        % takes spike train and converts it to spike file
        
        DefValues(26) = 7; % wild extension
        set(0,'Userdata',DefValues);
        
        strdlg=[NAME(1:length(NAME)-4) '.spm'];
        
        if nargin == 4, % Automatically number trials
                tnum = in3;
        else 
                tnum = 999;
        end
        
        if in2==1, % Ask about new spk file name
                [filename, pathname] = uiputfile(strdlg, 'Convert to ...', .4, .4);
                if filename == 0, 
                        return;
                else
                        NAME = filename;
                end;
                name = [pathname,NAME];
        else 
                NAME = strdlg;
        end
        
        
        T = in1;
        SpikesData = find(T==1);
        
        % SpikesInf
        % #trial
        % #spikes
        % to
        % tend
        % modality
        % spikes arrival times 
        
        
        
        if (~isempty(T)),
                
                row_num = size(T,2); % each train is in column
                cvec = [];
                [fid,message] = fopen(NAME,'wb');
                for(i=1:row_num)
                        TT = T(:,i);
                        SpikesNum = sum(TT);
                        SpikesInf = [tnum SpikesNum 0 length(TT) 1];
                        SpikesData = (find(TT==1))';
                        EyeMotionLength = 1;
                        EyeTimeInterval= 0;
                        HorEyeInterval = 0 ;
                        VerEyeInterval = 0;
                        StimVelocity = 999;
                        StimTilt = 999;
                        
                        cvec = [SpikesInf SpikesData EyeMotionLength EyeTimeInterval HorEyeInterval VerEyeInterval StimVelocity StimTilt];
                        fwrite(fid,cvec,'float');
                        cvec = [];   
                        tnum = tnum + 1;
                end;
                fclose(fid);
        end
        if in2,       
                unitret('spikes',NAME);
        end
        
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'convert_txt_spike_files'))
        % takes many TXT spike files and converts them to spk files
        
        num = in1;
        
        [filename, pathname] = uigetfile('*.txt', ['Convert ',num2str(num),'TXT Train...'], .4, .4);
        if filename == 0, return; end;
        FullName = [pathname,filename];
        NAME = filename;
        [fid,message] = fopen(FullName,'rt');
        if fid<0, 
                error(message);
        end;    
        
        com = ['cd ' pathname(1:length(pathname)-1)]; 
        eval(com);
        
        T = fscanf(fid,'%d');
        unitret('convert_train_to_spike_file',T,0,num);
        
        
        unitret('convert_txt_spike_files',num+1)
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'convert_txt_multi_spike_file'))
        % takes TXT spike file with many trains (each column - one train) and converts them to spk files
        [filename, pathname] = uigetfile('*.txt', ['Convert TXT Trains...'], .4, .4);
        if filename == 0, return; end;
        FullName = [pathname,filename];
        NAME = filename;
        [fid,message] = fopen(FullName,'rt');
        if fid<0, 
                error(message);
        end;    
        
        com = ['cd ' pathname(1:length(pathname)-1)]; 
        eval(com);
        
        eval(['load ',NAME,'-ascii']);
        eval(['T = ',NAME(1:length(NAME)-4),';'])
        
        
        unitret('convert_train_to_spike_file',T,0,1);
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'convert_txt_multi_spike_times_file'))
        % Prepare DDE form Excel
        % 
        bc =[0.5529    0.8118    0.8941];
        EXCEL_NAME = 'sheet1';
        range = 'r1c1:r_c10';
        
        Fig = figure('Backingstore','on','Color',bc,...
                'Units','Normalized','Position',[0.3 0.4 .4 .2],'Resize','Off', 'Name',...
                'SELECT EXCEL SHEET','MenuBar','none','Number','off');
        
        uicontrol(Fig,'Style','text','Position',[.07 .45 .3 .15],...
                'Units','normal','ForegroundColor','b',...
                'BackgroundColor',[0.7529    0.7529    0.7529],'String','Get data from:',...
                'HorizontalAlignment','center');
        
        uicontrol(Fig,'Style','frame','Position',[.05 .13 .65 .6],...
                'Units','normalized','BackgroundColor',[0.7529    0.7529    0.7529],...
                'ForegroundColor','k');
        
        u1 = uicontrol(Fig,'Style','edit','Position',[.35 .5 .3 .1],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String',EXCEL_NAME,...
                'HorizontalAlignment','left','Callback','global EXCEL_NAME; ');
        
        u2 = uicontrol(Fig,'Style','edit','Position',[.35 .2 .3 .1],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0.5020  0 0.5020],'String',range,...
                'HorizontalAlignment','left','Callback','global range; ');
        
        
        OK_button=uicontrol(Fig,'Style','pushbutton','Position',[.75 .7 .22 .22],'Userdata',u1, ...
                'Units','Normalized','String','OK');
        set(Fig,'Userdata',[u1 u2]);
        set(OK_button,'Callback',['u = get(gcf,''Userdata''); global EXCEL_NAME range; EXCEL_NAME = get(u(1),''String''); range = get(u(2),''String''); delete(',num2str(Fig), '),unitret(''get_from_excel'',EXCEL_NAME,range);']);
        
        cancel=uicontrol(Fig,'Style','pushbutton','Position',[.75 .4 .22 .22],...
                'Units','Normalized','String','Cancel','Callback',['delete(',num2str(Fig), '), return']);
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'get_from_excel'))
        % spike arrival times from excel sheet (each column - one train) and converts them to spk files
        
        global EXCEL_NAME range;
        
        channel = ddeinit('excel',EXCEL_NAME);
        
        SAT = ddereq(channel,range);
        
        rc = ddeterm(channel);
        
        % Convert SAT to 0,1 matrix
        
        SegLen = ceil( max(max(SAT))/10 )*10; 
        SegNum = size(SAT,2);
        
        T = zeros(SegLen,SegNum);
        
        for i = 1:SegNum,
                ind = find(SAT(:,i)>0);
                T(SAT(ind,i),i) = ones(size(ind));
        end
        
        unitret('convert_train_to_spike_file',T,1,1);
        
        
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'about Unitret'))
        % About Unitret
        Fig = figure('Backingstore','on','Color',[ 0.6137    0.6961    0.6725],...
                'Units','Normalized','Position',[0.1 0.1 .8 .8],'Resize','Off', 'Name',...
                'About Unitret','MenuBar','none','Number','off'); 

	about_unitret_string = help('unitret');
	ind = findstr(about_unitret_string,'#');

	about_unitret_string = [about_unitret_string(ind+1:end) about_unitret_string(1:ind)];
        u = uicontrol(gcf,'Style','edit','FontName','Fixedsys','Units','Normalized','Position',[0.05 0.2 0.9 0.75],'Max',2,...
		'String',about_unitret_string,'HorizontalAlignment','left');
        
        close=uicontrol(Fig,'Style','pushbutton','Units','Normalized','Position',[.45 .05 .1 .05],...
                'String','Close','Callback',['delete(',num2str(Fig), '), return']);

	
        uicontrol('Style','text','Units','Normalized','Position',[0.05 0.13 0.8 0.05],'String',...
		'Scroll down for more info (click in text window and press "PageDown" or "Down Arrow")',...
		'HorizontalAlignment','left','BackgroundColor',[ 0.6137    0.6961    0.6725],'ForegroundColor',[0 0.502 0.502]);
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'setup_EM'))
        
        
        Fig1 = figure('Backingstore','off','Name','EM Setup','Color','w',...
                'Units','Normal','Position',[.22 .1 .7 .8],'Resize','on', 'Menubar','none','Number','off');
        set(gcf,'Pointer','Watch');
        
        uicontrol(Fig1,'Style','text','Position',[.2 .91 .5 .08],...
                'Units','normal','ForegroundColor','m',...
                'BackgroundColor','w','String','Saccade detection:',...
                'HorizontalAlignment','center');

	uicontrol(Fig1,'Style','text','Position',[.75 .28 .15 .05],...
                'Units','normal','ForegroundColor','k',...
                'BackgroundColor','w','String','Blink interval (ms)',...
                'HorizontalAlignment','left');
 
	uicontrol(Fig1,'Style','edit','Position',[.75 .25 .05 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(170)),...
                'HorizontalAlignment','left','Callback','unitret(''update'',170,0,1);');

	uicontrol(Fig1,'Style','radiobutton','Position',[.85 .25 .26 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Blink detector', 'HorizontalAlignment','left',...
                'value',DefValues(169),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(169) = val; set(0,''userdata'',ud);']);

       	uicontrol(Fig1,'Style','radiobutton','Position',[.85 .2 .26 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','SEM detector', 'HorizontalAlignment','left',...
                'value',DefValues(156),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(156) = val; set(0,''userdata'',ud);']);

        uicontrol(Fig1,'Style','radiobutton','Position',[.85 .15 .26 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Take Drifts', 'HorizontalAlignment','left',...
                'value',DefValues(145),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(145) = val; set(0,''userdata'',ud);']);
        
        uicontrol(Fig1,'Style','radiobutton','Position',[.85 .1 .26 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Sac. detector', 'HorizontalAlignment','left',...
                'value',DefValues(40),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(40) = val; set(0,''userdata'',ud);']);
        
        uicontrol(Fig1,'Style','text','Position',[.02 .85 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Fast EM Thr. (deg/s): from','HorizontalAlignment','left');
        %---------SaccadesThresholdLowerLim	
        u1 = uicontrol(Fig1,'Style','edit','Position',[.5 .85 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(93)),...
                'HorizontalAlignment','left','Callback','unitret(''update'',93,0,1);');
        %---------SaccadesThresholdUpperLim
        u1 = uicontrol(Fig1,'Style','edit','Position',[.6 .85 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(102)),...
                'HorizontalAlignment','left','Callback','unitret(''update'',102,0,1);');
        
        %---------
        uicontrol(Fig1,'Style','text','Position',[.02 .80 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Stable fixation Thr. (deg/s)','HorizontalAlignment','left');
        
        u1 = uicontrol(Fig1,'Style','edit','Position',[.5 .80 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(90)),...
                'HorizontalAlignment','left','Callback','unitret(''update'',90,0,1);');
        %---------
        uicontrol(Fig1,'Style','text','Position',[.02 .75 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Stable before (ms)','HorizontalAlignment','left');
        
        u1 = uicontrol(Fig1,'Style','edit','Position',[.5 .75 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(91)),...
                'HorizontalAlignment','left','Callback','unitret(''update'',91,0,1);');
        %---------
        uicontrol(Fig1,'Style','text','Position',[.02 .70 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Stable after (ms)','HorizontalAlignment','left');
        
        u1 = uicontrol(Fig1,'Style','edit','Position',[.5 .70 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(92)),...
                'HorizontalAlignment','left','Callback','unitret(''update'',92,0,1);');
        
        %---------
        uicontrol(Fig1,'Style','text','Position',[.02 .65 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','No Overlap before (ms)','HorizontalAlignment','left');
        
        u1 = uicontrol(Fig1,'Style','edit','Position',[.5 .65 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(133)),...
                'HorizontalAlignment','left','Callback','unitret(''update'',133,0,1);');
        %---------
        uicontrol(Fig1,'Style','text','Position',[.02 .60 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','No Overlap after (ms)','HorizontalAlignment','left');
        
        u1 = uicontrol(Fig1,'Style','edit','Position',[.5 .60 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(134)),...
                'HorizontalAlignment','left','Callback','unitret(''update'',134,0,1);');

	%---------
        uicontrol(Fig1,'Style','text','Position',[.02 .50 .15 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Sem Interval (ms)','HorizontalAlignment','left');
        
        u1 = uicontrol(Fig1,'Style','edit','Position',[.2 .50 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(157)),...
                'HorizontalAlignment','left','Callback','unitret(''update'',157,0,1);');

	%---------
        uicontrol(Fig1,'Style','text','Position',[.35 .50 .15 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Sem Threshold','HorizontalAlignment','left');
        
        u1 = uicontrol(Fig1,'Style','edit','Position',[.50 .50 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(158)),...
                'HorizontalAlignment','left','Callback','unitret(''update'',158,0,1);');
        
        %---------
        uicontrol(Fig1,'Style','text','Position',[.02 .4 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Sigma','HorizontalAlignment','left');
        
        if DefValues(94)
                enable = 'on';
        else
                enable = 'off';
        end
        
        u1 = uicontrol(Fig1,'Style','edit','Position',[.2 .4 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(25)),...
                'HorizontalAlignment','left','enable',enable,'Callback','unitret(''update'',25,0,1);');
        
        u2 = uicontrol(Fig1,'Style','checkbox','Position',[.05 .45 .26 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0    0.2824    0.4157],'String','Smoothing', 'HorizontalAlignment','left',...
                'value',DefValues(94),'callback',...
                [' u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        ' u1Hndl = get(gco,''Userdata''); if val, set(u1Hndl,''enable'',''on''); else set(u1Hndl,''enable'',''off''); end;',...
                        'ud=get(0,''UserData''); ud(94) = val; set(0,''userdata'',ud);']);
        
        set(u2,'Userdata',u1);
        
        %--------- Interpolation of EM
        uicontrol(Fig1,'Style','text','Position',[.02 .3 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','I. Rate (Hz)','HorizontalAlignment','left');
        
        if DefValues(95),
                enable = 'on';
        else
                enable = 'off';
        end
        
        u3 = uicontrol(Fig1,'Style','edit','Position',[.2 .3 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(96)),...
                'HorizontalAlignment','left','enable',enable,'Callback','unitret(''update'',96,0,1);');
        
        u4 = uicontrol(Fig1,'Style','checkbox','Position',[.05 .35 .26 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0    0.2824    0.4157],'String','Interpolation', 'HorizontalAlignment','left',...
                'value',DefValues(95),'callback',...
                [' u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        ' u3Hndl = get(gco,''Userdata''); if val, set(u3Hndl,''enable'',''on''); else set(u3Hndl,''enable'',''off''); end;',...
                        'ud=get(0,''UserData''); ud(95) = val; set(0,''userdata'',ud);']);
        
        set(u4,'Userdata',u3);
        
        %------------ Disp. Velocity Gain
        
        u5 = uicontrol(Fig1,'Style','radiobutton','Position',[.70 .35 .26 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Display Vel. | Gain', 'HorizontalAlignment','left',...
                'value',DefValues(97),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'u6Hndl = get(gco,''Userdata''); if val, set(u6Hndl,''enable'',''on''); else set(u6Hndl,''enable'',''off''); end;',...  
                        'ud=get(0,''UserData''); ud(97) = val; set(0,''userdata'',ud);']);
        
        
        
        if DefValues(97)
                enable = 'on';
        else
                enable = 'off';
        end
        
        u6 = uicontrol(Fig1,'Style','edit','Position',[.85 .35 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(98)),...
                'HorizontalAlignment','left','enable',enable,'Callback','unitret(''update'',98,0,1);');
        
        set(u5,'Userdata',u6);
        
        %-----------Saccades Window
        u7 = uicontrol(Fig1,'Style','checkbox','Position',[.05 .05 .4 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0    0.2824    0.4157],'String','Sac. Window: before', 'HorizontalAlignment','left',...
                'value',DefValues(99),'callback',...
                [' u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'uu = get(gco,''Userdata''); if val, set(uu,''enable'',''on''); else set(uu,''enable'',''off''); end;',...  
                        'ud=get(0,''UserData''); ud(99) = val; set(0,''userdata'',ud);']);
        
        if DefValues(99)
                enable = 'on';
        else
                enable = 'off';
        end
        
        u8 = uicontrol(Fig1,'Style','edit','Position',[.3 .05 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(100)),...
                'HorizontalAlignment','left','enable',enable,'Callback','unitret(''update'',100,0,1);');
        
        uicontrol(Fig1,'Style','text','Position',[.41 .05 .5 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0    0.2824    0.4157],'String','after','HorizontalAlignment','left');
        
        u9 = uicontrol(Fig1,'Style','edit','Position',[.45 .05 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','b','String',num2str(DefValues(101)),...
                'HorizontalAlignment','left','enable',enable,'Callback','unitret(''update'',101,0,1);');
        
        set(u7,'Userdata',[u8 u9]);
        
        %-----------Saccades Sort
        u10 = uicontrol(Fig1,'Style','radiobutton','Position',[.85 .05 .15 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor','k','String','Sac. Sort', 'HorizontalAlignment','left',...
                'value',DefValues(103),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'uu = get(gco,''Userdata''); if val, set(uu,''enable'',''on''); else set(uu,''enable'',''off''); end;',...
                        'ud=get(0,''UserData''); ud(103) = val; set(0,''userdata'',ud);']);
        
        set(u10,'Userdata',[u8 u9]);
        
        %-----------Saccades Select Sorted 
        u11 = uicontrol(Fig1,'Style','radiobutton','Position',[.6 .05 .07 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0.3765 0.5490 0.7255],'String','b. >', 'HorizontalAlignment','left',...
                'value',DefValues(129),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'uu = get(gco,''Userdata''); if val, set(uu(1:3),''enable'',''on''); else set(uu,''enable'',''off''); end;',...
                        'ud=get(0,''UserData''); ud(129) = val; set(0,''userdata'',ud);']);
        
        u12 = uicontrol(Fig1,'Style','radiobutton','Position',[.675 .05 .07 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0.3765 0.5490 0.7255],'String','a. >', 'HorizontalAlignment','left',...
                'value',DefValues(130),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'uu = get(gco,''Userdata''); if val, set(uu(1:3),''enable'',''on''); else set(uu,''enable'',''off''); end;',...
                        'ud=get(0,''UserData''); ud(130) = val; set(0,''userdata'',ud);']);
        
        u13 = uicontrol(Fig1,'Style','radiobutton','Position',[.75 .05 .07 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0.3765 0.5490 0.7255],'String','equ.', 'HorizontalAlignment','left',...
                'value',DefValues(131),'callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'uu = get(gco,''Userdata''); if val, set(uu(1:3),''enable'',''on''); else set(uu,''enable'',''off''); end;',...
                        'ud=get(0,''UserData''); ud(131) = val; set(0,''userdata'',ud);']);
        
        set([u11 u12 u13],'Userdata',[u8 u9 u7]);
        
        
        %-----------EnhanceGrayImage
        
        uicontrol(Fig1,'Style','edit','Position',[.85 .45 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[1    0    0.3961],'String',num2str(DefValues(118)),...
                'HorizontalAlignment','left','enable','on','Callback','unitret(''update'',118,0,1);');
        
        uicontrol(Fig1,'Style','text','Position',[.7 .43 .15 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0    0.2510    0.5020],'String','Image Enhance','HorizontalAlignment','left');
        
        %-----------SaccadeImpactDelay
        
        uicontrol(Fig1,'Style','edit','Position',[.85 .55 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[1    0    0.3961],'String',num2str(DefValues(74)),...
                'HorizontalAlignment','left','enable','on','Callback','unitret(''update'',74,0,1);');
        
        uicontrol(Fig1,'Style','text','Position',[.7 .53 .15 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0    0.2510    0.5020],'String','Delay','HorizontalAlignment','left');
        
        
        %-----------EM Postion Window (-/+)
        
        uicontrol(Fig1,'Style','edit','Position',[.2 .11 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0.6    0.2863    0.3961],'String',num2str(DefValues(119)),...
                'HorizontalAlignment','left','enable','on','Callback','unitret(''update'',119,0,1);');
        
        uicontrol(Fig1,'Style','edit','Position',[.3 .11 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0.6    0.2863    0.3961],'String',num2str(DefValues(120)),...
                'HorizontalAlignment','left','enable','on','Callback','unitret(''update'',120,0,1);');
        
        uicontrol(Fig1,'Style','text','Position',[.05 .1 .15 .07],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0    0.2510    0.5020],'String','Position Window','HorizontalAlignment','left');
        
        %-----------Saccade Amplitude Window
        
        uicontrol(Fig1,'Style','edit','Position',[.6 .11 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0.6    0.2863    0.3961],'String',num2str(DefValues(122)),...
                'HorizontalAlignment','left','enable','on','Callback','unitret(''update'',122,0,1);');
        
        uicontrol(Fig1,'Style','edit','Position',[.7 .11 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0.6    0.2863    0.3961],'String',num2str(DefValues(121)),...
                'HorizontalAlignment','left','enable','on','Callback','unitret(''update'',121,0,1);');
        
        uicontrol(Fig1,'Style','text','Position',[.45 .1 .15 .07],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0    0.2510    0.5020],'String','Amp. Window','HorizontalAlignment','left');
        
        
        %-----------EM Direction 
        % Right
        uicontrol(Fig1,'Style','edit','Position',[.2 .17 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0.6    0.2863    0.3961],'String',num2str(DefValues(139)),...
                'HorizontalAlignment','left','enable','on','Callback','unitret(''update'',139,0,1);');
        % Left
        uicontrol(Fig1,'Style','edit','Position',[.3 .17 .10 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0.6    0.2863    0.3961],'String',num2str(DefValues(140)),...
                'HorizontalAlignment','left','enable','on','Callback','unitret(''update'',140,0,1);');
        
        uicontrol(Fig1,'Style','text','Position',[.05 .17 .15 .05],...
                'Units','normalized','BackgroundColor','w',...
                'ForegroundColor',[0    0.2510    0.5020],'String','Em dir range','HorizontalAlignment','left');
        
        %-----------Image Mode
        u = uicontrol(Fig1,'Style','Popupmenu','Units','Normalized','Position',[.5 .45 .15 .05],...
                'String','image|patch','Value',DefValues(128),'Callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(128) = val; set(0,''userdata'',ud);']);
        
        
       
        %-----------Fixation Window
        u = uicontrol(Fig1,'Style','Popupmenu','Units','Normalized','Position',[.5 .2 .15 .05],...
                'String','reject trial|take before|take within|take all','Value',DefValues(144),'Callback',...
                ['u=get(gcf,''CurrentObject''); val = get(u,''value'');',...
                        'ud=get(0,''UserData''); ud(144) = val; set(0,''userdata'',ud);']);
        %-----------------------
        OK_button=uicontrol(Fig1,'Style','pushbutton','Position',[.75 .83 .22 .12],...
                'Units','Normalized','String','OK','Callback',['delete(',num2str(Fig1), '); ',...
                        'drawnow;watchoff; unitret(''update'',0,2);']);
        
        cancel=uicontrol(Fig1,'Style','pushbutton','Position',[.75 .65 .22 .12],...
                'Units','Normalized','String','Cancel','Callback',['delete(',num2str(Fig1), '), return']);
        
        
        set(gcf,'Pointer','Arrow');
        set(TRET_DAT(1),'Pointer','Arrow');
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'interpolate'))    	
        CSR = 10; % Hz - current sampling rate 
        ISR = DefValues(96);     
        EyeTimeAxis = in1(1,:); % Time axis in ms
        HorizEyePos = in1(2,:);
        VertEyePos  = in1(3,:);
        
        NewTimeAxis = EyeTimeAxis(1):1000/ISR:EyeTimeAxis(length(EyeTimeAxis));
        IH = interp1(EyeTimeAxis,HorizEyePos,NewTimeAxis,'spline');
        IV = interp1(EyeTimeAxis,VertEyePos,NewTimeAxis,'spline');
        
        out1 = [NewTimeAxis;IH';IV'];
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'add_stimulus_on_rc'))
        % Add Stimulus on previous graph
        PH = DefValues(72); % Handler to previous plot
        set(0,'CurrentFigure',PH); hold on
        
        
        
        
        % Get RF and Stimulus Parameters from DefValues
        
        % Assign parameters to in1, in2, in3 as in add_em_plot
        in1 = DefValues(105:109); % BPBS, BRBS, X, Y, Tilt
        in2 = [DefValues(110) DefValues(71) DefValues(70) DefValues(77) DefValues(76)]; % ExtentMotion, RFInc border, RFInc size, ...
        in3 = DefValues(111:115); % SPBS, SRBS, X, Y, Tilt
        
        
        Xshift = DefValues(116);
        Yshift = DefValues(117);
        
        if any(get(gca,'view')~=[0 90]), % 3D
                SPerpenBoxSize = in3(1);
                SRadialBoxSize = in3(2);
                SXStartPos = in3(3)+Xshift-DefValues(80)/2; % -DefValues(80)/2 since Shifts are calculated for image: (0,0) is (50,50)
                SYStartPos = in3(4)+Yshift-DefValues(81)/2;
                STilt = 2*pi*in3(5)/360;
                
                
                % Calculate bar axis coordinates
                xa1 = SXStartPos+SRadialBoxSize/2*cos(STilt); 
                ya1 = SYStartPos+SRadialBoxSize/2*sin(STilt);
                
                xa2 = SXStartPos-SRadialBoxSize/2*cos(STilt);
                ya2 = SYStartPos-SRadialBoxSize/2*sin(STilt);
                
                %line([xa1 xa2], [ya1 ya2], [0 0], 'Color',[0 0.4078 0],'LineStyle','--','ButtonDownFcn','unitret(''assign_center'',gca);'), hold on
                
                % Take into account width of the stimulus
                veradd = SPerpenBoxSize/2*cos(STilt); 
                horadd = SPerpenBoxSize/2*sin(STilt); 
                
                x1 = xa2 - horadd;
                x4 = xa2 + horadd;
                x2 = xa1 - horadd;
                x3 = xa1 + horadd;
                
                y1 = ya2 + veradd;
                y4 = ya2 - veradd;
                y2 = ya1 + veradd;
                y3 = ya1 - veradd;
                
                line([x1 x2 x3 x4 x1 ],[y1 y2 y3 y4 y1],[0 0 0 0 0],'Color',[0 0.2588 0],'ButtonDownFcn','unitret(''assign_center'',gca);'), hold on
                
                
                
        else % 2D (plane) plot
                % Plot Sine/Flash/Static
                
                SPerpenBoxSize = in3(1);
                SRadialBoxSize = in3(2);
                SXStartPos = in3(3)+Xshift;
                SYStartPos = in3(4)+Yshift;
                STilt = 2*pi*in3(5)/360;
                
                
                % Calculate bar axis coordinates
                xa1 = SXStartPos+SRadialBoxSize/2*cos(STilt); 
                ya1 = SYStartPos+SRadialBoxSize/2*sin(STilt);
                
                xa2 = SXStartPos-SRadialBoxSize/2*cos(STilt);
                ya2 = SYStartPos-SRadialBoxSize/2*sin(STilt);
                
                %line([xa1 xa2], [ya1 ya2], 'Color',[0 0.4078 0],'LineStyle','--','ButtonDownFcn','unitret(''assign_center'',gca);'), hold on
                
                % Take into account width of the stimulus
                veradd = SPerpenBoxSize/2*cos(STilt); 
                horadd = SPerpenBoxSize/2*sin(STilt); 
                
                x1 = xa2 - horadd;
                x4 = xa2 + horadd;
                x2 = xa1 - horadd;
                x3 = xa1 + horadd;
                
                y1 = ya2 + veradd;
                y4 = ya2 - veradd;
                y2 = ya1 + veradd;
                y3 = ya1 - veradd;
                
                line([x1 x2 x3 x4 x1 ],[y1 y2 y3 y4 y1],'Color',[0 0.2588 0],'ButtonDownFcn','unitret(''assign_center'',gca);'), hold on
                
                Xlim = get(gca,'Xlim');
                Ylim = get(gca,'Ylim');
                
                %      set(gca,'XLim',[Xlim(1) Xlim(2)+SXStartPos],'YLim',[Ylim(1) Ylim(2)+SYStartPos]);
                unitret('update_ticklabels');
                
        end % of if 2D/3D      
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'add_stimuli_on_rc'))
        % Add Stimulus and RF on previous graph
        PH = DefValues(72); % Handler to previous plot
        set(0,'CurrentFigure',PH); hold on
        % Get RF and Stimulus Parameters from DefValues
        
        % Assign parameters to in1, in2, in3 as in add_em_plot
        in1 = DefValues(105:109); % BPBS, BRBS, X, Y, Tilt
        in2 = [DefValues(110) DefValues(71) DefValues(70) DefValues(77) DefValues(76)]; % ExtentMotion, RFInc border, RFInc size, ...
        in3 = DefValues(111:115); % SPBS, SRBS, X, Y, Tilt
        
        
        Xshift = DefValues(116);
        Yshift = DefValues(117);
        
        % DRAW:
        PerpenBoxSize = in1(1);
        RadialBoxSize = in1(2);
        XStartPos = in1(3) + Xshift;
        YStartPos = in1(4) + Yshift;
        Tilt = 2*pi*in1(5)/360;
        
        % Calculate bar axis coordinates
        xa1 = XStartPos+RadialBoxSize/2*cos(Tilt); 
        ya1 = YStartPos+RadialBoxSize/2*sin(Tilt);
        
        xa2 = XStartPos-RadialBoxSize/2*cos(Tilt);
        ya2 = YStartPos-RadialBoxSize/2*sin(Tilt);
        
        line([xa1 xa2], [ya1 ya2],'LineStyle','--','Color',[0 0.2510 0.5020]), hold on
        
        % Take into account width of the bar
        veradd = PerpenBoxSize/2*cos(Tilt); 
        horadd = PerpenBoxSize/2*sin(Tilt); 
        
        x1 = xa2 - horadd;
        x4 = xa2 + horadd;
        x2 = xa1 - horadd;
        x3 = xa1 + horadd;
        
        y1 = ya2 + veradd;
        y4 = ya2 - veradd;
        y2 = ya1 + veradd;
        y3 = ya1 - veradd;
        
        line([x1 x2 x3 x4 x1 ],[y1 y2 y3 y4 y1],'LineWidth',2,'Color',[0 0.2510 0.5020]), hold on
        
        %axis([0 200 0 200])
        
        % Plot Sweep
        SweepExtent = in2(1);
        
        alpha  = (pi - Tilt);
        
        xes = XStartPos - SweepExtent*sin(alpha); %(x end sweep)
        yes = YStartPos - SweepExtent*cos(alpha);
        
        line([XStartPos xes],[YStartPos yes],'Color',[ 0    0.5020    0.7529],'ButtonDownFcn','unitret(''assign_center'',gca);'), hold on
        h = plot(xes + (XStartPos - xes)/2, yes + (YStartPos - yes)/2,'rx');, hold on
        set(h,'ButtonDownFcn','unitret(''assign_center'',gca);');
        
        % plot RF INC limits
        leftlimI = in2(2); % from end of sweep
        rfsizeI  = in2(3);
        rigthlimI = leftlimI+rfsizeI;
        
        % Left border
        xlr=xes+(SweepExtent - leftlimI)*sin(alpha);
        ylr=yes+(SweepExtent - leftlimI)*cos(alpha);
        
        
        xl1 = xlr+RadialBoxSize/2*cos(Tilt); 
        yl1 = ylr+RadialBoxSize/2*sin(Tilt);
        
        xl2 = xlr-RadialBoxSize/2*cos(Tilt);
        yl2 = ylr-RadialBoxSize/2*sin(Tilt);
        
        line([xl1 xl2], [yl1 yl2], 'LineWidth',2,'Color','m'), hold on
        
        % Rigth border
        xrr=xes+(SweepExtent - rigthlimI)*sin(alpha);
        yrr=yes+(SweepExtent - rigthlimI)*cos(alpha);
        
        
        xr1 = xrr+RadialBoxSize/2*cos(Tilt); 
        yr1 = yrr+RadialBoxSize/2*sin(Tilt);
        
        xr2 = xrr-RadialBoxSize/2*cos(Tilt);
        yr2 = yrr-RadialBoxSize/2*sin(Tilt);
        
        line([xr1 xr2], [yr1 yr2], 'LineWidth',2,'Color','m'), hold on
        
        % plot RF DEC limits
        leftlimD = in2(4); % from end of sweep
        rfsizeD  = in2(5);
        rigthlimD = leftlimD+rfsizeD;
        
        % Left border
        xlr=xes+(SweepExtent - leftlimD)*sin(alpha);
        ylr=yes+(SweepExtent - leftlimD)*cos(alpha);
        
        
        xl1 = xlr+RadialBoxSize/2*cos(Tilt); 
        yl1 = ylr+RadialBoxSize/2*sin(Tilt);
        
        xl2 = xlr-RadialBoxSize/2*cos(Tilt);
        yl2 = ylr-RadialBoxSize/2*sin(Tilt);
        
        line([xl1 xl2], [yl1 yl2], 'LineWidth',2,'Color','k'), hold on
        
        % Rigth border
        xrr=xes+(SweepExtent - rigthlimD)*sin(alpha);
        yrr=yes+(SweepExtent - rigthlimD)*cos(alpha);
        
        
        xr1 = xrr+RadialBoxSize/2*cos(Tilt); 
        yr1 = yrr+RadialBoxSize/2*sin(Tilt);
        
        xr2 = xrr-RadialBoxSize/2*cos(Tilt);
        yr2 = yrr-RadialBoxSize/2*sin(Tilt);
        
        line([xr1 xr2], [yr1 yr2], 'LineWidth',2,'Color','k'), hold on
        
        
        % Plot Sine/Flash/Static
        
        SPerpenBoxSize = in3(1);
        SRadialBoxSize = in3(2);
        SXStartPos = in3(3)+Xshift;
        SYStartPos = in3(4)+Yshift;
        STilt = 2*pi*in3(5)/360;
        
        
        % Calculate bar axis coordinates
        xa1 = SXStartPos+SRadialBoxSize/2*cos(STilt); 
        ya1 = SYStartPos+SRadialBoxSize/2*sin(STilt);
        
        xa2 = SXStartPos-SRadialBoxSize/2*cos(STilt);
        ya2 = SYStartPos-SRadialBoxSize/2*sin(STilt);
        
        line([xa1 xa2], [ya1 ya2], 'Color',[0 0.4078 0],'LineStyle','--','ButtonDownFcn','unitret(''assign_center'',gca);'), hold on
        
        % Take into account width of the stimulus
        veradd = SPerpenBoxSize/2*cos(STilt); 
        horadd = SPerpenBoxSize/2*sin(STilt); 
        
        x1 = xa2 - horadd;
        x4 = xa2 + horadd;
        x2 = xa1 - horadd;
        x3 = xa1 + horadd;
        
        y1 = ya2 + veradd;
        y4 = ya2 - veradd;
        y2 = ya1 + veradd;
        y3 = ya1 - veradd;
        
        line([x1 x2 x3 x4 x1 ],[y1 y2 y3 y4 y1],'Color',[0 0.4078 0],'ButtonDownFcn','unitret(''assign_center'',gca);'), hold on
        
        Xlim = get(gca,'Xlim');
        Ylim = get(gca,'Ylim');
        
        set(gca,'XLim',[Xlim(1) Xlim(2)+XStartPos],'YLim',[Ylim(1) Ylim(2)+YStartPos]);
        unitret('update_ticklabels');
        
        %  set(gca,'ButtonDownFcn','unitret(''assign_center'',gca);');
        
        %------------------------------------------------------------------------
elseif strcmp(action,'assign_center');
        AX_HAND(1) = in1;
        if size(get(AX_HAND(1),'Userdata'),1) == 2,
                return % Only 2 points can be selected
        end
        
        set(gcf,'CurrentAxes',AX_HAND(1));
        PresPnt=get(AX_HAND(1),'CurrentPoint');
        limx = get(AX_HAND(1),'XLim');
        limy = get(AX_HAND(1),'YLim');
        x=PresPnt(1,1);
        y=PresPnt(1,2);
        if ((x >= limx(1)) & (y >= limy(1)) & (x <= limx(2)) &(y <= limy(2)))
                line('Xdata',x,'YData',y,'Linestyle','o','Color','c','markersize',4,'erasemode','background');
                ud = get(AX_HAND(1),'UserData');        
                set(AX_HAND(1),'UserData',[ud;x y]);
        end;     
        
        if size(get(AX_HAND(1),'Userdata'),1) == 2,
                % Update Shift fields
                x1 = ud(1,1);
                y1 = ud(1,2);
                Xshift = x1 - x;
                Yshift = y1 - y;
                ud = get(0,'Userdata');
                ud(116) = Xshift;
                ud(117) = Yshift;
                set(0,'Userdata',ud);
                unitret('add_stimuli_on_rc');
        end
        
        
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'image2patch'))
        X = in1;
        map = in2;
        mode = in3;
        
        [R,C] = find(X>0);
        h = [];
        if mode == 1, % On plane
                for i=1:length(R),
                        % hh = fill([C(i) C(i)+1 C(i)+1 C(i) C(i)],[R(i) R(i) R(i)+1 R(i)+1 R(i)], X(R(i),C(i)));
                        x1 = C(i)-0.5;
                        x2 = C(i)+0.5;
                        y1 = R(i)-0.5;
                        y2 = R(i)+0.5;
                        
                        hh = fill([x1 x2 x2 x1],[y1 y1 y2 y2], X(R(i),C(i)));
                        hold on
                        h = [h; hh]; 
                end
                axis([0 size(X,2) 0 size(X,1)])	
                axis('square')
                
                colormap(map)
                curax = gca;
                
                % Create colorbar
                nc = size(map,1);
                hcb = axes('Position',[0.92 0.2 0.03 0.7],'box','on','XTick',[],'Xlim',[0 1],'YLim',[0 nc],'YTick',[0:1:nc]);
                x1 = 0; x2 = 1;
                y1 = 0:nc-1;
                y2 = 1:nc;
                for i=1:nc,
                        fill([x1 x2 x2 x1],[y1(i) y1(i) y2(i) y2(i)], map(i,:)); hold on
                end 
                set(hcb,'box','on','XTick',[],'Xlim',[0 1],'YLim',[0 nc],'YTick',[0:1:nc]);
                
                set(gcf,'CurrentAxes',curax)
        elseif mode == 2, % On 2D (3D actually) plot
                for i=1:length(R),
                        Hc=DefValues(80)/2;
                        Vc=DefValues(81)/2;
                        
                        x1 = C(i)-0.5;
                        x2 = C(i)+0.5;
                        y1 = R(i)-0.5;
                        y2 = R(i)+0.5;
                        
                        hh = fill3([x1 x2 x2 x1]-Hc,[y1 y1 y2 y2]-Vc,[0 0 0 0], X(R(i),C(i)));
                        hold on
                        h = [h; hh];
                end 
                axis([0-Hc size(X,2)-Hc 0-Vc size(X,1)-Vc])		
                colormap(map)
        end % of if mode...
        
        set(h,'EdgeColor','none');
        
        
        out1 = h;

        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'process_exp_records'))
        % Batch processing of experimental records, selected by multiple file selection dialog
        
        global EM_STRUCTURE EM_STRUCTURE_ONE_FILE
        EM_STRUCTURE = [];
        
        if  (size(TRET_DAT,2) > 1 ),    % second member exists (pointer on graph figure)
                if strcmp(get(TRET_DAT(2),'Type'),'figure'),
                        delete(TRET_DAT(2));
                        TRET_DAT = TRET_DAT(1);
                end;
        end;    
        
	inipath = pwd;
	
	IsDir = 0;
	Prompt = 'Please, choose experimental data folder';
	while ~IsDir,
        	cell_direxp = inputdlg(Prompt, 'Enter name of the folder', 1, {'C:\Monk'});
        	if isempty(cell_direxp), return; end;
        	direxp=char(cell_direxp);
		Prompt = 'Folder do not exist! Please, type again!';
		IsDir = exist(direxp,'dir');
	end
        eval(['cd ',direxp]) % Change to data directory 

	% Get experimental records list
	d = dir('*.a??');
	str = {d.name};
	[inds,OK] = listdlg('PromtString','Select Experimental Records','SelectionMode','multiple','ListString',str);  
	if ~OK,	return;	end      

	LIST = char(str(inds)');
	
	IsDir = 0;
	Prompt ='Please, choose existing folder to save generated files';
	while ~IsDir,
        	cell_dir2save = inputdlg(Prompt, 'Enter name of the folder', 1, {inipath});
        	if isempty(cell_dir2save), return; end;
        	dir2save = char(cell_dir2save);
        	Prompt = 'Folder do not exist! Please, type again!';
		IsDir = exist(dir2save,'dir');
	end

        
        NumFilesInList = size(LIST,1);
        
        set(0,'CurrentFigure',TRET_DAT(1));
        text(0.1,0.2,[num2str(0),' of ',num2str(NumFilesInList)],'FontSize',16)
        

        ud = get(0,'Userdata');
        ud(141) = 1;
        set(0,'Userdata',ud);

        for k=1:NumFilesInList,
                
                unitret('process_exp',LIST(k,:),dir2save,[k NumFilesInList])
                if isempty(EM_STRUCTURE),
                        EM_STRUCTURE = [EM_STRUCTURE_ONE_FILE];
                elseif ~isempty(EM_STRUCTURE_ONE_FILE),
                        EM_STRUCTURE = [EM_STRUCTURE EM_STRUCTURE_ONE_FILE];
                end
        end % of for LIST
        
        if DefValues(135),
                eval(['cd ',dir2save])
                eval(['save ',filename(1:length(filename)-3),'ems EM_STRUCTURE DefValues']); % save EM data to .ems mat file with the list name 
        end
        
        ud(141) = 0;
        set(0,'Userdata',ud);
        eval(['cd ', inipath]);
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'process_exp_records_from_list'))
        % Batch processing of experimental records
        
        
        global EM_STRUCTURE EM_STRUCTURE_ONE_FILE
        EM_STRUCTURE = [];
        
        if  (size(TRET_DAT,2) > 1 ),    % second member exists (pointer on graph figure)
                if strcmp(get(TRET_DAT(2),'Type'),'figure'),
                        delete(TRET_DAT(2));
                        TRET_DAT = TRET_DAT(1);
                end;
        end;    
        
        % Get file names list (.lst - txt file - names in column)
        [filename, pathname] = uigetfile('*.lst', ['Please, choose file names list'], .4, .4);
        if filename == 0, return; end;
        
        
        FullName = [pathname,filename];
        fid=fopen(FullName,'rt');
        eval(['cd ', pathname]);
        LIST = [];
        
        while 1
                name = fgetl(fid);
                if ~isstr(name), break, end
                LIST = [LIST; name];
        end
        
        fclose(fid);

        cell_direxp = inputdlg('Please, choose experimental data folder', 'Enter name of the folder', 1, {'E:\Monk\98'});
        if isempty(cell_direxp), return; end;
        struct_direxp = cell2struct(cell_direxp,'dirname',1);
        direxp = struct_direxp.dirname;
        eval(['cd ',direxp]) % Change to data directory        
        
        cell_dir2save = inputdlg('Please, choose existing folder to save spike files', 'Enter name of the folder', 1, {pathname});
        if isempty(cell_dir2save), return; end;
        struct_dir2save = cell2struct(cell_dir2save,'dirname',1);
        dir2save = struct_dir2save.dirname;
        

        
        NumFilesInList = size(LIST,1);
        
        set(0,'CurrentFigure',TRET_DAT(1));
        text(0.1,0.2,[num2str(0),' of ',num2str(NumFilesInList)],'FontSize',16)

        ud = get(0,'Userdata');
        ud(141) = 1;
        set(0,'Userdata',ud);
        
        for k=1:NumFilesInList,
                
                unitret('process_exp',LIST(k,:),dir2save,[k NumFilesInList])
                if isempty(EM_STRUCTURE),
                        EM_STRUCTURE = [EM_STRUCTURE_ONE_FILE];
                elseif ~isempty(EM_STRUCTURE_ONE_FILE),
                        EM_STRUCTURE = [EM_STRUCTURE EM_STRUCTURE_ONE_FILE];
                end
        end % of for LIST
        
        if DefValues(135),
                eval(['cd ',dir2save])
                eval(['save ',filename(1:length(filename)-3),'ems EM_STRUCTURE DefValues']); % save EM data to .ems mat file with the list name 
        end
                
	ud(141) = 0;
        set(0,'Userdata',ud);
        eval(['cd ', pathname]);

       %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'process_exp_records_from_list_trials'))
        % Batch processing of experimental records
        
        
        global EM_STRUCTURE EM_STRUCTURE_ONE_FILE
        EM_STRUCTURE = [];
        
        if  (size(TRET_DAT,2) > 1 ),    % second member exists (pointer on graph figure)
                if strcmp(get(TRET_DAT(2),'Type'),'figure'),
                        delete(TRET_DAT(2));
                        TRET_DAT = TRET_DAT(1);
                end;
        end;    
        
        % Get file names list (.lst - txt file - names in column)
        [filename, pathname] = uigetfile('*.lst', ['Please, choose file names list'], .4, .4);
        if filename == 0, return; end;
        
        
        FullName = [pathname,filename];
        fid=fopen(FullName,'rt');
        eval(['cd ', pathname]);
        LIST = [];
        
	k = 1;
        while 1
                str = fgetl(fid);
                if ~isstr(str), break, end
		namelen = findstr(str,'|') - 2;
                LIST = [LIST; str(1:namelen)];
		if isempty(findstr(str((namelen+3):length(str)),':')),
			TRIALS2TAKE(k).trials = sscanf(str((namelen+3):length(str)),' %d');
		else
			trialstr = sscanf(str((namelen+3):length(str)),' %s');
			eval(['TRIALS2TAKE(k).trials = ',trialstr,';'])
		end
		k = k + 1;
        end
        
        fclose(fid);

        cell_direxp = inputdlg('Please, choose experimental data folder', 'Enter name of the folder', 1, {'C:\Monk\98\anal\'});
        if isempty(cell_direxp), return; end;
        struct_direxp = cell2struct(cell_direxp,'dirname',1);
        direxp = struct_direxp.dirname;
        cd(direxp);	 % Change to data directory      
  
        cell_dir2save = inputdlg('Please, choose existing folder to save spike files', 'Enter name of the folder', 1, {pathname});
        if isempty(cell_dir2save), return; end;
        struct_dir2save = cell2struct(cell_dir2save,'dirname',1);
        dir2save = struct_dir2save.dirname;
        

        
        NumFilesInList = size(LIST,1);
        
        set(0,'CurrentFigure',TRET_DAT(1));
        text(0.1,0.2,[num2str(0),' of ',num2str(NumFilesInList)],'FontSize',16);

        ud = get(0,'Userdata');
        ud(141) = 1;
        set(0,'Userdata',ud);
	
        for k=1:NumFilesInList,
                unitret('process_exp_trials',LIST(k,:),dir2save,[k NumFilesInList])
                if isempty(EM_STRUCTURE),
                        EM_STRUCTURE = [EM_STRUCTURE_ONE_FILE];
                elseif ~isempty(EM_STRUCTURE_ONE_FILE),
                        EM_STRUCTURE = [EM_STRUCTURE EM_STRUCTURE_ONE_FILE];
                end
        end % of for LIST
        
        if DefValues(135),
                eval(['cd ',dir2save])
                eval(['save ',filename(1:length(filename)-3),'ems EM_STRUCTURE DefValues']); % save EM data to .ems mat file with the list name 
        end
	ud(141) = 0;
        set(0,'Userdata',ud);        
        eval(['cd ', pathname]);
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'process_exp'))
        % Process one experimental record and save spike file
        
        NAME = in1;
        dir2save = in2;
        currdir = pwd;
        DefValues(73) = 1;
        TrialsPerFig = 3;
        set(0,'Userdata',DefValues);
        unitret('read_header',NAME,1);
        
        set(0,'CurrentFigure',TRET_DAT(1));
        text(0.1,0.2,[num2str(in3(1)),' of ',num2str(in3(2))],'FontSize',16)
        trial_inf  = get(TRET_DAT(1),'UserData');
        TrialsNum = trial_inf(2);
        if TrialsNum <= TrialsPerFig,
                set(0,'CurrentFigure',TRET_DAT(2))
                TrialsPerFig = TrialsNum;
        end
        
        for i = TrialsPerFig+1:TrialsPerFig:TrialsNum,
                unitret('redraw_exp',i);
        end 
        if DefValues(138),
                % eval(['cd ',dir2save])
		SAVE_DIR = dir2save;
		switch DefValues(174) % save format
		case 1
                	unitret('save',1);
		case 2
			unitret('save',34,'no dialog'); 
		case 3 
			unitret('save',35,'no dialog'); 
		end
                eval(['cd ',currdir])
        end
          
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'process_exp_trials'))
        % Process one experimental record and save spike file
        
        NAME = in1;
        dir2save = in2;
	k = in3(1);
        currdir = pwd;
	trials2take = TRIALS2TAKE(k).trials;
        DefValues(73) = trials2take(1);
	DefValues(4) = 1;
        TrialsPerFig = 1;
        set(0,'Userdata',DefValues);
        unitret('read_header',NAME,1);
        
        set(0,'CurrentFigure',TRET_DAT(1));
        text(0.1,0.2,[num2str(in3(1)),' of ',num2str(in3(2))],'FontSize',16)
        trial_inf  = get(TRET_DAT(1),'UserData');
        TrialsNum = trial_inf(2);
        if TrialsNum <= TrialsPerFig,
                set(0,'CurrentFigure',TRET_DAT(2))
                TrialsPerFig = TrialsNum;
        end
        
        for i = 2:length(trials2take),
                unitret('redraw_exp',trials2take(i));
        end 
        if DefValues(138),
               	% eval(['cd ',dir2save])
		SAVE_DIR = dir2save;
		switch DefValues(174) % save format
		case 1
                	unitret('save',1);
		case 2
			unitret('save',34,'no dialog'); 
		case 3 
			unitret('save',35,'no dialog'); 
		end
                eval(['cd ',currdir])
        end
        
       
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'convert_any_list_to_exp_list'))
        % Short Description:
        % Takes file list, converts it  to
        % filename.a?? form, finds appropriate 
        % files and outputs their names
        
        % Get file names list (.lst - txt file - names in column)
        [filename, pathname] = uigetfile('*.lst', ['Please, choose file names list'], .4, .4);
        if filename == 0, return; end;
        
        
        FullName = [pathname,filename];
        fid=fopen(FullName,'rt');
        eval(['cd ', pathname]);
        LIST = [];
        
        cell_direxp = inputdlg('Please, choose experimental data folder', 'Enter name of the folder', 1, {'C:\Monk\'});
        if isempty(cell_direxp), return; end;
        struct_direxp = cell2struct(cell_direxp,'dirname',1);
        direxp = struct_direxp.dirname;
        eval(['cd ',direxp]) % Change to data directory
        
        while 1
                name = fgetl(fid);
                if ~isstr(name), break, end
                LIST = [LIST; name];
        end
        
        fclose(fid);
        
        NumFilesInList = size(LIST,1);
        exp_name_list = [];
        
        if exist('templst.lst')
                delete('templst.lst');
        end
        
        diary('templst.lst')
        for k=1:NumFilesInList,
                LIST(k,10:12) = 'a**';
                eval(['dir ' LIST(k,:)])
                %exp_name_list = [exp_name_list; exp_name];
        end
        diary off
        
        
        
        fid=fopen('templst.lst','rt');
        while 1
                name = fgetl(fid);
                if ~isstr(name), break, end
                if ~isempty(name)
                        exp_name_list = [exp_name_list; name(1:12)];
                end
        end
        fclose(fid)
        
        delete('templst.lst');
        
        unique(exp_name_list,'rows')
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'set_file_wildcard'))
        
        
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'build_Fig2_menu'))
        Fig2 = in1;
        
        u1 = uimenu(Fig2,'label','&File');
        u1_1 = uimenu(u1,'Label','&Save','Callback','unitret(''save'',1);','enable','off' );
        u1_2 = uimenu(u1,'Label','Save &As...','Callback','unitret(''save'',2);');
        u1_3 = uimenu(u1,'Label','Return to &Experimental Record','Callback','unitret(''read_header'', get(min(get(0,''Children'')),''Name''), 1 )'); 
        
        u1_4 = uimenu(u1,'Label','&Save screen in HGL format As...','Callback','unitret(''save'',7);');
        u1_5 = uimenu(u1,'Label','&Copy to Clipboard as bitmap','Separator','on','Callback','print -dbitmap'); 
        u1_6 = uimenu(u1,'Label','C&opy to Clipboard as metafile','Separator','on','Callback','print -dmeta'); 
        
        u1_7 = uimenu(u1,'Label','Save Scatter &Data','Separator','on','Callback','unitret(''save'',3);','enable','off');
        u1_8 = uimenu(u1,'Label','Save Sca&tter Data As...','Callback','unitret(''save'',4);');
        u1_9 = uimenu(u1,'Label','Save &Quasy Stat. Int','Callback','unitret(''save'',6);','Enable','off');
        
        u1_10 = uimenu(u1,'Label','P&rint Setup...','Separator','on','Callback','print -dsetup;');     
        u1_11 = uimenu(u1,'Label','&Print','Callback','orient landscape; print;');
        u1_12 = uimenu(u1,'Label','E&xit','Separator','on','Callback','unitret(''exit'');');
        

	u2 = uimenu(Fig2,'Label','&Edit');
        u2_5 = uimenu(u2,'Label','&Edit Segments','Separator','off','Callback','unitret(''edit'',1)');
        u2_6 = uimenu(u2,'Label','E&nd Edit','Callback','unitret(''edit'',0)','enable','off');
        u2_7 = uimenu(u2,'Label','Edit &All according to input times','Separator','on','Callback','unitret(''edit'',2)');
        u2_8 = uimenu(u2,'Label','End Edit &All according to first','Separator','on','Callback','unitret(''edit'',4)');
        
        u2_9 = uimenu(u2,'Label','&Remove Segment','Separator','on','Callback','unitret(''remove_segment'',1)');
        u2_10 = uimenu(u2,'Label','&End Remove Segment','Callback','unitret(''remove_segment'',0)');
        
        u2_11 = uimenu(u2,'Label','&Display Concatenated','Separator','on','Callback','unitret(''display_concatenated'',1);');
        u2_12 = uimenu(u2,'Label','&Redraw Segments','Separator','off','Callback','unitret(''redraw_spk'',1);');
        u2_13 = uimenu(u2,'Label','&Display Averaged...','Separator','on','Callback','unitret(''display_averaged'',1);');


	
        u3 = uimenu(Fig2,'Label','&Setup');
        u3_1 = uimenu(u3,'Label','&Spike Setup','Callback','unitret(''setup_spk'')');
        u3_2 = uimenu(u3,'Label','S&pectra Setup','Callback','unitret(''spectra_setup'')');
	u3_3 = uimenu(u3,'Label','&Eye Spectra Setup','Callback','unitret(''eye_spectra_setup'')');
	u3_4 = uimenu(u3,'Label','&Analysis Setup','Callback','unitret(''analysis_setup'')');
	u3_5 = uimenu(u3,'Label','Auto &RF mapping Setup ','Callback','unitret(''setup_auto_rf_mapping'')');
	u3_6 = uimenu(u3,'Label','&Orientation Setup ','Callback','unitret(''setup_orientation'')');
	u3_7 = uimenu(u3,'Label','&Flash/Sac.-averaged TI Setup ','Callback','unitret(''setup_ti'')');
	

        
        u4 = uimenu(Fig2,'label','&Process');
        u4_1= uimenu(u4, 'Label','&Align Relatively to...');
        u4_2=uimenu(u4_1,'Label','Ma&ximum','Callback','process(''shift_maximum'');');
        u4_3=uimenu(u4_1,'Label','&Mean', 'Callback','process(''shift_mean'');');
        u4_4=uimenu(u4_1,'Label','&First spike', 'Callback','process(''align_first'');');
        
        u4_5=uimenu(u4,'Label','&Restore','Callback',...
                'process(''restore'');','Enable','off');
        u4_6=uimenu(u4,'Label','&Accumulation');
        
        u4_7=uimenu(u4_6,'Label','&Segments','Callback',...
                'process(''accumulation'');');
        u4_8=uimenu(u4_6,'Label','&Average','Callback',...
                'process(''accumulation'');');	
       
        set(u4_6,'UserData',[u4_7 u4_8]);
        
  
        u4_9=uimenu(u4,'Label','Spectrum of &eye record','Callback',...
                'process(''spectra'',15);','Separator','on');
        
        u4_10=uimenu(u4,'Label','Spe&ctrum of average','Callback',...
                'process(''spectra'',3);','Separator','on');
        u4_11=uimenu(u4,'Label','Spec&trum of autocorr','Callback',...
                'process(''spectra'',4);');
        u4_12=uimenu(u4,'Label','Spectrum of conca&tenated','Callback',...
                'process(''spectra'',5);');
        u4_13=uimenu(u4,'Label','Spectrum (&high resolution)','Callback',...
                'process(''spectra'',1);');
        u4_14=uimenu(u4,'Label','Spec&trum of raw','Callback',...
                'process(''spectra'',2);');
        
        u4_15=uimenu(u4,'Label','Harmonic Analysis on &PSTH','Callback',...
                'process(''spectra'',6);','Separator','on');
        u4_16=uimenu(u4,'Label','Harmonic Analysis on &Raw Conc.','Callback',...
                'process(''spectra'',7);');
        u4_17=uimenu(u4,'Label','&Full Harmonic Analysis','Callback',...
                'process(''spectra'',14);');
        
        u4_18=uimenu(u4,'Label','Harmonic Analysis on &Averaged','Callback',...
                'process(''spectra'',8);','Separator','on');
        u4_19=uimenu(u4,'Label','&Low Resolution Spectrum of Averaged','Callback',...
                'process(''spectra'',9);');	 
        u4_20=uimenu(u4,'Label','H&igh Resolution Spectrum of Averaged','Callback',...
                'process(''spectra'',10);');
        u4_21=uimenu(u4,'Label','"&Hochstein"','Callback',...
                'process(''spectra'',11);','Separator','on','enable','off');
        
        u4_22=uimenu(u4,'Label','Harmonic Analysis per segm. - average','Callback',...
                'process(''spectra'',12);','Separator','on');
        u4_23=uimenu(u4,'Label','Harmonic Analysis per segm. - no averaging','Callback',...
                'process(''spectra'',13);','Separator','off');	   	
        
        u4_24=uimenu(u4,'Label','&X-correlogram','Callback',...
                'process(''correlogram'');','Separator','on');
        
        u4_25=uimenu(u4,'Label','&Orientation tuning curve','Callback',...
                ['process(''ori_tuning'',''',NAME,''');']);
        
        u4_26=uimenu(u4,'Label','&SF Tuning curve','Callback',...
                ['process(''SF_tuning'',''',NAME,''');']);
        
        u4_27=uimenu(u4,'Label','&OI setup','Callback',...
                ['process(''OI_setup'',''',NAME,''');']);
        
        u4_28=uimenu(u4,'Label','Se&gments Statistics','Callback',...
                ['process(''Segments_Statistics'',''',NAME,''');']);
        
        u4_29=uimenu(u4,'Label','Raster','Callback',...
                ['process(''raster'',''',NAME,''',1);']);
        

         
        
        %%% current last uimenu of Process: 55	
        
        u5 = uimenu(Fig2,'Label','&Tools');
        
        % u63 = uimenu(u6, 'Label','&RF Stimulus Scheme','Callback','unitret(''rf_stim_scheme'',0);','Separator','on');
        % u64 = uimenu(u6, 'Label','&RF Stimulus on Display','Callback','unitret(''rf_stim_display'',0);');
        u5_1 = uimenu(u5, 'Label','&3D Eye Movement Plot','Callback','unitret(''eye_mov_plot'',0);','Separator','off');
        u5_2 = uimenu(u5, 'Label','&2D Eye Movement Plot','Callback','unitret(''eye_mov_plot'',1);');
        u5_3 = uimenu(u5, 'Label','Eye Movement - Spikes R&C','Callback','unitret(''eye_mov_spikes_rc'',0);');
        u5_4 = uimenu(u5, 'Label','Eye Movement - Spikes RC (&hist)','Callback','unitret(''eye_mov_spikes_rc'',1);');
        u5_5 = uimenu(u5, 'Label','Eye Movement Velocity','Callback','unitret(''eye_mov_velocity'',1);');
        u5_6 = uimenu(u5, 'Label','Add EM &plot','Callback','unitret(''add_em_plot'',1);');
        
        
        u6 = uimenu(Fig2,'Label','&Window');
        u6_1 = uimenu(u6, 'Label','Copy Previous Window to Clipboard as &bitmap','Callback','ud = get(0,''Userdata''); set(0,''CurrentFigure'',ud(72)); print -dbitmap');
        u6_2 = uimenu(u6, 'Label','Copy Previous Window to Clipboard as &metafile','Callback','ud = get(0,''Userdata''); set(0,''CurrentFigure'',ud(72)); print -dmeta');
        u6_3 = uimenu(u6, 'Label','&Print Previous Window','Callback','ud = get(0,''Userdata''); set(0,''CurrentFigure'',ud(72)); print -dwin;');
        u6_4 = uimenu(u6, 'Label','&Save in HGL format','Callback','ud = get(0,''Userdata''); set(0,''CurrentFigure'',ud(72)); process(''save_hgl'');');
        u6_5 = uimenu(u6, 'Label','&Save in *.m format','Callback','ud = get(0,''Userdata''); set(0,''CurrentFigure'',ud(72)); process(''save_m'');');
             
        
        TRET_DAT(2:9) = [Fig2 u1_1 u2_5 u2_6 u4_5 u4_6 u1_7 u1_9];
        % set(TRET_DAT(2),'UserData',Spk);
        
        if (strcmp(in2,'show_spikes'));
                % Change Show_Return_Menu to Return (to previous experimental record)
                set(Show_Return_Menu, 'Label', 'Return to Experimental Record', 'Callback', 'unitret(''read_header'', get(gcf, ''Name''), 1 )');
        end
        
        %--------------------------------------------------------------------------------------------------------------        
elseif(strcmp(action,'peak_firing_rate')),
        DefValues(147) = 1;		% split to cycles    
        DefValues(155) = 1;		% apply hist
        prevDefValues(1)=DefValues(1);
        DefValues(1) = 20;		% apply bin
        DefValues(20) = DefValues(1);
        
        set(0,'Userdata',DefValues);		    
        unitret('show_spikes');
        
        
        % return spike bin to initial status
        DefValues(1)=prevDefValues(1);
        set(0,'Userdata',DefValues);		    
        
        % return back to experimental record
        % unitret('read_header', get(min(get(0,'Children')),'Name'), 1 );
        %--------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'grand_handle')),
        name = in1;
        data = in2;
        
        if sum(GRAND_HANDLE) == 0,
                % Initialize displays
                
                GRAND_HANDLE(1) = uicontrol(TRET_DAT(1),'Style','edit','Units','normalized','Position',[.1 .2 .8 .1],...
                        'BackgroundColor','w','ForegroundColor','b','String',num2str(data,2),'HorizontalAlignment','left');
                
                GRAND_HANDLE(2) = uicontrol(TRET_DAT(1),'Style','text','String',[name],'units','normalized',...
                        'Position',[.2 .3 .5 .04],'ForegroundColor',[0.5020 0 0.2510], 'BackgroundColor',[ 0.8157    0.8039    0.7255]);
                
        else 
                % Displays already exist
                
                set(GRAND_HANDLE(1),'string',num2str(data,2));
                set(GRAND_HANDLE(2),'string',[name]);	
        end
        
	if DefValues(160)	% fill clipboard
		excelclipcopy(data,0);	
	end
		
        
        %-----------------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'read_ini')),
        out1 = load(in1);
        
        
        
        %-----------------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'write_ini')),
        inifid = fopen(in1,'w');
        for i=1:length(DefValues),
                fprintf(inifid,'%d\n',DefValues(i));
        end
        fclose(inifid);

	%-----------------------------------------------------------------------------------------------------------------------        
elseif(strcmp(action,'generate_list' )),
	if in1 == 0

		[filename, pathname] = uiputfile('*.lst', 'Save list as');
	 	if filename == 0, return; end;               
	        FullName = [pathname,filename];
	        fid=fopen(FullName,'w');
	        eval(['cd ', pathname]);
		Fig1 = figure('Backingstore','off','Name','Generate list...','Color','w',...
	                'Units','Normal','Position',[.3 .2 .5 .5],'Resize','on', 'Menubar','none','Number','off');

              
	        %---------
	        uicontrol(Fig1,'Style','text','Position',[.02 .80 .5 .05],...
	                'Units','normalized','BackgroundColor','w',...
	                'ForegroundColor','k','String','pattern','HorizontalAlignment','left');
        
	        u1 = uicontrol(Fig1,'Style','edit','Position',[.2 .80 .50 .05],...
	                'Units','normalized','BackgroundColor','w',...
	                'ForegroundColor','b','String','*.*',...
	                'HorizontalAlignment','left');        
        
	
		set(Fig1,'Userdata',[u1 fid]);

		ok_callback = ['unitret(''generate_list'',1,gcf)']; 

	        %---------------------     
	        OK_button=uicontrol(Fig1,'Style','pushbutton','Position',[.75 .9 .22 .06],...
	                'Units','Normalized','String','OK','Callback',ok_callback);
        
	        cancel=uicontrol(Fig1,'Style','pushbutton','Position',[.75 .82 .22 .06],...
	                'Units','Normalized','String','Cancel','Callback',['fclose(''all''); delete ',filename,'; delete(',num2str(Fig1), '), return']);   
	else
		Fig1 = in2;
		Fig1ud = get(Fig1,'Userdata');
		u1 = 	Fig1ud(1);
		fid = 	Fig1ud(2);
		pattern = get(u1,'String');

		d = dir(pattern);
		
		if 0
		for i = 1:size(d,1)
			if (~d(i).isdir) & ( strcmp(extension,'.*') | strcmp(d(i).name(length(d(i).name)-3:length(d(i).name)),extension) )...
			& ~strcmp(d(i).name(length(d(i).name)-3:length(d(i).name)),'.lst')
				fprintf(fid,'%s\n',d(i).name);
			end
		end
		end
		for i = 1:size(d,1)
			fprintf(fid,'%s\n',d(i).name);
		end
		
		
		fclose(fid);
		delete(Fig1);

	end   
	%-----------------------------------------------------------------------------------------------------------------------        
elseif(strcmp(action,'batch_conver' )),
		[logfilename, logpathname] = uiputfile('bconver.log', 'Save log as');
	 	if logfilename == 0, return; end;               
	        LogFullName = [logpathname,logfilename];
		cd(logpathname);
		fid=fopen(LogFullName,'w');
		% d = dir('*.etd');
		d = dir('*.f32'); 
		fprintf(fid,'%s\n\n',['Convertion new->old format initiated on ',datestr(now)]);
		hw = waitbar(0,'Batch converting, please wait...');
		disp('Batch converting, please wait...');
		nfiles = size(d,1);
		for i = 1:nfiles
			waitbar(i/nfiles);
			fprintf(fid,'%s\t',d(i).name);
			status = conver('start',d(i).name);
			fprintf(fid,'%s\n',status);
			
		end
		disp('DONE.');

		delete(hw);
		fclose(fid);
		if 1
			!C:\Progra~1\Pfe\Pfe32.exe bconver.log
		end
	%-----------------------------------------------------------------------------------------------------------------------        
elseif(strcmp(action,'convert_all' )),
		[logfilename, logpathname] = uiputfile('bconver.log', 'Save log as');
	 	if logfilename == 0, return; end;               
	        LogFullName = [logpathname,logfilename];
		cd(logpathname);

		% remove e1
		d = dir('*.*');
		hw = waitbar(0,'Batch e1 remove, please wait...');
		disp('Batch e1 remove, please wait...');
		nfiles = size(d,1);
		for i = 1:nfiles
			waitbar(i/nfiles);		
			if ~isempty(findstr(d(i).name,'e1'))
				newname = [d(i).name(1:8) d(i).name(11:end)];
				eval(['!move ' d(i).name ' ' newname]);
				disp(['renamed file ' d(i).name ' to ' newname])
			end
		end

		disp('DONE.');
		delete(hw);

		% rename *.f32
		d = dir('*.f32');
		hw = waitbar(0,'Batch renaming, please wait...');
		disp('Batch renaming, please wait...');
		nfiles = size(d,1);
		for i = 1:nfiles
			waitbar(i/nfiles);
			newname = [d(i).name(1:8) '.f32'];
			if exist([pathname '\' newname])
				eval(['!move ' newname ' ' newname(1:4) '1' newname(6:length(newname))]);
				disp(['renamed file ' newname ' to ' newname(1:4) '1' newname(6:length(newname))])
				newname(5) = '2';
			end
			eval(['!move ' d(i).name ' ' newname]);
			disp(['renamed file ' d(i).name ' to ' newname])
		end

		disp('DONE.');
		delete(hw);


		% batch convert
		fid=fopen(LogFullName,'w');

		d = dir('*.f32'); 
		fprintf(fid,'%s\n\n',['Convertion new->old format initiated on ',datestr(now)]);
		hw = waitbar(0,'Batch converting, please wait...');
		disp('Batch converting, please wait...');
		nfiles = size(d,1);
		for i = 1:nfiles
			waitbar(i/nfiles);
			fprintf(fid,'%s\t',d(i).name);
			status = conver('start',d(i).name);
			fprintf(fid,'%s\n',status);
			
		end
		disp('DONE.');

		delete(hw);
		fclose(fid);
		if 1
			!C:\Progra~1\Pfe\Pfe32.exe bconver.log
		end
        %--------------------------------------------------------------------------------------------------------------
	
elseif(strcmp(action,'process_spike_records_from_list'))
        % Batch processing of experimental spike records
               
        
        if  (size(TRET_DAT,2) > 1 ),    % second member exists (pointer on graph figure)
                if strcmp(get(TRET_DAT(2),'Type'),'figure'),
                        delete(TRET_DAT(2));
                        TRET_DAT = TRET_DAT(1);
                end;
        end;    
        
        % Get file names list (.lst - txt file - names in column)
        [filename, pathname] = uigetfile('*.lst', ['Please, choose file names list'], .4, .4);
        if filename == 0, return; end;
        
        
        FullName = [pathname,filename];
        fid=fopen(FullName,'rt');
        eval(['cd ', pathname]);
      
        k=1;
        while 1
                name = fgetl(fid);
                if ~isstr(name), break, end
                LIST(k).name = name;
		k = k+1;
        end
        
        fclose(fid);
	NumFilesInList = size(LIST,2);

	curdir = pwd;
        cell_dirspk = inputdlg('Please, choose spike records data folder', 'Enter name of the folder', 1, {curdir});
        if isempty(cell_dirspk), return; end;
        struct_dirspk = cell2struct(cell_dirspk,'dirname',1);
        dirspk = struct_dirspk.dirname;
        eval(['cd ',dirspk]) % Change to data directory        

	if 0
        cell_dir2save = inputdlg('Please, choose existing folder to save spike files', 'Enter name of the folder', 1, {pathname});
        if isempty(cell_dir2save), return; end;
        struct_dir2save = cell2struct(cell_dir2save,'dirname',1);
        dir2save = struct_dir2save.dirname;
	end

        % load base_maxmod.dat -ascii
	% load base_maxres.dat -ascii
        
        
        set(0,'CurrentFigure',TRET_DAT(1));
        ht = text(0.1,0.2,[num2str(0),' of ',num2str(NumFilesInList)],'FontSize',16);

        ud = get(0,'Userdata');
        ud(141) = 1;
        set(0,'Userdata',ud);
	
        disp(['Processing spike records batch...'])
        for k=1:NumFilesInList,               
                unitret('spikes',LIST(k).name);
		% here comes the processing part, implement this
		% later as dynamically linked script
		ud(54) = abs(base_maxres(k))/1000;
		set(0,'UserData',ud);
		out1 = process('spectra',7);	% raw concatenated
		str = sprintf('%.2f',out1.rm);
		if ~isempty(findstr(LIST(k).name,'auto'))
			out1 = process('spectra',12); % per segment
			str = [sprintf('%d\t %.2f\t',round(out1.phase),out1.rm),str];
		end
		disp(str);
		unitret('close_all_graphic_windows');
		set(ht,'String',[num2str(k),' of ',num2str(NumFilesInList)])
        end % of for LIST
        
        
        eval(['cd ', pathname]);

	ud(141) = 0;
        set(0,'Userdata',ud);
	%-----------------------------------------------------------------------------------------------------------------------
	
elseif(strcmp(action,'process_spk'))
        % Process one spike record and save spike file
        
        NAME = in1;
        dir2save = in2;
        currdir = pwd;
        DefValues(73) = 1;
        TrialsPerFig = 3;
        set(0,'Userdata',DefValues);
        unitret('read_header',NAME,1);
        
        set(0,'CurrentFigure',TRET_DAT(1));
        text(0.1,0.2,[num2str(in3(1)),' of ',num2str(in3(2))],'FontSize',16)
        trial_inf  = get(TRET_DAT(1),'UserData');
        TrialsNum = trial_inf(2);
        if TrialsNum <= TrialsPerFig,
                set(0,'CurrentFigure',TRET_DAT(2))
                TrialsPerFig = TrialsNum;
        end
        
        for i = TrialsPerFig+1:TrialsPerFig:TrialsNum,
                unitret('redraw_exp',i);
	end
	%-----------------------------------------------------------------------------------------------------------------------
	
elseif(strcmp(action,'transform_list'))
        % Short Description:
        % Takes file list and transforms it to a new list according
	% to specified format
        
        % Get file names list (.lst - txt file - names in column)
        [filename, pathname] = uigetfile('*.lst', ['Please, choose file names list'], .4, .4);
        if filename == 0, return; end;
                
        FullName = [pathname,filename];
        fid=fopen(FullName,'rt');
        eval(['cd ', pathname]);
        NEWLIST = [];

	[newfilename,newpathname]= uiputfile('*.lst', ['Please, choose new file names list'], .4, .4);
	if newfilename == 0, return; end;

	newlist = [newpathname, newfilename];
	newfid = fopen(newlist,'wt');
	
        cell_dividertoken = inputdlg('Please, enter divider token', 'Copy old name up to ...', 1, {'.spi'});
        if isempty(cell_dividertoken), return; end;
        struct_dividertoken = cell2struct(cell_dividertoken,'divtoken',1);
        dividertoken = struct_dividertoken.divtoken;

	cell_newtoken = inputdlg('Please, enter the new token', 'Add to name ...', 1, {''});
        if isempty(cell_newtoken), return; end;
        struct_newtoken = cell2struct(cell_newtoken,'newtoken',1);
        newtoken = struct_newtoken.newtoken;

        
        while 1
                name = fgetl(fid);
                if ~isstr(name), break, end
		temptoken = newtoken;
		if ~isempty(findstr(name,'.cl1'))
			newtoken = ['.cell1' newtoken];
		end
		if ~isempty(findstr(name,'.cl2'))
			newtoken = ['.cell2' newtoken];
		end
		up2idx = findstr(name,dividertoken) - 1; % up to index
		newname = [name(1:up2idx) newtoken];
                fprintf(newfid,'%s\n',newname);
		newtoken = temptoken;
	end

        fclose(fid);
	fclose(newfid);
	%--------------------------------------------------------------------------------------------------------------	
elseif(strcmp(action,'rename_f32'))  
	% find all *.f32 files, remove -C*, rename if MU
	[filename, pathname] = uiputfile('temp.log', 'Change to desired directory');
 	if filename == 0, return; end;               
	cd(pathname);
	d = dir('*.f32');
	hw = waitbar(0,'Batch renaming, please wait...');
	disp('Batch renaming, please wait...');
	nfiles = size(d,1);
	for i = 1:nfiles
		waitbar(i/nfiles);
		newname = [d(i).name(1:8) '.f32'];
		if exist([pathname '\' newname])
			eval(['!move ' newname ' ' newname(1:4) '1' newname(6:length(newname))]);
			disp(['renamed file ' newname ' to ' newname(1:4) '1' newname(6:length(newname))])
			newname(5) = '2';
		end
		eval(['!move ' d(i).name ' ' newname]);
		disp(['renamed file ' d(i).name ' to ' newname])
	end
	      
     	disp('DONE.');
	delete(hw);
	%--------------------------------------------------------------------------------------------------------------	
elseif(strcmp(action,'remove_e1'))  
	% find all files, remove e1
	[filename, pathname] = uiputfile('temp.log', 'Change to desired directory');
 	if filename == 0, return; end;               
	cd(pathname);
	d = dir('*.*');
	hw = waitbar(0,'Batch e1 remove, please wait...');
	disp('Batch e1 remove, please wait...');
	nfiles = size(d,1);
	for i = 1:nfiles
		waitbar(i/nfiles);		
		if ~isempty(findstr(d(i).name,'e1'))
			newname = [d(i).name(1:8) d(i).name(11:14)];
			eval(['!move ' d(i).name ' ' newname]);
			disp(['renamed file ' d(i).name ' to ' newname])
		end
	end
	      
     	disp('DONE.');
	delete(hw);
        %--------------------------------------------------------------------------------------------------------------	

elseif(strcmp(action,'ttst2sid'))	
	tt = in1;
	st = in2;

	if tt==0 & st==0
		out1 = 1;
		out2 = 'static';		
	elseif tt==2 & st==0
		out1 = 2;
		out2 = 'flash';
	elseif (tt==1 & st==0) | (tt==3 & st==0)
		out1 = 3;
		out2 = 'sweep';
	elseif tt==3 & st==6
		out1 = 4;
		out2 = 'wsine';
	elseif tt==3 & st==10
		out1 = 5;
		out2 = 'csine-si';
	elseif tt==3 & st==7
		out1 = 6;
		out2 = 'csine-sq';
	elseif tt==3 & st==11
		out1 = 7;
		out2 = 'csine-ramp';
	elseif tt==3 & st==12
		out1 = 8;
		out2 = 'fwsine';
	elseif tt==3 & st==13
		out1 = 9;
		out2 = 'wsquare';
	elseif tt==1 & st==14
		out1 = 10;
		out2 = 'sqsweep';
	elseif tt==1 & st==8
		out1 = 11;
		out2 = 'ssine';
	else
		out1 = -1;
		out2 = 'unknown';
	end
        %--------------------------------------------------------------------------------------------------------------	

elseif(strcmp(action,'close_all_graphic_windows'))	
	h=sort(get(0,'Children'));
	% for h=t(3:length(t)),close(h);end;
	delete(h(3:length(h)));
	global figcounter;
	figcounter=3;

elseif(strcmp(action,'tile_all_graphic_windows'))	
	h=sort(get(0,'Children'));
	% for h=t(3:length(t)),close(h);end;
	tile_windows(h(3:length(h)));
        %--------------------------------------------------------------------------------------------------------------	

elseif(strcmp(action,'help_win'))
	  fig = figure( ...
         'Visible','on', ...
         'HandleVisibility','on', ...
         'MenuBar','none', ...
         'Name','UNITRET Help Window', ...
         'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'NumberTitle','off', ...
         'IntegerHandle','off', ...
         'Units','Normalized', ...
         'CreateFcn','', ...
         'Tag','HelpFigure');

	ListBox = uicontrol('Parent',fig, ...
         'BackgroundColor',[1 1 1], ...
         'CallBack','', ...
         'Max',2, ...
         'Units','Normalized', ...
         'Position',[0.05 0.15 0.9 0.8], ...
         'String',in1, ...
         'Style','listbox', ...
         'Tag','ListBox', ...
         'Value',[]);

 	uicontrol(fig,'Style','pushbutton','Units','Normalized','Position',[.4 .02 .2 .1],...
                'String','Close','Callback',['close(gcf), return']);
	%-----------------------------------------------------------------------------------------------------------------------
	
elseif(strcmp(action,'analysis_setup'))
	
	global STIM
	MarkedData = unitret('get_markeddata');

	if isempty(STIM)
		errordlg('No STIM data was saved for this file - exiting!','ERROR');
		return
	end

	mod = ' [both]';
	if DefValues(189)==3,
		MarkedData = MarkedData(find(MarkedData(:,5)==0),:);
		mod = ' [even]';
	elseif DefValues(189)==2
		mod = ' [odd]';
		MarkedData = MarkedData(find(MarkedData(:,5)==1),:);
	end

	

	if (~isempty(MarkedData)),
                
                row_num = size(MarkedData,1);
                if row_num < 1, % less than 1 segment, exit!
                        errordlg('No segments selected!','ERROR');
                        return;
                end
                for i=1:row_num,
			stim(i) = STIM(MarkedData(i,1));
		end
	else
		warndlg(['No data for ' mod ' . Exiting...'],'Warning');
		return;
	end

	infostr = [num2str(row_num) ' segments' mod ' | '  ];
	
	paramNames = fieldnames(stim);
	for i = 6:length(paramNames),

		% [X{1:length(stim)}]=eval(['deal(stim.',char(paramNames(i)),')']);
		% ^^^ should work, but does not work for large sets...???
		% if any(diff(cat(1,X{:}))),

		c = struct2cell(stim);
		if any(diff(cat(1,c{i,:,:})))
			paramNames{i}=['***' char(paramNames(i))];
		end
	end	

	bgcol = [0.752941176470588 0.752941176470588 0.752941176470588];

	h = findobj('Tag','Analysis Setup');
	if ~isempty(h);
		delete(h);
	end
			 
	h0 = figure('Backingstore','off','Name','Analysis Setup',...
		 'Resize','On', 'Menubar','none','Number','off',...
		'Color',bgcol, ...
		'InvertHardcopy','off', ...
		'NumberTitle','off', ...
		'PaperPosition',[18 180 576 432], ...
		'PaperUnits','points', ...
		'Position',[536 144 376 420], ...
		'Tag','Analysis Setup', ...
		'ToolBar','none');

	h1 = uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',bgcol, ...
		'FontWeight','demi', ...
		'HorizontalAlignment','left', ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.05 0.9 0.2 0.05], ...
		'String','measure', ...
		'Style','text', ...
		'Tag','StaticText1');
	h1 = uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',bgcol, ...
		'FontWeight','demi', ...
		'HorizontalAlignment','left', ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.4 0.9 0.2 0.05], ...
		'String','parameter', ...
		'Style','text', ...
		'Tag','StaticText1');

	measureNames = {'spike count' 'mean firing rate' 'RM' 'peak response' 'condition time'};
	hMeasure = uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',[1 1 1], ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.05 0.85 0.3 0.05], ...
		'String',measureNames, ...
		'Style','popupmenu', ...
		'Tag','PopupMenu1', ...
		'ToolTip','parameters that differ between segments are marked by ***',...
		'Value',DefValues(175));
	
	hParam = uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',[1 1 1], ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.4 0.85 0.3 0.05], ...
		'String',paramNames, ...
		'Style','popupmenu', ...
		'Tag','PopupMenu1', ...
		'Value',DefValues(176));

	hNormalize = uicontrol(h0,'Style','radiobutton',...
		'Units','normalized',...
		'Position',[.05 .7 .3 .05],...
                'BackgroundColor',bgcol,...
                'ForegroundColor','k','String','normalize', 'HorizontalAlignment','left',...
                'value',DefValues(177));

	hIndHisto = uicontrol(h0,'Style','radiobutton',...
		'Units','normalized',...
		'Position',[.4 .7 .3 .05],...
                'BackgroundColor',bgcol,...
                'ForegroundColor','k','String','ind. histograms', 'HorizontalAlignment','left',...
                'value',DefValues(194));

	h1 = uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',bgcol, ...
		'FontWeight','demi', ...
		'HorizontalAlignment','left', ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.4 0.55 0.4 0.05], ...
		'String','analysis figure options', ...
		'Style','text', ...
		'Tag','StaticText1');
		
	hFigOptions = uicontrol('Parent',h0, ...
		'Units','normalized', ...
		'BackgroundColor',[1 1 1], ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.4 0.5 0.4 0.05], ...
		'String',{'no analysis figure','open once and append','open new each time'}, ...
		'Style','popupmenu', ...
		'Tag','PopupMenu1', ...
		'Value',DefValues(178));

	hLogX = uicontrol(h0,'Style','radiobutton',...
		'Units','normalized',...
		'Position',[.4 .6 .3 .05],...
                'BackgroundColor',bgcol,...
                'ForegroundColor','k','String','log X scale', 'HorizontalAlignment','left',...
		'ToolTip','log X scale in analysis plot',...
                'value',DefValues(195));

	hSaveMat = uicontrol(h0,'Style','radiobutton',...
		'Units','normalized',...
		'Position',[.05 .6 .3 .05],...
                'BackgroundColor',bgcol,...
                'ForegroundColor','k','String','save to *.MAT', 'HorizontalAlignment','left',...
                'value',DefValues(179));

	hDisplay = uicontrol(h0,'Style','radiobutton',...
		'Units','normalized',...
		'Position',[.05 .5 .3 .05],...
                'BackgroundColor',bgcol,...
                'ForegroundColor','k','String','display printout', 'HorizontalAlignment','left',...
		'ToolTip','display printout in MATLAB command window',...
                'value',DefValues(180));
	
		
	hClose = uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',[0.501960784313725 0.501960784313725 0.752941176470588], ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.75 0.85 0.2 0.1], ...
		'String','Close', ...
		'Tag','Close');

	hAnalyze = uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',[0.501960784313725 0.501960784313725 0.752941176470588], ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.75 0.7 0.2 0.1], ...
		'String','Analyze', ...
		'Tag','Analyze');

	% infostr = [infostr char(STIM(1).Format) sprintf('\n') char(STIM(1).FileName) sprintf('\n') num2str(STIM(1).SID) sprintf('\n') char(STIM(1).StimulusName) sprintf('\n')];
	switch DefValues(184),
		case 1
			err_mode = '';
		case 2
			err_mode = ' | +/-STD';
		case 3
			err_mode = ' | +/-SEM';
	end
		
	infostr = [infostr char(STIM(1).Format) ' | ' char(STIM(1).FileName) ' | ' num2str(STIM(1).SID) ' - ' char(STIM(1).StimulusName) err_mode];
		   
	UD.hMeasure = hMeasure;
	UD.hParam = hParam;
	UD.hNormalize = hNormalize;
	UD.hFigOptions = hFigOptions;
	UD.hSaveMat = hSaveMat;
	UD.hDisplay = hDisplay;
	UD.hIndHisto = hIndHisto;
	UD.hLogX = hLogX;
		
	UD.MarkedData = MarkedData;
	UD.stim	= stim;
	UD.infostr = infostr;
	
	hAnalyzeCallBack1 = ['UD=get(gcf,''UserData''); hMeasure=UD.hMeasure; hParam=UD.hParam;',...
			     'hNormalize=UD.hNormalize; hFigOptions=UD.hFigOptions; hSaveMat=UD.hSaveMat; hDisplay=UD.hDisplay; hIndHisto=UD.hIndHisto; hLogX=UD.hLogX;',...
			     'ud=get(0,''UserData''); val=get([hMeasure hParam hNormalize hFigOptions hSaveMat hDisplay hIndHisto hLogX],''value'');',...
			     'ud([175:180 194 195])=cat(1,val{:}); set(0,''UserData'',ud);'];
	hAnalyzeCallBack2 = ['delete(gcf); unitret(''analyze_param_space'',UD.MarkedData,UD.stim,UD.infostr);'];

	set(gcf,'UserData',UD);,	     
	set(hAnalyze,'CallBack',[hAnalyzeCallBack1 hAnalyzeCallBack2]);
	set(hClose,'CallBack',[hAnalyzeCallBack1 'delete(gcf); return;']);
	
	h1 = uicontrol(h0,'Style','edit','Units','Normalized','Position',[0.05 0.05 0.90 0.3],'Max',2,...
		'String',infostr,'HorizontalAlignment','left');

	%-----------------------------------------------------------------------------------------------------------------------
		
elseif(strcmp(action,'analyze_param_space'))	
	MarkedData = in1;
	stim = in2;
	infostr = in3;

	measureNames = {'spike count' 'mean firing rate' 'harmonic amplitude' 'peak response' 'condition time'};
	measureNamesAbbr = {'count' 'mfr' 'rm'};
	
	measureAnalysis = DefValues(175);
	paramAnalysis = DefValues(176);
	
	row_num = size(MarkedData,1);

	paramNames = fieldnames(stim);
	%[param{1:row_num}]=eval(['deal(stim.',paramNames{paramAnalysis},')']);
	%param=cat(1,param{:});l
	c = struct2cell(stim);
	param=cat(1,c{paramAnalysis,:,:});
	
	uparam = unique(param);
	[sparam, sortedIdx] = sort(param);
	MarkedData = MarkedData(sortedIdx,:);
 

	if row_num < 1, % less than 1 segment, exit!
		errordlg('No segments selected!','ERROR');
		return;
	end

	pointIdx = 1;
	MarkedDataIdx1 = 1;
	MarkedDataIdx2 = 1;

	data2excel = [];
		      
	for i=1:row_num,
		if sparam(i)>uparam(pointIdx), % start new datapoint
			
			% fix for TempFreq -- harmonic content analysis
			if strcmp(paramNames{paramAnalysis},'TempFreq');
				DefValues(75)=uparam(pointIdx);
				set(0,'UserData',DefValues);
			end
			
			MarkedDataIdx2 = i-1;
			[measure(pointIdx,:) data2excel_datapoint hist_xy(pointIdx) measure_error(pointIdx)]=process('analyze',MarkedData(MarkedDataIdx1:MarkedDataIdx2,:));
			N(pointIdx) = size(MarkedData(MarkedDataIdx1:MarkedDataIdx2,:),1);
			data2excel = [data2excel; data2excel_datapoint];
			MarkedDataIdx1 = i;
			pointIdx = pointIdx + 1;
		end
		
	end
	
	% fix for TempFreq -- harmonic content analysis
	if strcmp(paramNames{paramAnalysis},'TempFreq');
		DefValues(75)=uparam(pointIdx);
		set(0,'UserData',DefValues);
	end
			
	MarkedDataIdx2 = row_num;
	[measure(pointIdx,:) data2excel_datapoint hist_xy(pointIdx) measure_error(pointIdx)]=process('analyze',MarkedData(MarkedDataIdx1:MarkedDataIdx2,:));
	N(pointIdx) = size(MarkedData(MarkedDataIdx1:MarkedDataIdx2,:),1);
	data2excel = [data2excel; data2excel_datapoint];
		      
	measure_error = cat(1,measure_error.err);

	if DefValues(160),		% fill clipboard
		excelclipcopy(data2excel,0);	
	end
	
	if DefValues(194),		% separate histograms
		hAnalysisFig = figure('Color',[1 1 1], 'Name', ['Analysis window: PSTH as function of ' paramNames{paramAnalysis}],...
				      'Tag','Analysis histograms window', 'Units','Normalized','Position',[0.1 0.5 0.8 0.3]);
		for i=1:pointIdx,
			hSubplot(i) = subplot(1,pointIdx,i);
			set(line,'Xdata',hist_xy(i).xx,'YData',hist_xy(i).yy,'Color','k');
			title([paramNames{paramAnalysis} ' ' num2str(uparam(i))],'FontSize',8);
			Ylim = get(gca,'Ylim');
			Ylims(i) = Ylim(2);
		end

		set(hSubplot,'Ylim',[0 max(Ylims)],'FontSize',8,'TickDir','out'); 
	end		
		      
	if DefValues(177),		% normalize max to 1
		measure = measure/norm(measure,inf);
		measure_std = measure_std/norm(measure,inf);
		normalizeOpt = '_norm';
	else
		normalizeOpt = '';
	end

	if DefValues(178) == 1		% do not open figure

	else

		if DefValues(178)==2	% append to existing figure
			hAnalysisFig = findobj('Tag','Analysis window');
			if length(hAnalysisFig) < 1
				warndlg('Can not append to figure: no analysis window is open.','Warning');
				return;
			elseif length(hAnalysisFig) > 1
				warndlg('Can not append to figure: more than one analysis window is open.','Warning');
				return;
			else
				UD = get(hAnalysisFig,'UserData');
				if (UD.paramAnalysis ~= paramAnalysis | UD.measureAnalysis ~= measureAnalysis)
					errordlg('Can not append to figure: different parameter/meausure selected.','Warning');
					return;
				else
					set(0,'CurrentFigure',hAnalysisFig);
					set(hAnalysisFig,'CurrentAxes',UD.hAxes);
					hold on;
					MarkerIndex = UD.MarkerIndex + 1;
					if MarkerIndex > 12,
						MarkerIndex = 1;
						warndlg('Can not append more than 12 plots to figure.','Warning');
						return;
					end
					infostr = strvcat(get(UD.hInfoStr,'String'),['[' int2str(MarkerIndex) '] ' infostr]);
					set(UD.hInfoStr,'String',infostr);

					hAxes = UD.hAxes;
					hInfoStr = UD.hInfoStr;
					
				end
			end


		else

			ColorOrder = [

		   1    0    0;
		   0	0    1;
		   0	0.5         0;
		   0    0.7500    0.7500;
		   0.7500         0    0.7500;
		   0.7500    0.7500         0;
		   0.2500    0.2500    0.2500;];
		
				
			hAnalysisFig = figure('Color',[1 1 1], 'Name', ['Analysis window: ' measureNames{measureAnalysis} ' as function of ' paramNames{paramAnalysis}],...
				      'Tag','Analysis window');
			
			hAxes = axes('Units','Normalized','Position',[0.1 0.1 0.7 0.8],'ColorOrder',ColorOrder,'NextPlot','add');

			MarkerIndex = 1;
			
			hInfoStr = uicontrol('Parent',gcf, ...
			'Units','normalized', ...
			'HorizontalAlignment','left', ...
			'ForegroundColor',[0 0 1],...
			'BackgroundColor',[1 1 1],...
			'ListboxTop',0, ...
			'Position',[0.825 0.05 0.15 0.9], ...
			'String',['[' int2str(MarkerIndex) '] ' infostr], ...
			'Style','text', ...
			'Tag','InfoStr');

			

		end

		if DefValues(195),	% log X scale
			uparam_ori = uparam;
			uparam = log10(uparam);
			zeroIdx = find(uparam_ori==0);
			uparam(zeroIdx)=log10(0.005);
		end
		

		if ~isempty(measure_error),
			errorbar(uparam,measure,measure_error,'k');
			hold on;
		end


			
		if size(measure,2) == 1,
			Marker = {'o' 'square' 'diamond' 'v' '^' '>' '+' '*' 'x'  '<' 'pentagram' 'hexagram'};
			hAnalysisPlot = plot(uparam,measure,'LineStyle','-','Color','k','Marker',Marker{MarkerIndex},'MarkerFaceColor','k','Tag',['AnalysisPlot' num2str(MarkerIndex)]);
		else
			Marker = {'o' 'square' 'diamond' 'v' '^' '>' '+' '*' 'x'  '<' 'pentagram' 'hexagram'};
			LineStyle = {'-' '--' ':' '-.' };
			hAnalysisPlot = plot(uparam,measure,'LineStyle',LineStyle{MarkerIndex},'Marker',Marker{MarkerIndex},'Tag',['AnalysisPlot' num2str(MarkerIndex)]);

			if measureAnalysis==3 % harmonic content
				% find RM
				RM = measure(:,2)./measure(:,1);
				[RM_maxres_cond,ii] = find(measure==max(max(measure)));
				RM_maxres = RM(RM_maxres_cond);
				RM_maxmod_cond = find(RM==max(RM));
				RM_maxmod = RM(RM_maxmod_cond);
				title(['RM_maxres=',num2str(RM_maxres,2),' (',num2str(uparam(RM_maxres_cond)),...
					'); RM_maxmod=',num2str(RM_maxmod,2),' (',num2str(uparam(RM_maxmod_cond)),')']);
				
				% find RM_align
				% data2excel format: [rm rm_align dc phase max_harmonic max_harmonic_amp]
				RM_maxmod_a = -1; RM_maxres_a = -1;
				RM_maxmod_cond_a = RM_maxmod_cond; RM_maxres_cond_a = RM_maxres_cond;
				% RM_maxmod_cond_a = 1; RM_maxres_cond_a = 1;
				if data2excel(1,2)~=-1,
					RM_a = data2excel(:,2);
					% measure_a = [data2excel(:,3) data2excel(:,3).*data2excel(:,2)];
					% [RM_maxres_cond_a,ii] = find(measure_a==max(max(measure_a)));
					RM_maxres_a = RM_a(RM_maxres_cond_a);
					% RM_maxmod_cond_a = find(RM_a==max(RM_a));
					RM_maxmod_a = RM_a(RM_maxmod_cond_a);
				end
				disp('--- RM analysis ---');
				disp(sprintf('%0.2f\t%0.2f\t%0.2f\t%0.2f\t%0.2f\t%0.2f\t%0.2f\t%0.2f\n',RM_maxmod,RM_maxres,RM_maxmod_a,RM_maxres_a,...
								uparam(RM_maxmod_cond),uparam(RM_maxres_cond),uparam(RM_maxmod_cond_a),uparam(RM_maxres_cond_a)));

				legend(['F0' ; 'F1' ; 'F2'],0);
			end
			
		end

		set(gca,'YLimMode','auto');
		Ylim = get(gca,'Ylim');
		set(gca,'Ylim',[0 Ylim(2)]);

		if DefValues(195),		% log X scale
			set(gca,'XTick',uparam,'XTickLabel',uparam_ori);
		end
			
		
		xlabel(paramNames{paramAnalysis});
		ylabel(measureNames{measureAnalysis});


		if DefValues(178)==2,
			hAllKids = get(gca,'Children');
			k = 1;
			for i=1:MarkerIndex,
				hPlots(i) = hAllKids(find(strcmp(get(hAllKids,'Tag'),['AnalysisPlot' num2str(i)])));
			end
			legend_str = int2str([1:MarkerIndex]');
			legend(hPlots,legend_str ,0);
		end
		
		UD.hInfoStr = hInfoStr;
		UD.hAxes = hAxes;
		UD.paramAnalysis = paramAnalysis;
		UD.measureAnalysis = measureAnalysis;
		UD.MarkerIndex = MarkerIndex;
		

		set(hAnalysisFig,'UserData',UD);


	end				% of figure options

	if DefValues(195),		% log X scale
		uparam = uparam_ori;	% return to original (not log-transformed) parameters
	end
		
	out1.param = uparam';
	out1.measure = measure';
	out1.measure_error = measure_error;
	out1.n = N;


        if DefValues(179)                               % save to MAT
        mode = 'both';
                if DefValues(189)==3,
                        mode = 'even';
                elseif DefValues(189)==2
                        mode = 'odd';
                end
                matfilename = [deblank(stim(1).FileName) '.' mode '.' paramNames{paramAnalysis} '.' measureNamesAbbr{measureAnalysis} normalizeOpt '.fun'];
		ini_dir = cd;
		% cd(SAVE_DIR); Think about that! Meanwhile save to
		% current dir, either where exp record (after show spikes) or where spk
                save(matfilename,'out1','infostr');
		unitret('display_message',['file ' matfilename ' saved to ' ini_dir] );
                
        end 
	
	if DefValues(180)
		unitret('display_message',out1);
	end
	
	

	%-----------------------------------------------------------------------------------------------------------------------

elseif(strcmp(action,'set_markeddata'))	
	set(TRET_DAT(2), 'UserData',in1);
	
	
	%-----------------------------------------------------------------------------------------------------------------------

	elseif(strcmp(action,'get_markeddata'))

	if length(TRET_DAT)==1
		out1=get(gcf,'UserData');
	else
		out1=get(TRET_DAT(2),'UserData');
	end
		

	%-----------------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'preferences'))
	h = findobj('Tag','Preferences');
	if ~isempty(h);
		delete(h);
	end

	bgcol = [0.7529    0.7529    0.7529];
		   
	h0 = figure('Backingstore','off','Name','Preferences',...
		'Resize','On', 'Menubar','none','Number','off',...
		'Color',bgcol, ...
		'InvertHardcopy','off', ...
		'NumberTitle','off', ...
		'Units','Normalized',...
		'Position',[0.1 0.2 0.4 0.6], ...
		'Tag','Preferences', ...
		'ToolBar','none');

	hClipboard = uicontrol(h0,'Style','radiobutton',...
		'Units','normalized',...
		'Position',[.05 .9 .5 .05],...
                'BackgroundColor',bgcol,...
                'ForegroundColor','k','String','copy data to clipboard', 'HorizontalAlignment','left',...
                'value',DefValues(160));

	uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',bgcol, ...
		'FontWeight','normal', ...
		'HorizontalAlignment','left', ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[.05 .83 .5 .05], ...
		'String','system run mode for conversion', ...
		'Style','text', ...
		'Tag','StaticText1');
		
	hSystemVersion = uicontrol('Parent',h0, ...
		'Units','normalized', ...
		'BackgroundColor',[1 1 1], ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.05 0.8 0.1 0.05], ...
		'String',sprintf('%.1f',DefValues(187)), ...
		'Style','edit', ...
		'Tag','System Version');

	
	hSaveSTIM = uicontrol(h0,'Style','radiobutton',...
		'Units','normalized',...
		'Position',[.05 .7 .5 .05],...
                'BackgroundColor',bgcol,...
                'ForegroundColor','k','String','save STIM together with spike file',...
		'HorizontalAlignment','left',...
                'value',DefValues(188));

		
	hCancel = uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',[0.501960784313725 0.501960784313725 0.752941176470588], ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.75 0.85 0.2 0.1], ...
		'String','Cancel', ...
		'Tag','Cancel');

	hOK = uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',[0.501960784313725 0.501960784313725 0.752941176470588], ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.75 0.7 0.2 0.1], ...
		'String','OK', ...
		'Tag','OK');

	cancel_Callback = ['delete(gcf); return;'];
	set(hCancel,'Callback',cancel_Callback);

	ud(1,:) = [hClipboard 160];
	ud(2,:) = [hSystemVersion 187];   
	ud(3,:) = [hSaveSTIM 188];
		   
	set(gcf,'UserData',ud);
	set(hOK, 'Callback',['ud = get(gcf,''UserData''); unitret(''update_defaults'',ud);' cancel_Callback]);


	
	HelpString = 	['Help for ',action,'|',...
			'|',...
			'copy data to clipboard - numeric output of certain functions will be copied to clipboard|',...
			'system run mode for conversion - format for BrainWare -> Unitret conversion|',...
			'save STIM together with spike file - for retrieving stimulus parameters together with saved spikes|',...
			];

	
	Help_button=uicontrol(h0,'Style','pushbutton','Units','Normalized','Position',[.75 .55 .2 .1],...
                'String','Help','Callback',['u=get(gcf,''CurrentObject''); str=get(u,''UserData''); unitret(''help_win'',str)']);
	set(Help_button,'Userdata',HelpString);
	
	HTML_HELP_button=uicontrol(h0,'Style','pushbutton','Units','Normalized','Position',[.75 .4 .2 .1], 'BackgroundColor',[0.5020    0.5020    0.2510],...
                'String','HTML Help','Callback',['global APP_PATH; cd(APP_PATH); !hh.exe unitret.chm::/HelpPreferences.html']);

	
	%-----------------------------------------------------------------------------------------------------------------------

elseif(strcmp(action,'display_message'))
	out1=get(TRET_DAT(2),'UserData');
	disp([ '===== Begin UNITRET message: (' datestr(now) ')']);
	disp(in1);
	disp([ '===== End UNITRET message =====' sprintf('\n')]);

	%-----------------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'update_defaults'))
	ud = in1;
	for i=1:size(ud,1),
		if strcmp(get(ud(i,1),'Style'),'edit'),
			DefValues(ud(i,2))=str2num(get(ud(i,1),'String'));
		else
			DefValues(ud(i,2))=(get(ud(i,1),'Value'));
		end
	end
	set(0,'UserData',DefValues);
	
	%-----------------------------------------------------------------------------------------------------------------------
elseif(strcmp(action,'setup_auto_rf_mapping'))
	h = findobj('Tag','Setup Auto RF map');
	if ~isempty(h);
		delete(h);
	end

	bgcol = [0.7529    0.7529    0.7529];
		   
	h0 = figure('Backingstore','off','Name','Setup Auto RF mapping',...
		'Resize','On', 'Menubar','none','Number','off',...
		'Color',bgcol, ...
		'InvertHardcopy','off', ...
		'NumberTitle','off', ...
		'Units','Normalized',...
		'Position',[0.1 0.2 0.4 0.6], ...
		'Tag','Setup Auto RF map', ...
		'ToolBar','none');

	hAutoRFmap = uicontrol(h0,'Style','radiobutton',...
		'Units','normalized',...
		'Position',[.05 .9 .5 .05],...
                'BackgroundColor',bgcol,...
                'ForegroundColor','k','String','Auto RF mapping', 'HorizontalAlignment','left',...
                'value',DefValues(182));

	uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',bgcol, ...
		'FontWeight','normal', ...
		'HorizontalAlignment','left', ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[.05 .83 .4 .05], ...
		'String','Significance (p<...)', ...
		'Style','text', ...
		'Tag','StaticText1');
		
	hAutoRFmapSign = uicontrol(h0,'Style','edit',...
		'Units','normalized',...
		'Position',[.05 .8 .1 .05],...
                'BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(183)), 'HorizontalAlignment','left');

	uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',bgcol, ...
		'FontWeight','normal', ...
		'HorizontalAlignment','left', ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[.05 .73 .4 .05], ...
		'String','Error bars', ...
		'Style','text', ...
		'Tag','StaticText1');	
		
	hAutoRFmapErrorBar = uicontrol('Parent',h0, ...
		'Units','normalized', ...
		'BackgroundColor',[1 1 1], ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[.05 .7 .3 .05], ...
		'String',{'no error bars','STD','SEM'}, ...
		'Style','popupmenu', ...
		'Tag','PopupMenu1', ...
		'Value',DefValues(184));

	uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',bgcol, ...
		'FontWeight','normal', ...
		'HorizontalAlignment','left', ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[.05 .63 .4 .05], ...
		'String','Baseline activity (spikes/s)', ...
		'Style','text', ...
		'Tag','StaticText1');

		
	hAutoRFmapBaseline = uicontrol(h0,'Style','edit',...
		'Units','normalized',...
		'Position',[.05 .6 .1 .05],...
                'BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(54)), 'HorizontalAlignment','left');
		
		
	hCancel = uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',[0.501960784313725 0.501960784313725 0.752941176470588], ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.75 0.85 0.2 0.1], ...
		'String','Cancel', ...
		'Tag','Cancel');

	hOK = uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',[0.501960784313725 0.501960784313725 0.752941176470588], ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.75 0.7 0.2 0.1], ...
		'String','OK', ...
		'Tag','OK');

	cancel_Callback = ['delete(gcf); return;'];
	set(hCancel,'Callback',cancel_Callback);

	ud(1,:) = [hAutoRFmap 182];
	ud(2,:) = [hAutoRFmapSign 183];
	ud(3,:) = [hAutoRFmapErrorBar 184];
	ud(4,:) = [hAutoRFmapBaseline 54];
		   
	set(gcf,'UserData',ud);
	
	set(hOK, 'Callback',['ud = get(gcf,''UserData''); unitret(''update_defaults'',ud);' cancel_Callback 'unitret(''update'',0,3);']);

	%-----------------------------------------------------------------------------------------------------------------------
	
elseif(strcmp(action,'setup_orientation'))
	h = findobj('Tag','Setup Orientation');
	if ~isempty(h);
		delete(h);
	end

	bgcol = [0.7529    0.7529    0.7529];
		   
	h0 = figure('Backingstore','off','Name','Setup Orientation',...
		'Resize','On', 'Menubar','none','Number','off',...
		'Color',bgcol, ...
		'InvertHardcopy','off', ...
		'NumberTitle','off', ...
		'Units','Normalized',...
		'Position',[0.1 0.2 0.4 0.6], ...
		'Tag','Setup Auto RF map', ...
		'ToolBar','none');

	uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',bgcol, ...
		'FontWeight','normal', ...
		'HorizontalAlignment','left', ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[.05 .93 .4 .05], ...
		'String','filter half-width', ...
		'Style','text', ...
		'Tag','StaticText1');
		
	hFilterHalfWidth = uicontrol(h0,'Style','edit',...
		'Units','normalized',...
		'Position',[.05 .9 .1 .05],...
                'BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(185)), 'HorizontalAlignment','left');

	uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',bgcol, ...
		'FontWeight','normal', ...
		'HorizontalAlignment','left', ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[.05 .83 .4 .05], ...
		'String','peak shift threshold', ...
		'Style','text', ...
		'Tag','StaticText1');
		
	hShiftThreshold = uicontrol(h0,'Style','edit',...
		'Units','normalized',...
		'Position',[.05 .8 .1 .05],...
                'BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(186)), 'HorizontalAlignment','left');
		
		
	hCancel = uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',[0.501960784313725 0.501960784313725 0.752941176470588], ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.75 0.85 0.2 0.1], ...
		'String','Cancel', ...
		'Tag','Cancel');

	hOK = uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',[0.501960784313725 0.501960784313725 0.752941176470588], ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.75 0.7 0.2 0.1], ...
		'String','OK', ...
		'Tag','OK');

	cancel_Callback = ['delete(gcf); return;'];
	set(hCancel,'Callback',cancel_Callback);

	ud(1,:) = [hFilterHalfWidth 185];
	ud(2,:) = [hShiftThreshold 186];
		   
	set(gcf,'UserData',ud);
	
	set(hOK, 'Callback',['ud = get(gcf,''UserData''); unitret(''update_defaults'',ud);' cancel_Callback 'unitret(''update'',0,3);']);


	HelpString = 	['Help for ',action,'|',...
			'|',...
			'Setup for orientation tuning curves|',...
			'Hanning filter half-width @ half-height (deg, window length =4*half-width)|',...
			'peak shift threshold - shift peak to 90 deg if abs(90-peak)>threshold (use 91 for "no shift")|',...
			];

	
	Help_button=uicontrol(h0,'Style','pushbutton','Units','Normalized','Position',[.75 .55 .2 .1],...
                'String','Help','Callback',['u=get(gcf,''CurrentObject''); str=get(u,''UserData''); unitret(''help_win'',str)']);
	set(Help_button,'Userdata',HelpString);
	
	HTML_HELP_button=uicontrol(h0,'Style','pushbutton','Units','Normalized','Position',[.75 .4 .2 .1], 'BackgroundColor',[0.5020    0.5020    0.2510],...
                'String','HTML Help','Callback',['global APP_PATH; cd(APP_PATH); !hh.exe unitret.chm::/HelpSetupOrientation.html']);
	%-----------------------------------------------------------------------------------------------------------------------

elseif(strcmp(action,'setup_ti'))
	h = findobj('Tag','Setup TI');
	if ~isempty(h);
		delete(h);
	end

	bgcol = [0.7529    0.7529    0.7529];
		   
	h0 = figure('Backingstore','off','Name','Setup TI',...
		'Resize','On', 'Menubar','none','Number','off',...
		'Color',bgcol, ...
		'InvertHardcopy','off', ...
		'NumberTitle','off', ...
		'Units','Normalized',...
		'Position',[0.1 0.2 0.4 0.6], ...
		'Tag','Setup TI', ...
		'ToolBar','none');

	hTI = uicontrol(h0,'Style','radiobutton',...
		'Units','normalized',...
		'Position',[.05 .9 .5 .05],...
                'BackgroundColor',bgcol,...
                'ForegroundColor','k','String','TI', 'HorizontalAlignment','left',...
                'value',DefValues(190));


	uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',bgcol, ...
		'FontWeight','normal', ...
		'HorizontalAlignment','left', ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[.05 .83 .4 .05], ...
		'String','base (ms)', ...
		'Style','text', ...
		'Tag','StaticText1');
		
	hBase = uicontrol(h0,'Style','edit',...
		'Units','normalized',...
		'Position',[.05 .8 .1 .05],...
                'BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(191)), 'HorizontalAlignment','left');

	uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',bgcol, ...
		'FontWeight','normal', ...
		'HorizontalAlignment','left', ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[.05 .73 .4 .05], ...
		'String','peak (ms)', ...
		'Style','text', ...
		'Tag','StaticText1');
		
	hPeak = uicontrol(h0,'Style','edit',...
		'Units','normalized',...
		'Position',[.05 .7 .1 .05],...
                'BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(192)), 'HorizontalAlignment','left');

	uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',bgcol, ...
		'FontWeight','normal', ...
		'HorizontalAlignment','left', ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[.05 .63 .4 .05], ...
		'String','tail (ms)', ...
		'Style','text', ...
		'Tag','StaticText1');
		
	hTail = uicontrol(h0,'Style','edit',...
		'Units','normalized',...
		'Position',[.05 .6 .1 .05],...
                'BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(193)), 'HorizontalAlignment','left');


	uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',bgcol, ...
		'FontWeight','normal', ...
		'HorizontalAlignment','left', ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[.35 .83 .4 .05], ...
		'String','base activity (spikes/s)', ...
		'Style','text', ...
		'Tag','StaticText1');
		
	hBaseActivity = uicontrol(h0,'Style','edit',...
		'Units','normalized',...
		'Position',[.35 .8 .1 .05],...
                'BackgroundColor','w',...
                'ForegroundColor','k','String',num2str(DefValues(54)), 'HorizontalAlignment','left');


	hPresetsCallback = ['v = get(gco,''Value'');',...
			    'if v==1, base = 40; peak = 100; tail = 150; elseif v==2, base = 150; peak = 250; tail = 350; end;',...
			    'hh = get(gco,''Userdata''); set(hh(1),''String'',num2str(base)); set(hh(2),''String'',num2str(peak)); set(hh(3),''String'',num2str(tail));'];
	
	hPresets = uicontrol('Parent',h0, ...
		'Units','normalized', ...
		'BackgroundColor',[1 1 1], ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[.05 .5 .2 .05], ...
		'String',{'flash','sac'}, ...
		'Style','popupmenu', ...
		'Tag','PopupMenu1', ...
		'Callback',hPresetsCallback,...
		'Value',1);

	set(hPresets, 'Userdata',[hBase hPeak hTail]);
		
	hCancel = uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',[0.501960784313725 0.501960784313725 0.752941176470588], ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.75 0.85 0.2 0.1], ...
		'String','Cancel', ...
		'Tag','Cancel');

	hOK = uicontrol('Parent',h0, ...
		'Units','points', ...
		'BackgroundColor',[0.501960784313725 0.501960784313725 0.752941176470588], ...
		'ListboxTop',0, ...
		'Units','normalized', ...
		'Position',[0.75 0.7 0.2 0.1], ...
		'String','OK', ...
		'Tag','OK');


	cancel_Callback = ['delete(gcf); return;'];
	set(hCancel,'Callback',cancel_Callback);

	ud(1,:) = [hTI 190];
	ud(2,:) = [hBase 191];
	ud(3,:) = [hPeak 192];
	ud(4,:) = [hTail 193];
	ud(5,:) = [hBaseActivity 54];

		   
	set(gcf,'UserData',ud);
	
	set(hOK, 'Callback',['ud = get(gcf,''UserData''); unitret(''update_defaults'',ud); delete(gcf); unitret(''update'',0,3);' ]);


	HelpString = 	['Help for ',action,'|',...
			'|',...
			'Setup for analysis of flash / saccade-triggered averages: transiency index (TI)|',...
			'base (ms) - end of "base" period |',...
			'peak (ms) - end of "peak" period |',...
			'tail (ms) - end of "tail" period |',...
			'base activity (spikes/s) - |',...
			'if base <= 0, base activity will be used as base|',...
			];

	
	Help_button=uicontrol(h0,'Style','pushbutton','Units','Normalized','Position',[.75 .55 .2 .1],...
                'String','Help','Callback',['u=get(gcf,''CurrentObject''); str=get(u,''UserData''); unitret(''help_win'',str)']);
	set(Help_button,'Userdata',HelpString);
	
	HTML_HELP_button=uicontrol(h0,'Style','pushbutton','Units','Normalized','Position',[.75 .4 .2 .1], 'BackgroundColor',[0.5020    0.5020    0.2510],...
                'String','HTML Help','Callback',['global APP_PATH; cd(APP_PATH); !hh.exe unitret.chm::/HelpSetupTI.html']);

	%-----------------------------------------------------------------------------------------------------------------------

elseif(strcmp(action,'call_external_mfile'))
	ori_dir = cd;	 
	cd(MFILE_PATH);
	
	[filename, pathname] = uigetfile('*.m' , 'Call mfile...', .4, .4);
	if filename == 0, cd(ori_dir); return; end;
	mfilename = [pathname filename(1:end-2)];
	clear(mfilename);
	addpath(pathname);
	MFILE_PATH = pathname;
	run(mfilename);
	cd(ori_dir);
	 

				 
		
	%-----------------------------------------------------------------------------------------------------------------------
	
end;				% elseif(strcmp(action,'.....')),



% catch
	
% Now do the error handling
if 0
lasterror = lasterr;

if lasterror~='',
	DefValues(141) = 0;
        set(0,'Userdata',DefValues);		% exit batch mode, in case the error occured during the batch
	errordlg(lasterror,'Error Handling');
	lasterr('');
	return
end
end

% end					% of try...catch...end
